<TeXmacs|1.99.9>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package-dtd|bluish-combo|1.0|bluish-combo|1.0>

    <\src-purpose>
      Bluish theme for presentations and posters.
    </src-purpose>

    <src-copyright|2013--2019|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <use-package|light-combo>

  <copy-theme|bluish|light>

  <\active*>
    <\src-comment>
      Main colors
    </src-comment>
  </active*>

  <assign|bluish-strong-color|#602060>

  <assign|bluish-math-color|#503050>

  <\active*>
    <\src-comment>
      Titles
    </src-comment>
  </active*>

  <assign|bluish-title-bar-color|<macro|dark blue>>

  <assign|bluish-title-color|<macro|white>>

  <\active*>
    <\src-comment>
      Standard ornaments
    </src-comment>
  </active*>

  <assign|bluish-ornament-extra-color|dark blue>

  <assign|bluish-ornament-render-title|<value|ornament-render-title-white>>

  <assign|bluish-ornament-color|pastel blue>

  <assign|bluish-ornament-sunny-color|#f4f4ff>

  <assign|bluish-ornament-shadow-color|#d8d8ff>

  <\active*>
    <\src-comment>
      Sessions
    </src-comment>
  </active*>

  <assign|bluish-input-color|pastel blue>

  <assign|bluish-fold-bar-color|#c0c0e0>

  <assign|bluish-fold-title-color|#a0a0d0>
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>