
/****************************************************************************
* General
****************************************************************************/

QWidget {
    font-size: 14px;
    icon-size: 16px;
}

QFileDialog {
    min-width: 800px;
    min-height: 600px;
}

QMenuBar {
    padding-top: 5px;
    spacing: 10px;
}

QMenu::item:disabled {
    color: #A0A0A0;
}

QMenu::item * {
    margin: 3px;
}

QStatusBar::item, QStatusBar QWidget {
    border: 0px;
}

NomacQComboBox {
    min-height: 18px;
}

NomacQCheckBox, NomacQCheckBox::indicator {
    min-width: 10px;
    min-height: 10px;
}

QToolButton::menu-indicator,
QToolBar#mainToolBar QToolButton::menu-indicator,
QToolBar#modeToolBar QToolButton::menu-indicator {
    border: none;
    background: none;
    image: none;
}

QToolButton::disabled,
QToolBar#mainToolBar QToolButton:disabled,
QToolBar#modeToolBar QToolButton:disabled {
    color: #808080;
}

QScrollBar:horizontal {
    min-height: 16px;
}

QScrollBar:vertical {
    min-width: 16px;
}

/****************************************************************************
* Counter extremely ugly native Qt/Mac toolbars
****************************************************************************/

MacosQWidget {
    selection-color: #FFFFFF;
}

MacosQMenuBar {
    background: #CCCCCC;
}

MacosQMenuBar::item {
    background: #CCCCCC;
    padding: 0px 5px;
    padding-top: 10px;
}

MacosUniQToolBar * {
    border: none;
    padding: 0px;
    margin: 0px;
}

MacosNonuniQToolBar {
    background: #CCCCCC;
    border-bottom: 1px solid #B0B0B0;
}

MacosNonuniQToolBar#mainToolBar, MacosNonuniQToolBar#mainToolBar MacosNonuniQWidget {
    background: #CCCCCC;
    padding-bottom: 1px;
}

MacosNounimQToolBar#modeToolBar, MacosNounimQToolBar#modeToolBar MacosNounimQWidget {
    background: #DCDCDC;
}

MacosQToolBar#focusToolBar, MacosQToolBar#focusToolbar MacosQWidget {
    background: #ECECEC;
}

MacosQToolBar#userToolBar, MacosQToolBar#userToolbar MacosQWidget {
    background: #F8F8F8;
}

MacosQStatusBar {
    background: #ECECEC;
    border-top: 1px solid #B0B0B0;
}

MacosQStatusBar::item, MacosQStatusBar MacosQWidget {
    background: #ECECEC;
    border: 0px;
}

MacosQStatusBar MacosQLineEdit {
    background: #FFFFFF;
}

MacosNonuniQToolButton,
MacosNonuniQToolBar#mainToolBar MacosNonuniQToolButton,
MacosNounimQToolBar#modeToolBar MacosNounimQToolButton {
    background: none;
    padding-left: 0px;
    padding-right: 0px;
}

MacosNonuniQt4QToolButton {
    background-color: rgba(96,96,96,0%);
}

MacosQToolButton:hover,
MacosQToolBar#mainToolBar MacosQToolButton:hover,
MacosQToolBar#modeToolBar MacosQToolButton:hover,
MacosQToolBar#focusToolBar MacosQToolButton:hover {
    background: none;
}

MacosQt4QToolButton:hover,
MacosQt4QToolBar#mainToolBar MacosQToolButton:hover,
MacosQt4QToolBar#modeToolBar MacosQToolButton:hover,
MacosQt4QToolBar#focusToolBar MacosQToolButton:hover {
    background: #C0C0C0;
    border: 0px;
    border-radius: 3px;
}

MacosQToolButton:pressed,
MacosQToolButton:checked,
MacosQToolBar#mainToolBar MacosQToolButton:pressed,
MacosQToolBar#mainToolBar MacosQToolButton:checked,
MacosQToolBar#modeToolBar MacosQToolButton:pressed,
MacosQToolBar#modeToolBar MacosQToolButton:checked,
MacosQToolBar#focusToolBar MacosQToolButton:pressed,
MacosQToolBar#focusToolBar MacosQToolButton:checked {
    background: #A0A0A0;
    border: 0px;
    border-radius: 3px;
}

MacosQWidget#centralWidget {
    background: #A0A0A0;
}

/****************************************************************************
* Side tools
****************************************************************************/

QDockWidget#sideTools::title {
    background: #D4D4D4;
    text-align: center;
}

QDockWidget#sideTools QWidget#title {
    background: #D4D4D4;
    font-weight: bold;
}

QDockWidget#sideTools QWidget#title * {
    background: #D4D4D4;
    font-weight: bold;
    margin: 5px;
}

QDockWidget#sideTools QWidget#subtitle {
    font-weight: bold;
}

QDockWidget#sideTools QWidget#subtitle * {
    font-weight: bold;
    margin: 5px;
}

QDockWidget#sideTools QWidget#discrete * {
    color: #505050;
    font-size: 12px;
}

QDockWidget#sideTools QWidget#discrete QPushButton {
    background: none;
    border: none;
}

QDockWidget#sideTools QWidget#discrete QPushButton:hover {
    background: #F8F8F8;
    border: none;
}

QDockWidget#sideTools QWidget#discrete QPushButton:pressed {
    background: #D0D0D0;
    border: none;
}
