
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : mathemagix-kbd.scm
;; DESCRIPTION : Keyboard shortcuts for Mathemagix
;; COPYRIGHT   : (C) 2012  Gregoire Lecerf
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(texmacs-module (mathemagix-kbd)
  (:use (dynamic scripts-kbd)))

;;(kbd-map
;;  (:mode mathemagix-scripts-math?)
;;  ("\" " "\"")
;;  ("$" "$"))

;;(kbd-map
;;  (:mode in-mathemagix-math?)
;;  ;;("'" "'")
;;  ("\"" "\""))
