((FandolSong sansserif) (FandolHei))
((FandolSong typewriter) (FandolFang))
((FandolSong italic) (FandolKai))
((Hiragino\ Mincho\ Pro sansserif) (Hiragino\ Kaku\ Gothic\ Pro))
((Hiragino\ Mincho\ ProN sansserif) (Hiragino\ Kaku\ Gothic\ ProN))
((IPAMincho bold) (IPAGothic))
((IPAMincho sansserif) (IPAGothic))
((IPAPMincho bold) (IPAPGothic))
((IPAPMincho sansserif) (IPAPGothic))
((MS\ Mincho bold) (MS\ Gothic))
((MS\ Mincho sansserif) (MS\ Gothic))
((Sazanami\ Mincho bold) (Sazanami\ Gothic))
((Sazanami\ Mincho sansserif) (Sazanami\ Gothic))
((SimSun bold) (SimHei))
((SimSun sansserif) (SimHei))
((SimSun italic) (KaiTi_GB2312))
((SimSun typewriter) (FangSong_GB2312))

((Songti\ SC sansserif) (PingFang\ SC))

((STSong bold) (STHeiti))
((STSong sansserif) (STHeiti))
((STSong italic) (STKaiti))
((STSong typewriter) (STFangsong))
((TakaoMincho bold) (TakaoGothic))
((TakaoMincho sansserif) (TakaoGothic))
((TakaoPMincho bold) (TakaoPGothic))
((TakaoPMincho sansserif) (TakaoPGothic))
((UnBatang sansserif) (UnDotum))
((UnBatang italic) (UnGraphic))
((UnBatang typewriter) (UnGungseo))

((concrete cjk) (FandolSong))
((concrete cjk) (SimSun))
((roman cjk) (FandolSong))
((roman cjk) (SimSun))
((Stix cjk) (FandolSong))
((Stix cjk) (SimSun))

((Bodoni\ 72 smallcaps) (Bodoni\ 72\ Smallcaps))
((Bodoni\ 72\ Oldstyle smallcaps) (Bodoni\ 72\ Smallcaps))
((Linux\ Libertine sansserif) (Linux\ Biolinum))
((TeX\ Gyre\ Pagella typewriter) (roman typewriter))

((Calibri typewriter) (Consolas))
((Cambria sansserif) (Calibri))
((Cambria typewriter) (Consolas))
((Constantia sansserif) (Corbel))
((Constantia typewriter) (Consolas))
((Corbel typewriter) (Consolas))
