;; Unicode characters which are imported specially in TeXmacs

;; (C) 2002-2003  David Allouche
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.

("#00A0"	" ")		; no-break space = non-breaking space
("#2006"	" ")		; six-per-em space
("#2009"	" ")		; thin space
("#2019"	"'")		; right single quotation mark
