("GNU" "GNU")
("H modifier" "modificator H")
("LaTeX" "LaTeX")
("M modifier" "modificator M")
("TeX" "TeX")
("abbreviation" "prescurtare")
("about" "despre")
("about menu" "despre")
("above" "deasupra")
("abstract" "rezumat")
("accent" "accent")
("accept" "acceptare")
("accept all scripts" "acceptaµi toate script-urile")
("accept no scripts" "nu acceptaµi nici un script")
("accept script" "acceptare script")
("acknowledgment" "mulµumiri")
("acronym" "acronim")
("action" "acµiune")
("activate" "activare")
("acute" "acut")
("add switch after" "ad ugare switch dup ")
("add switch before" "ad ugare switch īnainte")
("address" "adres ")
("address block" "bloc de adres ")
("advanced" "avansat")
("advanced layout features" "caracteristici avansate de a³ezare īn pagin ")
("after" "dup ")
("albanian" "albanez ")
("algorithm" "algoritm")
("align cell to the bottom" "aliniere celul  jos")
("align cell to the left" "aliniere celul  la stānga")
("align cell to the right" "aliniere celul  la dreapta")
("align cell to the top" "aliniere celul  sus")
("align table at base of left column" "alinierea tabelului la baza coloanei din stānga")
("align table at base of middle column" "alinierea tabelului la baza coloanei din mijloc")
("align table at base of origin column" "alinierea tabelului la baza coloanei de origine")
("align table at base of right column" "alinierea tabelului la baza coloanei din dreapta")
("align table at fraction bar height" "alinierea tabelului la īnaltimea liniei de fracµie")
("align table at the base of bottom row" "alinierea tabelului la baza liniei de jos")
("align table at the base of middle row" "alinierea tabelului la baza liniei din mijloc")
("align table at the base of origin row" "alinierea tabelului la baza liniei de origine")
("align table at the base of top row" "alinierea tabelului la baza liniei de sus")
("align table at the bottom" "aliniere tabel jos")
("align table at the center" "aliniere tabel la mijloc")
("align table at the horizontal center" "aliniere tabel centrare orizontala")
("align table at the left" "aliniere tabel la stānga")
("align table at the top" "aliniere tabel sus")
("align table to the right" "aliniere tabel la dreapta")
("align text to the left" "aliniere text la stānga")
("align text to the right" "aliniere text la dreapta")
("alignment" "aliniere")
("all" "totul")
("allow" "permisiune")
("allowed extension" "extensie permis ")
("allowed reduction" "reducere permis ")
("alpha release" "versiune alpha")
("alt key" "tasta alt")
("and" "³i")
("appendix" "anexa")
("apply" "aplicare")
("april" "aprilie")
("arab" "arab")
("archaic" "arhaic")
("architecture" "arhitectur ")
("argument" "argument")
("arithmetic" "aritmetic ")
("armenian" "armean ")
("arrow" "s geat ")
("arrows" "s geµi")
("article" "articol")
("as on paper" "ca pe hārtie")
("assign" "atribuire")
("at fraction bar height" "la īn lµimea liniei de fracµie")
("at the baseline" "la linia de baz ")
("at the bottom" "jos")
("at the left" "la stānga")
("at the middle" "īn mijloc")
("at the right" "la dreapta")
("at the top" "sus")
("attach" "ata³are")
("attach buffer to which project" "ata³are buffer - la care proiect")
("august" "august")
("author" "autor")
("authorize" "autorizare")
("automatic" "automat")
("automatically generated content" "generare automat  a cuprinsului")
("axiom" "axiom ")
("background" "background")
("background color" "culoare de fond")
("backward replace" "īnlocuire īnapoi")
("backward search" "c utare īnapoi")
("bad data format" "nu este bun formatul")
("bar" "bar ")
("bard" "bard")
("base level" "nivel de baza")
("bashkirian" "bashkirian")
("basic" "de baz ")
("basic data types" "tipuri de date de baz ")
("basic types" "tipuri de baz ")
("be useful" "fiµi util")
("become a TeXmacs developer" "deveniµi un dezvoltator TeXmacs")
("before" "īnainte")
("begin" "īnceput")
("below" "sub")
("beta release" "versiune beta")
("bibliography" "bibliografie")
("bibliography file" "fi³ier de bibliografie")
("bibliography style" "stil de bibliografie")
("big" "mare")
("big figure" "figur  mare")
("big operator" "operator mare")
("big skip" "salt mare")
("big table" "tabel mare")
("binary operation" "operaµie binar ")
("binary relation" "relaµie binar ")
("black" "negru")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard matematic")
("blackletter" "blackletter")
("blue" "albastru")
("body" "corp")
("bold" "bold")
("book" "carte")
("border" "bordur ")
("both" "amāndou ")
("bottom" "jos")
("bottom border" "bordura de jos")
("bottom margin" "marginea de jos")
("bottom padding" "spaµiul de jos")
("branch" "ramur ")
("break" "salt")
("breaking" "īntrerupere")
("breve" "grav")
("british" "britanic")
("brown" "maro")
("browse" "navigare")
("browse web" "navigare pe web")
("browser" "browser")
("buffer" "buffer")
("bulgarian" "bulgar ")
("bullet" "bullet")
("bullets" "bullets")
("by" "prin")
("by typing" "tastānd")
("bytes free" "bytes liberi")
("bytes used" "bytes utilizaµi")
("calligraphic" "caligrafic")
("cancel" "anulare")
("caps-lock key" "tasta caps-lock")
("case" "caz")
("cc" "copie la")
("cell" "celul ")
("cell background color" "culoare fond celul ")
("cell border" "bordura celulei")
("cell height" "īn lµimea celulei")
("cell operation mode" "mod de operare īn celule")
("cell width" "l µimea celulei")
("center" "centru")
("center text" "centrare text")
("centered" "centrat")
("centered block" "bloc centrat")
("centered tabular" "tabel centrat")
("change border of cell" "schimbare bordur  celul ")
("change cell operation mode" "schimbare mod de operare celul ")
("change log" "log schimb ri")
("changes" "schimb ri")
("chapter" "capitol")
("check" "verificare")
("check text for spelling errors" "verificare text pentru erori de ortografie")
("chinese" "chinez ")
("choice" "alegere")
("citation" "citat")
("cite" "a cita")
("class" "clas ")
("clear" "³terge")
("clear selection" "³terge selecµia")
("clipped" "trunchiat")
("clipped and magnified" "trunchiat ³i m rit")
("clipped and resized" "trunchiat ³i redimensionat")
("clone" "clonare")
("clone window" "clonare fereastr ")
("close" "īnchide")
("close TeXmacs" "īnchide TeXmacs")
("close buffer" "īnchide bufferul")
("close session" "īnchide sesiunea")
("close window" "īnchide fereastra")
("closing" "īnchidere")
("code" "cod")
("color" "culoare")
("column" "coloan ")
("column contains glued items" "coloana conµine elemente lipite")
("compatibility with other formats" "compatibilitate cu alte formate")
("compile article" "compilare articol")
("compile book" "compilare carte")
("compile buffer" "compilare buffer")
("compile project" "compilare proiect")
("complex" "complex")
("concrete" "concret")
("condensed" "condensat")
("condition" "condiµie")
("configuration" "configurare")
("content tag" "marcator de cuprins")
("context dependent icons" "icon-uri dependente de context")
("continuation of" "continuare a")
("convention" "convenµie")
("converters to other data formats" "conversie īn alt format")
("copy" "copiere")
("copy text" "copiere text")
("copy to" "copiere c tre")
("copying" "copiere")
("corollary" "corolar")
("correct text" "text corect")
("cursors" "cursor")
("custom tab" "tab personalizat")
("customizing TeXmacs" "personalizare TeXmacs")
("customizing the TeXmacs styles" "personalizare stiluri TeXmacs")
("custum tab" "tab persoanlizat")
("cut" "decupare")
("cut text" "decupare text")
("cut to" "decupare c tre")
("cypriot" "cipriot")
("cyrillic" "chirilic")
("cyrillic input method" "tastatur  chirilic ")
("cyrillic italic right" "chirilic italic drept")
("czech" "ceh ")
("dancers" "dansatori")
("danish" "danez ")
("dash" "liniuµ ")
("dashes" "liniuµe")
("data conversion" "conversie de date")
("data format" "format date")
("date" "data")
("deactivate" "dezactivare")
("deactivate table" "dezactivare tabel")
("december" "decembrie")
("decorate atoms" "decorare atomi")
("default" "valoare implicit ")
("default padding" "spaµiere implicit ")
("definition" "definiµie")
("delete" "³tergere")
("delete column" "³tergere coloan ")
("delete row" "³tergere linie")
("denominator" "numitor")
("description" "descriere")
("destination" "destinaµie")
("detach" "deta³are")
("determinant" "determinant")
("devangari" "devanagari")
("developers guide" "ghidul dezvoltatorului")
("directory" "director")
("disable first indentation" "dezactivare prima indentare")
("disable first indentation after" "dezactivare prima indentare dup ")
("disable first indentation before" "dezactivare prima indentare īnainte")
("disable indentation" "dezactivare indentare")
("disable indentation after" "dezactivare indentare dup ")
("disable indentation before" "dezactivare indentare īnainte")
("disable last indentation" "dezactivare ultima indentare")
("disable last indentation after" "dezactivare ultima indentare dup ")
("disable last indentation before" "dezactivare ultima indentare īnainte")
("disallow" "interzicere")
("distribute unused space" "distribuire spaµiu neutilizat")
("div" "div")
("document" "document")
("document format" "formatul documentului")
("document style" "stilul documentului")
("document styles" "stilurile documentului")
("documentation" "documentaµie")
("documents are trees" "documentele sunt arbori")
("dot" "punct")
("dots" "puncte")
("double stroke" "linie dubl ")
("down" "jos")
("dpi" "dpi")
("duplicate" "duplicat")
("dutch" "olandez ")
("dynamic libraries" "biblioteci dinamice")
("edit" "editare")
("editing tools" "unelte de editare")
("email" "email")
("emphasize" "scoatere īn evidenµ ")
("emphasize text" "scoatere text īn evidenµ ")
("empty box" "cutie goal ")
("enable first indentation" "activare prima indentare")
("enable first indentation after" "activare prima indentare dup ")
("enable first indentation before" "activare prima indentare īnainte")
("enable indentation" "activare indentare")
("enable indentation after" "activare indentare dupa")
("enable indentation before" "activare indentare īnainte")
("enable last indentation" "activare ultima indentare")
("enable last indentation after" "activare ultima indentare dup ")
("enable last indentation before" "activare ultima indentare īnainte")
("encl" "inclus")
("end" "sfār³it")
("english" "englez ")
("enter a title" "introduceµi un titlu")
("enumerate" "enumerare")
("enumerate|Alpha" "Litere")
("enumerate|Roman" "Roman")
("enumerate|alpha" "litere")
("enumerate|roman" "roman")
("env" "mediu")
("environment" "mediu")
("epilogue" "epilog")
("equal" "egal")
("equation" "ecuaµie")
("equations" "ecuaµii")
("equivalent for" "echivalent pentru")
("error" "eroare")
("esperanto" "esperanto")
("etruscan" "etrusc ")
("evaluate" "evaluare")
("evaluate scheme expression" "evaluare expresie scheme")
("even page footer" "footer pentru paginile pare")
("even page header" "header pentru paginile pare")
("even page margin" "margini pentru paginile pare")
("even page text" "text pentru paginile pare")
("exact horizontal" "orizontal exact")
("exact mode" "mod exact")
("exam" "examen")
("example" "exemplu")
("exclusive" "exclusiv")
("exclusive or" "sau exclusiv")
("executable" "executabil")
("execute" "execut ")
("execute a TeXmacs command" "execut  o comand  TeXmacs")
("execute system command" "execut  o comand  sistem")
("executive" "executiv")
("exercise" "exerciµiu")
("expand" "l rgire")
("explained" "explicat")
("export" "exportare")
("export as" "exportare ca")
("extend or normal" "'extins' sau 'normal'")
("extern " "extern")
("extra" "extra")
("extract format" "extragere format")
("extras" "extras")
("family" "familie")
("february" "februarie")
("figure" "figur ")
("file" "fi³ier")
("file name" "numele fi³ierului")
("file not found" "nu g sesc fi³ierul")
("find next match" "g se³te urmatoarea potrivire")
("find text" "c utare text")
("finnish" "finlandez ")
("first contact" "primul contact")
("first indentation" "prima indentare")
("first item" "primul element")
("first page" "prima pagin ")
("first start" "pornire")
("flat" "plat")
("flexibility" "flexibilitate")
("flexibility factor for vertical spacing" "factor de flexibilitate pentru spaµierea vertical ")
("floating figure" "figur  flotant ")
("floating object" "obiect flotant")
("floating table" "tabel flotant")
("fold" "īndoire")
("folded" "īndoit")
("font" "font")
("font base size" "m rimea fontului de baz ")
("font dpi" "dpi-ul fontului")
("font family" "familia fontului")
("font name" "numele fontului")
("font series" "seria fontului")
("font shape" "forma fontului")
("font size" "m rimea fontului")
("font variant" "variante de font")
("fonts" "fonturi")
("footer" "footer")
("footnote" "not  de picior")
("for" "pentru")
("foreground" "foreground")
("foreign" "str in")
("format" "format")
("formatted date" "dat  formatat ")
("formula" "formul ")
("formula style" "stil formul ")
("forward replace" "īnlocuire īnainte")
("forward search" "c utare īnainte")
("fraction" "fracµie")
("french" "francez ")
("full manuals" "manuale complete")
("function" "funcµie")
("further customization" "personalizare")
("future changes" "schimb ri viitoare")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs nu ofer  nici o garanµie juridic ")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs este sub licenµ  GNU")
("general architecture of TeXmacs" "arhitectura general  TeXmacs")
("general negation" "negaµie general ")
("generating font file" "generare fi³ier font")
("generic" "generic")
("georgian" "georgian ")
("german" "german ")
("getting started" "la īnceput")
("glossary" "glosar")
("glossary entry" "intrare īn glosar")
("glue" "lipire")
("glue decorations" "lipire decoraµii")
("go" "pornire")
("gothic" "gotic")
("graphical interface" "interfaµ  grafic ")
("grave" "grav")
("greater" "mai mare")
("greater or equal" "mai mare sau egal")
("greek" "grec")
("greek letter" "liter  greceasc ")
("green" "verde")
("grey" "gri")
("group" "grup")
("happy typing" "tastare fericit ")
("has been aborted" "a fost oprit")
("has completed its task" "³i-a terminat sarcina")
("hat" "circumflex")
("header" "header")
("header and footer" "header ³i footer")
("hebrew" "ebraic ")
("height" "īn lµime")
("height is exactly the specified height" "folosirea īn lµimii specificate")
("height is maximum of specified height and box height" "īn lµimea este maximul dintre īn lµimea specificat  ³i īn lµimea cutiei")
("height is minimum of specified height and box height" "īn lµimea este minimul dintre īn lµimea specificat  ³i īn lµimea cutiei")
("height magnification" "m rirea īn lµimii")
("help" "ajutor")
("help me" "ajutor")
("help us" "ajutaµi-ne")
("here" "aici")
("home" "r d cin ")
("horizontal" "orizontal")
("horizontal cell alignment" "aliniere orizontal  a celulei")
("horizontal ink separation" "separare orizontal  a cernelei")
("horizontal part" "partea orizontal ")
("horizontal position" "poziµia orizontal ")
("horizontal space" "spaµiu orizontal")
("horizontal table alignment" "aliniere orizontal  a tabelului")
("horizontally align cell to the base" "aliniere orizontal  a celulei la baz ")
("horizontally center the cell" "centrare orizontal  a celulei")
("how much longer may pages become" "cāt de lungi pot deveni paginile")
("how much shorter may pages become" "cāt de scurte pot deveni paginile")
("huge" "enorm")
("hungarian" "maghiar ")
("hyperlink" "hyperlink")
("hyphenation" "desp rµire īn silabe")
("icelandic" "islandez ")
("if" "dac ")
("image" "imagine")
("image links" "leg turi la imagine")
("implementation" "implementare")
("import" "import")
("improving the current implementation" "īmbun t µire a implementarii curente")
("inactive" "inactiv")
("include" "includere")
("include a document" "include un document")
("include file" "include un fi³ier")
("inclusion into TeXmacs" "includere īn TeXmacs")
("inclusions" "includeri")
("indent" "indentare")
("indentation flag" "marcator de indentare")
("index" "index")
("index entry" "intrare īn index")
("index level" "nivel al indexului")
("insert" "inserare")
("insert Pr" "inserare Pr")
("insert a TeXmacs symbol" "inserare simbol TeXmacs")
("insert a big operator" "inserare operator mare")
("insert a binary operation" "inserare operaµie binar ")
("insert a binary relation" "inserare relaµie binar ")
("insert a blackboard bold character" "inserare caracter blackboard bold")
("insert a bold calligraphic character" "inserare caracter caligrafic bold")
("insert a bold character" "inserare caracter bold")
("insert a calligraphic character" "inserare caracter caligrafic")
("insert a fraction" "inserare fracµie")
("insert a fraktur character" "inserare caracter gotic")
("insert a greek character" "inserare caracter grec")
("insert a large left delimiter" "inserare delimitator mare stānga")
("insert a large right delimiter" "inserare delimitator mare dreapta")
("insert a large separator" "inserare separator mare")
("insert a left subscript" "inserare indice la stānga")
("insert a link" "inserare leg tur ")
("insert a miscellaneous symbol" "inserare simboluri diverse")
("insert a new branch" "inserare ramur  nou ")
("insert a new item" "inserare element nou")
("insert a picture" "inserare imagine")
("insert a square root" "inserare r d cin  patrat ")
("insert a table" "inserare tabel")
("insert a table or a matrix" "inserare tabel sau matrice")
("insert an" "insereaz  un")
("insert an accent" "inserare accent")
("insert an arrow" "inserare s geat ")
("insert an environment" "inserare mediu")
("insert an n" "inserare r d cin  de ordinul n")
("insert appendix" "inserare apendix")
("insert arccos" "inserare arccos")
("insert arcsin" "inserare arcsin")
("insert arctan" "inserare arctan")
("insert arg" "inserare arg")
("insert argument" "inserare argument")
("insert automatically generated content" "inserare cuprins generat automat")
("insert big contour integral" "inserare integral  pe countur mare")
("insert big coproduct" "inserare coprodus mare")
("insert big direct sum" "inserare sum  direct  mare")
("insert big dotted point" "inserare punct īn cerc mare")
("insert big integral" "inserare integral  mare")
("insert big intersection" "inserare intersecµie mare")
("insert big logical and" "inserare I logic mare")
("insert big logical or" "inserare SAU logic mare")
("insert big product" "inserare produs mare")
("insert big square union" "inserare reuniune unghiular  mare")
("insert big summation" "inserare sumare mare")
("insert big tensor product" "inserare produs tensorial mare")
("insert big union" "inserare reuniune mare")
("insert big union sum" "inserare sum  de reuniuni mare")
("insert big vertical space" "inserare spaµiu vertical mare")
("insert chapter" "inserare capitol")
("insert column" "inserare coloan ")
("insert column to the left" "inserare coloan  la stānga")
("insert column to the right" "inserare coloan  la dreapta")
("insert cos" "inserare cos")
("insert cosh" "inserare cosh")
("insert cot" "inserare cot")
("insert coth" "inserare coth")
("insert csc" "inserare csc")
("insert deg" "inserare deg")
("insert det" "inserare det")
("insert dim" "inserare dim")
("insert dollar" "inserare dolar")
("insert equation" "inserare ecuaµie")
("insert executable markup" "inserare de conµinut executabil")
("insert exp" "inserare exp")
("insert footnote" "inserare not  de picior")
("insert formula" "inserare formul ")
("insert gcd" "inserare gcd")
("insert hom" "inserare hom")
("insert horizontal interword space" "inserare spaµiu orizontal īntre cuvinte")
("insert image" "inserare imagine")
("insert inactive markup" "inserare de conµinut inactiv")
("insert inf" "inserare inf")
("insert ker" "inserare ker")
("insert large" "inserare mare")
("insert lg" "inserare lg")
("insert lim" "inserare lim")
("insert liminf" "inserare liminf")
("insert limsup" "inserare limsup")
("insert ln" "inserare ln")
("insert log" "inserare log")
("insert mathematics" "inserare matematic ")
("insert max" "inserare max")
("insert medium horizontal space" "inserare spaµiu orizontal mediu")
("insert medium vertical space" "inserare spaµiu vertical mediu")
("insert min" "inserare min")
("insert negative horizontal space" "inserare spaµiu orizontal negativ")
("insert new item or number" "inserare element nou sau num r")
("insert new rows or columns" "inserare linii sau coloane noi")
("insert or delete rows or columns" "inserare sau ³tergere linii sau coloane")
("insert row" "inserare linie")
("insert row above" "inserare linie deasupra")
("insert row below" "inserare linie dedesupt")
("insert sec" "inserare sec")
("insert section" "inserare secµiune")
("insert sharp" "inserare diez")
("insert sin" "inserare sin")
("insert sinh" "inserare sinh")
("insert small horizontal space" "inserare spaµiu orizontal mic")
("insert small vertical space" "inserare spaµiu vertical mic")
("insert structural markup" "inserare de conµinut structural")
("insert subsection" "inserare sub-secµiune")
("insert subsubsection" "inserare sub-sub-secµiune")
("insert sup" "inserare sup")
("insert tan" "inserare tan")
("insert tanh" "inserare tanh")
("insert thick horizontal space" "inserare spaµiu orizontal larg")
("interfacing" "interfaµare")
("interfacing TeXmacs with other systems" "interfaµare TeXmacs cu alte sisteme")
("interjection" "interjecµie")
("interline separation" "separaµia īntre linii")
("interline space" "spaµiul īntre linii")
("internationalization" "internaµionalizare")
("interparagraph space" "spaµiul īntre paragrafe")
("interrupt execution" "īntrerupere execuµie")
("introduction" "introducere")
("invisible" "invizibil")
("invisible citation" "citat invizibil")
("irish" "irlandez ")
("is running" "ruleaz ")
("is tuple" "este tupl ")
("ispell does not respond" "ispell nu r spunde")
("ispell is already busy" "ispell este deja lansat")
("italian" "italian ")
("italic" "italic")
("italic right" "italic drept")
("itemize" "list ")
("january" "ianuarie")
("japanese" "japonez ")
("july" "iulie")
("june" "iunie")
("justified" "aliniat la ambele capete")
("justify text" "aliniere text")
("key" "tast ")
("keyboard" "tastatur ")
("keyboard equivalent" "echivalent tastatur ")
("keyboard modifiers" "modoficatori de tastatur ")
("keyboard shortcut" "scurt tur ")
("keymaps" "tastaturi")
("keyword" "cuvānt cheie")
("keywords" "cuvinte cheie")
("kill" "distruge")
("known bugs" "bug-uri cunoscute")
("label" "etichet ")
("landscape" "landscape")
("language" "limb ")
("large" "mare")
("large closing bracket" "parantez  īnchis  mare")
("large delimiter" "delimitator mare")
("large opening bracket" "parantez  deschis  mare")
("large separator" "separator mare")
("last indentation" "ultima indentare")
("last page" "ultima pagin ")
("latex command" "comand  latex")
("latin" "latin")
("layout" "a³ezare īn pagin ")
("left" "la stānga")
("left border" "bordura din stānga")
("left margin" "marginea din stānga")
("left padding" "spaµierea din stānga")
("left prime" "prim la stānga")
("left aligned" "aliniate la stānga")
("left slanted" "italic spre stānga")
("left subscript" "indice la stānga")
("left superscript" "exponent la stānga")
("left surrounding" "īnconjurare la stānga")
("legal" "legal")
("lemma" "lem ")
("length" "lungime")
("less" "mai mic")
("less or equal" "mai mic sau egal")
("letter" "scrisoare")
("license" "licenµ ")
("light" "u³or")
("limitations" "limit ri")
("limits" "limite")
("line" "linie")
("line break" "īntrerupere linie")
("line stretch" "īntindere linie")
("link" "leg tur ")
("link image" "leg tur  imagine")
("list" "list ")
("list of figures" "list  de figuri")
("list of tables" "list  de tabele")
("load" "īncarc ")
("load LaTeX file" "īncarc  fi³ier LaTeX")
("load TeX file" "īncarc  fi³ier TeX")
("load TeXmacs file" "īncarc  fi³ier TeXmacs")
("load TeXmacs style file" "īncarc  fi³ier de stil TeXmacs")
("load a file" "īncarc  un fi³ier")
("load buffer" "īncarc  buffer")
("load file" "īnc rcare fi³ier")
("load html file" "īncarc  fi³ier html")
("load image" "īncarc  imagine")
("load in new window" "īncarc  īn fereastr  nou ")
("load latex file" "īncarc  fi³ier latex")
("load more recent autosave file" "īncarc  fi³ierul salvat automat cel mai recent")
("load tex file" "īnc rcare fi³ier text")
("load verbatim file" "īnc rcare fi³ier verbatim")
("loaded" "īnc rcat")
("long" "lung")
("look and feel" "aspectul interfeµei")
("look up" "c utare")
("lower border" "bordura de jos")
("macro" "macro")
("magenta" "mov")
("magic" "magic")
("magnification" "m rire")
("magnified" "m rit")
("main" "principal")
("main icon bar" "bara cu iconiµe principal ")
("major changes" "schimb ri majore")
("make a page insertion" "creare inserare pagin ")
("make a subscript" "creare indice")
("make a superscript" "creare exponent")
("make acute" "creare accent ascuµit")
("make bar" "creare bar ")
("make check" "creare check")
("make fraction" "creare fracµie")
("make grave" "creare accent grav")
("make hat" "creare accent circumflex")
("make label" "creare etichet ")
("make negation" "creare negaµie")
("make page reference" "creare referinµ  pagin ")
("make reference" "creare referinµ ")
("make square root" "creare r d cin  patrat ")
("make tilde" "creare tilda")
("make title" "creare titlu")
("make vector" "creare vector")
("making donations" "donaµii")
("manual" "manual")
("map to" "trimitere c tre")
("march" "martie")
("margins" "margini")
("margins as on paper" "marginile ca pe hārtie")
("master" "master")
("master file" "fi³ier master")
("math" "maths")
("math font" "font matematic")
("math font family" "familie font matematic")
("math font series" "serie font matematic")
("math font shape" "form  font matematic")
("mathematical" "matematic")
("mathematical formulas" "formule matematice")
("mathematical typesetting" "aranjare īn pagin  matematic ")
("mathematics" "matematic ")
("matrix" "matrice")
("maximal number of columns" "num r maxim de coloane")
("maximal number of rows" "num r maxim de linii")
("maximum mode" "mod maximum")
("may" "mai")
("medium" "mediu")
("medium skip" "salt mediu")
("meminfo" "informaµii memorie")
("merge" "ad ugare")
("messy" "īncurcat")
("meta key" "tasta meta")
("middle" "mijloc")
("minimal number of columns" "num r minim de coloane")
("minimal number of rows" "num r minim de linii")
("minimum mode" "mod minimum")
("minus" "minus")
("miscellaneous" "divers")
("mod" "mod")
("mode" "mod")
("modifier" "modificator")
("modify cell alignment" "modificare aliniere celule")
("modify cell border" "modificare bordur  celul ")
("modify cell padding" "modificare spaµiu īn jurul celulei")
("modify cell size" "modificare m rime celul ")
("modify table border" "modificare bordur  tabel")
("modify table padding" "modificare spaµiu īn jurul tabelului")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "mai multe informaµii despre GNU TeXmacs pot fi g site īn meniul  ajutor")
("mosaic" "mosaic")
("move down" "deplasare īn jos")
("move object" "mutare obiect")
("move to the right when finished" "deplasare la dreapta pentru a termina")
("move up" "deplasare īn sus")
("n-th" "al n-lea")
("n-th root" "r d cin  de ordinul n")
("name" "nume")
("negation" "negaµie")
("new" "nou")
("new buffer" "buffer nou")
("new column" "coloan  nou ")
("new item" "element nou")
("new line" "linie nou ")
("new number" "num r nou")
("new page" "pagin  nou ")
("new page before" "pagin  nou  īnainte")
("new paragraph" "paragraf nou")
("new roman" "roman nou")
("new row" "linie nou ")
("new table" "tabel nou")
("next line" "linia urm toare")
("no changes need to be saved" "nu exist  modific ri pentru salvare")
("no dictionary for" "nu exist  dicµionar pentru")
("no first indentation" "f r  prim aindentare")
("no indentation" "f r  indentare")
("no line break" "f r  īntrerupere de linie")
("no matches found" "nu a fost g sit  nici o potrivire")
("no more matches for" "nu mai exist  potriviri pentru")
("no more redo information available" "nu mai sunt disponibile informaµii pentru redo")
("no more undo information available" "nu mai sunt disponibile informaµii pentru undo")
("no name" "f r  nume")
("no page break after" "f r  īntrerupere pagin  dup ")
("no page break before" "f r  īntrerupere pagin  īnainte")
("no spelling errors found in text" "textul nu conµine erori de ortografie")
("no style" "f r  stil")
("none" "nimic")
("normal" "normal")
("norwegian" "norvegian ")
("not" "non")
("not equal" "diferit")
("not found" "nu a fost g sit")
("notation" "notaµie")
("note" "not ")
("november" "noiembrie")
("number" "num r")
("number of columns" "num r de coloane")
("number equation" "numerotare ecuaµie")
("numbered equation" "ecuaµie numerotat ")
("numbered equations" "ecuaµii numerotate")
("numerator" "num r tor")
("numeric" "numeric")
("objectives" "obiective")
("occurrences" "apariµii")
("october" "octombrie")
("odd page footer" "footer pentru paginile impare")
("odd page header" "header pentru paginile impare")
("odd page margin" "marginea pentru paginile impare")
("odd page text" "text pentru paginile impare")
("off" "dezactivat")
("ok" "ok")
("old english" "engleza veche")
("old slavonic" "slavona veche")
("old style" "stil antic")
("on" "activat")
("on cells" "pentru celule")
("on columns" "pentru coloane")
("on entire table" "pentru īntregul tabel")
("on rows" "pentru linii")
("one spelling error has been corrected" "o eroare de ortografie a fost corectat ")
("online documentation" "documentaµie online")
("online help" "ajutor online")
("open" "deschide")
("open a new buffer" "deschide un buffer nou")
("open new window" "deschide o fereastr  nou ")
("opening" "deschidere")
("operation on named selection" "operaµie asupra selecµiei specificate")
("operation on primary selection" "operaµie asupra selecµiei primare")
("operation on secondary selection" "operaµie asupra selecµiei secundare")
("operation on ternary selection" "operaµie asupra selecµiei terµiare")
("optical" "optic")
("option" "opµiune")
("options" "opµiuni")
("or" "sau")
("orange" "portocaliu")
("orientation" "orientare")
("origin" "origine")
("original welcome message" "mesaj welcome original")
("other" "altul")
("other pages" "alte pagini")
("other projects" "alte proiecte")
("other style" "alt stil")
("outlined roman" "roman dublat")
("over" "peste")
("padding" "spaµiere")
("page" "pagin ")
("page bottom margin" "marginea de jos a paginii")
("page break" "īntrerupere pagin ")
("page break before" "īntrerupere pagin  īnainte")
("page height" "īn lµime pagin ")
("page insertion" "inserare pagin ")
("page layout" "aranjare īn pagin ")
("page number text" "text pentru num rul de pagin ")
("page numbering" "numerotare pagini")
("page reference" "referinµ  la pagin ")
("page right margin" "marginea din dreapta a paginii")
("page top margin" "marginea de sus a paginii")
("page type" "tip de pagin ")
("page width" "l µimea paginii")
("paper" "hārtie")
("paper type" "tip de hārtie")
("papyrus" "papirus")
("paragraph" "paragraf")
("paragraph mode" "tip de paragraf")
("paragraph width" "l µime paragraf")
("part" "parte")
("past changes" "schimb ri efectuate")
("paste" "lipire")
("paste from" "lipire din")
("paste text" "lipire text")
("path" "cale")
("perform operations on cells" "efectuare operaµie asupra celulelor")
("perform operations on columns" "efectuare operaµie asupra coloanelor")
("perform operations on entire table" "efectuare operaµie asupra īntregului tabel")
("perform operations on rows" "efectuare operaµie asupra liniilor")
("permanent" "permanent")
("person" "persoan ")
("personal dictionary has been modified" "dicµionarul personal a fost midificat")
("phantasy" "fantezie")
("philosophy" "filozofie")
("phoenician" "fenician")
("phonetic" "fonetic")
("pink" "roz")
("plain block" "bloc standard")
("plain tabular" "tabel standard")
("planned changes" "schimb ri planificate")
("plans for the future" "planuri de viitor")
("please" "v  rog")
("please wait" "v  rog a³teptaµi")
("plus" "plus")
("polish" "polonez ")
("porting TeXmacs to other platforms" "portare TeXmacs pe alte platforme")
("portrait" "portrait")
("portuguese" "portughez ")
("position" "poziµie")
("position float" "poziµie flotant ")
("position floating object" "poziµionare obiect flotant")
("position the table" "poziµionare tabel")
("postscript" "postscript")
("postscript image" "imagine postscript")
("pre-alpha release" "versiune pre-alpha")
("preamble" "preambul")
("preamble mode" "mod preambul")
("preferences" "preferinµe")
("presentation mode" "mod prezentare")
("preview before printing" "previzualizare īnainte de tip rire")
("preview with ghostview" "previzualizare cu ghostview")
("primary" "primar")
("prime" "prim")
("print" "imprimare")
("print all" "tip re³te tot")
("print all to file" "imprimare īn fi³ier")
("print page selection" "imprimare pagini selectate")
("print page selection to file" "imprimare pagini selectat īn fi³ieri")
("print to postscript file" "imprimare īn fi³ier postscript")
("printer" "imprimant ")
("printer dpi" "rezoluµie imprimant ")
("printing command" "comand  pentru imprimant ")
("problem" "problem ")
("professional" "profesional")
("prog" "prog")
("prog font" "font pentru programe")
("prog font family" "familie font pentru programe")
("prog font series" "serie font pentru programe")
("prog font shape" "form  font pentru programe")
("program" "program")
("program mode" "mod programare")
("programming" "programare")
("progressive" "progresiv")
("project" "proiect")
("projects" "proiecte")
("prologue" "prolog")
("prompt on scripts" "cerere acceptare pentru script-uri")
("proof" "demonstraµie")
("proportional" "proporµional")
("proportional typewriter" "proporµional - ma³in  de scris")
("proposition" "propoziµie")
("query replace" "cerere īnlocuire")
("quit" "p r sire")
("quotation" "citat")
("quote" "a cita")
("range" "interval")
("really close it" "chiar s -l īnchid")
("really huge" "cu adev rat enorm")
("really quit" "doriµi cu adev rat p r sirea programului")
("red" "ro³u")
("redo" "redo")
("redo undone changes" "refacere schimb ri anulate")
("reduce bottom margin by" "reducerea marginii de jos cu")
("reduce left margin by" "reducerea marginii din stānga cu")
("reduce margins" "reducere margini")
("reduce right margin by" "reducerea marginii din dreapta cu")
("reduce top margin by" "reducerea marginii de sus cu")
("reduction bottom margin" "reducerea marginii de jos")
("reduction even page margin" "reducerea marginii paginilor pare")
("reduction odd page margin" "reducerea marginii paginilor impare")
("reduction page bottom margin" "reducerea marginii paginii jos")
("reduction page right margin" "reducerea marginii paginii din dreapta")
("reduction page top margin" "reducerea marginii paginii de sus")
("reduction right margin" "reducerea marginii din drepata")
("reduction top margin" "reducerea marginii de sus")
("reference" "referinµ ")
("references" "referinµe")
("regular" "normal")
("release" "versiune")
("reload" "reīnc rcare")
("remark" "observaµie")
("remove number" "³tergere num r")
("remove this switch" "³terge acest switch")
("renumber this page" "renumeroteaz  aceast  pagin ")
("repeat object" "repetare obiect")
("replace" "īnlocuire")
("replace by" "īnlocuire cu")
("replaced" "īnlocuit")
("replaced one occurrence" "o apariµie īnlocuit ")
("reset" "reset")
("resize object" "redimensionare obiect")
("resized" "redimensionat")
("return" "return")
("revert" "reactualizare")
("revert buffer" "actualizare buffer")
("right" "la drepata")
("right border" "bordura din dreapta")
("right margin" "marginea din drepata")
("right padding" "spaµiere la dreapta")
("right page margin" "marginea paginii īn dreapta")
("right aligned" "aliniate la dreapta")
("right subscript" "indice la dreapta")
("right superscript" "exponent la dreapta")
("right surrounding" "īnconjurare la dreapta")
("rigid" "fix")
("rigid horizontal" "fix orizontal")
("rigid space" "spaµiu fix")
("roman" "roman")
("romanian" "romān ")
("root" "r d cin ")
("rotate backward" "rotire īnapoi")
("rotate forward" "rotire īnainte")
("row" "linie")
("row contains glued items" "linia conµine elemente lipite")
("runic" "rune")
("running author" "autor curent")
("running title" "titlu curent")
("russian" "rus ")
("russian and Ukrainian users" "utilizatori ru³i ³i ucraineni")
("sample" "e³antion")
("sans serif" "sans serif")
("save" "salvare")
("save TeXmacs file" "salvare fi³ier TeXmacs")
("save TeXmacs style file" "salvare fi³ier de stil TeXmacs")
("save as" "salvare ca")
("save as LaTeX" "salvare format LaTeX")
("save as TeX" "salvare format TeX")
("save buffer" "salvare buffer")
("save buffer as" "salvare buffer ca")
("save file" "salvare fi³ier")
("save html file" "salvare format html")
("save image" "salvare imagine")
("save latex file" "salvare fi³ier latex")
("save tex file" "sa³vare fi³ier tex")
("save this buffer" "salveaz  acest buffer")
("save verbatim file" "salvare fi³ier verbatim")
("saved" "salvat")
("screen layout" "aranjare pe ecran")
("screen margins" "margini pe ecran")
("script" "indice")
("script above" "indice deasupra")
("script below" "indice dedesupt")
("script script size" "m rime indice la indice")
("script size" "m rime indice")
("scripts not accepted" "script-urile nu sunt acceptate")
("search" "c utare")
("searching" "caut")
("secondary" "secundar")
("section" "secµiune")
("security" "securitate")
("see" "vezi")
("select a document style" "selectare stil document")
("select a foreground color" "selectare culoare")
("select a language" "selectare limb ")
("selected region" "regiune selectat ")
("selection" "selecµie")
("selections" "selecµii")
("seminar" "seminar")
("separation between lines" "spaµierea īntre linii")
("separation between paragraphs" "spaµierea īntre paragrafe")
("separator" "separator")
("september" "septambrie")
("serb" "sārb ")
("series" "serii")
("series|right" "drept")
("session" "sesiune")
("session name" "nume sesiune")
("session type" "tip sesiune")
("sessions" "sesiuni")
("set" "set")
("set background color of cell" "alegere culoare background pentru celul ")
("set cell mode" "alegere mod de operare asupra celulei")
("set extension center" "alegere centru de extindere")
("set height" "stabilirea īn lµimii")
("set height of cell" "stabilirea īn lµimii celulei")
("set margins" "alegere margini")
("set n" "stabilire n")
("set paragraph margins" "alegere margini paragraf")
("set paragraph mode" "stabilire mod de aliniere a paragrafului")
("set printer dpi" "stabilire rezoluµie imprimant ")
("set printing command" "alegere comand  de tip rire")
("set special cell properties" "stabilire propriet µi speciale pentru celul ")
("set special table properties" "stabilire propriet µi speciale pentru tabel")
("set text width" "alegere l µime text")
("set width" "stabilire l µime")
("set width of cell" "stabilirea l µimii celulei")
("settings" "caracteristici")
("setup printer" "configurare imprimant ")
("shape" "form ")
("shift-down" "shift-jos")
("shift-right" "shift-dreapta")
("show" "afi³are")
("show header and footer" "afi³are header ³i footer")
("show on screen" "afi³are pe ecran")
("shrinking factor" "factor de strāngere")
("signature" "semn tur ")
("size" "m rime")
("size limits" "limitele m rimii")
("slanted" "oblic")
("sloppy" "relaxat")
("small" "mic")
("small caps" "majuscule mici")
("small figure" "figur  mic ")
("small skip" "salt mic")
("small table" "tabel mic")
("source code" "cod surs ")
("space" "spaµiu")
("space between lines" "spaµiul dintre linii")
("space between paragraphs" "spaµiul dintre paragrafe")
("spacing" "spaµiere")
("spanish" "spaniol ")
("special" "special")
("special cell properties" "propriet µi speciale ale celulei")
("special table properties" "prpriet µi speciale ale tabelului")
("specific" "specific")
("spell" "ortografie")
("spell checking complete" "corectare ortografic  terminat ")
("spelling error" "gre³eal  de ortografie")
("spelling errors have been corrected" "gre³elile de ortografie au fost corectate")
("split" "īmp rµire")
("square root" "r d cin  patrat ")
("start" "start")
("start a new chapter" "īncepere capitol nou")
("start a new section" "īncepere secµiune nou ")
("start an interactive session" "īncepere sesiune interactiv ")
("status bar" "bar  de stare")
("stretchable" "extensibil")
("stretchable horizontal" "extensibil orizontal")
("stretchable vertical" "extensibil vertical")
("stroke" "ap sare")
("strokes" "ap s ri")
("strong" "ap sat")
("structural" "structural")
("style" "stil")
("styles" "stiluri")
("sub" "sub")
("subparagraph" "sub-paragraf")
("subscript" "indice")
("subsection" "sub-secµiune")
("subsub" "sub-sub")
("subsubsection" "sub-sub-secµiune")
("summary" "rezumat")
("summary of the principal TeXmacs tags" "rezumat al principalilor marcatori TeXmacs")
("superpose" "superposer")
("superscript" "exponent")
("swedish" "suedez ")
("switch" "switch")
("switch to first" "comutare la primul")
("switch to formula style" "comutare la stil formul ")
("switch to last" "comutare la ultimul")
("switch to next" "comutare la urm torul")
("switch to previous" "comutare la precedentul")
("switching and folding" "schimbare ³i pliere")
("symbol" "simbol")
("system environment variables" "variabile de mediu ale sistemului")
("tab" "tabulare")
("table" "tabel")
("table command" "comand  tabel")
("table of contents" "cuprins")
("tables" "tabele")
("tabular" "tabulare")
("tabular material" "tabel")
("teXmacs as an interface" "TeXmacs ca interfaµ ")
("teXmacs fonts" "fonturi TeXmacs")
("teXmacs notice" "note despre TeXmacs")
("teXmacs style files" "fi³ier de stil TeXmacs")
("ternary" "terµiar")
("test" "test")
("tex" "tex")
("text" "text")
("text font" "font īn mod text")
("text height correction" "corecµie pentru īn lµimea textului")
("text width" "l µime text")
("texts" "texte")
("th century bc" "-lea secol ī.Chr")
("th root" "r d cin  de ordinul")
("the TeXmacs authors" "autorii TeXmacs")
("the application did not send its usual startup banner" "aplicaµia nu a trimis mesajul obi³nuit de pornire")
("the application does not reply" "aplicaµia nu r spunde")
("the application is already running" "aplicaµia este deja pornit ")
("the boxes produced by the typesetter" "cutiile produse de tehnoredactor")
("the graphical user interface" "interfaµa grafic  cu utilizatorul")
("the leaves of TeXmacs trees" "frunzele arborelui TeXmacs")
("the mycas example" "exemplul 'mycas'")
("the primitive TeXmacs constructs" "construcµii TeXmacs primitive")
("the standard TeXmacs styles" "stiluri TeXmacs standard")
("theorem" "teorem ")
("there are unsaved documents" "exist  fi³iere nesalvate")
("this document has not been saved" "acest buffer nu a fost salvat")
("this document has been produced using" "acest document a fost creat folosind")
("this line" "aceast  linie")
("this page" "aceast  pagin ")
("tilda" "tilda")
("tilde" "tilda")
("times" "ori")
("tiny" "minuscul")
("title" "titlu")
("to the left" "spre stānga")
("to the right" "spre dreapta")
("today" "ast zi")
("tools" "unelte")
("top" "sus")
("top border" "bordura de sus")
("top level" "nivel superior")
("top margin" "marginea de sus")
("top padding" "spaµiere sus")
("translate" "traducere")
("tree" "arbore")
("tuple" "tupl ")
("turkish" "turc ")
("tutorial" "tutorial")
("type" "tip")
("type a latex command followed by" "tastaµi o comand  latex urmat  de")
("type body" "tip corp")
("type denominator" "introduceµi numitorul")
("type numerator" "introduceµi num r torul")
("type script" "introduceµi indicele")
("typesetted boxes" "cutii tehnoredactate")
("typewriter" "ma³in  de scris")
("typewriter small caps" "majuscule mici - ma³in  de scris")
("typing a simple text" "tastarea unui text simplu")
("typing simple texts" "tastarea textelor simple")
("ugaritic" "ugaritic")
("ukrainian" "ucrainean ")
("undo" "anulare")
("undo last changes" "anularea ultimelor schimb ri")
("up" "sus")
("update" "actualizare")
("update from web" "actualizare de pe web")
("update image links" "actulizare leg turi la imagini")
("upper border" "bordura de sus")
("use TeXmacs" "folosiµi TeXmacs")
("use a black color" "folosire culoare neagr ")
("use a blue color" "folosire culoare albastr ")
("use a bold font" "folosire font bold")
("use a brown color" "folosire culoare maro")
("use a calligraphic font" "folosire font caligrafic")
("use a green color" "folosire culoare verde")
("use a grey color" "folosire culoare gri")
("use a magenta color" "folosire culoare mov")
("use a orange color" "folosire culoare portocalie")
("use a pink color" "folosire culoare roz")
("use a red color" "folosire culoare ro³ie")
("use a sans serif font" "folosire font sans-serif")
("use a typewriter font" "folosire font ma³in  de scris")
("use a white color" "folosire culoare alb ")
("use a yellow color" "folosire culoare galben ")
("use blackboard bold font" "folosire font blackboard")
("use bold font series" "folosire serie font bold")
("use calligraphic font" "folosire font caligrafic")
("use calligraphical font" "folosire font caligrafic")
("use footnote font size" "folosire m rime font ca la nota de picior")
("use fraktur font" "folosire font gothic")
("use huge font size" "folosire font de m rime enorm ")
("use italic font shape" "folosire form  font italic")
("use large font size" "folosire m rime font mare")
("use left hand column as border" "folosirea coloanei din stānga ca bordur ")
("use medium font series" "folosire font m rime medie")
("use normal font size" "folosire font m rime normal ")
("use package" "utilizare pachet")
("use paragraph width" "utilizarea l µimii paragrafului")
("use really huge font size" "folosire font m rime cu adev rat enorm ")
("use right font shape" "folosire font drept")
("use right hand column as border" "folosirea coloanei din dreapta ca bordur ")
("use roman font family" "folosire font familie roman")
("use row above as border" "folosirea liniei de sus ca bordur ")
("use row below as border" "folosirea liniei de jos ca bordur ")
("use sans serif font family" "folosire font familie sans-serif")
("use script font size" "folsoire font m rime foarte mic ")
("use slanted font shape" "folsoire font de form  oblic ")
("use small capitals" "folosire majuscule mici")
("use small font size" "folosire font de m rime mic ")
("use small-caps font shape" "folosire font de forma majuscule mici")
("use the blackboard bold font" "folosire font blackboard bold")
("use the fraktur font" "folsoire font gothic")
("use tiny font font size" "folosire font de m rime minuscul ")
("use typewriter font family" "folosire font familie ma³in  de scris")
("use very large font size" "folosire font de m rime foarte mare")
("user manual" "manual de utilizare")
("user provided icons" "iconiµe definite de utilizator")
("value" "valoare")
("variable" "variabil ")
("variant" "variant ")
("vector" "vector")
("verbatim" "verbatim")
("verse" "vers")
("vertical" "vertical")
("vertical after" "vertical dup ")
("vertical before" "vertical īnainte")
("vertical cell alignment" "alinierea vertical  a celulei")
("vertical part" "parte vertical ")
("vertical position" "poziµie vertical ")
("vertical space" "spaµiu vertical")
("vertical table alignment" "alinierea vertical  a tabelului")
("vertically align cell to the base" "aliniere vertical  a celulei la baz ")
("vertically center the cell" "centrar  vertical  a celulei")
("very large" "foarte mare")
("very small" "foarte mic")
("vietnamese" "vietnamez ")
("view" "vedere")
("visible" "vizibil")
("warning" "avertisment")
("welcome" "welcome")
("welcome to GNU TeXmacs" "bine aµi venit la GNU TeXmacs")
("what is new" "nout µi")
("when finished" "pentru terminare")
("while" "īn timp ce")
("white" "alb")
("wide accent" "accent larg")
("width" "l µime")
("width is exactly the specified width" "utilizarea exact a l µimii specificate")
("width is maximum of specified width and box width" "l µimea este maximul dintre l µimea specificat  ³i l µimea cutiei")
("width is minimum of specified width and box width" "l µimea este minimul dintre l µimea specificat  ³i l µimea cutiei")
("width magnification" "m rirea l µimii")
("window" "fereastr ")
("window height" "īn lµimea ferestrei")
("window width" "l µimea ferestrei")
("windows key" "tasta windows")
("with" "cu")
("write a name" "scrie un nume")
("write bold mathematics" "scriere matemaitc  bold")
("write bold text" "scriere text bold")
("write italic text" "scriere text italic")
("write sample text" "scriere text ilustrativ")
("write strong text" "scriere text ap sat")
("write typewriter text" "scriere font ma³in  de scris")
("write verbatim text" "scriere text verbatim")
("writing data converters" "scriere convertori de date")
("writing your own style files" "scrierea propriilor fi³iere de stil")
("yellow" "galben")
("you can also obtain" "puteµi de asemenea obµine")
("your document is back in its original state" "documentul dvs. a revenit īn forma original ")
("your first interface" "prima dvs. interfaµ ")
