("\"encryption\" features from the preference panel" "\"crittografia\" funzioni dal pannello delle preferenze")
("alignment of balloon" "allineamento del palloncino")
("allowed positions of floating object" "posizioni consentite dell'oggetto galleggiante")
("and perform casual settings from the \"Encryption\" tab" "ed esegui impostazioni casuali dalla scheda \"Crittografia\"")
("animate folding" "piega animata")
("animate unfolding" "spiegazione animata")
("arch series" "serie ad arco")
("art Pen" "art pen")
("art frame" "cornice d'arte")
("background evaluations" "valutazioni di base")
("beamer" "beamer")
("bench" "panca")
("bend bottom" "piega fondo")
("bend corner" "angolo piega")
("bend diagonal" "piega diagonale")
("bend in" "piega")
("bend out" "piega")
("bezier" "bezier")
("big environment box" "big environment box")
("big focus" "grande attenzione")
("blackboard embold" "embold lavagna")
("bottom tools" "strumenti inferiori")
("broken white" "bianco rotto")
("build buffer" "build buffer")
("build buffer in" "build buffer in")
("build-all" "build-all")
("bump" "bump")
("cJK" "cJK")
("checkable field" "campo selezionabile")
("collect garbage" "raccolta rifiuti")
("commit" "commit")
("debug" "debug")
("drop" "drop")
("effect pen" "penna effetto")
("explicit keystroke" "battitura esplicita")
("field reference" "riferimento campo")
("horizontal collapse distance" "distanza di collasso orizzontale")
("impact" "impact")
("jump in" "salta dentro")
("live input-output" "live input-output")
("manila paper" "carta manila")
("map arguments" "argomenti della mappa")
("only keep folded" "tenere solo piegato")
("only keep unfolded" "solo aperto aperto")
("padded" "imbottito")
("particle" "particella")
("pretty tree output" "output albero grazioso")
("program bracket matching" "corrispondenza parentesi di programma")
("program bracket selections" "Selezioni parentesi programma")
("pulse" "impulso")
("remove folded" "rimuovi piegato")
("remove unfolded" "rimuovi non spiegato")
("retime" "retime")
("unfold" "spiegato")
("unfold all" "spiega tutto")
("unfold all fields" "spiega tutti i campi")
("unfolded" "spiegato")
("upight" "upight")
("you are attempting to open an encrypted file while" "stai tentando di aprire un file crittografato mentre")
("you might consider enabling the experimental" "potresti considerare di abilitare l'esperimento")