<TeXmacs|1.99.13>

<style|<tuple|source|std>>

<\body>
  <active*|<\src-title>
    <src-package|revtex-11pt|1.0>

    <\src-purpose>
      Macros defining sizes for a 11pt Revtex document.
    </src-purpose>

    <src-copyright|2012--2012|Joris van der Hoeven, François Poulain>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <assign|tex-text-width|<macro|468pt>>

  <assign|tex-top-margin|<macro|-37pt>>

  <assign|tex-head-height|<macro|12pt>>

  <assign|tex-top-skip|<macro|10pt>>

  <assign|tex-text-height|<macro|665.5pt>>

  <assign|tex-foot-skip|<macro|30pt>>

  <assign|tex-footnote-sep|<macro|1pt>>

  <assign|tex-column-sep|<macro|10pt>>

  <assign|par-first|<macro|15pt>>

  <assign|scriptsize|<macro|x|<with|font-size-base|8|par-sep|<minus|9.5pt|8pt>|<arg|x>>>>

  <assign|large|<macro|x|<with|font-size-base|12|par-sep|<minus|14pt|12pt>|<arg|x>>>>

  <assign|Large|<macro|x|<with|font-size-base|14.4|par-sep|<minus|18pt|14.4pt>|<arg|x>>>>

  <assign|LARGE|<macro|x|<with|font-size-base|17.28|par-sep|<minus|22pt|17.28pt>|<arg|x>>>>

  <assign|huge|<macro|x|<with|font-size-base|20.74|par-sep|<minus|25pt|20.74pt>|<arg|x>>>>

  <assign|Huge|<macro|x|<with|font-size-base|24.88|par-sep|<minus|30pt|24.88pt>|<arg|x>>>>
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>