;; Portions (C) International Organization for Standardization 1986
;; Permission to copy in any form is granted for use with
;; conforming SGML systems and applications as defined in
;; ISO 8879, provided this notice is included in all copies.
;; Character entity set. Typical invocation:
;; <!ENTITY % HTMLlat1 PUBLIC
;; "-//W3C//ENTITIES Latin 1//EN//HTML">
;; %HTMLlat1;

("nbsp"         "&#x00A0")      ; no-break space = non-breaking space
("iexcl"        "&#x00A1")      ; inverted exclamation mark
("cent"         "&#x00A2")      ; cent sign
("pound"        "&#x00A3")      ; pound sign
("curren"       "&#x00A4")      ; currency sign
("yen"          "&#x00A5")      ; yen sign = yuan sign
("brvbar"       "&#x00A6")      ; broken bar = broken vertical bar
("sect"         "&#x00A7")      ; section sign
("uml"          "&#x00A8")      ; diaeresis = spacing diaeresis
("copy"         "&#x00A9")      ; copyright sign
("ordf"         "&#x00AA")      ; feminine ordinal indicator
("laquo"        "&#x00AB")      ; left-pointing double angle quotation mark
("not"          "&#x00AC")      ; not sign
("shy"          "&#x00AD")      ; soft hyphen = discretionary hyphen
("reg"          "&#x00AE")      ; registered sign = registered trade mark sign
("macr"         "&#x00AF")      ; macron = spacing macron = overline
("deg"          "&#x00B0")      ; degree sign
("plusmn"       "&#x00B1")      ; plus-minus sign = plus-or-minus sign
("sup2"         "&#x00B2")      ; superscript two = superscript digit two
("sup3"         "&#x00B3")      ; superscript three = superscript digit three
("acute"        "&#x00B4")      ; acute accent = spacing acute
("micro"        "&#x00B5")      ; micro sign
("para"         "&#x00B6")      ; pilcrow sign = paragraph sign
("middot"       "&#x00B7")      ; middle dot = Georgian comma
("cedil"        "&#x00B8")      ; cedilla = spacing cedilla
("sup1"         "&#x00B9")      ; superscript one = superscript digit one
("ordm"         "&#x00BA")      ; masculine ordinal indicator
("raquo"        "&#x00BB")      ; right-pointing double angle quotation mark
("frac14"       "&#x00BC")      ; vulgar fraction one quarter
("frac12"       "&#x00BD")      ; vulgar fraction one half
("frac34"       "&#x00BE")      ; vulgar fraction three quarters
("iquest"       "&#x00BF")      ; inverted question mark
("Agrave"       "&#x00C0")      ; latin capital letter A with grave
("Aacute"       "&#x00C1")      ; latin capital letter A with acute
("Acirc"        "&#x00C2")      ; latin capital letter A with circumflex
("Atilde"       "&#x00C3")      ; latin capital letter A with tilde
("Auml"         "&#x00C4")      ; latin capital letter A with diaeresis
("Aring"        "&#x00C5")      ; latin capital letter A with ring above
("AElig"        "&#x00C6")      ; latin capital letter AE
("Ccedil"       "&#x00C7")      ; latin capital letter C with cedilla
("Egrave"       "&#x00C8")      ; latin capital letter E with grave
("Eacute"       "&#x00C9")      ; latin capital letter E with acute
("Ecirc"        "&#x00CA")      ; latin capital letter E with circumflex
("Euml"         "&#x00CB")      ; latin capital letter E with diaeresis
("Igrave"       "&#x00CC")      ; latin capital letter I with grave
("Iacute"       "&#x00CD")      ; latin capital letter I with acute
("Icirc"        "&#x00CE")      ; latin capital letter I with circumflex
("Iuml"         "&#x00CF")      ; latin capital letter I with diaeresis
("ETH"          "&#x00D0")      ; latin capital letter ETH
("Ntilde"       "&#x00D1")      ; latin capital letter N with tilde
("Ograve"       "&#x00D2")      ; latin capital letter O with grave
("Oacute"       "&#x00D3")      ; latin capital letter O with acute
("Ocirc"        "&#x00D4")      ; latin capital letter O with circumflex
("Otilde"       "&#x00D5")      ; latin capital letter O with tilde
("Ouml"         "&#x00D6")      ; latin capital letter O with diaeresis
("times"        "&#x00D7")      ; multiplication sign
("Oslash"       "&#x00D8")      ; latin capital letter O with stroke
("Ugrave"       "&#x00D9")      ; latin capital letter U with grave
("Uacute"       "&#x00DA")      ; latin capital letter U with acute
("Ucirc"        "&#x00DB")      ; latin capital letter U with circumflex
("Uuml"         "&#x00DC")      ; latin capital letter U with diaeresis
("Yacute"       "&#x00DD")      ; latin capital letter Y with acute
("THORN"        "&#x00DE")      ; latin capital letter THORN
("szlig"        "&#x00DF")      ; latin small letter sharp s = ess-zed
("agrave"       "&#x00E0")      ; latin small letter a with grave
("aacute"       "&#x00E1")      ; latin small letter a with acute
("acirc"        "&#x00E2")      ; latin small letter a with circumflex
("atilde"       "&#x00E3")      ; latin small letter a with tilde
("auml"         "&#x00E4")      ; latin small letter a with diaeresis
("aring"        "&#x00E5")      ; latin small letter a with ring above
("aelig"        "&#x00E6")      ; latin small letter ae
("ccedil"       "&#x00E7")      ; latin small letter c with cedilla
("egrave"       "&#x00E8")      ; latin small letter e with grave
("eacute"       "&#x00E9")      ; latin small letter e with acute
("ecirc"        "&#x00EA")      ; latin small letter e with circumflex
("euml"         "&#x00EB")      ; latin small letter e with diaeresis
("igrave"       "&#x00EC")      ; latin small letter i with grave
("iacute"       "&#x00ED")      ; latin small letter i with acute
("icirc"        "&#x00EE")      ; latin small letter i with circumflex
("iuml"         "&#x00EF")      ; latin small letter i with diaeresis
("eth"          "&#x00F0")      ; latin small letter eth
("ntilde"       "&#x00F1")      ; latin small letter n with tilde
("ograve"       "&#x00F2")      ; latin small letter o with grave
("oacute"       "&#x00F3")      ; latin small letter o with acute
("ocirc"        "&#x00F4")      ; latin small letter o with circumflex
("otilde"       "&#x00F5")      ; latin small letter o with tilde
("ouml"         "&#x00F6")      ; latin small letter o with diaeresis
("divide"       "&#x00F7")      ; division sign
("oslash"       "&#x00F8")      ; latin small letter o with stroke
("ugrave"       "&#x00F9")      ; latin small letter u with grave
("uacute"       "&#x00FA")      ; latin small letter u with acute
("ucirc"        "&#x00FB")      ; latin small letter u with circumflex
("uuml"         "&#x00FC")      ; latin small letter u with diaeresis
("yacute"       "&#x00FD")      ; latin small letter y with acute
("thorn"        "&#x00FE")      ; latin small letter thorn
("yuml"         "&#x00FF")      ; latin small letter y with diaeresis
