("a modifier" "a kombitast")
("GNU" "GNU")
("h modifier" "h kombitast")
("LaTeX" "LaTeX")
("m modifier" "m kombitast")
("TeX" "TeX")
("abbreviation" "forkortelse")
("about" "om")
("about menu" "om menu")
("above" "over")
("abstract" "abstract")
("accent" "accent")
("accept" "acceptér")
("accept all scripts" "acceptér alle scripts")
("accept no scripts" "acceptér ingen scripts")
("accept script" "acceptér script")
("acknowledgment" "anerkendelse")
("acronym" "akronym")
("action" "handling")
("activate" "aktivér")
("acute" "aigu")
("add switch after" "tilføj kontakt efter")
("add switch before" "tilføj kontakt før")
("address" "addresse")
("address block" "addresseområde")
("advanced" "avanceret")
("advanced layout features" "avancerede layout funktioner")
("after" "efter")
("albanian" "albansk")
("algorithm" "algoritme")
("align cell to the bottom" "justér celle med bund")
("align cell to the left" "justér celle med venstre side")
("align cell to the right" "justér celle med højre side")
("align cell to the top" "justér celle med top")
("align table at base of left column" "justér tabel med bunden af venstre søjle")
("align table at base of middle column" "justér tabel med bunden af midterste søjle")
("align table at base of origin column" "justér tabel med bunden af basissøjle")
("align table at base of right column" "justér tabel med bunden af højre søjle")
("align table at fraction bar height" "justér tabel til brøker")
("align table at the base of bottom row" "justér tabel med bunden af bundrækken")
("align table at the base of middle row" "justér tabel med bunden af  midterste række")
("align table at the base of origin row" "justér tabel med bunden af basisrækken")
("align table at the base of top row" "justér tabel med bunden af toprækken")
("align table at the bottom" "justér tabel med bunden")
("align table at the center" "justér tabel med centrum")
("align table at the horizontal center" "justér tabel med vandret centrum")
("align table at the left" "justér tabel med venstre side")
("align table at the top" "justér tabel med top")
("align table to the right" "justér tabel med højre side")
("align text to the left" "venstrejustéret tekst")
("align text to the right" "højrejustéret tekst")
("aligned" "justeret")
("alignment" "justering")
("all" "alle")
("allow" "tillad")
("allowed extension" "tilladt udvidelse")
("allowed reduction" "tilladt reducéring")
("alpha release" "alpha udgave")
("alt key" "alt tast")
("and" "og")
("appendix" "appendix")
("apply" "tilføj")
("april" "april")
("arab" "arabisk")
("archaic" "arkæisk")
("architecture" "arkitektur")
("argument" "argument")
("arithmetic" "aritmetik")
("armenian" "armensk")
("arrow" "pil")
("arrows" "pile")
("article" "artikel")
("as on paper" "som på papir")
("assign" "fastsæt")
("at fraction bar height" "til brøkstregshøjde")
("at the baseline" "til basislinie")
("at the bottom" "til bunden")
("at the left" "til venstre side")
("at the middle" "til midten")
("at the right" "til højre side")
("at the top" "til toppen")
("attach" "tilføj")
("attach buffer to which project" "tilføj buffer til hvilket projekt")
("august" "august")
("author" "forfatter")
("authorize" "tillad")
("automatic" "automatisk")
("automatically close brackets" "luk paranteser automatisk")
("automatically generated content" "automatisk genreret indhold")
("axiom" "axiom")
("background" "baggrund")
("background color" "baggrundsfarve")
("backward replace" "erstat baglæns")
("backward search" "søg baglæns")
("bad data format" "forkert data-format")
("bar" "bjælke")
("bard" "skjald")
("base level" "basisniveau")
("bashkirian" "bashkirisk")
("basic" "grundliggende")
("basic data types" "grundliggende datatyper")
("basic types" "grundliggende typer")
("be useful" "være nyttigt")
("become a TeXmacs developer" "bliv TeXmacs udvikler")
("before" "før")
("begin" "begynd")
("below" "efter")
("beta release" "beta udgave")
("bibliography" "bibliografi")
("bibliography file" "bibliografiarkiv")
("bibliography style" "bibliografiopsætning")
("big" "stor")
("big figure" "stor figur")
("big operator" "stor operator")
("big skip" "stort mellemrum")
("big table" "stor tabel")
("binary operation" "binær operation")
("binary relation" "binær relation")
("black" "sort")
("blackboard bold" "blackboard, fed")
("blackboard math" "blackboard math")
("blackletter" "gotisk skrift")
("blue" "blå")
("body" "brødtekst")
("bold" "fed")
("book" "bog")
("border" "kant")
("both" "begge")
("bottom" "bund")
("bottom border" "bundkant")
("bottom margin" "bundmargen")
("bottom padding" "bundmellemrum")
("branch" "gren")
("break" "linieudgang")
("breaking" "ombrydning")
("breve" "petit")
("british" "britisk")
("broken white" "brækket hvid")
("brown" "brun")
("browse" "gennemse")
("browse web" "kig på internettet")
("browser" "browser")
("buffer" "buffer")
("bulgarian" "bulgarsk")
("bullet" "bullit")
("bullets" "bulitter")
("by" "af")
("by typing" "ved maskinskrivning")
("bytes free" "bytes ubrugt")
("bytes used" "bytes brugt")
("calligraphic" "kalligrafisk")
("cancel" "annullér")
("caps-lock key" "skiftelås tasten")
("case" "tilfælde")
("cc" "kapitler")
("cell" "celle")
("cell background color" "celle baggrundsfarve")
("cell border" "cellekant")
("cell height" "cellehøjde")
("cell operation mode" "celle virkningsmåde")
("cell width" "cellebredde")
("center" "centrér")
("center text" "centrér tekst")
("centered" "centreret")
("centered block" "centreret blok")
("centered tabular" "centeret tabel")
("change border of cell" "skift cellekant")
("change cell operation mode" "skrift cellefunktion")
("change log" "seneste ændringer")
("changes" "ændringer")
("chapter" "kapitel")
("check" "kontrollér")
("check text for spelling errors" "kontrollér tekst for stavefejl")
("chinese" "kinesisk")
("choice" "valg")
("citation" "citat")
("cite" "citér")
("class" "klasse")
("clear" "slet")
("clear selection" "slet det valgte")
("clipped" "beskåret")
("clipped and magnified" "beskåret og forstørret")
("clipped and resized" "beskåret og omformet")
("clone" "duplikér")
("clone window" "duplikér vindue")
("close" "luk")
("close TeXmacs" "luk Texmacs")
("close buffer" "luk buffer")
("close session" "luk session")
("close window" "luk vindue")
("closing" "lukker")
("code" "kode")
("color" "farve")
("column" "søjle")
("column contains glued items" "søjle indeholder faste genstande")
("compact" "kompakt")
("compatibility with other formats" "kompatiblilitet med andre formater")
("compile article" "sammensæt artikel")
("compile book" "sammensæt bog")
("compile buffer" "sammensæt buffer")
("compile project" "sammensæt projekt")
("complex" "kompleks")
("concrete" "concrete")
("condensed" "sammentrukket")
("condition" "betingelse")
("configuration" "konfiguration")
("content" "indhold")
("content tag" "indholdstype")
("context dependent icons" "kontekstafhængige ikoner")
("continuation of" "fortsættelse af")
("convention" "konvention")
("converters to other data formats" "oversættere til andre formater")
("copy" "kopiér")
("copy text" "kopiér tekst")
("copy to" "kopiér til")
("copying" "kopierer")
("corollary" "resultat")
("correct text" "ret tekst")
("cursors" "indsætningsmærker")
("custom tab" "tilpasset tabulator")
("customizing TeXmacs" "tilpas TeXmacs")
("customizing the TeXmacs styles" "tilpasser TeXmacs's opsætninger")
("custum tab" "tilpasset tabulator")
("cut" "klip")
("cut text" "klip tekst")
("cut to" "klip til")
("cypriot" "cypriot")
("cyrillic" "kyrillisk")
("cyrillic input method" "kyrillisk input metode")
("cyrillic italic right" "kyrillisk kursiv højre")
("czech" "tjekkisk")
("dancers" "dansere")
("danish" "dansk")
("dark grey" "mørk grå")
("dash" "bindestreg")
("dashes" "bindestreger")
("data conversion" "data ")
("data format" "data-format")
("date" "dato")
("deactivate" "deaktivér")
("deactivate table" "deaktivér tabel")
("december" "december")
("decorate atoms" "dekorationsatomer")
("default" "standard")
("default padding" "standardmellemrum")
("definition" "definition")
("delete" "slet")
("delete column" "slet søjle")
("delete row" "slet række")
("denominator" "nævner")
("description" "beskrevet liste")
("destination" "destination")
("detach" "adskil")
("determinant" "determinant")
("devangari" "devangari")
("developers guide" "udviklerguide")
("directory" "mappe")
("disable first indentation" "slå første indrykning fra")
("disable first indentation after" "slå 'første indrykning efter' fra")
("disable first indentation before" "slå 'første indrykning før' fra")
("disable indentation" "slå indrykning fra")
("disable indentation after" "slå 'indrykning efter' fra")
("disable indentation before" "slå 'indrykning før' fra")
("disallow" "nægt")
("distribute unused space" "fordel ubrugt plads")
("div" "div")
("do not remap" "ingen ændring")
("document" "dokument")
("document format" "dokumentformat")
("document style" "dokumenttypografi")
("document styles" "dokumenttypografier")
("documentation" "dokumentation")
("documents are trees" "dokumenter er træer")
("dot" "prik")
("dots" "prikker")
("double stroke" "dobbelt streg")
("down" "ned")
("dpi" "dpi")
("duplicate" "dublér")
("dutch" "hollandsk")
("dynamic libraries" "dynamiske biblioteker")
("edit" "rediger")
("editing tools" "redigeringsværktøjer")
("email" "e-post")
("emphasize" "fremhæv")
("emphasize text" "skriv fremhævet tekst")
("empty box" "tøm kasse")
("enable first indentation" "slå første indrykning til")
("enable first indentation after" "slå 'første indrykning efter' til")
("enable first indentation before" "slå 'første indrykning før' til")
("enable indentation" "slå indrykning til")
("enable indentation after" "slå 'indrykning efter' til")
("enable indentation before" "slå 'indrykning før' til")
("encl" "encl")
("end" "slut")
("english" "engelsk")
("enter a title" "skriv en titel")
("enumerate" "nummereret liste")
("enumerate|Alpha" "nummereret|Alpha")
("enumerate|Roman" "nummereret|Roman")
("enumerate|alpha" "nummereret|alpha")
("enumerate|roman" "nummereret|roman")
("env" "omr")
("environment" "område")
("epilogue" "epilog")
("equal" "lig")
("equation" "ligning")
("equations" "ligninger")
("equivalent for" "lig med")
("error" "fejl")
("esperanto" "esperanto")
("etruscan" "etruskisk")
("evaluate" "udregn")
("evaluate scheme expression" "udregn scheme udtryk")
("even page footer" "lige siders sidefod")
("even page header" "lige siders sidehoved")
("even page margin" "lige sider margen")
("even page text" "lige siders tekst")
("exact horizontal" "nøjagtig vandret")
("exact mode" "nøjagtig")
("exam" "eksamen")
("example" "eksempel")
("exclusive" "eksklusiv")
("exclusive or" "eksklusiv eller")
("executable" "udførbar")
("execute" "udfør")
("execute a TeXmacs command" "udfør en TeXmacskommando")
("execute system command" "udfør en systemkommando")
("executive" "executive")
("exercise" "øvelse")
("expand" "udvid")
("explained" "forklaret")
("export" "eksportér")
("export as" "eksportér som")
("extend or normal" "udvid eller normal")
("extern " "ekstern")
("extra" "ekstra")
("extract format" "træk format ud")
("family" "familie")
("february" "februar")
("figure" "figur")
("file" "arkiv")
("file name" "dokumentnavn")
("file not found" "kunne ikke finde dokument")
("find next match" "find næste")
("find text" "find tekst")
("finnish" "finsk")
("first contact" "første kontakt")
("first indentation" "første indrykning")
("first item" "første genstand")
("first page" "første side")
("first start" "første begyndelse")
("flat" "flad")
("flexibility" "fleksibilitet")
("flexibility factor for vertical spacing" "fleksibilitetsfaktor for lodrette mellemrum")
("floating figure" "flydende figur")
("floating object" "flydende objekt")
("floating table" "flydende tabel")
("fold" "fold")
("folded" "foldet")
("font" "skrift")
("font base size" "basis skriftstørrelse")
("font dpi" "skrift dpi")
("font family" "skriftfamilie")
("font name" "skriftnavn")
("font series" "skriftserie")
("font shape" "skriftform")
("font size" "skriftstrørrelse")
("font variant" "skriftvariant")
("fonts" "skrifter")
("footer" "sidefod")
("footnote" "fodnote")
("for" "for")
("foreground" "forgrund")
("foreign" "udlandsk")
("format" "format")
("formatted date" "formateret dato")
("formula" "formel")
("formula style" "formeltypografi")
("forward replace" "forlæns erstat")
("forward search" "forlæns søgning")
("fraction" "brøk")
("french" "fransk")
("full manuals" "hele brugerhåndbøger")
("function" "funktion")
("further customization" "yderligere tilpasning")
("future changes" "fremtidige ændringer")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs kommer uden nogen former for garanti")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs er distriburet under GNU general public license")
("general architecture of TeXmacs" "TeXmacs' overordnede struktur")
("general negation" "generel negation")
("generating font file" "genererer skrifthjælpefil")
("generic" "standard")
("georgian" "georgisk")
("german" "tysk")
("getting started" "kom igang")
("glossary" "ordforklaring")
("glossary entry" "ordforklaringspunkt")
("glue" "lim")
("glue decorations" "lim dekorationer")
("go" "gå")
("gothic" "gotisk")
("graphical interface" "grafisk grænseflade")
("grave" "accent grave")
("greater" "større")
("greater or equal" "større eller lig")
("greek" "græsk")
("greek letter" "græsk bogstav")
("green" "grøn")
("grey" "grå")
("group" "gruppe")
("happy typing" "glædelig skrivning")
("has been aborted" "er blevet afbrudt")
("has completed its task" "har afsluttet sin opgave")
("hat" "hat")
("header" "sidehoved")
("header and footer" "sidehoved og sidefod")
("hebrew" "hebraisk")
("height" "højde")
("height is exactly the specified height" "højde er præcis den specificerede højde")
("height is maximum of specified height and box height" "højde er maksimum af den specificerede højde og kassehøjde")
("height is minimum of specified height and box height" "højde er minimum af den specificerede højde og kassehøjde")
("height magnification" "højde forstørrelse")
("help" "hjælp")
("help me" "hjælp mig")
("help us" "hjælp os")
("here" "her")
("home" "hjem")
("horizontal" "vandret")
("horizontal cell alignment" "vandret cellejustering")
("horizontal ink separation" "vandret blækseperation")
("horizontal part" "vandret del")
("horizontal position" "horisontal placering")
("horizontal space" "vandret mellemrum")
("horizontal table alignment" "vandret tabeljustering")
("horizontally align cell to the base" "justér celle til bunden vandret")
("horizontally center the cell" "centrér celle vandret")
("how much longer may pages become" "hvor meget længere må sider være")
("how much shorter may pages become" "hvor meget kortere må sider være")
("huge" "enorm")
("hungarian" "ungarnsk")
("hyperlink" "hyperlink")
("hyphenation" "orddeling")
("icelandic" "islandsk")
("if" "hvis")
("image" "billede")
("image links" "billedelinks")
("implementation" "implementation")
("import" "importér")
("improving the current implementation" "forbedring af den nuværende implementation")
("inactive" "inaktiv")
("include" "inkludér")
("include a document" "inkludér et dokument")
("include file" "inkludér et arkiv")
("inclusion into TeXmacs" "inklusioner i TeXmacs")
("inclusions" "inklusioner")
("indent" "indrykning")
("indentation flag" "indrykningsflag")
("index" "index")
("index entry" "indexpunkt")
("index level" "indexniveau")
("insert" "indsæt")
("insert Pr" "indsæt Pr")
("insert a TeXmacs symbol" "indsæt et TeXmacssymbol")
("insert a big operator" "indsæt en stor operator")
("insert a binary operation" "indsæt en binær operator")
("insert a binary relation" "indsæt en binær relation")
("insert a blackboard bold character" "indsæt et fedt blackboardtegn")
("insert a bold calligraphic character" "indsæt et fedt kalligrafisk tegn")
("insert a bold character" "indsæt et fedt tegn")
("insert a calligraphic character" "indsæt et kalligrafisk tegn")
("insert a fraction" "indsæt en brøk")
("insert a fraktur character" "indsæt et frakturtegn")
("insert a greek character" "indsæt et græsk bogstav")
("insert a large left delimiter" "indsæt et stort venstre afgrænsetegn")
("insert a large right delimiter" "indsæt et stort højre afgrænsetegn")
("insert a large separator" "indsæt en stor adskiller")
("insert a left subscript" "indsæt venstre indextegn")
("insert a link" "indsæt et link")
("insert a miscellaneous symbol" "indsæt diverse symboler")
("insert a new branch" "indsæt en ny forgrening")
("insert a new item" "indsæt et nyt element")
("insert a picture" "indsæt et billede")
("insert a square root" "indsæt kvadratrod")
("insert a table" "indsæt en tabel")
("insert a table or a matrix" "indsæt en tabel eller en matrix")
("insert a wide symbol above" "indsæt et bredt symbol over")
("insert a wide symbol below" "indsæt et bredt symbol under")
("insert an" "indsæt en")
("insert an accent" "indsæt en accent")
("insert an arrow" "indsæt en pil")
("insert an environment" "indsæt et område")
("insert an n" "indsæt en n")
("insert appendix" "indsæt appendix")
("insert arccos" "indsæt arccos")
("insert arcsin" "indsæt arcsin")
("insert arctan" "indsæt arctan")
("insert arg" "indsæt arg")
("insert argument" "indsæt argument")
("insert automatically generated content" "indsæt automatisk genereret indhold")
("insert big contour integral" "indsæt stort kant-integrale")
("insert big coproduct" "indsæt stort co-product")
("insert big direct sum" "indsæt stor direkte sum")
("insert big dotted point" "indsæt stor prik-punkt")
("insert big integral" "indsæt stort integrale")
("insert big intersection" "indsæt stort skæringspunkt")
("insert big logical and" "indsæt stor logisk og")
("insert big logical or" "indsæt stor logisk eller")
("insert big product" "indsæt stort produkt")
("insert big square union" "indsæt stort kvardratenhed")
("insert big summation" "indsæt stor summation")
("insert big tensor product" "indsæt stort tensorprodukt")
("insert big union" "indsæt stor fællesmængde")
("insert big union sum" "indsæt stor fællessum")
("insert big vertical space" "indsæt stor lodret afstand")
("insert chapter" "indsæt kapitel")
("insert column" "indsæt søjle")
("insert column to the left" "indsæt søjle til venstre")
("insert column to the right" "indsæt søjle til højre")
("insert cos" "indsæt cos")
("insert cosh" "indsæt cosh")
("insert cot" "indsæt cot")
("insert coth" "indsæt coth")
("insert csc" "indsæt csc")
("insert deg" "indsæt deg")
("insert det" "indsæt det")
("insert dim" "indsæt dim")
("insert dollar" "indsæt dollar")
("insert equation" "indsæt ligning")
("insert executable markup" "indsæt udførbar markup")
("insert exp" "indsæt exp")
("insert footnote" "indsæt fodnote")
("insert formula" "indsæt formel")
("insert gcd" "indsæt gcd")
("insert hom" "indsæt hom")
("insert horizontal interword space" "indsæt vandret mellemrum mellem ord")
("insert image" "indsæt billede")
("insert inactive markup" "indsæt inaktiv markup")
("insert inf" "indsæt inf")
("insert ker" "indsæt ker")
("insert lg" "indsæt lg")
("insert lim" "indsæt lim")
("insert liminf" "indsæt liminf")
("insert limsup" "indsæt limsup")
("insert ln" "indsæt ln")
("insert log" "indsæt log")
("insert mathematics" "indsæt formler")
("insert max" "indsæt maks")
("insert medium horizontal space" "indsæt medium vandret mellemrum")
("insert medium vertical space" "indsæt medium lodret mellemrum")
("insert min" "indsæt min")
("insert negative horizontal space" "indsæt negativt vandret mellemrum")
("insert new item or number" "indsæt nyt punkt eller nummer")
("insert new rows or columns" "indsæt nye rækker eller søjler")
("insert or delete rows or columns" "indsæt eller slet rækker eller søjler")
("insert row" "indsæt række")
("insert row above" "indsæt række over")
("insert row below" "indsæt række under")
("insert sec" "indsæt sec")
("insert section" "indsæt afsnit")
("insert sharp" "indsæt sharp")
("insert sin" "indsæt sin")
("insert sinh" "indsæt sinh")
("insert small horizontal space" "indsæt lille vandret mellemrum")
("insert small vertical space" "indsæt lille lodret mellemrum")
("insert structural markup" "indsæt strukturel markup")
("insert subsection" "indsæt underafsnit")
("insert subsubsection" "indsæt underunderafsnit")
("insert sup" "indsæt sup")
("insert tan" "indsæt tan")
("insert tanh" "indsæt tanh")
("insert thick horizontal space" "indsæt tyk vandret mellemrum")
("interfacing" "grænseflader")
("interfacing TeXmacs with other systems" "TeXmacs og andre systemer")
("interjection" "interjektion")
("interline separation" "seperation mellem linier")
("interline space" "mellemrum mellem linier")
("internationalization" "internationalisering")
("interparagraph space" "mellemrum mellem paragraffer")
("interrupt execution" "afbryd kørsel")
("introduction" "introduktion")
("invisible" "usynlig")
("invisible citation" "usynlig citering")
("irish" "irsk")
("is running" "kører")
("is tuple" "er en tupel")
("ispell does not respond" "ispell reagerer ikke")
("ispell is already busy" "ispell har travlt nok i forvejen")
("italian" "italiensk")
("italic" "kursiv")
("italic right" "højre kursiv")
("itemize" "liste")
("january" "januar")
("japanese" "japansk")
("july" "juli")
("june" "juni")
("justified" "justeret")
("justify text" "justér tekst")
("key" "tast")
("keyboard" "tastatur")
("keyboard equivalent" "tastaturgenvej")
("keyboard modifiers" "kombitaster")
("keyboard shortcut" "tastaturgenvej")
("keymaps" "tastaturlayout")
("keyword" "nøgleord")
("keywords" "nøgleord")
("kill" "kill")
("known bugs" "kendte fejl")
("label" "mærke")
("landscape" "landskab")
("language" "sprog")
("large" "stor")
("large closing bracket" "stor lukkeparantes")
("large delimiter" "stor afgrænsetegn")
("large opening bracket" "stor åbneparantes")
("large separator" "stor adskiller")
("last page" "sidste side")
("latex command" "latex kommando")
("latin" "latin")
("layout" "layout")
("left" "venstre")
("left arrow" "venstrepil")
("left border" "venstre ramme")
("left margin" "venstre margen")
("left padding" "venstre mellemrum")
("left prime" "venstre primære")
("left aligned" "venstrejusteret")
("left slanted" "venstre skrånende")
("left subscript" "indextegn til venstre")
("left superscript" "potenstegn til venstre")
("left surrounding" "venstre nærhed")
("legal" "legal")
("lemma" "lemma")
("length" "længde")
("less" "mindre")
("less or equal" "mindre eller lig")
("letter" "brev")
("license" "licens")
("light" "lys")
("light grey" "lys grå")
("limitations" "begrænsninger")
("limits" "grænser")
("line" "linie")
("line break" "linieskift")
("line stretch" "liniestrækning")
("link" "link")
("link image" "link billede")
("list" "liste")
("list of figures" "figurliste")
("list of tables" "tabelliste")
("load" "indlæs")
("load LaTeX file" "åben LaTeX-dokument")
("load TeX file" "åben TeX-dokument")
("load TeXmacs file" "åben TeXmacs-dokument")
("load TeXmacs style file" "indlæs TeXmacs-typografi")
("load a file" "åben et arkiv")
("load buffer" "åben en buffer")
("load file" "åben arkiv")
("load html file" "åben html-dokument")
("load image" "indlæs billede")
("load in new window" "åben i nyt vindue")
("load latex file" "åben latex-dokument")
("load more recent autosave file" "åben nyere automatisk gemt udgave")
("load tex file" "åben tex-dokument")
("load verbatim file" "åben tekst-dokument")
("loaded" "indlæst")
("long" "lang")
("look and feel" "udseende")
("look up" "slå op")
("lower border" "nedre ramme")
("macro" "makro")
("magenta" "magenta")
("magic" "magisk")
("magnification" "forstørrelse")
("magnified" "forstørret")
("main" "primær")
("main icon bar" "primære ikonbjælke")
("major changes" "store ændringer")
("make a page insertion" "sideindsætning")
("make a subscript" "indsæt et indextegn")
("make a superscript" "indsæt et potenstegn")
("make acute" "indsæt aigu")
("make bar" "lav bjælke")
("make check" "lav check")
("make fraction" "indsæt brøk")
("make grave" "indsæt accent grave")
("make hat" "indsæt hat")
("make label" "indsæt mærke")
("make negation" "indsæt negation")
("make page reference" "indsæt sidehenvisning")
("make reference" "indsæt henvisning")
("make square root" "kvadratrod")
("make tilde" "indsæt tilde")
("make title" "indsæt titel")
("make vector" "indsæt vektor")
("making donations" "donationer")
("manual" "brugerhåndbog")
("map to" "ændrer til")
("march" "marts")
("margins" "margener")
("margins as on paper" "margener som på papir")
("master" "hoveddokument")
("master file" "hoveddokument")
("math" "formler")
("math font" "formelskrift")
("math font family" "formelskriftfamilie")
("math font series" "formelskriftserie")
("math font shape" "formelskriftform")
("mathematical" "matematisk")
("mathematical formulas" "matematiske formler")
("mathematical typesetting" "matematisk typografi")
("mathematics" "formler")
("matrix" "matrix")
("maximal number of columns" "maksimale antal søjler")
("maximal number of rows" "maksimale antal rækker")
("maximum mode" "maksimal")
("may" "maj")
("medium" "medium")
("medium skip" "medium mellemrum")
("meminfo" "meminfo")
("merge" "sammenlæg")
("messy" "messy")
("meta key" "meta tast")
("middle" "midten")
("minimal number of columns" "minimale antal søjler")
("minimal number of rows" "minimale antal rækker")
("minimum mode" "minimal")
("minus" "minus")
("miscellaneous" "diverse")
("mod" "mod")
("mode" "tilstand")
("modifier" "kombitast")
("modify cell alignment" "ændring af cellejustering")
("modify cell border" "ændring af cellekant")
("modify cell padding" "ændring af cellemellemrum")
("modify cell size" "ændring af cellestørrelse")
("modify table border" "ændring af tabelkant")
("modify table padding" "ændring af tabelmellemrum")
("mongolian" "mongolsk")
("more information about GNU TeXmacs can be found in the help" "mere information om GNU TeXmacs kan findes i hjælp")
("mosaic" "mosaik")
("move down" "flyt ned")
("move object" "flyt objekt")
("move to the right when finished" "flyt til højre bagefter")
("move up" "flyt op")
("n-th" "n-te")
("n-th root" "n-te rod")
("name" "navn")
("negation" "negation")
("new" "ny")
("new buffer" "ny buffer")
("new column" "ny søjle")
("new item" "nyt punkt")
("new line" "ny linie")
("new number" "nyt nummer")
("new page" "ny side")
("new page before" "ny side før")
("new paragraph" "ny paragraf")
("new roman" "new roman")
("new row" "ny række")
("new table" "ny tabel")
("next line" "næste linie")
("no" "nej")
("no changes need to be saved" "der er ikke brug for at arkivere ændringer")
("no dictionary for" "ingen ordbog til")
("no first indentation" "ingen første indrykning")
("no indentation" "ingen indrykning")
("no line break" "ingen linieskift")
("no matches found" "ingen magen til fundet")
("no more matches for" "ikke flere mage til")
("no more redo information available" "ikke flere gentagetrin tilgængelige")
("no more undo information available" "ikke flere fortrydelsestrin tilgængelige")
("no name" "uden navn")
("no page break after" "intet sideskift efter")
("no page break before" "intet sideskift før")
("no spelling errors found in text" "der blev ikke fundet nogen stavefejl i teksten")
("no style" "ingen typografi")
("none" "ingen")
("normal" "normal")
("norwegian" "norsk")
("not" "ikke")
("not equal" "ikke lig")
("not found" "ikke fundet")
("notation" "notering")
("note" "note")
("november" "november")
("number" "nummer")
("number of columns" "antal spalter")
("number equation" "nummerér ligning")
("numbered equation" "nummereret ligning")
("numbered equations" "nummererede ligninger")
("numerator" "nummerator")
("numeric" "numerisk")
("objectives" "mål")
("occurrences" "forekomster")
("october" "oktober")
("odd page footer" "ulige siders sidefod")
("odd page header" "ulige siders sidehoved")
("odd page margin" "ulige siders margen")
("odd page text" "ulige siders tekst")
("off" "fra")
("ok" "ok")
("old english" "gammelt engelsk")
("old slavonic" "gammel slavisk")
("old style" "gammelt udseende")
("on" "til")
("on cells" "på celler")
("on columns" "på søjler")
("on entire table" "på hele tabellen")
("on rows" "på rækker")
("one spelling error has been corrected" "der er rettet én stavefejl")
("online documentation" "online dokumentation")
("online help" "online hjælp")
("open" "åben")
("open a new buffer" "åben en ny buffer")
("open new window" "åben nyt vindue")
("opening" "åbner")
("operation on named selection" "operation på det nævnte valgte")
("operation on primary selection" "operation på det primært valgte")
("operation on secondary selection" "operation på det sekundært valgte")
("operation on ternary selection" "operation på det tertiært valgte")
("optical" "optisk")
("option" "indstilling")
("options" "indstillinger")
("or" "eller")
("orange" "orange")
("orientation" "orientering")
("origin" "oprindelse")
("original welcome message" "original velkomstbesked")
("other" "andre")
("other pages" "andre sider")
("other projects" "andre projekter")
("other style" "anden typografi")
("outlined roman" "kontureret serif")
("over" "over")
("overbrace" "overbrace")
("overline" "linie over")
("padding" "mellemrum")
("page" "side")
("page bottom margin" "nederste sidemargen")
("page break" "sideskift")
("page break before" "sideskift før")
("page height" "side højde")
("page insertion" "sideindsætning")
("page layout" "sidelayout")
("page number text" "sidenummertekst")
("page numbering" "sidenummerering")
("page reference" "sidehenvisning")
("page right margin" "højre sidemargen")
("page setup" "sideopsætning")
("page top margin" "øverste sidemargen")
("page type" "side type")
("page width" "sidebredde")
("paper" "papir")
("paper type" "papirtype")
("papyrus" "papyrus")
("paragraph" "paragraf")
("paragraph mode" "paragraftilstand")
("paragraph width" "paragrafbredde")
("part" "del")
("past changes" "tidligere ændringer")
("paste" "sæt ind")
("paste from" "sæt ind fra")
("paste text" "indsæt tekst")
("path" "sti")
("perform operations on cells" "udfør handlinger på enkelte celler")
("perform operations on columns" "udfør handlinger på søjler")
("perform operations on entire table" "udfør handlinger på hele tabellen")
("perform operations on rows" "udfør handlinger på rækker")
("permanent" "permanent")
("person" "person")
("personal dictionary has been modified" "brugerordbogen er blevet ændret")
("phantasy" "fantasi")
("philosophy" "filosofi")
("phoenician" "phønikisk")
("phonetic" "phonetisk")
("pink" "pink")
("plain block" "normal blok")
("plain tabular" "normal tabel")
("planned changes" "planlagte ændringer")
("plans for the future" "fremtidsplaner")
("please" "venligst")
("please wait" "vent venligst")
("plus" "plus")
("polish" "polsk")
("porting TeXmacs to other platforms" "overføre TeXmacs til andre platforme")
("portrait" "portræt")
("portuguese" "portugisisk")
("position" "position")
("position float" "placér flyder")
("position floating object" "placér flydende objekt")
("position the table" "placér tabellen")
("postscript" "postscript")
("postscript image" "postscript-billede")
("pre-alpha release" "præaplha udgave")
("preamble" "forord")
("preamble mode" "forords tilstand")
("preferences" "indstillinger")
("presentation" "præsentation")
("presentation mode" "præsentationstilstand")
("preview before printing" "se eksempel før udskrivning")
("preview with ghostview" "se eksempel med ghostview")
("primary" "primær")
("prime" "første")
("print" "udskriv")
("print all" "udskriv alle")
("print all to file" "udskriv alle til arkiv")
("print page selection" "udskriv det valgte")
("print page selection to file" "udskriv det valgte til arkiv")
("print to postscript file" "udskriv til postscriptarkiv")
("printer" "printer")
("printer dpi" "printer opløsning")
("printing command" "udskrivnings kommando")
("problem" "probelm")
("professional" "professionel")
("prog" "prog")
("prog font" "progskrift")
("prog font family" "progskriftfamilie")
("prog font series" "progskriftserie")
("prog font shape" "progskriftform")
("program" "program")
("program mode" "program tilstand")
("programming" "programmering")
("progressive" "progressivt")
("project" "projekt")
("projects" "projekter")
("prologue" "prolog")
("prompt on scripts" "spørg ved scripts")
("proof" "bevis")
("proportional" "proportionel")
("proportional typewriter" "proportionel skrivemaskine")
("proposition" "forslag")
("query replace" "søg erstat")
("quit" "slut")
("quotation" "citat")
("quote" "citering")
("range" "interval")
("really close it" "vil du virkelig lukke den")
("really huge" "virkelig enorm")
("really quit" "vil du virkelig slutte")
("red" "rød")
("redo" "gentag")
("redo undone changes" "gentag fortrudte handlinger")
("reduce bottom margin by" "reducér bund margen med")
("reduce left margin by" "reducér venstre margen med")
("reduce margins" "reducér margener")
("reduce right margin by" "reducér højre margen med")
("reduce top margin by" "reducér top margen med")
("reduction even page margin" "reduktion af lige siders margen")
("reduction odd page margin" "reduktion af ulige siders margen")
("reduction page bottom margin" "reduktion af bundmargen")
("reduction page right margin" "reduktion af højre margen")
("reduction page top margin" "reduktion af topmargen")
("reference" "henvisning")
("references" "henvisninger")
("regular" "normal")
("release" "udgave")
("reload" "genindlæs")
("remark" "bemærkning")
("remove number" "fjern nummer")
("remove this switch" "fjern denne kontakt")
("renumber this page" "renummerér denne side")
("repeat object" "gentag objekt")
("replace" "erstat")
("replace by" "erstat med")
("replaced" "erstattet")
("replaced one occurrence" "én forekomst erstattet")
("reset" "nulstil")
("resize object" "skalér")
("resized" "skaleret")
("return" "retur")
("revert" "hent seneste")
("revert buffer" "hent seneste buffer")
("right" "højre")
("right arrow" "højrepil")
("right border" "højre ramme")
("right margin" "højre margen")
("right padding" "højre mellemrum")
("right aligned" "højrejusteret")
("right subscript" "indextegn til højre")
("right superscript" "potenstegn til højre")
("right surrounding" "højre nærhed")
("rigid" "stift")
("rigid horizontal" "vandret stift")
("rigid space" "stift mellemrum")
("romanian" "romænsk")
("root" "root")
("rotate backward" "rotér forlæns")
("rotate forward" "rotér baglæns")
("row" "række")
("row contains glued items" "række indeholder faste genstande")
("runic" "runer")
("running author" "løbende forfatter")
("running title" "løbende titel")
("russian" "russisk")
("sample" "eksempel")
("sans serif" "sans serif")
("save" "arkivér")
("save TeXmacs file" "arkivér TeXmacs-dokument")
("save TeXmacs style file" "arkivér TeXmacs-typografidokument")
("save as" "arkivér som")
("save as LaTeX" "arkivér som LaTeX")
("save as TeX" "arkivér som TeX")
("save buffer" "arkivér buffer")
("save buffer as" "arkivér buffer som")
("save file" "arkivér dokument")
("save html file" "arkivér html-dokument")
("save image" "arkivér billede")
("save latex file" "arkivér latex-dokument")
("save tex file" "arkiver tex-dokument")
("save this buffer" "arkivér denne buffer")
("save verbatim file" "arkivér tekst-dokument")
("saved" "arkiveret")
("screen layout" "skærmlayout")
("screen margins" "skærmmargener")
("script" "index- og potenstegn")
("script above" "tegn over")
("script below" "tegn under")
("script script size" "indexes index størrelse")
("script size" "indexstørrelse")
("scripts not accepted" "scripts er ikke tilladt")
("search" "søg")
("searching" "søger")
("secondary" "sekundær")
("section" "afsnit")
("security" "sikkerhed")
("see" "se")
("select a document style" "vælg en dokumenttypografi")
("select a foreground color" "vælg en forgrundsfarve")
("select a language" "vælg et sprog")
("selected region" "valgte område")
("selection" "det valgte")
("selections" "det valgte")
("seminar" "seminar")
("separation between lines" "adskillelse mellem linier")
("separation between paragraphs" "adskillelse mellem paragraffer")
("separator" "seperator")
("september" "september")
("serb" "serbisk")
("series" "serier")
("series|right" "serier|højre")
("session" "session")
("session name" "sessionsnavn")
("session type" "sessionstype")
("sessions" "sessioner")
("set" "indstil")
("set background color of cell" "indstil cellebaggrundsfarve")
("set cell mode" "indstil celletilstand")
("set extension center" "indstil udvidelsescentrum")
("set height" "indstil højde")
("set height of cell" "indstil cellehøjde")
("set margins" "indstil margener")
("set n" "indstil n")
("set paragraph margins" "indstil paragrafmargener")
("set paragraph mode" "indstil paragrafjustering")
("set printer dpi" "indstil printer opløsning")
("set printing command" "indstil udskrivningskommando")
("set span" "indstil spænd")
("set special cell properties" "indstil særlige celleegenskaber")
("set special table properties" "indstil særlige tabelegenskaber")
("set text width" "indstil tekstbredde")
("set width" "indstil bredde")
("set width of cell" "indstil cellebredde")
("settings" "indstillinger")
("setup printer" "indstil printer")
("shape" "form")
("shift-down" "skift-ned")
("shift-right" "skift-op")
("show" "vis")
("show header and footer" "vis sidehoved og -fod")
("show on screen" "vis på skærmen")
("shrinking factor" "formindskelsesfaktor")
("signature" "underskrift")
("size" "størrelse")
("size limits" "grænser for størrelsen")
("slanted" "skrånende")
("sloppy" "sjusket")
("small" "lille")
("small caps" "små bogstaver")
("small figure" "lille figur")
("small skip" "lille mellemrum")
("small table" "lille tabel")
("source code" "kildekode")
("space" "mellemrum")
("space between lines" "mellemrum mellem linier")
("space between paragraphs" "mellemrum mellem paragraffer")
("spacing" "mellemrum")
("spanish" "spansk")
("special" "særlig")
("special cell properties" "særlige celleegenskaber")
("special table properties" "særlige tabelegenskaber")
("specific" "specifik")
("spell" "stavekontrol")
("spell checking complete" "stavekontrol afsluttet")
("spelling error" "stavefejl")
("spelling errors have been corrected" "stavefejl er blevet rettet")
("split" "det")
("square root" "kvadratrod")
("start" "start")
("start a new chapter" "begynd på et nyt kapitel")
("start a new section" "begynd på et nyt afsnit")
("start an interactive session" "start en interaktiv session")
("status bar" "statusbjælke")
("stretchable" "strækbar")
("stretchable horizontal" "vandret strækbar")
("stretchable vertical" "lodret strækbar")
("stroke" "indtastning")
("strokes" "indtastninger")
("strong" "kraftig")
("structural" "strukturel")
("style" "typografi")
("styles" "typografier")
("sub" "under")
("subparagraph" "underparagraf")
("subscript" "indextegn")
("subsection" "underafsnit")
("subsub" "underunder")
("subsubsection" "underunderafsnit")
("summary" "opsummering")
("summary of the principal TeXmacs tags" "opsummering af de vigtigste TeXmacs-tags")
("superpose" "overpræg")
("superposed" "overpræget")
("superscript" "potenstegn")
("swedish" "svensk")
("switch" "kontakt")
("switch to first" "skift til første")
("switch to formula style" "skift til formeltypografi")
("switch to last" "skift til sidste")
("switch to next" "skift til næste")
("switch to previous" "skift til forrige")
("switching and folding" "kontakter og foldning")
("symbol" "symbol")
("system environment variables" "systemområdevariable")
("tab" "tabulator")
("table" "tabel")
("table command" "tabelkommando")
("table of contents" "indholdsfortegnelse")
("tables" "tabeller")
("tabular" "tabel")
("tabular material" "tabeller")
("teXmacs as an interface" "teXmacs som en grænseflade")
("teXmacs fonts" "teXmacs skrifter")
("teXmacs notice" "teXmacsnote")
("teXmacs style files" "teXmacs typografidokumenter")
("ternary" "tertiær")
("test" "prøve")
("tex" "tex")
("text" "tekst")
("text font" "tekstskrift")
("text height correction" "korrektion af teksthøjde")
("text width" "tekstbredde")
("texts" "tekster")
("th century bc" "te århundrede fkr")
("th root" "te rod")
("thai" "thailandsk")
("the TeXmacs authors" "TeXmacs' forfattere")
("the application did not send its usual startup banner" "programmet gav os ikke det normale startbanner")
("the application does not reply" "programmet svarer ikke")
("the application is already running" "programmet kører allerede")
("the boxes produced by the typesetter" "de af typesetteren fremstillede kasser")
("the graphical user interface" "det grafiske brugerflade")
("the leaves of TeXmacs trees" "bladene på TeXmacstræet")
("the mycas example" "mycas eksemplet")
("the primitive TeXmacs constructs" "de basale TeXmacskonstruktioner")
("the standard TeXmacs styles" "standard typografierne i TeXmacs")
("theorem" "theorem")
("there are unsaved documents" "der er dokumenter der ikke er arkiveret")
("this document has not been saved" "denne buffer er ikke arkiveret")
("this document has been produced using" "dette dokument er fremstillet med")
("this line" "denne linie")
("this page" "denne side")
("tilda" "tilde")
("tilde" "tilde")
("times" "times")
("tiny" "lillebitte")
("title" "titel")
("to the left" "til venstre")
("to the right" "til højre")
("today" "i dag")
("tools" "redskaber")
("top" "top")
("top border" "øverste kant")
("top level" "øverste niveau")
("top margin" "øvertste margen")
("top padding" "øverste mellemrum")
("translate" "oversæt")
("tree" "træ")
("tuple" "tuple")
("turkish" "tyrkisk")
("tutorial" "vejledning")
("type" "type")
("type a latex command followed by" "skriv en latex kommando fulgt af")
("type body" "skriv brødtekst")
("type denominator" "skriv nævner")
("type numerator" "skriv tæller")
("type script" "skriv script")
("typesetted boxes" "typesettede kasser")
("typewriter" "skrivemaskine")
("typewriter small caps" "små skrivemaskinebogstaver")
("typing a simple text" "at skrive en enkel tekst")
("typing simple texts" "skriv enkle tekster")
("ugaritic" "ugaritisk")
("ukrainian" "ukrainsk")
("underbrace" "underbrace")
("underline" "understreg")
("undo" "fortryd")
("undo last changes" "fortryd de sidste ændringer")
("up" "op")
("update" "opdatér")
("update from web" "opdatér fra internettet")
("update image links" "opdatér billledelinks")
("upper border" "øvre ramme")
("use TeXmacs" "brug TeXmacs")
("use a black color" "brug en sort farve")
("use a blue color" "brug en blå farve")
("use a bold font" "brug en fed skrift")
("use a brown color" "brug en brun farve")
("use a calligraphic font" "brug en kalligrafisk skrift")
("use a green color" "brug en grøn farve")
("use a grey color" "brug en grå farve")
("use a magenta color" "brug en magenta farve")
("use a orange color" "brug en orange farve")
("use a pink color" "brug en pink farve")
("use a red color" "brug en rød farve")
("use a sans serif font" "brug en sans serif skrift")
("use a typewriter font" "brug en skrivemaskineskrift")
("use a white color" "brug en hvid farve")
("use a yellow color" "brug en gul")
("use blackboard bold font" "brug fed blackboard")
("use bold font series" "brug den fede skriftserie")
("use calligraphical font" "brug kalligrafisk skrift")
("use footnote font size" "brug fodnoteskriftstørrelse")
("use fraktur font" "brug fraktuskrift")
("use huge font size" "brug enorm skriftstørrelse")
("use italic font shape" "brug skråstillet skriftform")
("use large font size" "brug stor skriftstørrelse")
("use left hand column as border" "brug venstre søjle som kant")
("use medium font series" "brug medium skriftserier")
("use normal font size" "brug normal skriftstørrelse")
("use package" "brug pakke")
("use paragraph width" "brug paragrafbredde")
("use really huge font size" "brug virkelig enorm skriftstørrelse")
("use right font shape" "brug højre skriftform")
("use right hand column as border" "brug højre søjle som kant")
("use roman font family" "brug serif skriftfamilie")
("use row above as border" "brug rækken over som kant")
("use row below as border" "brug rækken under som kant")
("use sans serif font family" "brug sans serif skriftfamilie")
("use script font size" "brug scriptskriftstørrelse")
("use slanted font shape" "brug skrånende skriftform")
("use small capitals" " små kapitæler")
("use small font size" "brug lille skriftstørrelse")
("use small-caps font shape" "brug små kaptæler skriftform")
("use the blackboard bold font" "brug den fede blackboard-skrift")
("use the fraktur font" "brug frakturskriften")
("use tiny font font size" "brug lillebitte skriftstørrelse")
("use typewriter font family" "brug skrivemaskineskriftfamilien")
("use very large font size" "brug meget stor skriftstørrelse")
("user manual" "brugerhåndbog")
("user provided icons" "ikoner lavet af brugerne")
("users of Cyrillic languages" "brugere af kyrilliske sprog")
("value" "værdi")
("variable" "variabel")
("variant" "variant")
("vector" "vektor")
("verbatim" "ordret")
("verse" "vers")
("vertical" "lodret")
("vertical after" "lodret efter")
("vertical before" "lodret før")
("vertical cell alignment" "lodret cellejustering")
("vertical part" "lodret del")
("vertical position" "lodret placering")
("vertical space" "lodret mellemrum")
("vertical table alignment" "lodret tabeljustering")
("vertically align cell to the base" "justér cellen til bunden lodret")
("vertically center the cell" "centrer cellen lodret")
("very large" "meget stor")
("very small" "meget lille")
("vietnamese" "vietnamesisk")
("view" "vis")
("visible" "synlig")
("warning" "advarsel")
("welcome" "velkommen")
("welcome to GNU TeXmacs" "velkommen til GNU TeXmacs")
("what is new" "nyheder")
("when finished" "når færdigtgjort")
("while" "mens")
("white" "hvid")
("wide accent" "bred accent")
("wide bar" "bred bjælke")
("width" "bredde")
("width is exactly the specified width" "bredde er præcis det specificerede")
("width is maximum of specified width and box width" "bredde er maksimum af det specificerede og kassebredde")
("width is minimum of specified width and box width" "bredde er minimum af det specificerede og kassebredde")
("width magnification" "breddeforstørrelse")
("window" "vindue")
("window height" "vinduehøjde")
("window width" "vinduebredde")
("windows key" "windowstast")
("with" "med")
("write a name" "skriv et navn")
("write bold mathematics" "skriv fede formler")
("write bold text" "skriv fed tekst")
("write italic text" "skriv kursiv tekst")
("write sample text" "skriv eksempeltekst")
("write strong text" "skriv kraftig tekst")
("write typewriter text" "skriv skrivemaskinetekst")
("write verbatim text" "skriv ordret tekst")
("writing data converters" "skriv dataoversættere")
("writing your own style files" "skriv dine egne typografidokumenter")
("yellow" "gul")
("yes" "ja")
("you can also obtain" "du kan også få")
("your document is back in its original state" "dit dokument er tilbage i dets oprindelige tilstand")
("your first interface" "din første grænseflade")
("autosave" "autoarkiver")
("background evaluations" "baggrundsudregninger")
("basic communication using pipes" "simpel kommunikation ved brug af videreføringer")
("completion" "færdiggørelse")
("contact" "kontakt")
("contribute" "deltag")
("disable" "slå fra")
("download" "download")
("fold input field" "fold indtastningsfelt")
("formatted and structured output" "formateret og struktureret resultat")
("hybrid command" "hybridkommando")
("input mode" "indtastningstilstand")
("insert fields" "indsæt felter")
("insert input field above" "indsæt indtastningsfelt over")
("insert input field below" "indsæt indtastningsfelt under")
("insert macro" "indsæt makro")
("insert text field" "indsæt tekstfelt")
("insert value" "indsæt verdi")
("mathematical and customized input" "matematisk og brugerdefineret indtastning")
("mathematical input" "matematisk indtastning")
("miscellaneous features" "diverse funktioner")
("multiline input" "flerlinie indtastning")
("my documents" "mine dokumenter")
("next" "næste")
("no matches found for" "ingen fundne mage til")
("plugin" "udvidelse")
("plugins" "udvidelser")
("previous" "forrige")
("prompts and default input" "prompter og standardindtastninger")
("remove all output fields" "fjern alle resultatfelter")
("remove fields" "fjern felter")
("remove input field" "fjern indtastningsfelt")
("remove input field above" "fjern indtastningsfelt over")
("search results for" "resultaterne af søgningen efter")
("search words in my documents" "søg efter ord i mine dokumenter")
("search words in the documentation" "søg efter ord i brugerhåndbøgerne")
("search words in the source code" "søg efter ord i kildekoden")
("sending commands to TeXmacs" "give TeXmacs kommandoer")
("slovene" "slovensk")
("split session" "delt session")
("teXmacs plugins" "teXmacsudvidelser")
("your language" "dit sprog")
("a series" "a serien")
("activate once" "aktivér én gang")
("activation" "aktivering")
("american" "amerikansk")
("angular" "vinkler")
("apply macro" "anvend makro")
("apply macro once" "anvend makro én gang")
("arch series" "arch serien")
("b series" "b serien")
("closing style" "afslutningstype")
("common formats" "almindelige størrelser")
("compactification" "kompaktificering")
("compactify" "kompaktificér")
("control the evaluation of expressions" "kontrollér udregningen")
("detailed" "detaljerede")
("deactivate" "slå fra")
("deactivate once" "slå fra én gang")
("edit source tree" "redigér kildetræ")
("formatting" "formattering")
("functional" "funktionel")
("informative flags" "beskrivende flag")
("inline arguments" "indbyggede argumenter")
("insert a condition" "indsæt en betingelse")
("insert a control flow instruction" "indsæt en flow-kontrol instruktion")
("insert a numerical operation" "indsæt en numerisk operation")
("insert a textual operation" "indsæt en tekstuel operation")
("insert an operation on tuples" "indsæt en tupel-operation")
("maximal" "maksimale")
("minimal" "minimale")
("only inline tags" "kun inline tags")
("repeat" "gentag")
("set or get environment variables" "indstil eller vis systemvariabler")
("source tags" "kilde-tags")
("standard formats" "standardformater")
("stretch" "stræk")
("stretched" "strukket")
("write a macro" "skriv en makro")
("automatic quotes" "automatiske citationstegn")
("swiss" "schweizisk")
("presentation tag" "præsentationsmærke")
("reference guide for the TeXmacs primitives" "TeXmacs' urtyper")
("reference guide for the standard TeXmacs styles" "TeXmacs' standardtypografier")
("font type" "skrifttype")
("preview command" "se udskrift på skærm med")
("the document has not been saved" "bufferen er ikke arkiveret")
("recover autosave file" "gendan automatisk arkiveret dokument")
("short" "korte")
("mathematical font" "formelskrift")
("program font" "programskrift")
("web" "internet")
("create web site" "lav hjemmeside")
("source" "kildekode")
("long macro" "lang makro")
("compound" "sammensat")
("get label" "hent mærke")
("get arity" "hent aritet")
("map arguments" "kortlæg argumenter")
("quasiquote" "quasicitering")
("unquote" "slut citering")
("unevaluated value" "ikke-udregnet værdi")
("unevaluated argument" "ikke-udregnet argument")
("evaluation" "udregning")
("control flow" "flow-kontrol")
("for each" "for hver")
("find file" "find arkiv")
("display style" "vis typografi")
("two dots" "to prikker")
("circle" "cirkel")
("activate hidden" "aktivér skjult")
("add package" "tilføj pakke")
("alternative specification" "altenativ specifikation")
("even page left margin" "lige sides venstre margen")
("even page shift" "lige sideskift")
("general note" "hovednote")
("hidden" "skjult")
("homepage" "hjemmeside")
("insert author" "indsæt forfatter")
("insert title" "indsæt titel")
("mutator tags" "")
("new double page" "ny dobbeltside")
("new double page before" "ny dobbeltside før")
("odd page left margin" "ulige sides venstre margen")
("odd page right margin" "ulige sides højre margen")
("odd page shift" "ulige sideskift")
("reference guide" "manual")
("remove package" "fjern pakke")
("show hidden" "vis skjulte")
("standard TeXmacs styles" "standard TeXmacs typografier")
("standard environment variables" "standard områdevariabler")
("stylesheet language" "typografiarkssprog")
("subtitle" "undertitel")
("the TeXmacs format" "TeXmacs formatet")
("upright" "opretstående")
("written with TeXmacs" "skrevet med TeXmacs")

