("A modifier" "modificador A")
("GNU" "GNU")
("H modifier" "modificador H")
("LaTeX" "LaTeX")
("M modifier" "modificador M")
("TeX" "TeX")
("abbreviation" "abreviação")
("about" "sobre TeXmacs")
("about menu" "menu sobre")
("above" "acima")
("abstract" "resumo")
("accent" "acento")
("accept" "aceitar")
("accept all scripts" "aceitar todos scripts")
("accept no scripts" "não aceitar scripts")
("accept script" "aceitar script")
("acronym" "acrônimo")
("action" "ação")
("activate" "ativar")
("acute" "agudo")
("address" "endereço")
("address block" "bloco de endereço")
("advanced" "avançado")
("advanced layout features" "Ferramentas de diagramação avançada")
("after" "depois de")
("albanian" "Albanês")
("algorithm" "algoritmo")
("align cell to the bottom" "alinhar célula abaixo")
("align cell to the left" "alinhar célula à esquerda")
("align cell to the right" "alinhar célula à direita")
("align cell to the top" "alinhar célula acima")
("align table at base of left column" "alinhar tabela à base da coluna esquerda")
("align table at base of middle column" "alinhar tabela à base da coluna do meio")
("align table at base of origin column" "alinhar tabela à base da coluna de origem")
("align table at base of right column" "alinhar tabela à base da coluna direita")
("align table at fraction bar height" "alinhar tabela à altura do traço de fração")
("align table at the base of bottom row" "alinhar tabela à base da última linha")
("align table at the base of middle row" "alinhar tabela à base da linha do meio")
("align table at the base of origin row" "alinhar tabela à base da linha de origem")
("align table at the base of top row" "alinhar tabela à base da primeira linha")
("align table at the bottom" "alinhar tabela abaixo")
("align table at the center" "alinhar tabela ao centro")
("align table at the horizontal center" "alinhar tabela ao centro horizontal")
("align table at the left" "alinhar tabela à esquerda")
("align table at the top" "alinhar tabela acima")
("align table to the right" "alinhar tabela à direita")
("align text to the left" "alinhar texto à esquerda")
("align text to the right" "alinhar texto à direita")
("alignment" "alinhamento")
("all" "tudo")
("allow" "permitir")
("allowed extension" "extensão permitida")
("allowed reduction" "redução permitida")
("alpha release" "alpha release")
("alt key" "tecla alt")
("and" "e")
("appendix" "apêndice")
("apply" "aplicar")
("april" "abril")
("arab" "árabe")
("archaic" "arcaico")
("architecture" "arquitetura")
("argument" "argumento")
("arithmetic" "aritmética")
("armenian" "armênio")
("arrow" "flecha")
("arrows" "setas")
("article" "artigo")
("as on paper" "como no papel")
("assign" "atribuir")
("at fraction bar height" "à altura do traço de fração")
("at the baseline" "à linha base")
("at the bottom" "abaixo")
("at the left" "à esquerda")
("at the middle" "ao meio")
("at the right" "à direita")
("at the top" "ao topo")
("attach" "vincular")
("attach buffer to which project" "vincular buffer ao projeto")
("august" "agosto")
("author" "autor")
("authorize" "autorizar")
("automatic" "automático")
("automatically generated content" "conteúdo gerado automaticamente")
("axiom" "axioma")
("background" "fundo")
("background color" "cor de fundo")
("backward replace" "substituir anterior")
("backward search" "procurar anterior")
("bad data format" "formato de dados incorreto")
("bar" "barra")
("bard" "bardo")
("base level" "nível base")
("bashkirian" "bashkírio")
("basic" "básico")
("basic data types" "tipos de dados básicos")
("basic types" "tipos básicos")
("be useful" "seja útil")
("become a TeXmacs developer" "torne-se um desenvolvedor TeXmacs")
("before" "antes de")
("begin" "princípio")
("below" "acima")
("beta release" "beta release")
("bibliography" "bibliografia")
("bibliography file" "arquivo de bibliografia")
("bibliography style" "estilo da bibliografia")
("big" "grande")
("big figure" "figura grande")
("big operator" "operador grande")
("big skip" "salto grande")
("big table" "tabela grande")
("binary operation" "operação binária")
("binary relation" "relação binária")
("black" "negro")
("blackboard bold" "quadro-negro sombreado")
("blackboard math" "quadro-negro matemático")
("blackletter" "blackletter")
("blue" "azul")
("body" "corpo")
("bold" "grosso")
("book" "livro")
("border" "borda")
("both" "ambos")
("bottom" "baixo")
("bottom border" "borda inferior")
("bottom margin" "margem inferior")
("bottom padding" "borda interna inferior")
("branch" "ramo")
("break" "quebra")
("breaking" "partindo")
("breve" "breve")
("british" "britânico")
("brown" "marrom")
("browse" "navegar")
("browse web" "navegar na rede")
("browser" "navegador")
("buffer" "buffer")
("bulgarian" "búlgaro")
("bullet" "marcador")
("bullets" "marcadores")
("by" "por")
("by typing" "escrevendo")
("bytes free" "bytes livres")
("bytes used" "bytes usados")
("calligraphic" "caligrafia")
("cancel" "cancelar")
("caps-lock key" "tecla CAPS-LOCK")
("case" "case")
("cc" "cc")
("cell" "célula")
("cell background color" "cor de fundo da célula")
("cell border" "borda da célula")
("cell height" "altura da célula")
("cell operation mode" "modo de operação da célula")
("cell width" "largura da célula")
("center" "centro")
("center text" "centralizar texto")
("centered" "centralizado")
("centered block" "bloco centralizado")
("centered tabular" "tabular centralizado")
("change border of cell" "mudar borda da célula")
("change cell operation mode" "mudar modo de operação da célula")
("change log" "arquivo de registro de alterações")
("changes" "mudanças")
("chapter" "capítulo")
("check" "check")
("check text for spelling errors" "verificar erros de ortografia")
("chinese" "chinês")
("choice" "chave")
("citation" "citação")
("cite" "citar")
("class" "classe")
("clear" "limpar")
("clear selection" "limpar seleção")
("clipped" "grampeado")
("clipped and magnified" "grampeado e ampliado")
("clipped and resized" "grampeado e redimensionado")
("clone" "duplicar")
("clone window" "duplicar janela")
("close" "fechar")
("close TeXmacs" "fechar TeXmacs")
("close buffer" "fechar buffer")
("close session" "encerrar sessão")
("close window" "fechar janela")
("closing" "fechamento")
("code" "código")
("color" "cor")
("column" "coluna")
("column contains glued items" "a coluna contém elementos colados")
("compatibility with other formats" "compatibilidade com outros formatos")
("compile article" "compilar artigo")
("compile book" "compilar livro")
("compile buffer" "compilar buffer")
("compile project" "compilar projeto")
("complex" "complexo")
("concrete" "concrete")
("condensed" "condensado")
("condition" "condição")
("configuration" "configuração")
("content tag" "tag de conteúdo")
("context dependent icons" "ícones dependentes do contexto")
("continuation of" "continuação de")
("convention" "convenção")
("converters to other data formats" "conversores para outros formatos")
("copy" "copiar")
("copy text" "copiar texto")
("copy to" "copiar para")
("copying" "copiando")
("corollary" "corolário")
("correct text" "corrigir texto")
("cursors" "cursores")
("custom tab" "marca de tabulação customizada")
("customizing TeXmacs" "adaptando o TeXmacs")
("customizing the TeXmacs styles" "adaptando os estilos do TeXmacs")
("cut" "cortar")
("cut text" "cortar texto")
("cut to" "cortar para")
("cypriot" "cipriota")
("cyrillic" "cirílico")
("cyrillic input method" "método de entrada para cirílico")
("cyrillic italic right" "cirílico cursivo direita")
("czech" "tcheco")
("dancers" "bailarinos")
("danish" "dinamarquês")
("dash" "tracessão")
("dashes" "travessões")
("data conversion" "conversão de dados")
("data format" "formato de dados")
("date" "data")
("deactivate" "desativar")
("deactivate table" "desativar tabela")
("december" "dezembro")
("decorate atoms" "decorar átomos")
("default" "padrão")
("default padding" "borda interna padrão")
("definition" "definição")
("delete" "apagar")
("delete column" "apagar coluna")
("delete row" "apagar linha")
("denominator" "denominador")
("description" "descrição")
("destination" "destino")
("detach" "desvincular")
("determinant" "determinante")
("devangari" "devangari")
("developers guide" "guia para desenvolvedores")
("directory" "diretório")
("disable first indentation" "desabilitar primeira indentação")
("disable first indentation after" "desabilitar primeira identação depois")
("disable first indentation before" "desabilitar primeira indentação antes")
("disable indentation" "desabilitar indentação")
("disable indentation after" "desabilitar indentação depois")
("disable indentation before" "desabilitar indentação antes")
("disable last indentation" "desabilitar última indentação")
("disable last indentation after" "desabilitar última indentação depois")
("disable last indentation before" "desabilitar última indentação antes")
("disallow" "impedir")
("distribute unused space" "distribuir espaço vazio")
("div" "div")
("document" "documento")
("document format" "formato de documento")
("document style" "estilo de documento")
("document styles" "estilos de documento")
("documentation" "documentação")
("documents are trees" "documentos são árvores")
("dot" "ponto")
("dots" "pontos")
("double stroke" "traço duplo")
("down" "abaixo")
("dpi" "dpi")
("duplicate" "duplicar")
("dutch" "holandês")
("dynamic libraries" "bibliotecas dinâmicas")
("edit" "editar")
("editing tools" "ferramentas de edição")
("email" "email")
("emphasize" "destacar")
("emphasize text" "destacar texto")
("empty box" "caixa vazia")
("enable first indentation" "habilitar primeira indentação")
("enable first indentation after" "habilitar primeira indentação depois")
("enable first indentation before" "habilitar primeira indentação antes")
("enable indentation" "habilitar indentação")
("enable indentation after" "habilitar indentação depois")
("enable indentation before" "habilitar indentação antes")
("enable last indentation" "habilitar última indentação")
("enable last indentation after" "habilitar última indentação depois")
("enable last indentation before" "habilitar última indentação antes")
("encl" "incluso")
("end" "fim")
("english" "inglês")
("enter a title" "introduzir um título")
("enumerate" "enumerar")
("enumerate|Alpha" "enumerar|Alpha")
("enumerate|Roman" "enumerar|Romano")
("enumerate|alpha" "enumerar|alpha")
("enumerate|roman" "enumerar|romano")
("env" "env")
("environment" "ambiente")
("epilogue" "epílogo")
("equal" "igual")
("equation" "equação")
("equations" "equações")
("equivalent for" "equivalente para")
("error" "erro")
("esperanto" "esperanto")
("etruscan" "etrusco")
("evaluate" "avaliar")
("evaluate scheme expression" "avaliar expressão scheme")
("even page footer" "rodapé de páginas pares")
("even page header" "cabeçalho de páginas pares")
("even page margin" "margem da página par")
("even page text" "texto de páginas pares")
("exact horizontal" "horizontal exato")
("exact mode" "modo exato")
("exam" "exame")
("example" "exemplo")
("exclusive" "exclusivo")
("exclusive or" "ou exclusivo")
("executable" "executável")
("execute" "executar")
("execute a TeXmacs command" "executar um comando TeXmacs")
("execute system command" "executar comando do sistema")
("executive" "executivo")
("exercise" "exercício")
("expand" "expandir")
("explained" "explicado")
("export" "exportar")
("export as" "exportar como")
("extend or normal" "extendido ou normal")
("extern " "externo")
("extra" "extra")
("extract format" "extrair formato")
("family" "família")
("february" "fevereiro")
("figure" "figura")
("file" "arquivo")
("file name" "nome do arquivo")
("file not found" "arquivo  não encontrado")
("find next match" "buscar termo coincidente seguinte ")
("find text" "buscar texto")
("finnish" "finlandês")
("first contact" "primeiro contato")
("first indentation" "primeira indentação")
("first item" "primeiro elemento")
("first page" "primeira página")
("first start" "primeiro começo")
("flat" "fino")
("flexibility" "flexibilidade")
("flexibility factor for vertical spacing" "fator de flexibilidade para espaçamento vertical")
("floating figure" "figura flutuante")
("floating object" "objeto flutuante")
("floating table" "tabela flututante")
("fold" "dobra")
("folded" "dobrado")
("font" "fonte")
("font base size" "tamanho fonte base")
("font dpi" "font dpi")
("font family" "família da fonte")
("font name" "nome da fonte")
("font series" "estilo da fonte")
("font shape" "formato da fonte")
("font size" "tamanho da fonte")
("font variant" "variante da fonte")
("fonts" "fontes")
("footer" "rodapé")
("footnote" "nota de rodapé")
("for" "for")
("foreground" "primeiro plano")
("foreign" "estrangeiro")
("format" "formato")
("formatted date" "data formatada")
("formula" "fórmula")
("formula style" "estilo de fórmula")
("forward replace" "substituir à frente")
("forward search" "procurar à frente")
("fraction" "fração")
("french" "francês")
("full manuals" "manuais completos")
("function" "função")
("further customization" "adaptação para o usuário avançado")
("future changes" "mudanças futuras")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs não tem nenhuma forma de garantia legal")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs está sob a licensa pública GNU (GNU GPL)")
("general architecture of TeXmacs" "arquitetura geral do TeXmacs")
("general negation" "negação geral")
("generating font file" "gerando arquivo de fontes")
("generic" "genérico")
("georgian" "georgiano")
("german" "alemão")
("getting started" "iniciando")
("glossary" "glossário")
("glossary entry" "item do glossário")
("glue" "cola")
("glue decorations" "colar decorações")
("go" "ir para")
("gothic" "gótica")
("graphical interface" "interface gráfica")
("grave" "grave")
("greater" "maior")
("greater or equal" "maior ou igual")
("greek" "grego")
("greek letter" "letra grega")
("green" "verde")
("grey" "cinza")
("group" "grupo")
("happy typing" "boa escrita")
("has been aborted" "abortado")
("has completed its task" "finalizou sua tarefa")
("hat" "chapéu")
("header" "cabeçalho")
("header and footer" "cabeçalho e rodapé")
("hebrew" "hebraico")
("height" "altura")
("height is exactly the specified height" "altura é exatamente a altura especificada")
("height is maximum of specified height and box height" "altura é o máximo dentre a altura especificada e altura da caixa")
("height is minimum of specified height and box height" "altura é o mínimo dentre a altura especificada e altura da caixa")
("height magnification" "ampliação da altura")
("help" "ajuda")
("help me" "ajude me")
("help us" "ajude-nos")
("here" "aqui")
("home" "início")
("horizontal" "horizontal")
("horizontal cell alignment" "alinhamento horizontal da célula")
("horizontal ink separation" "separação de tinta horizontal")
("horizontal part" "parte horizontal")
("horizontal position" "posição horizontal")
("horizontal space" "espaço horizontal")
("horizontal table alignment" "alinhamento horizontal da tabela")
("horizontally align cell to the base" "alinhar a célula horizontalmente à base")
("horizontally center the cell" "centralizar horizontalmente a célula")
("how much longer may pages become" "quanto mais longas podem ficar as páginas")
("how much shorter may pages become" "quanto mais curtas podem ficar as páginas")
("huge" "enorme")
("hungarian" "húngaro")
("hyperlink" "hiperlink")
("hyphenation" "hifenação")
("icelandic" "islandês")
("if" "if")
("image" "imagem")
("image links" "links para imagens")
("implementation" "implementação")
("import" "importar")
("improving the current implementation" "melhorando a implementação atual")
("inactive" "inativo")
("include" "incluir")
("include a document" "incluir um documento")
("include file" "incluir um arquivo")
("inclusion into TeXmacs" "inclusão no TeXmacs")
("inclusions" "inclusões")
("indent" "indentar")
("indentation flag" "indentação")
("index" "índice")
("index entry" "item do índice")
("index level" "nível de índice")
("insert" "inserir")
("insert Pr" "inserir Pr")
("insert a TeXmacs symbol" "inserir um símbolo TeXmacs")
("insert a big operator" "inserir um operador grande")
("insert a binary operation" "inserir uma operação binária")
("insert a binary relation" "inserir uma relação binária")
("insert a calligraphic character" "inserir um caracter caligráfico")
("insert a fraction" "inserir uma fração")
("insert a fraktur character" "inserir um caracter fraktur")
("insert a greek character" "inserir uma letra grega")
("insert a large left delimiter" "inserir um delimitador grande à esquerda")
("insert a large right delimiter" "inserir um delimitador grande à direita")
("insert a large separator" "inserir um separador amplo")
("insert a left subscript" "inserir um subíndice à esquerda")
("insert a link" "inserir um link")
("insert a miscellaneous symbol" "inserir um símbolo miscelâneo")
("insert a new branch" "inserir um novo ramo")
("insert a new item" "inserir um novo elemento")
("insert a picture" "inserir uma imagem")
("insert a square root" "inserir uma raiz quadrada")
("insert a table" "inserir uma tabela")
("insert a table or a matrix" "inserir uma tabela ou uma matriz")
("insert an" "inserir um/a")
("insert an accent" "inserir um acento")
("insert an arrow" "inserir uma flecha")
("insert an environment" "inserir um novo ambiente")
("insert an n" "inserir um/a n")
("insert appendix" "inserir apêndice")
("insert arccos" "inserir arccos")
("insert arcsin" "inserir arcsin")
("insert arctan" "inserir arctan")
("insert arg" "inserir arg")
("insert argument" "inserir argumento")
("insert automatically generated content" "inserir conteúdo gerado automaticamente")
("insert big contour integral" "inserir integral de contorno grande")
("insert big coproduct" "inserir co-produtório grande")
("insert big direct sum" "inserir soma direta grande")
("insert big dotted point" "inserir produto pontual grande")
("insert big integral" "inserir integral grande")
("insert big intersection" "inserir intersecção grande")
("insert big logical and" "inserir Y lógico grande")
("insert big logical or" "inserir O lógico grande")
("insert big product" "inserir produtório grande")
("insert big square union" "inserir união quadrada grande")
("insert big summation" "inserir somatório grande")
("insert big tensor product" "inserir produto tensorial grande")
("insert big union" "inserir união grande")
("insert big union sum" "inserir soma união grande")
("insert big vertical space" "inserir espaço vertical grande")
("insert chapter" "inserir capítulo")
("insert column" "inserir coluna")
("insert column to the left" "inserir coluna à esquerda")
("insert column to the right" "inserir coluna à direita")
("insert cos" "inserir cos")
("insert cosh" "inserir cosh")
("insert cot" "inserir cot")
("insert coth" "inserir coth")
("insert csc" "inserir csc")
("insert deg" "inserir deg")
("insert det" "inserir det")
("insert dim" "inserir dim")
("insert dollar" "inserir dólar")
("insert equation" "inserir equação")
("insert executable markup" "inserir markup executável")
("insert exp" "inserir exp")
("insert footnote" "inserir nota de rodapé")
("insert formula" "inserir fórmula")
("insert gcd" "inserir gcd")
("insert hom" "inserir hom")
("insert horizontal interword space" "inserir espaço horizontal entre palavras")
("insert image" "inserir imagem")
("insert inactive markup" "executar markup inativo")
("insert inf" "inserir inf")
("insert ker" "inserir ker")
("insert lg" "inserir lg")
("insert lim" "inserir lim")
("insert liminf" "inserir liminf")
("insert limsup" "inserir limsup")
("insert ln" "inserir ln")
("insert log" "inserir log")
("insert mathematics" "inserir expressão matemática")
("insert max" "inserir max")
("insert medium horizontal space" "inserir espaço horizontal médio")
("insert medium vertical space" "inserir espaço vertical médio")
("insert min" "inserir min")
("insert negative horizontal space" "inserir espaço horizontal negativo")
("insert new item or number" "inserir novo elemento ou número")
("insert new rows or columns" "inserir linhas ou colunas")
("insert or delete rows or columns" "inserir ou apagar linhas ou colunas")
("insert row" "inserir linha")
("insert row above" "inserir linha acima")
("insert row below" "inserir linha abaixo")
("insert sec" "inserir sec")
("insert section" "inserir seção")
("insert sharp" "inserir sharp")
("insert sin" "inserir sen")
("insert sinh" "inserir senh")
("insert small horizontal space" "inserir espaço horizontal pequeno")
("insert small vertical space" "inserir espaço vertical pequeno")
("insert structural markup" "inserir markup estrutural")
("insert subsection" "inserir subseção")
("insert subsubsection" "inserir subsubseção")
("insert sup" "inserir sup")
("insert tan" "inserir tan")
("insert tanh" "inserir tanh")
("insert thick horizontal space" "inserir espaço horizontal grosso")
("interjection" "interjeição")
("interline separation" "separação entre linhas")
("interline space" "espaço entre linhas")
("internationalization" "internacionalização")
("interparagraph space" "espaço entre páragrafos")
("interrupt execution" "interromper execução")
("introduction" "introdução")
("invisible" "invisível")
("invisible citation" "citação invisível")
("irish" "irlandês")
("is running" "está executando")
("is tuple" "é tuple")
("ispell does not respond" "ispell não responde")
("ispell is already busy" "ispell está ocupado")
("italian" "italiano")
("italic" "itálico")
("italic right" "itálico direita")
("itemize" "listar")
("january" "janeiro")
("japanese" "japonês")
("july" "julho")
("june" "junho")
("justified" "justificado")
("justify text" "justificar texto")
("key" "tecla")
("keyboard" "teclado")
("keyboard equivalent" "equivalente do teclado")
("keyboard modifiers" "modificadores do teclado")
("keyboard shortcut" "atalho do teclado")
("keymaps" "mapa de teclado")
("keyword" "palavra chave")
("keywords" "palavras chaves")
("kill" "matar")
("known bugs" "bugs conhecidos")
("label" "etiqueta")
("landscape" "paisagem")
("language" "linguagem")
("large" "grande")
("large closing bracket" "parêntesis fechando grande")
("large delimiter" "delimitador grande")
("large opening bracket" "parêntesis abrindo grande")
("large separator" "separador grande")
("last indentation" "última indentação")
("last page" "última página")
("latex command" "comando de latex")
("latin" "latin")
("layout" "layout")
("left" "esquerda")
("left border" "borda esquerda")
("left margin" "margem esquerda")
("left padding" "borda interna esquerda")
("left prime" "prime esquerdo")
("left aligned" "alinhado à esquerda")
("left slanted" "inclinada esquerda")
("left subscript" "subíndice à esquerda")
("left superscript" "superíndice à esquerda")
("left surrounding" "vizinhança esquerda")
("legal" "legal")
("lemma" "lema")
("length" "length")
("less" "menor")
("less or equal" "menor ou igual")
("letter" "carta")
("license" "licença")
("light" "leve")
("limitations" "limitações")
("limits" "limites")
("line" "linha")
("line break" "quebra de linha")
("line stretch" "elasticidade da linha")
("link" "link")
("link image" "criar link para imagem")
("list" "lista")
("list of figures" "lista de figuras")
("list of tables" "lista de tabelas")
("load" "carregar")
("load LaTeX file" "carregar arquivo LaTeX")
("load TeX file" "carregar arquivo TeX")
("load TeXmacs file" "carregar arquivo TeXmacs")
("load TeXmacs style file" "carregar arquivo de estilos TeXmacs")
("load a file" "carregar um arquivo")
("load buffer" "carregar buffer")
("load file" "carregar arquivo")
("load html file" "carregar arquivo html")
("load image" "carregar imagem")
("load in new window" "carregar em nova janela")
("load latex file" "carregar arquivo latex")
("load more recent autosave file" "carregar último arquivo gravado")
("load tex file" "carregar arquivo tex")
("load verbatim file" "carregar arquivo verbatim")
("loaded" "carregado")
("long" "alto")
("look and feel" "aparência")
("look up" "look up")
("lower border" "borda inferior")
("macro" "macro")
("magenta" "magenta")
("magic" "mágico")
("magnification" "ampliação")
("magnified" "ampliado")
("main" "principal")
("main icon bar" "barra de ícones principal")
("major changes" "mudanças importantes")
("make a page insertion" "faça uma inserção de página")
("make a subscript" "criar um subíndice")
("make a superscript" "criar um superíndice")
("make acute" "fazer agudo")
("make bar" "fazer barra")
("make check" "fazer check")
("make fraction" "fazer fração")
("make grave" "fazer grave")
("make hat" "fazer chapéu")
("make label" "criar etiqueta")
("make negation" "fazer negação")
("make page reference" "criar referência de página")
("make reference" "criar referência")
("make square root" "fazer raiz quadrada")
("make tilde" "fazer til")
("make title" "compor título")
("make vector" "fazer vetor")
("making donations" "fazendo doações")
("manual" "manual")
("map to" "mapear para")
("march" "março")
("margins" "margens")
("margins as on paper" "margens como no papel")
("master" "mestre")
("master file" "arquivo mestre")
("math" "math")
("math font" "fonte math")
("math font family" "família da fonte math")
("math font series" "estilo da fonte math")
("math font shape" "formato da fonte math")
("mathematical" "matemático")
("mathematical formulas" "fórmulas matemáticas")
("mathematical typesetting" "tipografia matemática")
("mathematics" "matemáticos")
("matrix" "matriz")
("maximal number of columns" "número máximo de colunas")
("maximal number of rows" "número máximo de linhas")
("maximum mode" "modo máximo")
("may" "maio")
("medium" "médio")
("medium skip" "salto mediano")
("meminfo" "meminfo")
("merge" "merge")
("messy" "confusa")
("meta key" "tecla meta")
("middle" "médio")
("minimal number of columns" "número mínimo de colunas")
("minimal number of rows" "número mínimo de linhas")
("minimum mode" "modo mínimo")
("minus" "menos")
("miscellaneous" "miscelâneo")
("mod" "mod")
("mode" "modo")
("modifier" "modificador")
("modify cell alignment" "modificar alinhamento da célula")
("modify cell border" "modificar borda da célula")
("modify cell padding" "modificar borda interna da célula")
("modify cell size" "modificar tamanho da célula")
("modify table border" "modificar borda da tabela")
("modify table padding" "modificar borda interna da tabela")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "mais informações sobre GNU TeXmacs na ajuda")
("mosaic" "mosaico")
("move down" "desloca para baixo")
("move object" "mover objeto")
("move to the right when finished" "move a direita quando finalizado")
("move up" "desloca para cima")
("n-th" "n-ésima")
("n-th root" "raiz n-ésima")
("name" "nome")
("negation" "negação")
("new" "novo")
("new buffer" "novo buffer")
("new column" "nova coluna")
("new item" "novo elemento")
("new line" "nova linha")
("new number" "novo número")
("new page" "nova página")
("new page before" "página nova antes de")
("new paragraph" "novo parágrafo")
("new roman" "new roman")
("new row" "nova linha")
("new table" "nova tabela")
("next line" "próxima linha")
("no" "não")
("no changes need to be saved" "as mudanças não precisam ser gravadas")
("no dictionary for" "sem dicionário para")
("no first indentation" "sem primeira indentação")
("no indentation" "sem indentação")
("no last indentation" "sem última indentação")
("no line break" "sem quebra de linha")
("no matches found" "sem termos coincidentes")
("no more matches for" "não há mais termos coincidentes")
("no more redo information available" "não há mais informação 'refazer' disponível")
("no more undo information available" "não há mais informação 'desfazer' disponível")
("no name" "sem nome")
("no page break after" "sem quebra de página após")
("no page break before" "sem quebra de página antes")
("no spelling errors found in text" "não foram encontrados erros de ortografia no texto")
("no style" "sem estilo")
("none" "nenhum")
("normal" "normal")
("norwegian" "norueguês")
("not" "não")
("not equal" "não igual")
("not found" "não encontrado")
("notation" "notação")
("note" "nota")
("november" "novembro")
("number" "número")
("number equation" "numerar equação")
("number of columns" "número de colunas")
("numbered equation" "equação numerada")
("numbered equations" "equações numeradas")
("numerator" "numerador")
("numeric" "numérico")
("objectives" "objetivos")
("occurrences" "ocorrências")
("october" "outubro")
("odd page footer" "rodapé de página impar")
("odd page header" "cabeçalho de página impar")
("odd page margin" "margem da página ímpar")
("odd page text" "texto de página impar")
("off" "desativado")
("ok" "ok")
("old english" "inglês antigo")
("old slavonic" "eslavo antigo")
("old style" "estilo antigo")
("on" "ativado")
("on cells" "nas células")
("on columns" "nas colunas")
("on entire table" "na tabela inteira")
("on rows" "nas linhas")
("one spelling error has been corrected" "um erro ortográfico foi corrigido")
("online documentation" "documentação on-line")
("online help" "ajuda on-line")
("open" "abrir")
("open a new buffer" "abrir um novo buffer")
("open new window" "abrir nova janela")
("opening" "abrindo")
("operation on named selection" "operação na seleção nomeada")
("operation on primary selection" "operação na seleção primária")
("operation on secondary selection" "operação na seleção secundária")
("operation on ternary selection" "operação na seleção ternária")
("optical" "ótica")
("option" "opção")
("options" "opções")
("or" "ou")
("orange" "laranja")
("orientation" "orientação")
("origin" "origem")
("original welcome message" "mensagem original de boas-vindas")
("other" "outro")
("other pages" "outras páginas")
("other projects" "outros projetos")
("other style" "outro estilo")
("outlined roman" "perfil romano")
("over" "sobre")
("padding" "borda interna")
("page" "página")
("page bottom margin" "margem inferior da página")
("page break" "quebra de página")
("page break before" "quebra de página antes")
("page height" "altura de página")
("page insertion" "inserção de página")
("page layout" "layout de página")
("page number text" "texto da numeração de página")
("page numbering" "numeração de página")
("page reference" "referência de página")
("page right margin" "margem direita da página")
("page top margin" "margem superior da página")
("page type" "tipo de página")
("page width" "largura de página")
("paper" "papel")
("paper type" "tipo de papel")
("papyrus" "papiro")
("paragraph" "parágrafo")
("paragraph mode" "modo do paragráfo")
("paragraph width" "largura do parágrafo")
("part" "parte")
("past changes" "mudanças passadas")
("paste" "colar")
("paste from" "colar de")
("paste text" "colar texto")
("path" "caminho")
("perform operations on cells" "realizar operaçôes nas células")
("perform operations on columns" "realizar operações nas colunas")
("perform operations on entire table" "realizar operações na tabela inteira")
("perform operations on rows" "realizar operações nas linhas")
("permanent" "permanente")
("person" "pessoa")
("personal dictionary has been modified" "dicionário pessoal foi modificado")
("phantasy" "fantasia")
("philosophy" "filosofia")
("phoenician" "fenício")
("phonetic" "fonético")
("pink" "rosa")
("plain" "natural")
("plain block" "bloco simples")
("plain tabular" "tabular simples")
("planned changes" "mudanças planejadas")
("plans for the future" "planos para o futuro")
("please" "por favor")
("please wait" "por favor aguarde")
("plus" "mais")
("polish" "polonês")
("porting TeXmacs to other platforms" "tranportando o TeXmacs para outras plataformas")
("portrait" "retrato")
("portuguese" "português")
("position" "posição")
("position float" "posicionar flutuatante")
("position floating object" "posicionar objeto flutuante")
("position the table" "posicionar a tabela")
("postscript" "postscript")
("postscript image" "imagem postscript")
("pre-alpha release" "pre-alpha release")
("preamble" "preâmbulo")
("preamble mode" "modo de preâmbulo")
("preferences" "preferências")
("presentation mode" "modo de apresentação")
("preview before printing" "visualizar antes de imprimir")
("preview with ghostview" "visualizar com ghostview")
("primary" "primário")
("prime" "prime")
("print" "imprimir")
("print all" "imprimir tudo")
("print all to file" "imprimir tudo em um arquivo")
("print page selection" "imprimir seleção")
("print page selection to file" "imprimir seleção em um arquivo")
("print to postscript file" "imprimir em arquivo postscript")
("printer" "impressora")
("printer dpi" "dpi da impressora")
("printing command" "comando de impressão")
("problem" "problema")
("professional" "profissional")
("prog" "prog")
("prog font" "fonte prog")
("prog font family" "familia da fonte prog")
("prog font series" "estilo da fonte prog")
("prog font shape" "forma da fonte prog")
("program" "programa")
("program mode" "modo programa")
("programming" "programação")
("progressive" "progressivo")
("project" "projeto")
("projects" "projetos")
("prologue" "prólogo")
("prompt on scripts" "perguntar em todos os scripts")
("proof" "demostração")
("proportional" "proporcional")
("proportional typewriter" "typewriter proporcional")
("proposition" "proposição")
("query replace" "substituir")
("quit" "sair")
("quotation" "citação")
("quote" "citar")
("range" "range")
("really close it" "fechar realmente")
("really huge" "gigante")
("really quit" "sair de verdade")
("red" "vermelho")
("redo" "refazer")
("redo undone changes" "refazer as últimas alterações")
("reduce bottom margin by" "reduzir margem inferior por")
("reduce left margin by" "reduzir margem esquerda por")
("reduce margins" "reduzir margens")
("reduce right margin by" "reduzir margem direita por")
("reduce top margin by" "reduzir margem superior por")
("reduction even page margin" "redução da margem da página par")
("reduction odd page margin" "redução da margem da página ímpar")
("reduction page bottom margin" "redução da margem inferior da página")
("reduction page right margin" "redução da margem direita da página")
("reduction page top margin" "redução da margem superior da página")
("reference" "referência")
("references" "referências")
("regular" "regular")
("release" "release")
("reload" "recarregar")
("remark" "comentário")
("remove number" "remover númeração")
("renumber this page" "renumerar esta página")
("repeat object" "repetir objeto")
("replace" "substituir")
("replace by" "substituir por")
("replaced" "substituído")
("replaced one occurrence" "substituída uma ocorrência")
("reset" "reiniciar")
("resize object" "redimensionar objeto")
("resized" "redimensionado")
("return" "return")
("revert" "reverter para")
("revert buffer" "recuperar buffer")
("right" "direita")
("right border" "borda direita")
("right margin" "margem direita")
("right padding" "borda interna direita")
("right aligned" "alinhado à direita")
("right subscript" "subíndice à direita")
("right superscript" "superíndice à direita")
("right surrounding" "vizinhança direita")
("rigid" "rígido")
("rigid horizontal" "horizontal rígida")
("rigid space" "espaço rígido")
("romanian" "romano")
("root" "raiz")
("rotate backward" "rodar para trás")
("rotate forward" "rodar para a frente")
("row" "linha")
("row contains glued items" "a linha contém elementos colados")
("runic" "rúnico")
("russian" "russo")
("russian and Ukrainian users" "usuários russos e ucranianos")
("sample" "amostra")
("sans serif" "sans serif")
("save" "salvar")
("save TeXmacs file" "salvar arquivo TeXmacs")
("save TeXmacs style file" "salvar arquivo de estilos TeXmacs")
("save as" "salvar como")
("save as LaTeX" "salvar como LaTeX")
("save as TeX" "salvar como TeX")
("save buffer" "salvar buffer")
("save buffer as" "salvar buffer como")
("save file" "salvar arquivo")
("save html file" "salvar arquivo html")
("save image" "salvar imagem")
("save latex file" "salvar arquivo latex")
("save tex file" "salvar arquivo tex")
("save this buffer" "salvar este buffer")
("save verbatim file" "salvar arquivo verbatim")
("saved" "salvar")
("screen layout" "layout da tela")
("screen margins" "margens na tela")
("script" "índice")
("script above" "índice acima")
("script below" "índice abaixo")
("script script size" "tamanho de script de script")
("script size" "tamanho de script")
("scripts not accepted" "scripts não aceitos")
("search" "procurar")
("searching" "procurando")
("secondary" "secundário")
("section" "seção")
("security" "segurança")
("see" "ver")
("select a document style" "selecionar um estilo de documento")
("select a foreground color" "selecionar uma cor de primeiro plano")
("select a language" "selecionar uma linguagem")
("selected region" "região selecionada")
("selection" "seleção")
("selections" "seleções")
("seminar" "seminário")
("separation between lines" "separação entre linhas")
("separation between paragraphs" "separação entre parágrafos")
("separator" "separador")
("september" "setembro")
("serb" "sérvio")
("series" "estilo")
("series|right" "estilo|direita")
("session" "sessão")
("session name" "nome da sessão")
("session type" "tipo de sessão")
("sessions" "sessões")
("set" "configurar")
("set background color of cell" "definir cor de fundo da célula")
("set cell mode" "definir modo de célula")
("set extension center" "definir centro da expansão")
("set height" "definir altura")
("set height of cell" "definir altura da célula")
("set margins" "configurar margens")
("set n" "configura n")
("set paragraph margins" "definir margens de parágrafo")
("set paragraph mode" "definir modo de parágrafo")
("set printer dpi" "configurar dpi da impressora")
("set printing command" "configurar arquivo de impressão")
("set span" "definir extensão")
("set special cell properties" "definir propriedades especiais de célula")
("set special table properties" "definir propriedades especiais de tabela")
("set text width" "configurar largura do texto")
("set width" "definir largura")
("set width of cell" "definir largura da célula")
("settings" "ajustes")
("setup printer" "configurar impressora")
("shape" "forma")
("shift-down" "shift-abaixo")
("shift-right" "shift-direita")
("show" "mostrar")
("show header and footer" "mostrar cabeçalho e rodapé")
("show on screen" "mostrar na tela")
("shrinking factor" "fator de redução")
("signature" "assinatura")
("size" "tamanho")
("size limits" "limites de tamanho")
("slanted" "inclinado")
("small" "pequeno")
("small caps" "caixa alta")
("small figure" "figura pequena")
("small skip" "salto pequeno")
("small table" "tabela pequena")
("source code" "código fonte")
("space" "espaço")
("space between lines" "espaço entre as linhas")
("space between paragraphs" "espaço entre os parágrafos")
("spacing" "espaçado")
("spanish" "espanhol")
("special" "especial")
("special cell properties" "propriedades especiais de célula")
("special table properties" "propriedades especiais de tabela")
("specific" "específico")
("spell" "ortografia")
("spell checking complete" "verificação de ortografia finalizada")
("spelling error" "error ortográfico")
("spelling errors have been corrected" "os erros ortográficos foram corrigidos")
("split" "dividir")
("square root" "raiz quadrada")
("start" "inicia")
("start a new chapter" "iniciar um novo capítulo")
("start a new section" "iniciar uma nova seção")
("start an interactive session" "iniciar uma sessão interativa")
("stretchable" "esticável")
("stretchable horizontal" "esticável horizontal")
("stretchable vertical" "esticável vertical")
("strong" "forte")
("structural" "estrutural")
("style" "estilo")
("styles" "estilos")
("sub" "sub")
("subparagraph" "subparágrafo")
("subscript" "subíndice")
("subsection" "subseção")
("subsub" "subsub")
("subsubsection" "subsubseção")
("summary" "resumo")
("superpose" "superpor")
("superposed" "superpostos")
("superscript" "superíndice")
("swedish" "sueco")
("switch to first" "mudar para o primeiro")
("switch to formula style" "mudar o estilo de fórmula")
("switch to last" "mudar para o último")
("switch to next" "mudar para o próximo")
("switch to previous" "mudar para o anterior")
("symbol" "símbolo")
("system environment variables" "variáveis de sistema do ambiente")
("tab" "tabulador")
("table" "tabela")
("table command" "comando de tabela")
("table of contents" "tabela de conteúdos")
("tables" "tabelas")
("tabular" "tabular")
("tabular material" "material tabular")
("teXmacs as an interface" "teXmacs como uma interface")
("teXmacs fonts" "fontes do teXmacs")
("teXmacs notice" "aviso do teXmacs")
("teXmacs style files" "arquivos de estilo do teXmacs")
("ternary" "ternário")
("test" "testar")
("tex" "tex")
("text" "texto")
("text font" "fonte texto")
("text height correction" "correção da altura do texto")
("text width" "largura do texto")
("texts" "textos")
("th century bc" "-ava centuria ac")
("th root" "ésima raiz")
("thai" "tailandês")
("the TeXmacs authors" "os autores do TeXmacs")
("the application did not send its usual startup banner" "a aplicação não enviou seu aviso de início habitual")
("the application does not reply" "a aplicação não responde")
("the application is already running" "a aplicação já está sendo executada")
("the boxes produced by the typesetter" "as caixas produzidas pelo tipógrafo")
("the graphical user interface" "a interface gráfica")
("the leaves of TeXmacs trees" "as folhas da árvore do TeXmacs")
("the mycas example" "o exemplo mycas")
("the primitive TeXmacs constructs" "as primitivas do TeXmacs")
("the standard TeXmacs styles" "os estilos padrão do TeXmacs")
("theorem" "teorema")
("there are unsaved documents" "há arquivos não gravados")
("this document has not been saved" "este buffer não foi salvo")
("this document has been produced using" "este documento foi produzido usando")
("this line" "esta linha")
("this page" "esta página")
("tilda" "tilda")
("tilde" "til")
("times" "vezes")
("tiny" "pequeno")
("title" "título")
("to the left" "à esquerda")
("to the right" "à direita")
("today" "hoje")
("tools" "ferramentas")
("top" "alto")
("top border" "borda superior")
("top level" "nível superior")
("top margin" "margem superior")
("top padding" "borda interna superior")
("translate" "traduzir")
("tree" "árvore")
("tuple" "tuple")
("turkish" "turco")
("tutorial" "tutorial")
("type" "tipo")
("type a latex command followed by" "escreva um comando de latex seguido por")
("type body" "escreva o corpo")
("type denominator" "escreva o denominador")
("type numerator" "escreva o numerador")
("type script" "escreva o índice")
("typesetted boxes" "caixas tipográficas")
("typewriter" "typewriter")
("typewriter small caps" "typewriter minúsculo")
("typing a simple text" "digitando um texto simples")
("typing simple texts" "digitando textos simples")
("ugaritic" "ugarítico")
("ukrainian" "ucraniano")
("undo" "desfazer")
("undo last changes" "desfazer as últimas alterações")
("up" "acima")
("update" "atualizar")
("update image links" "atualizar links de imagens")
("upper border" "borda superior")
("use a black color" "usar cor negra")
("use a blue color" "usar cor azul")
("use a brown color" "usar cor marrom")
("use a calligraphic font" "usar uma fonte caligráfica")
("use a green color" "usar cor verde")
("use a grey color" "usar cor cinza")
("use a magenta color" "usar cor magenta")
("use a orange color" "usar cor laranja")
("use a pink color" "usar cor rosa")
("use a red color" "usar cor vermelha")
("use a sans serif font" "usar uma fonte sans serif")
("use a typewriter font" "usar uma fonte typewriter")
("use a white color" "usar cor branca")
("use a yellow color" "usar cor amarela")
("use blackboard bold font" "usar fonte quadro-negro negrito")
("use bold font series" "usar estilo de fonte negrito")
("use calligraphical font" "usar fonte de caligrafia")
("use footnote font size" "usar tamanho de fonte rodapé")
("use fraktur font" "usar fonte fraktur")
("use huge font size" "usar tamanho de fonte enorme")
("use italic font shape" "usar forma de fonte cursiva")
("use large font size" "usar tamanho de fonte grande")
("use left hand column as border" "usar coluna da esquerda como borda")
("use medium font series" "usar estilo de fonte médio")
("use normal font size" "usar tamanho de fonte normal")
("use package" "usar pacote")
("use paragraph width" "usar largura de parágrafo")
("use really huge font size" "usar tamanho de fonte gigante")
("use right font shape" "usar forma de fonte reta")
("use right hand column as border" "usar coluna da direita como borda")
("use roman font family" "usar família de fonte romana")
("use row above as border" "usar linha acima como borda")
("use row below as border" "usar linha abaixo como borda")
("use sans serif font family" "usar família de fonte sans serif")
("use script font size" "usar tamanho de fonte índice")
("use slanted font shape" "usar forma de fonte inclinada")
("use small capitals" "usar minúsculas")
("use small font size" "usar tamanho de fonte pequeno")
("use small-caps font shape" "usar forma de fonte minúsculas")
("use the blackboard bold font" "usar fonte quadro-negro negrito")
("use the fraktur font" "usar uma fonte fraktur")
("use tiny font font size" "usar tamanho de fonte diminuta")
("use typewriter font family" "usar família de fonte typewriter")
("use very large font size" "usar tamanho de fonte muito grande")
("user manual" "manual do usuário")
("user provided icons" "ícones proporcionados pelo usuário")
("value" "valor")
("variable" "variável")
("variant" "varianta")
("vector" "vetor")
("verbatim" "verbatim")
("verse" "verso")
("vertical" "vertical")
("vertical after" "vertical posterior")
("vertical before" "vertical anterior")
("vertical cell alignment" "alinhamento vertical da célula")
("vertical part" "parte vertical")
("vertical position" "posição vertical")
("vertical space" "espaço vertical")
("vertical table alignment" "alinhamento vertical da tabela")
("vertically align cell to the base" "alinhar célula verticalmente à base")
("vertically center the cell" "centralizar verticamente a célula")
("very large" "muito grande")
("very small" "muito pequeno")
("vietnamese" "vietnamita")
("view" "ver")
("visible" "visível")
("warning" "aviso")
("welcome" "bem vindo")
("welcome to GNU TeXmacs" "bem vindo ao GNU TeXmacs")
("what is new" "quais as novidades")
("when finished" "quando finalizado")
("while" "while")
("white" "branco")
("wide accent" "acento ancho")
("width" "largura")
("width is exactly the specified width" "largura é exatamente a largura especificada")
("width is maximum of specified width and box width" "largura é o máximo dentre largura especificada e largura da caixa")
("width is minimum of specified width and box width" "largura é o máximo dentre largura especificada e largura da caixa")
("width magnification" "ampliação da largura")
("window" "janela")
("window height" "altura da janela")
("window width" "largura da janela")
("windows key" "tecla windows")
("with" "com")
("write a name" "escrever nome")
("write bold mathematics" "escrever termo matemático em negrito")
("write bold text" "escrever em negrito")
("write italic text" "escrever em itálico")
("write sample text" "escrever texto estilo sample")
("write strong text" "escrever texto estilo forte")
("write typewriter text" "escrever estilo máquina")
("write verbatim text" "escrever texto estilo verbatim")
("writing data converters" "escrevendo conversores de dados")
("writing your own style files" "escrevendo seus próprios arquivos de estilo")
("yellow" "amarelo")
("yes" "sim")
("you can also obtain" "você também pode obter")
("your document is back in its original state" "seu documento foi colocado no estado original")
("your first interface" "sua primeira interface")
