("\"encryption\" features from the preference panel" "«функции шифрования» из панели настроек")
("(Re)Build autocompletion index" "(Re) Построить индекс автозаполнения")
("a series" "серия")
("a.C.M. computing class" "класс вычислительной техники")
("a.M.S. subject class" "А.М.С. предметный класс")
("abbreviated authors" "сокращенных авторов")
("abreviated authors" "сокращенных авторов")
("accent above" "акцент выше")
("accent below" "акцент ниже")
("accept during this pass" "принять во время этого прохода")
("acknowledgments" "благодарностей")
("activate hidden" "активировать скрытый")
("activate once" "активировать один раз")
("activation" "активация")
("active link types" "активных типов ссылок")
("add" "добавить")
("add abstract information" "добавить абстрактную информацию")
("add author information" "добавить информацию об авторе")
("add branch after" "добавить ветку после")
("add branch before" "добавить ветку перед")
("add other package" "добавить другой пакет")
("add style package" "добавить пакет стиля")
("add title information" "добавить заголовок информации")
("addition" "сложение")
("adjust" "настроить")
("adjust limits" "отрегулировать пределы")
("advanced font customization" "расширенная настройка шрифтов")
("affiliation" "Принадлежность")
("align cell to the decimal comma" "выровнять ячейку по десятичной запятой")
("align cell to the decimal dot" "выровнять ячейку по десятичной точке")
("align table at axis" "выровнять таблицу по оси")
("alignment of balloon" "выравнивание баллона")
("all cells" "все клетки")
("all data attached to this identity will be lost" "все данные, прикрепленные к этой личности, будут потеряны")
("all saved passphrases will be lost forever" "все сохраненные парольные фразы будут потеряны навсегда")
("allow for macro definitions in preamble" "разрешить определения макросов в преамбуле")
("allowed page height extension" "допустимое увеличение высоты страницы")
("allowed page height reduction" "допустимое уменьшение высоты страницы")
("allowed positions" "разрешенных позиций")
("allowed positions of floating object" "разрешенных положений плавающего объекта")
("alpha transparency" "альфа-прозрачность")
("also on paper" "также на бумаге")
("alter" "перешить")
("alternate" "альтернатива")
("alternate except here" "альтернатива, кроме здесь")
("alternate from here on" "чередуйся отсюда")
("alternate only here" "чередуйте только здесь")
("alternate until here" "чередовать до здесь")
("always" "всегда")
("american" "американец")
("amplified" "усилено")
("and perform casual settings from the \"Encryption\" tab" "и выполнить случайные настройки на вкладке «Шифрование»")
("animate" "одушевленные")
("animate folding" "анимация складывания")
("animate unfolding" "одушевление разворачивается")
("animated" "анимированных")
("animation" "анимация")
("animation toolbar" "панель инструментов анимации")
("annotate" "аннотировать")
("answer" "ответ")
("answer field" "поле ответа")
("answer to question" "ответ на вопрос")
("answers only" "только ответы")
("any" "любой")
("appear" "появляются")
("apply macro" "применить макрос")
("apply macro once" "применить макрос один раз")
("approximate" "приблизительный")
("arc" "дуга")
("arc cosine" "арккосинус")
("arc sine" "арк синус")
("arc tangent" "Арктангенс")
("arch series" "арочные серии")
("are you sure you want to delete collected public keys" "Вы уверены, что хотите удалить собранные открытые ключи")
("are you sure you want to delete selected public keys" "Вы уверены, что хотите удалить выбранные открытые ключи")
("are you sure you want to delete selected secret keys" "Вы уверены, что хотите удалить выбранные секретные ключи")
("are you sure you want to destroy the wallet" "Вы уверены, что хотите уничтожить кошелек")
("art frame" "художественная рамка")
("arxiv category" "АРХИВНАЯ КАТЕГОРИЯ")
("as visual grid" "как визуальная сетка")
("aspect" "аспект")
("attach master" "прикрепить мастера")
("auto" "авто")
("auto-save file" "Автосохранение файла")
("automatic brackets" "автоматических скобок")
("automatic content generation" "Автоматическая генерация контента")
("automatic program brackets" "автоматических программных скобок")
("automatically import bibliographies when opening files" "автоматически импортировать библиографии при открытии файлов")
("automatically remember all passphrases in the wallet" "автоматически запоминает все пароли в кошельке")
("automatically save" "автоматически сохранить")
("axis" "ось")
("b series" "серии «В»")
("back" "назад")
("backtrace errors" "ошибки возврата")
("base" "база")
("baseline" "базовый уровень")
("beamer" "проектор")
("beamer formats" "форматов beamer")
("beamer theme" "Бимер тема")
("bench" "скамейка")
("bend bottom" "Изгиб дна")
("bend corner" "угол сгиба")
("bend diagonal" "Диагональ изгиба")
("bend in" "согнуть")
("bend out" "согнуть")
("bezier" "Безье")
("bibTeX command" "команда bibTeX")
("bidirectional" "двунаправленный")
("big environment box" "большая коробка среды")
("big focus" "большой фокус")
("binary operator" "бинарный оператор")
("bitmap resolution (dpi)" "растровое разрешение (т / д)")
("black floral I" "черный цветочный я")
("black floral II" "черный цветочный II")
("blackboard embold" "доска сложить")
("blank column" "пустой столбец")
("blank row" "пустой ряд")
("block" "блок")
("block content" "Блок контента")
("block of code" "блок кода")
("blur" "размытие")
("both versions" "обе версии")
("bottom baseline" "нижняя базовая линия")
("bottom cell border" "нижняя граница ячейки")
("bottom cell padding" "заполнение нижней ячейки")
("bottom table border" "нижняя граница таблицы")
("bottom table padding" "нижняя обивка стола")
("bottom tools" "нижних инструментов")
("box" "коробка")
("browse back" "просмотр назад")
("browse forward" "просмотр вперед")
("browse modules documentation" "Просмотр документации модулей")
("buffer management" "Управление буфером")
("buffer must be on disk" "буфер должен быть на диске")
("buffer must have a name" "буфер должен иметь имя")
("build buffer" "строительный буфер")
("build buffer in" "встроенный буфер")
("build directory" "Построить каталог")
("build directory in" "построить каталог в")
("build link pages" "построить страницы ссылок")
("build-all" "построить все")
("bump" "шишка")
("busy" "занят")
("cJK" "cJK")
("cJK spacing" "cJK интервал")
("calculus" "Исчисление")
("cancelled" "отменено")
("cannot download directory to file" "невозможно загрузить каталог в файл")
("cannot rename across different servers" "невозможно переименовать на разных серверах")
("cannot upload directory to file" "невозможно загрузить каталог в файл")
("cartesian" "декартов")
("carved wood" "резного дерева")
("case-insensitive search" "поиск без учета регистра")
("categories" "категории")
("category" "категория")
("cell properties" "Свойства ячейки")
("cells" "клеток")
("change default unit" "изменить единицы измерения по умолчанию")
("change passphrase" "изменить пароль")
("change step-size" "изменить размер шага")
("change tags" "изменить теги")
("change the TeXmacs preferences" "изменить настройки TeXmacs")
("change the border of the table" "изменить границу таблицы")
("change the style of mathematical formulas" "Изменить стиль математических формул")
("character contraction" "сокращение символов")
("character encoding" "кодировка символов")
("character expansion" "Расширение персонажа")
("check for updates" "проверить наличие обновлений")
("checkable field" "проверяемое поле")
("cipher algorithm for passphrase encryption" "алгоритм шифрования для парольной фразы")
("circle" "круг")
("classification" "Классификация")
("clean slate" "чистого листа")
("clear all fields" "очистить все поля")
("clear local information" "Очистить местную информацию")
("clear menu" "Очистить меню")
("clear undo history" "Очистить историю отмены")
("click Ok button twice to discard this warning" "дважды нажмите кнопку Ok, чтобы отменить это предупреждение")
("clip" "клип")
("clipboard image format" "формат изображения буфера обмена")
("close animation tool" "Закрыть инструмент анимации")
("close document" "закрыть документ")
("close program" "Закрыть программу")
("close replace tool" "Закрыть заменить инструмент")
("close search tool" "Закрыть инструмент поиска")
("close spell tool" "инструмент заклинания")
("close translations to rebuild" "Закрыть переводы, чтобы восстановить")
("closed bezier" "закрытое безье")
("closed curve" "замкнутая кривая")
("closed smooth" "закрыто гладко")
("closed spline" "закрытый сплайн")
("closing style" "закрывающий стиль")
("cluster by affiliation" "кластер по принадлежности")
("collect garbage" "собрать мусор")
("collected keys" "собранных ключей")
("color of the axes" "Цвет топоров")
("color of the subunits" "Цвет субъединиц")
("color of the units" "Цвет единиц")
("colors" "цветов")
("column to the left" "столбец слева")
("column to the right" "столбец справа")
("columns" "колонны")
("column separation" "Разделение колонн")
("commit file" "файл фиксации")
("common" "общих")
("common formats" "распространенных форматов")
("commutative diagram" "Коммутативная диаграмма")
("compactify" "компактифицировать")
("complete bibliographic reference" "Полная библиографическая ссылка")
("complex actions" "сложных действий")
("compose" "сочинять")
("compress" "компресс")
("compress into toolbar" "сжать в панель инструментов")
("compressed" "сжатых")
("conceal" "скрыть")
("configure look and feel" "настроить внешний вид")
("confirm database entry" "подтвердить запись в базе данных")
("confirm entry" "подтвердить запись")
("confirm selected database entries" "подтвердить выбранные записи базы данных")
("confirm selected entries" "подтвердить выбранные записи")
("conservative conversion options" "консервативные варианты преобразования")
("consoles" "консоли")
("constellation" "Созвездие")
("context aids" "контекстные пособия")
("contextual hints" "контекстных подсказок")
("continue" "продолжить")
("continued fraction" "продолжение фракции")
("contour" "контур")
("contract logarithms" "контрактных логарифмов")
("control the evaluation of expressions" "Контроль оценки выражений")
("convert" "конвертировать")
("convertible" "кабриолет")
("copyright" "авторское право")
("cork charset with TeX catcode definition in preamble" "пробковая кодировка с определением кода TeX в преамбуле")
("correct" "правильно")
("correct all" "исправить все")
("correct formula" "правильная формула")
("correct manually" "исправить вручную")
("correct mathematical formulas" "правильных математических формул")
("correction" "коррекция")
("cosine" "косинус")
("count characters" "кол-ва символов")
("count lines" "подсчета строк")
("count words" "считать слова")
("create a new document" "Создать новый документ")
("create link" "Создать ссылку")
("create preamble" "создать преамбулу")
("create remote directory" "Создать удаленный каталог")
("create remote file" "Создать удаленный файл")
("create subprogram" "создать подпрограмму")
("create subsession" "создать подсессию")
("create table macro" "создать макрос таблицы")
("creating new account" "Создание новой учетной записи")
("creating technical pictures" "Создание технических картинок")
("crop" "урожай")
("crop marks" "меток обрезки")
("cross" "крест")
("crossed boxes" "скрещенных ящиков")
("crossed circles" "скрещенных кругов")
("current user version" "текущая версия пользователя")
("current version" "текущая версия")
("cursor" "курсор")
("curve" "кривая")
("curve intersections" "пересечения кривых")
("curve points" "кривых точек")
("customizations" "Настройки")
("customizing and extending the user interface" "Настройка и расширение пользовательского интерфейса")
("data" "данных")
("database entry" "Запись в базе данных")
("database tool" "инструмент базы данных")
("database toolbar" "Панель инструментов базы данных")
("deactivate once" "отключить один раз")
("dead" "мертвых")
("debug" "отладка")
("debugging console" "консоль отладки")
("debugging tool" "Инструмент отладки")
("decimal comma" "десятичная запятая")
("decimal dot" "десятичная точка")
("decomposed" "разложено")
("decorated" "украшен")
("decorated wood" "украшенная древесина")
("decrease size" "уменьшить размер")
("decrypt" "расшифровать")
("default size" "размер по умолчанию")
("degrade" "деградировать")
("degraded" "деградировал")
("delete documentation cache" "Удалить кеш документации")
("delete entries" "Удалить записи")
("delete link" "Удалить ссылку")
("deleted" "удалено")
("describe" "опишите")
("describe tag" "опишите тег")
("destroy" "уничтожить")
("detach master" "отделяют мастера")
("detailed menus" "подробных меню")
("details in menus" "Подробности в меню")
("determine margins from text width" "определить поля по ширине текста")
("developer" "разработчик")
("developer tool" "инструмент разработчика")
("device" "устройство")
("diamond" "бриллиант")
("differentiate" "дифференцировать")
("dilate" "Дилат")
("direction of progression" "Направление развития")
("direction of translation" "Направление перевода")
("disable coloring on paper" "отключить раскраску на бумаге")
("disable encryption" "отключить шифрование")
("disappear" "исчезнуть")
("disk" "диск")
("display style" "стиль отображения")
("displayed formula" "Отображаемая формула")
("dissociate joined cells" "Разобщить соединенные клетки")
("distort" "искажение")
("distorted" "искажено")
("division" "дивизия")
("document font selector" "Выбор шрифта документа")
("document language" "Язык документа")
("document page format" "Формат страницы документа")
("document paragraph format" "Формат абзаца документа")
("document updates run" "запуск обновлений документа")
("downwards" "вниз")
("dragging" "перетаскивания")
("draw image" "нарисовать изображение")
("draw over" "рисовать над")
("draw over selection" "отрисовка выбора")
("drop" "падение")
("due to" "из-за")
("dynamic" "динамический")
("eRROR" "ОШИБКА")
("edit animation" "Редактировать анимацию")
("edit groups of objects" "Редактировать группы объектов")
("edit macro" "Редактировать макрос")
("edit macros" "Редактировать макросы")
("edit preamble" "Редактировать преамбулу")
("edit source" "Редактировать источник")
("edit style" "Редактировать стиль")
("edit translations file" "Редактировать файл переводов")
("education" "Образование")
("effect pen" "ручка эффекта")
("eigenvalues" "собственных значений")
("eighth" "восьмой")
("embold" "Embold")
("emboss" "тиснение")
("enable page breaking" "Разбить страницу")
("encoding" "кодировка")
("encrypt" "зашифровать")
("encryption" "Шифрование")
("encryption facilities are not currently available" "Средства шифрования в настоящее время недоступны")
("encryption facilities have not been enabled for TeXmacs" "Средства шифрования не были включены для TeXmacs")
("enforce brackets to match" "привести скобки в соответствие")
("engrave" "гравировка")
("enter data" "введите данные")
("enter graphics" "введите графику")
("enter graphics mode" "войти в графический режим")
("enter new passphrase for encryption" "введите новую фразу-пароль для шифрования")
("enter passphrase for decryption" "введите пароль для расшифровки")
("enter passphrase for identity" "введите пароль для идентификации")
("enter title information" "введите информацию о названии")
("entire table" "весь стол")
("entry up to date in database" "запись в базе данных")
("enunciation" "Изложение")
("environment variable" "переменная окружения")
("environments" "среды")
("erode" "разрушать")
("error messages" "Сообщения об ошибках")
("error output" "Ошибка вывода")
("error status report" "Отчет о состоянии ошибки")
("error: bracket does not match" "ошибка: скобка не совпадает")
("error: cyclic or missing chunks detected" "ошибка: обнаружены циклические или отсутствующие фрагменты")
("error: file not found" "ошибка: файл не найден")
("error: ghostview does not seem to be installed on your system" "ошибка: ghostview, похоже, не установлен в вашей системе")
("error: one of the alternatives should be filled out" "ошибка: одна из альтернатив должна быть заполнена")
("error: only one alternatives should be filled out" "ошибка: должна быть заполнена только одна альтернатива")
("error: should fill out name for referencing" "ошибка: следует указать имя для ссылки")
("error: should fill out required field" "ошибка: необходимо заполнить обязательные поля")
("evaluable field" "оцениваемое поле")
("evaluate above" "оценить выше")
("evaluate all" "оценить все")
("evaluate below" "оценить ниже")
("evaluate fields" "оцените поля")
("evaluate fields in order" "Оцените поля по порядку")
("evaluate script" "Оценить сценарий")
("evaluation switch" "Переключатель оценки")
("evaluation tag" "тег оценки")
("even page" "четная страница")
("even pages" "четных страниц")
("events" "событий")
("exact" "точный")
("execution of scripts" "Выполнение скриптов")
("exit graphics" "Графика выхода")
("exit graphics mode" "Выход из графического режима")
("exit left" "Выход налево")
("exit right" "Выход вправо")
("exit tag on the left" "тег выхода слева")
("exit tag on the right" "тег выхода справа")
("expand TeXmacs macros with no LaTeX equivalents" "Расширить макросы TeXmacs без эквивалентов LaTeX")
("expand beamer slides" "Развернуть слайды проектора")
("expand inclusions" "Развернуть включения")
("expand logarithms" "развернуть логарифмы")
("expand trigonometric functions" "Расширить тригонометрические функции")
("expand unrecognized macros" "развернуть нераспознанные макросы")
("expand user-defined macros" "Расширить пользовательские макросы")
("expanded" "расширенный")
("experimental features (to be used with care)" "Экспериментальные функции (следует использовать с осторожностью)")
("explain" "объяснить")
("explanatory item" "пояснительный пункт")
("explicit keystroke" "явное нажатие клавиши")
("explicit margins" "явные поля")
("exponential" "экспоненциальный")
("export bibliography" "Экспортная библиография")
("export entries in buffer" "Экспорт записей в буфер")
("export file" "экспортный файл")
("export formulas as images" "Экспорт формул в виде изображений")
("export mathematical formulas as MathML" "экспортировать математические формулы как MathML")
("export mathematical formulas as images" "Экспорт математических формул в виде изображений")
("export selected entries" "Экспорт выбранных записей")
("export selection" "Выбор экспорта")
("export selection as image" "Экспорт выбора в виде изображения")
("export selections as" "Экспортировать выбор как")
("export sessions" "экспортных сессий")
("exported bibliographic entries" "экспортированные библиографические записи")
("exported bibliographic references" "Экспортированные библиографические ссылки")
("extend" "расширить")
("extended" "расширенный")
("extensible left arrow" "расширяемая стрелка влево")
("extensible right arrow" "расширяемая стрелка вправо")
("extern" "extern")
("external" "внешний")
("extra branch" "дополнительная ветка")
("extra interline space" "дополнительное межстрочное пространство")
("extra name" "дополнительное имя")
("extract" "экстракт")
("extract style file" "Извлечь файл стиля")
("extract style package" "Пакет стилей извлечения")
("factor" "фактор")
("fade" "исчезают")
("fade in" "исчезать")
("fade out" "исчезают")
("fast" "быстро")
("fast decrease" "быстрое уменьшение")
("fast environments" "быстрое окружение")
("fast increase" "быстрое увеличение")
("field reference" "ссылка на поле")
("fifth" "пятый")
("file saved" "файл сохранен")
("fill color" "цвет заливки")
("fill out" "заполнить")
("filter" "фильтр")
("finished collecting symbols documentation" "Закончил сбор документации по документации")
("first" "первый")
("first chunk" "Первый кусок")
("first difference" "первое отличие")
("first error" "Первая ошибка")
("first field" "первое поле")
("first occurrence" "Первое появление")
("first similar" "Первый аналог")
("fit to screen" "по размеру экрана")
("fit to screen width" "по размеру экрана")
("five columns" "пять столбцов")
("fixed" "исправлено")
("flag is off" "флаг выключен")
("flag is on" "флаг включен")
("flatten" "сплющить")
("floating algorithm" "Плавающий алгоритм")
("floating phantom" "плавающий фантом")
("focus" "Фокус")
("focus dependent icons" "Фокус зависимые значки")
("fold all" "сложить все")
("fold all fields" "сложить все поля")
("fold back" "откинуть")
("follow external links" "перейти по внешним ссылкам")
("follow inverse links" "переходить по обратным ссылкам")
("font effects" "эффекты шрифта")
("font selector" "Выбор шрифта")
("force reloading of translations" "Принудительная перезагрузка переводов")
("forward" "вперед")
("four columns" "четыре колонны")
("four dots" "четыре точки")
("fourth" "четвертый")
("fraktur" "Фрактур")
("framed" "подставил")
("from" "от")
("from center" "от центра")
("front matter" "Фасад")
("full" "полный")
("full author list" "Полный список авторов")
("gap" "разрыв")
("garbage collection" "Сборка мусора")
("gaussian" "гауссов")
("gcd" "жк")
("general" "генерал")
("generated LaTeX document contains no errors" "сгенерированный документ LaTeX не содержит ошибок")
("generated field" "сгенерированное поле")
("geometry" "геометрия")
("get list with remote versions" "получить список с удаленными версиями")
("glyphs" "глифов")
("gnaw" "грызть")
("gnawed" "грыз")
("gnuPG command" "команда gnuPG")
("gnuPG error: buffer encryption failed" "Ошибка gnuPG: сбой шифрования буфера")
("gnuPG error: cannot find suitable secret key to decrypt" "Ошибка gnuPG: не удается найти подходящий секретный ключ для расшифровки")
("gnuPG requires name and email to have at least 5 characters" "gnuPG требует, чтобы имя и адрес электронной почты имели не менее 5 символов")
("go to anchor" "иди на якорь")
("go to anchor or float" "идти на якорь или плавать")
("go to anchor or footnote" "перейти на якорь или сноску")
("go to first similar tag" "перейти к первому похожему тегу")
("go to float" "иди плавать")
("go to footnote" "перейти к сноске")
("go to last similar tag" "Перейти к последнему похожему тегу")
("go to next similar tag" "перейти к следующему похожему тегу")
("go to previous similar tag" "перейти к предыдущему похожему тегу")
("go to section" "перейти в раздел")
("grain" "зерно")
("granite" "гранит")
("graphical effects" "Графические эффекты")
("graphical interface font scale" "Масштаб шрифта графического интерфейса")
("graphics" "графика")
("graphics geometry" "Графическая геометрия")
("graphics grids" "графических сеток")
("greyed" "серых")
("grid" "сетка")
("grid curves" "Кривые сетки")
("grid points" "точки сетки")
("grid-curve intersections" "пересечения сетки-кривой")
("group of objects" "группа объектов")
("group/ungroup" "группа / разгруппировка")
("grouped" "сгруппировано")
("guarantee transparent source tracking" "Гарантируйте прозрачное отслеживание источника")
("half wide" "половина ширины")
("hand drawn" "рисованной")
("headers" "заголовки")
("hidden" "скрыто")
("history" "история")
("homepage" "домашняя страница")
("homoglyph substitutions" "Замены гомоглифов")
("horizontal alignment" "Горизонтальное выравнивание")
("horizontal collapse distance" "расстояние горизонтального обрушения")
("horizontal margins" "горизонтальные поля")
("hyphenate as" "Дефис как")
("icon" "иконка")
("if hyphenated" "если переносится")
("ignore" "игнорировать")
("impact" "удар")
("import bibliography" "Импортная библиография")
("import database entry" "Импорт базы данных")
("import entries in buffer" "Импорт записей в буфер")
("import entry" "импортная запись")
("import file" "файл импорта")
("import selected database entries" "Импорт выбранных записей базы данных")
("import selected entries" "Импорт выбранных записей")
("import selections as" "импортировать выбор как")
("import sessions" "сеанса импорта")
("import sophisticated objects as pictures" "Импортировать сложные объекты в виде картинок")
("imported bibliographic entries" "импортированные библиографические записи")
("in popup windows" "во всплывающих окнах")
("inanimated" "неодушевленных")
("inch" "дюймов")
("incomplete entries found to be filled out" "Незавершенные записи найдены для заполнения")
("increase size" "увеличение размера")
("indent paragraphs" "отступ абзацев")
("indentation" "отступ")
("indication" "индикация")
("informative flags" "Информационные флаги")
("initialize" "инициализировать")
("ink here" "чернила здесь")
("ink in" "чернил в")
("ink out" "чернил")
("inline" "встроенных")
("inline arguments" "встроенных аргументов")
("inline code" "встроенный код")
("inline content" "встроенный контент")
("inline formula" "Встроенная формула")
("inner bottom" "внутреннее дно")
("inner left" "Внутренний левый")
("inner right" "Внутренний правый")
("inner top" "внутренняя вершина")
("input command" "Команда ввода")
("input field" "поле ввода")
("input options" "Варианты ввода")
("insert a computer program" "вставить компьютерную программу")
("insert a condition" "вставить условие")
("insert a control flow instruction" "вставить инструкцию потока управления")
("insert a gap" "вставить пробел")
("insert a list" "вставить список")
("insert a multiple choice" "вставить множественный выбор")
("insert a negation" "вставить отрицание")
("insert a new entry" "вставить новую запись")
("insert a note or a floating object" "вставить заметку или плавающий объект")
("insert a numerical operation" "Вставить числовую операцию")
("insert a prominent piece of text" "вставить заметный фрагмент текста")
("insert a question" "вставить вопрос")
("insert a root" "вставить корень")
("insert a script" "вставить скрипт")
("insert a section block" "вставить блок сечения")
("insert a textual operation" "вставить текстовую операцию")
("insert a textual operator" "вставить текстовый оператор")
("insert above" "вставить выше")
("insert abstract" "вставить реферат")
("insert an answer" "вставить ответ")
("insert an enunciation" "вставить изложение")
("insert an operation on tuples" "вставить операцию на кортежи")
("insert annotation" "вставить аннотацию")
("insert author" "вставить автора")
("insert below" "вставить ниже")
("insert copyright and license information" "вставить информацию об авторских правах и лицензии")
("insert explanatory item" "Вставить пояснительный элемент")
("insert field above" "вставить поле выше")
("insert field below" "вставить поле ниже")
("insert large delimiters" "вставить большие разделители")
("insert last name" "вставить фамилию")
("insert left" "вставить слева")
("insert missing invisible operators" "вставить пропущенные невидимые операторы")
("insert more names" "вставить больше имен")
("insert particle" "вставить частицу")
("insert plain text" "вставить обычный текст")
("insert right" "вставить справа")
("insert similar above" "вставить аналогичное выше")
("insert similar below" "вставить аналогичный ниже")
("insert similar block above" "вставить аналогичный блок выше")
("insert similar block below" "вставить аналогичный блок ниже")
("insert subtable" "вставить субтаблицу")
("insert symbol documentation" "вставить документацию по символам")
("insert template" "вставить шаблон")
("insert text field above" "вставить текстовое поле выше")
("insert text field below" "вставить текстовое поле ниже")
("insert title" "вставить заголовок")
("insert title after name" "вставить заголовок после имени")
("insert user interface related markup" "вставить разметку, связанную с пользовательским интерфейсом")
("inserting control points" "вставка контрольных точек")
("integrate" "интегрировать")
("interactive command" "Интерактивная команда")
("interactive questions" "Интерактивные вопросы")
("intercharacter compression" "межсимвольное сжатие")
("intercharacter stretching" "межсимвольное растяжение")
("interrupted" "прервано")
("invalid multi-paragraph selection" "Неверный выбор из нескольких абзацев")
("invalid renaming" "Недопустимое переименование")
("invert" "инвертировать")
("inverted breve" "перевернутая грудь")
("invisible ending" "невидимое окончание")
("invisible newline" "Невидимый перевод строки")
("invisible opening" "Невидимое отверстие")
("join selected cells" "соединить выбранные ячейки")
("jump in" "прыгать")
("junior" "младший")
("keep evaluated expressions" "держать оцененные выражения")
("keep local" "держи локально")
("keep remote" "держи дистанционно")
("keep track of source code" "отслеживать исходный код")
("keep unfolded" "держать в развернутом виде")
("keyboard configuration" "Настройка клавиатуры")
("laptop presentations" "презентации ноутбуков")
("large cells" "большие клетки")
("large displayed" "большой дисплей")
("large displayed fraction" "большая отображаемая дробь")
("large tables" "больших столов")
("last" "последний")
("last difference" "последняя разница")
("last error" "Последняя ошибка")
("last field" "последнее поле")
("last name" "фамилия")
("last occurrence" "Последнее появление")
("last similar" "последний подобный")
("lcm" "lcm")
("left axis" "левая ось")
("left baseline" "левая базовая линия")
("left bottom" "левый низ")
("left cell border" "левая граница ячейки")
("left cell padding" "заполнение левой ячейки")
("left center" "левый центр")
("left click: add point; Right click: undo" "левый клик: добавить точку; правый клик: отменить")
("left click: finish; Right click: undo" "левый клик: закончить; правый клик: отменить")
("left click: new object" "левый клик: новый объект")
("left click: operate" "левый клик: работа")
("left down" "влево")
("left on even pages" "осталось на четных страницах")
("left table border" "левая граница таблицы")
("left table padding" "Обивка левого стола")
("left top" "левый верх")
("left up" "влево")
("left-right arrow" "стрелка влево-вправо")
("leftwards" "влево")
("let the environment float" "пусть окружающая среда плавает")
("line breaking" "разрыв строки")
("line wrapping" "перенос строки")
("linear 2D" "Линейный 2D")
("linear algebra" "линейная алгебра")
("lines around" "строк вокруг")
("link image and copies as" "ссылка на изображение и копирование как")
("link image as" "ссылка на изображение как")
("link mode" "Режим связи")
("link to URL" "ссылка на URL")
("linking tool" "инструмент для связывания")
("live" "вживую")
("live input-output" "живой ввод-вывод")
("load help file" "загрузить файл справки")
("load remote file" "Загрузить удаленный файл")
("loading" "загрузка")
("local entries" "местных записей")
("loci" "локусов")
("locus" "Локус")
("locus rendering" "Рендеринг локуса")
("logarithm" "логарифм")
("logarithmic" "логарифмический")
("logarithmic base" "логарифмическая основа")
("logarithms" "логарифмы")
("logging in" "вход в систему")
("logical and" "логично и")
("logical implication" "логический подтекст")
("logical not" "не логично")
("logical or" "логический или")
("login" "логин")
("logout" "Выйти")
("long macro" "длинный макрос")
("long text" "длинный текст")
("look for more fonts" "искать больше шрифтов")
("loops" "петель")
("macro argument" "макро аргумент")
("macro definition" "макроопределение")
("macro name" "имя макроса")
("macros" "макрос")
("magnify horizontally" "увеличить по горизонтали")
("magnify vertically" "увеличить вертикально")
("main presentation style" "Основной стиль презентации")
("make a letter environment" "составь буквенную среду")
("make a multi-slide presentation" "сделать презентацию с несколькими слайдами")
("make floating" "сделать плавающим")
("make link" "сделать ссылку")
("make non floating" "сделать не плавающим")
("manila paper" "Манильская бумага")
("marginal note" "примечание на полях")
("margins from width" "поля от ширины")
("margins on paper" "поля на бумаге")
("margins on screen" "поля на экране")
("marked" "отмечено")
("material" "материал")
("mathematical output" "Математический вывод")
("matrices" "матриц")
("maximal cell height" "максимальная высота ячейки")
("maximal clustering" "максимальная кластеризация")
("maximal table height" "максимальная высота стола")
("maximal table width" "максимальная ширина стола")
("maximum" "максимум")
("meander" "меандр")
("memory" "память")
("memory usage" "использование памяти")
("menu" "меню")
("merge lines into paragraphs unless separated by blank lines" "объединить строки в абзацы, если они не разделены пустыми строками")
("messages" "сообщений")
("meta data" "метаданных")
("metadata" "метаданные")
("metal" "металл")
("middle baseline" "средняя базовая линия")
("minimal cell height" "минимальная высота клетки")
("minimal cell width" "минимальная ширина ячейки")
("minimal line separation" "Минимальное разделение линий")
("minimal table height" "минимальная высота стола")
("minimal table width" "минимальная ширина стола")
("minimum" "минимум")
("mirror" "зеркало")
("miscellanous" "разное")
("mode dependent icons" "Иконки, зависящие от режима")
("modify remote live document" "изменить удаленный живой документ")
("module" "модуль")
("monospaced" "моноширинный")
("more information about GNU TeXmacs can be found in the Help" "Более подробную информацию о GNU TeXmacs можно найти в справке")
("more information about GNU TeXmacs can be found in the Help->About menu" "Более подробную информацию о GNU TeXmacs можно найти в меню Справка-> О программе")
("motion" "движение")
("mouse over object" "мышь над объектом")
("move" "двигаться")
("move objects" "Переместить объекты")
("move over object on which to operate" "переместить объект, на котором нужно работать")
("multiline" "мультилинии")
("multiple choice" "множественный выбор")
("multiple root" "множественный корень")
("multiplication" "Умножение")
("navigation options" "Варианты навигации")
("never" "никогда")
("new account" "новый аккаунт")
("new bibliography dialogue" "Новый библиографический диалог")
("new document" "новый документ")
("new entry" "новая запись")
("new identity" "новая личность")
("new locus" "новый локус")
("new macro" "новый макрос")
("new passphrase" "новый пароль")
("new remote directory" "новый удаленный каталог")
("new remote file" "новый удаленный файл")
("new style fonts" "шрифты нового стиля")
("new style page breaking" "Разрыв страницы нового стиля")
("new version" "новая версия")
("new window" "новое окно")
("newer version" "более новая версия")
("next chunk" "следующий кусок")
("next difference" "Следующая разница")
("next error" "Следующая ошибка")
("next field" "Следующее поле")
("next occurrence" "следующее вхождение")
("next screen" "следующий экран")
("next similar" "следующий аналог")
("no clustering" "нет кластеризации")
("no completions" "без доработок")
("no errors have been corrected" "ошибки не исправлены")
("no grid" "нет сетки")
("no new public key in document" "нет нового открытого ключа в документе")
("no page break" "без разрыва страницы")
("no page numbers" "без номеров страниц")
("no parent" "нет родителей")
("no selection" "нет выбора")
("no spelling errors" "нет орфографических ошибок")
("normal loci" "нормальных локусов")
("not allowed to remove home directory" "не разрешено удалять домашний каталог")
("not connected to server" "не подключен к серверу")
("not yet implemented" "еще не реализовано")
("notebook" "тетрадь")
("number of polar steps" "число полярных шагов")
("number of subunit steps" "количество шагов субъединицы")
("numbering" "нумерация")
("numeric spreadsheet" "Цифровая таблица")
("odd page" "нечетная страница")
("odd pages" "нечетные страницы")
("of fingerprint" "отпечатка пальца")
("old version" "старая версия")
("older version" "старая версия")
("on the footer" "в нижнем колонтитуле")
("on your system and set it up from the \"Security\" tab" "в вашей системе и настройте его на вкладке «Безопасность»")
("one column" "одна колонна")
("one error has been corrected" "одна ошибка была исправлена")
("one lower case letter, one non alpha-numeric symbol" "одна строчная буква, один не буквенно-цифровой символ")
("one numeric character, one upper case letter" "один числовой символ, одна заглавная буква")
("only convert changes when re-importing" "конвертировать изменения только при повторном импорте")
("only convert changes with respect to imported version" "только преобразовывать изменения относительно импортированной версии")
("only convert changes with respect to tracked version" "конвертировать изменения только в отслеживаемую версию")
("only implemented for complete subtrees" "реализовано только для полных поддеревьев")
("only inline tags" "только встроенные теги")
("only keep folded" "только держать сложенным")
("only keep unfolded" "только держать в развернутом виде")
("only show semantic focus" "Показать только смысловой фокус")
("opacity" "непрозрачность")
("open bibliography" "Открытая библиография")
("open identities" "открытые личности")
("open in new window" "открыть в новом окне")
("open key manager" "менеджер открытых ключей")
("open licence agreement" "Открытое лицензионное соглашение")
("open mailbox" "открыть почтовый ящик")
("open module browser" "браузер с открытым модулем")
("open symbol browser" "Открытый браузер символов")
("open tool in separate window" "открыть инструмент в отдельном окне")
("operation mode" "Режим работы")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "или укажите полный путь к команде «gpg» или «gpg2»")
("order" "заказ")
("ordinary symbol" "обычный символ")
("ornamented" "орнаментированные")
("other login" "другой логин")
("other package" "другой пакет")
("outer bottom" "внешнее дно")
("outer left" "Левый край")
("outer right" "правый верхний")
("outer top" "внешний верх")
("outline" "контур")
("outlined" "обведено")
("outlined emboss" "контурное тиснение")
("outlined engrave" "Контурная гравюра")
("output options" "Параметры вывода")
("oval" "овал")
("overlap" "перекрытие")
("overlay" "оверлей")
("overlays" "оверлеев")
("overlined" "подчеркнуто")
("overview of the scheme extension language" "Обзор схемы расширения языка")
("padded" "мягкий")
("page background" "фон страницы")
("page break after" "разрыв страницы после")
("page breaking algorithm" "алгоритм разрыва страницы")
("page number" "номер страницы")
("page number rendering" "рендеринг номера страницы")
("page rendering" "рендеринг страницы")
("palette" "палитра")
("panorama" "Панорама")
("paragraphs" "абзацев")
("parametric curve" "Параметрическая кривая")
("parametric surface" "Параметрическая поверхность")
("parenthesis" "скобка")
("parenthesized" "в скобках")
("particle" "частица")
("passphrase encryption" "шифрование парольной фразы")
("passphrase wallet facilities are not currently available" "Услуги кошелька для парольной фразы в настоящее время недоступны")
("passphrases are expected to have at least: 8 characters" "пароли должны содержать не менее 8 символов")
("passphrases mismatch" "несоответствие парольных фраз")
("pastel" "пастель")
("pause" "пауза")
("pen width" "ширина пера")
("permanent footer" "постоянный колонтитул")
("permanent header" "постоянный заголовок")
("permanently add to dictionary" "навсегда добавить в словарь")
("permanently insert into dictionary" "навсегда вставить в словарь")
("permissions" "разрешений")
("phantom" "фантом")
("phantoms" "фантомов")
("physics and astronomy class" "Физика и астрономия")
("picture" "картинка")
("pine" "сосна")
("plain" "равнина")
("plain boxes" "простые коробки")
("plain circles" "простых кругов")
("play" "игра")
("play animation" "Воспроизвести анимацию")
("please install GnuPG software from https://www.gnupg.org" "Пожалуйста, установите программное обеспечение GnuPG с https://www.gnupg.org")
("plot" "сюжет")
("plug-ins" "плагинов")
("plural" "множественное число")
("point" "точка")
("polar" "полярный")
("polygon" "полигон")
("pop server settings" "Настройки поп-сервера")
("position of marginal note" "позиция маржинальной ноты")
("poster formats" "форматов постеров")
("poster theme" "тема плаката")
("postfix" "постфикс")
("preferences for editing mathematical formulas" "Настройки для редактирования математических формул")
("preferences for tag" "Настройки тега")
("prefix" "префикс")
("presentation tool" "Инструмент представления")
("preserve" "заповедник")
("preserve tags" "сохранить теги")
("pretty tree output" "красивый вывод дерева")
("preview" "превью")
("previous difference" "предыдущая разница")
("previous error" "Предыдущая ошибка")
("previous field" "предыдущее поле")
("previous occurrence" "Предыдущее вхождение")
("previous screen" "предыдущий экран")
("previous similar" "предыдущий аналог")
("primitive or macro" "примитив или макрос")
("print buffer" "буфер печати")
("print buffer to file" "печать буфера в файл")
("print to file" "печать в файл")
("printer setup" "Настройка принтера")
("program bracket matching" "совпадение скобок программы")
("program bracket selections" "Выбор программных скобок")
("program commands" "Программные команды")
("program font" "программный шрифт")
("program interface for buffer management" "Программный интерфейс для управления буфером")
("programming routines for editing documents" "Программы программирования для редактирования документов")
("prominent" "выдающихся")
("provoke C++ error" "вызвать ошибку C++")
("provoke menu error" "вызвать ошибку меню")
("provoke scheme error" "провоцировать ошибку схемы")
("pseudo code" "псевдокод")
("public key encryption" "шифрование с открытым ключом")
("public keys" "открытые ключи")
("pulse" "пульс")
("qt GUI only, sorry. Use \"Export selection\"" "Только графический интерфейс qt, извините. Используйте «Экспорт выбора»")
("qt-widgets" "qt-widgets")
("quantifier" "квантификатор")
("question" "вопрос")
("questions only" "только вопросы")
("questions with answers" "вопросов с ответами")
("quick evaluation of formulas" "Быстрая оценка формул")
("rank" "ранг")
("raw" "сырой")
("really delete user identity" "действительно удалить личность пользователя")
("really tiny" "действительно крошечный")
("rebuild translations file" "Восстановить файл переводов")
("recent" "недавний")
("recent documents" "последние документы")
("recipients" "получателей")
("recognize" "узнают")
("recover autosave file" "восстановить файл автосохранения")
("rectangular" "прямоугольник")
("reduce" "уменьшить")
("reduce trigonometric functions" "Снижение тригонометрических функций")
("reduced margins" "уменьшенная наценка")
("reference guide for the TeXmacs primitives" "Справочное руководство для примитивов TeXmacs")
("reference guide for the standard TeXmacs styles" "Справочное руководство для стандартных стилей TeXmacs")
("regenerate" "регенерировать")
("register file" "регистр файлов")
("relate" "относиться")
("relation" "отношение")
("release left button: finish editing" "отпустить левую кнопку: закончить редактирование")
("remote" "удаленный")
("remote connections" "Удаленные подключения")
("remote control" "Пульт дистанционного управления")
("remote controllers with keyboard simulation" "Пульты дистанционного управления с имитацией клавиатуры")
("remote directory" "Удаленный каталог")
("remote servers" "удаленных серверов")
("remote tool" "Удаленный инструмент")
("remove" "удалить")
("remove banner" "Удалить баннер")
("remove database entry" "удалить запись в базе данных")
("remove downwards" "убрать вниз")
("remove entries" "удалить записи")
("remove entry" "удалить запись")
("remove field above" "Удалить поле выше")
("remove field below" "удалить поле ниже")
("remove folded" "убрать сложенный")
("remove last field" "удалить последнее поле")
("remove leftwards" "удалить влево")
("remove link" "удалить ссылку")
("remove next field" "удалить следующее поле")
("remove previous field" "удалить предыдущее поле")
("remove rightwards" "удалить вправо")
("remove selected database entries" "Удалить выбранные записи базы данных")
("remove selected entries" "удалить выбранные записи")
("remove superfluous invisible operators" "убрать лишние невидимые операторы")
("remove tag" "удалить тег")
("remove this branch" "удалить эту ветку")
("remove unfolded" "удалить в развернутом виде")
("remove upwards" "убрать вверх")
("removed entries from database" "Удалено записей из базы данных")
("removed entry from database" "Удалена запись из базы данных")
("rename" "переименовать")
("rename section" "переименовать раздел")
("replace TeXmacs styles with no LaTeX equivalents" "заменить стили TeXmacs без эквивалентов LaTeX")
("replace all further occurrences" "заменить все дальнейшие вхождения")
("replace one occurrence" "заменить одно вхождение")
("replace toolbar" "заменить панель инструментов")
("replace unrecognized styles" "заменить непризнанные стили")
("reset error counters" "Сброс счетчиков ошибок")
("resize" "изменить размер")
("resize objects" "изменить размер объектов")
("restart TeXmacs in order to let changes take effect" "перезапустите TeXmacs, чтобы изменения вступили в силу")
("restart in order to let the new look and feel take effect" "перезапустите, чтобы новый эффект вступил в силу")
("retain" "сохранить")
("retime" "время")
("retina settings" "Настройки сетчатки")
("retrieve email" "восстановить электронную почту")
("retrieve remote live document" "получить удаленный живой документ")
("retrieved contents" "найденное содержимое")
("reverse" "реверс")
("reverse ordering" "обратный порядок")
("ridged paper" "ребристая бумага")
("right baseline" "Правая базовая линия")
("right cell border" "Правая граница ячейки")
("right cell padding" "заполнение правой ячейки")
("right down" "прямо вниз")
("right on even pages" "прямо на четных страницах")
("right table border" "правая граница таблицы")
("right table padding" "Правый отступ таблицы")
("right up" "вверх")
("rightwards" "направо")
("rigid box" "Жесткая коробка")
("rotate" "повернуть")
("rotate objects" "вращать объекты")
("rough" "грубо")
("rough paper" "грубая бумага")
("round" "раунд")
("round overbrace" "круглый оверрейс")
("round underbrace" "Круглый подлокотник")
("row above" "строка выше")
("row below" "строка ниже")
("rows" "строки")
("run" "беги")
("run current file" "запустить текущий файл")
("same names" "одноименных")
("same screen margins as on paper" "те же поля экрана, что и на бумаге")
("sample text" "образец текста")
("save auxiliary data" "Сохранить вспомогательные данные")
("save entries" "Сохранить записи")
("save entry" "сохранить запись")
("save image as" "сохранить изображение как")
("save position" "Сохранить позицию")
("save remote file" "сохранить удаленный файл")
("saved modifications in database" "Сохраненные изменения в базе данных")
("scheme command" "Схема команд")
("scheme developers guide" "Руководство разработчика схемы")
("scheme extensions" "Схема расширения")
("scheme interface for the graphical mode" "Схема интерфейса для графического режима")
("screen rendering" "рендеринг экрана")
("screens" "экранов")
("screenshot" "скриншот")
("scripting language" "Язык сценариев")
("scripts" "сценария")
("search and replace" "Поиск и замена")
("search toolbar" "панель инструментов поиска")
("second" "второй")
("secret keys" "секретных ключей")
("sections" "секций")
("see documentation" "см. Документацию")
("select pen" "выберите ручку")
("select the action to be undertaken for each conflict" "выберите действие, которое нужно предпринять для каждого конфликта")
("select view mode" "Выбрать режим просмотра")
("semantic correctness" "семантическая корректность")
("semantic editing" "Семантическое редактирование")
("semantic selections" "семантические выделения")
("semantics" "семантика")
("senior" "старший")
("serif" "засечек")
("server" "сервер")
("session commands" "сеансовых команд")
("set default" "установить по умолчанию")
("set difference" "Разница набора")
("set intersection" "установить пересечение")
("set number of columns" "установить количество столбцов")
("set number of rows" "Задать количество строк")
("set or get environment variables" "установить или получить переменные окружения")
("set properties" "Задать свойства")
("set union" "установить союз")
("set user information" "Задать информацию о пользователе")
("seventh" "седьмой")
("several equations" "несколько уравнений")
("shadow" "тень")
("shadowed" "затенено")
("shadowed raise" "теневой рейз")
("shift" "смена")
("show all parts" "показать все детали")
("show current focus" "Показать текущий фокус")
("show full context" "Показать полный контекст")
("show key presses" "Показать нажатие клавиш")
("show main document" "Показать основной документ")
("show memory usage" "показать использование памяти")
("show one part" "показать одну часть")
("show panorama" "Показать панораму")
("show preamble" "Показать преамбулу")
("show several parts" "показать несколько частей")
("show subunits" "Показать подразделения")
("show table cells" "Показать ячейки таблицы")
("show timings" "Показать тайминги")
("side tools" "боковые инструменты")
("simple" "просто")
("simplification" "упрощение")
("simplified evaluation of formulas" "Упрощенная оценка формул")
("simplified menus" "Упрощенные меню")
("simplify" "Упростить")
("sine" "синус")
("sixth" "шестой")
("skew" "перекос")
("skip all" "пропустить все")
("slant" "Наклон")
("slashed fraction" "разрезанная фракция")
("slides" "слайды")
("slow" "медленно")
("slow decrease" "медленное снижение")
("slow increase" "медленное увеличение")
("small capitals" "маленьких столиц")
("small environment box" "маленькая коробка окружения")
("small focus" "маленький фокус")
("small inline" "маленький встроенный")
("small inline fraction" "маленькая встроенная дробь")
("smash" "разбить")
("smooth" "гладкий")
("smooth end" "гладкий конец")
("smooth extremities" "гладкие конечности")
("smooth start" "плавный старт")
("snap" "оснастка")
("snap distance" "мгновенное расстояние")
("snap to curves" "привязка к кривым")
("snap to grid" "привязка к сетке")
("snap to grid curve" "привязка к кривой сетки")
("snap to intersections of curves" "привязка к пересечениям кривых")
("snap to text borders" "привязка к границам текста")
("snap to text corners" "привязка к углам текста")
("solution" "решение")
("solution to exercise" "Решение для упражнений")
("solution to problem" "решение проблемы")
("solutions" "решений")
("sound" "звук")
("source macros tool" "инструмент исходного макроса")
("source tags" "исходных тегов")
("south" "юг")
("south east" "юго-восток")
("space bar in math mode" "пробел в математическом режиме")
("space bar in text mode" "Пробел в текстовом режиме")
("space stretchability" "растяжимость пространства")
("span" "пролет")
("span over all columns" "охватывает все столбцы")
("special functions" "Специальные функции")
("special properties" "Особые свойства")
("specific baseline" "Конкретный базовый уровень")
("specify color alternation" "указать чередование цветов")
("specify how to traverse the manual" "указать, как пройти руководство")
("specify semantics of a symbol or formula" "указать семантику символа или формулы")
("specify the size of the table" "указать размер таблицы")
("spell check" "проверка орфографии")
("spline" "сплайн")
("split program" "Сплит программа")
("square" "квадрат")
("square overbrace" "Квадратный сгиб")
("square underbrace" "Квадратный подкреп")
("standard Output" "Стандартный выход")
("standard formats" "стандартные форматы")
("standard fraction" "стандартная фракция")
("star" "звезда")
("start server" "стартовый сервер")
("statement" "заявление")
("statistics" "Статистика")
("status" "статус")
("stop server" "остановка сервера")
("storage" "хранилище")
("store tracking information in LaTeX files" "Хранить информацию отслеживания в файлах LaTeX")
("stretch" "растянуть")
("stretch factor" "фактор растяжения")
("strict Ascii" "Строгая Ация")
("strike through" "пробить")
("structured insert above" "Структурная вставка выше")
("structured insert at the left" "структурированная вставка слева")
("structured insert at the right" "структурированная вставка справа")
("structured insert below" "структурированная вставка ниже")
("structured remove downwards" "структурированное удаление вниз")
("structured remove leftwards" "структурированное удаление влево")
("structured remove rightwards" "структурированное удаление вправо")
("structured remove upwards" "структурированное удаление вверх")
("structured variant" "структурированный вариант")
("style options" "опции стиля")
("style parameters" "Параметры стиля")
("subject" "предмет")
("submenu" "подменю")
("subscript below" "нижний индекс ниже")
("subsubmenu" "Sububmenu")
("subsubsubmenu" "sububsubmenu")
("subsubsubsubmenu" "sububsubsubmenu")
("subtable" "подтаблицы")
("subtitle" "субтитры")
("subtraction" "вычитание")
("summarized" "суммировано")
("superscript above" "верхний индекс выше")
("supported plug-ins" "поддерживаемые плагины")
("surface" "поверхность")
("inflate" "зыби")
("swiss" "швейцарский")
("switch to buffer" "переключиться в буфер")
("symbol properties not found" "Свойства символа не найдены")
("symbols" "символов")
("synchronize" "синхронизировать")
("synchronize bibliographic references" "Синхронизировать библиографические ссылки")
("synchronize with remote server" "синхронизировать с удаленным сервером")
("synopsis" "Синопсис")
("system command" "системная команда")
("tab-completion" "табуляция")
("tabbed" "с вкладками")
("table breaking" "Стол ломается")
("table height" "высота стола")
("table properties" "Свойства таблицы")
("table width" "ширина стола")
("tags with special rendering" "тегов со специальным рендерингом")
("tangent" "касательная")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "ожидается буфер teXmacs")
("teXmacs buffer on disk expected" "Ожидается буфер teXmacs на диске")
("teXmacs extensions to scheme and utilities" "Расширения teXmacs для схемы и утилит")
("teXmacs macro" "макрос teXmacs")
("teXmacs package" "пакет teXmacs")
("teXmacs style" "стиль teXmacs")
("test routine" "тестовая рутина")
("testing tree-view" "тестирование дерева")
("text borders" "границы текста")
("text box style" "стиль текстового поля")
("text corners" "текстовые углы")
("textual" "текстовый")
("textual operator" "текстовый оператор")
("textual spreadsheet" "текстовая таблица")
("the TeXmacs plug-in system" "система плагинов TeXmacs")
("the document has not been saved" "документ не был сохранен")
("theme parameters" "Параметры темы")
("these collected public keys will be definitely lost" "эти собранные открытые ключи будут точно потеряны")
("these public keys will be definitely lost" "эти открытые ключи будут точно потеряны")
("these secret keys will be definitely lost" "эти секретные ключи будут точно потеряны")
("thicken" "утолщаются")
("third" "третий")
("this" "это")
("this column" "этот столбец")
("this page footer" "нижний колонтитул этой страницы")
("this page header" "этот заголовок страницы")
("this page number" "этот номер страницы")
("this row" "этот ряд")
("this style specifies page margins in the TeX way" "этот стиль определяет поля страницы способом TeX")
("three columns" "три колонны")
("three dots" "три точки")
("through popup windows" "через всплывающие окна")
("through the menus" "через меню")
("thumbnails" "миниатюры")
("time evolution" "эволюция времени")
("title presentation options" "Параметры представления заголовка")
("title style" "стиль заголовка")
("title suffix" "суффикс заголовка")
("titled block" "титулованный блок")
("toggle cell wrapping mode" "Переключить режим обтекания ячейки")
("toggle here" "здесь переключиться")
("toggle off" "выключить")
("toggle on" "включить")
("tolerant" "толерантный")
("top baseline" "верхний базовый уровень")
("top cell border" "верхняя граница ячейки")
("top cell padding" "верхняя ячейка заполнения")
("top table border" "верхняя граница стола")
("top table padding" "верхняя накладка стола")
("transform" "преобразовать")
("transform cell into subtable" "превратить ячейку в подтаблицу")
("translations" "переводы")
("translations loaded" "переводов загружено")
("transpose" "транспонировать")
("traversal" "обход")
("traverse" "траверса")
("triangle" "треугольник")
("triangularize" "треугольник")
("trigonometric" "тригонометрические")
("trigonometry" "Тригонометрия")
("turn off" "выключить")
("turn on" "включить")
("two columns" "две колонны")
("two dots" "две точки")
("type a latex command followed by return" "введите латексную команду, а затем возврат")
("underlined" "подчеркнуто")
("unfold" "развернуть")
("unfold all" "разверни все")
("unfold all fields" "Развернуть все поля")
("unit" "блок")
("unit length" "длина единицы")
("unknown secret key fingerprint" "Отпечаток неизвестного секретного ключа")
("unregistered file" "незарегистрированный файл")
("unroll" "развернуть")
("unsecure script refused" "небезопасный сценарий отклонен")
("unsupported link mode" "Неподдерживаемый режим связи")
("until" "до")
("untitled block" "блок без названия")
("up to date" "в курсе")
("update buffer" "буфер обновления")
("update this buffer" "обновить этот буфер")
("update web site" "обновить веб-сайт")
("upight" "вверх")
("upload" "загрузка")
("upwards" "вверх")
("use CSS for more advanced formatting" "использовать CSS для более сложного форматирования")
("use MathML" "использовать MathML")
("use as master" "использовать как мастер")
("use extensible brackets" "использовать расширяемые скобки")
("use line wrapping for lines which are longer than 80 characters" "использовать перенос строк для строк длиной более 80 символов")
("use margin kerning (protrusion)" "использовать краевой кернинг (выступ))")
("use protrusion" "использовать выступ")
("use relative path" "использовать относительный путь")
("user interface" "пользовательский интерфейс")
("user interface language" "язык интерфейса пользователя")
("user preferences" "Пользовательские настройки")
("users of oriental languages" "пользователи восточных языков")
("utf-8 with inputenc LaTeX package" "UTF-8 с пакетом InTutenc LaTeX")
("utilities" "коммунальные услуги")
("vanish" "исчезают")
("verbose" "многословный")
("version" "версия")
("versioning tool" "инструмент управления версиями")
("vertical alignment" "вертикальное выравнивание")
("vertical margins" "вертикальные поля")
("vertical space after" "вертикальное пространство после")
("vertical space before" "вертикальное пространство перед")
("vertical space stretchability" "растяжимость по вертикали")
("visible except here" "видно кроме как здесь")
("visible from here on" "видно отсюда")
("visible only here" "видно только здесь")
("visible until here" "видно до здесь")
("visited loci" "посещенных локусов")
("wallet" "кошелек")
("wave" "волна")
("weight" "вес")
("when line wrapping" "когда перенос строки")
("whitespace" "пробел")
("wide" "в ширину")
("wide block" "широкий блок")
("wide colored" "широкий цвет")
("wide float" "широкий круг")
("wide footnote" "широкая сноска")
("wide tabular" "широкая таблица")
("widescreen" "широкоэкранный")
("wrap lines" "линии переноса")
("write a macro" "написать макрос")
("writing TeXmacs bibliography styles" "Написание стилей библиографии TeXmacs")
("writing documentation" "написание документации")
("wrong empty passphrase" "неправильный пустой пароль")
("wrong passphrase" "неправильный пароль")
("year" "год")
("you are attempting to open an encrypted file while" "Вы пытаетесь открыть зашифрованный файл во время")
("you might consider enabling the experimental" "Вы могли бы рассмотреть возможность включения эксперимента")
("you must add a bibliography file" "Вы должны добавить библиографический файл")
("you should also make sure that GnuPG is installed" "Вы также должны убедиться, что GnuPG установлен")
("your personal dictionary has been modified" "Ваш личный словарь был изменен")
("zoom" "зум")
("zoom in" "увеличить")
("zoom out" "уменьшить")
