("a modifier" "")
("a series" "")
("abbreviation" "줄임말")
("about" "...에 관하여")
("about menu" "메뉴에 관하여")
("above" "")
("abstract" "요약")
("accent" "")
("accept" "승인")
("accept all scripts" "")
("accept no scripts" "")
("accept script" "")
("acknowledgment" "감사의 말")
("acronym" "")
("action" "")
("activate" "")
("activate once" "")
("activate hidden" "")
("activation" "")
("acute" "")
("add package" "패키지 추가")
("add switch after" "")
("add switch before" "")
("address" "주소")
("address block" "")
("advanced" "고급")
("advanced layout features" "고급 레이아웃 설정")
("after" "")
("albanian" "알바니아어")
("algorithm" "알고리듬")
("align cell to the bottom" "")
("align cell to the left" "")
("align cell to the right" "")
("align cell to the top" "")
("align table at base of left column" "")
("align table at base of middle column" "")
("align table at base of origin column" "")
("align table at base of right column" "")
("align table at fraction bar height" "")
("align table at the base of bottom row" "")
("align table at the base of middle row" "")
("align table at the base of origin row" "")
("align table at the base of top row" "")
("align table at the bottom" "")
("align table at the center" "")
("align table at the horizontal center" "")
("align table at the left" "")
("align table at the top" "")
("align table to the right" "")
("align text to the left" "")
("align text to the right" "")
("aligned" "")
("alignment" "정렬")
("all" "")
("allow" "")
("allowed extension" "")
("allowed reduction" "")
("alpha release" "")
("alt key" "")
("alternative specification" "")
("american" "영어")
("and" "")
("angular" "")
("animation" "애니메이션")
("appendix" "")
("apply" "")
("apply macro" "")
("apply macro once" "")
("april" "4월")
("arab" "")
("arch series" "")
("archaic" "")
("architecture" "")
("argument" "")
("arithmetic" "")
("armenian" "")
("arrow" "화살표")
("arrows" "화살표")
("article" "소논문")
("as on paper" "")
("assign" "")
("at fraction bar height" "")
("at the baseline" "")
("at the bottom" "")
("at the left" "")
("at the middle" "")
("at the right" "")
("at the top" "")
("attach" "")
("attach buffer to which project" "")
("august" "8월")
("author" "저자")
("authorize" "")
("automatic" "자동")
("automatically close brackets" "")
("automatically generated content" "")
("automatic quotes" "")
("autosave" "자동저장")
("axis" "")
("axiom" "공리")
("b series" "")
("background" "")
("background color" "")
("background evaluations" "")
("backward replace" "")
("backward search" "")
("bad data format" "")
("bar" "")
("bard" "")
("base level" "")
("bashkirian" "")
("basic" "")
("basic communication using pipes" "")
("basic data types" "기본 데이터 형")
("basic types" "기본형")
("be useful" "")
("become a TeXmacs developer" "TeXmacs 개발자가 되려면")
("before" "")
("begin" "")
("below" "")
("beta release" "베타판")
("bibliography" "참고문헌")
("bibliography file" "참고문헌 파일")
("bibliography style" "참고문헌 스타일")
("big" "크게")
("big figure" "큰 그림")
("big operator" "큰 연산부호")
("big skip" "")
("big table" "큰 표")
("binary operation" "이항 연산부호")
("binary relation" "이항 관계부호")
("black" "검정색")
("blackboard bold" "")
("blackboard math" "")
("blackletter" "")
("blue" "파랑색")
("body" "")
("bold" "볼드체")
("book" "책")
("border" "")
("both" "")
("bottom" "")
("bottom border" "")
("bottom cell border" "")
("bottom cell padding" "")
("bottom margin" "")
("bottom padding" "")
("bottom table border" "")
("bottom table padding" "")
("branch" "가지")
("break" "나누기")
("breaking" "")
("breve" "")
("british" "영국영어")
("broken white" "")
("brown" "갈색")
("browse" "브라우즈")
("browse web" "")
("browser" "")
("buffer" "")
("bulgarian" "불가리아어")
("bullet" "")
("bullets" "")
("by" "")
("by typing" "")
("bytes free" "빈 바이트 영역")
("bytes used" "채워진 바이트 영역")
("calligraphic" "")
("cancel" "취소")
("caps-lock key" "")
("case" "")
("cc" "")
("cell" "")
("cell background color" "")
("cell border" "")
("cell height" "")
("cell operation mode" "")
("cell width" "")
("center" "중앙")
("center text" "중앙정렬")
("centered" "")
("centered block" "")
("centered tabular" "")
("change border of cell" "")
("change cell operation mode" "")
("change log" "변경이력")
("changes" "")
("chapter" "장(chapter)")
("check" "검사")
("check text for spelling errors" "")
("chinese" "중국어")
("choice" "선택")
("citation" "인용")
("cite" "")
("class" "")
("clear" "지움")
("clear selection" "")
("clipped" "")
("clipped and magnified" "")
("clipped and resized" "")
("clone" "")
("clone window" "같은 내용의 창 열기")
("close" "닫기")
("close TeXmacs" "TeXmacs 닫기")
("close buffer" "버퍼 닫기")
("close document" "문서 닫기")
("close session" "세션 닫기")
("close window" "창 닫기")
("closing" "클로징")
("closing style" "")
("code" "코드")
("color" "색상")
("column" "컬럼(단)")
("column contains glued items" "")
("common formats" "")
("compact" "")
("compactification" "")
("compactify" "")
("compatibility with other formats" "")
("compile article" "소논문을 컴파일")
("compile book" "책을 컴파일")
("compile buffer" "")
("compile project" "")
("completion" "완성")
("complex" "")
("concrete" "")
("condensed" "")
("condition" "")
("configuration" "설정")
("contact" "")
("content" "내용")
("content tag" "내용 태그")
("context dependent icons" "문맥 의존 아이콘")
("continuation of" "계속됨")
("contribute" "기여")
("control the evaluation of expressions" "식의 값을 제어")
("convention" "")
("converters to other data formats" "다른 포맷으로 변환")
("copy" "복사")
("copy text" "텍스트 복사")
("copy to" "...로 복사")
("copying" "복사 중")
("corollary" "따름정리")
("correct text" "")
("create web site" "웹 사이트 작성")
("cursors" "커서")
("custom tab" "")
("customizing TeXmacs" "TeXmacs 사용자 설정")
("customizing the TeXmacs styles" "TeXmacs 스타일 설정")
("custum tab" "")
("cut" "잘라내기")
("cut text" "텍스트 잘라내기")
("cut to" "...로 잘라내기")
("cypriot" "")
("cyrillic" "")
("cyrillic input method" "")
("cyrillic italic right" "")
("czech" "체코어")
("dancers" "")
("danish" "덴마크어")
("dark grey" "")
("dash" "")
("dashes" "")
("data conversion" "")
("data format" "")
("date" "날짜")
("deactivate" "")
("deactivate table" "")
("december" "12월")
("decorate atoms" "")
("default" "디폴트")
("default padding" "")
("definition" "정의")
("delete" "")
("delete column" "")
("delete row" "")
("denominator" "분모")
("description" "설명형나열")
("destination" "")
("detach" "")
("detailed" "상세히")
("determinant" "행렬식")
("devangari" "")
("developers guide" "개발자 안내서")
("directory" "디렉터리")
("disable" "비활성화")
("disable first indentation" "")
("disable first indentation after" "")
("disable first indentation before" "")
("disable indentation" "")
("disable indentation after" "")
("disable indentation before" "")
("deactivate" "")
("deactivate once" "")
("disallow" "")
("distribute unused space" "")
("div" "")
("do not remap" "")
("document" "문서")
("document format" "문서 포맷")
("document style" "문서 스타일")
("document styles" "문서 스타일(들)")
("documentation" "도움문서")
("documents are trees" "문서 트리")
("dot" "")
("dots" "")
("double stroke" "")
("down" "")
("download" "내려받기")
("dpi" "")
("duplicate" "")
("dutch" "네덜란드어")
("dynamic libraries" "")
("edit" "편집")
("edit source tree" "소스 편집")
("editing tools" "도구 편집")
("email" "전자우편")
("emphasize" "강조")
("emphasize text" "텍스트 강조")
("empty box" "빈 상자")
("enable first indentation" "")
("enable first indentation after" "")
("enable first indentation before" "")
("enable indentation" "")
("enable indentation after" "")
("enable indentation before" "")
("encl" "")
("end" "")
("english" "영어")
("enter a title" "제목 입력")
("enumerate" "번호부나열")
("enumerate|Alpha" "")
("enumerate|Roman" "")
("enumerate|alpha" "")
("enumerate|roman" "")
("env" "")
("environment" "환경")
("epilogue" "")
("equal" "같다")
("equation" "식")
("equations" "식(들)")
("equivalent for" "")
("error" "에러")
("esperanto" "에스페란토어")
("etruscan" "")
("evaluate" "검토")
("evaluate scheme expression" "스킴 표현 검토")
("even page footer" "짝수쪽 바닥글")
("even page header" "짝수쪽 머리글")
("even page margin" "짝수쪽 여백")
("even page left margin" "짝수쪽 왼쪽 여백")
("even page shift" "")
("even page text" "")
("exact horizontal" "")
("exact mode" "")
("exam" "시험지")
("example" "보기")
("exclusive" "")
("exclusive or" "")
("executable" "실행가능")
("execute" "실행")
("execute a TeXmacs command" "TeXmacs 명령 실행")
("execute system command" "시스템 명령 실행")
("executive" "")
("exercise" "연습문제")
("expand" "전개")
("explained" "")
("export" "내보내기")
("export as" "...로 내보내기")
("extend or normal" "")
("extern " "")
("extra" "")
("extract format" "")
("family" "")
("february" "2월")
("figure" "그림")
("file" "파일")
("file name" "파일이름")
("file not found" "파일이 없습니다")
("find next match" "다음 찾기")
("find text" "텍스트 찾기")
("finnish" "핀란드어")
("first contact" "")
("first indentation" "첫단락 들여쓰기")
("first item" "")
("first page" "")
("first start" "처음 시작하기")
("flat" "")
("flexibility" "")
("flexibility factor for vertical spacing" "수직 간격 자동조절자")
("floating figure" "떠다니는 그림")
("floating object" "떠다니는 개체")
("floating table" "떠다니는 표")
("fold" "접기")
("fold input field" "")
("folded" "접힘")
("font" "서체")
("font base size" "서체 기본 크기")
("font dpi" "서체 dpi")
("font family" "글꼴 가족")
("font name" "글꼴 이름")
("font series" "글꼴 시리즈")
("font shape" "글꼴 shape")
("font size" "글꼴 크기")
("font type" "")
("font variant" "")
("fonts" "서체(들)")
("footer" "바닥글")
("footnote" "각주")
("for" "")
("foreground" "")
("foreign" "")
("format" "포맷")
("formatted and structured output" "")
("formatted date" "")
("formatting" "")
("formula" "수식")
("formula style" "")
("forward replace" "")
("forward search" "")
("fraction" "분수")
("french" "프랑스어")
("full manuals" "완전한 설명서")
("full screen mode" "전체화면")
("function" "함수")
("functional" "")
("further customization" "")
("future changes" "")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs는 아무런 보증도 제공하지 않습니다.")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs는 GNU general public license에 따라 개발되었습니다.")
("general architecture of TeXmacs" "")
("general negation" "")
("general note" "")
("generating font file" "폰트 파일을 만드는 중")
("generic" "일반")
("georgian" "")
("german" "독일어")
("getting started" "")
("glossary" "용어집")
("glossary entry" "")
("glue" "")
("glue decorations" "")
("go" "가기")
("gothic" "")
("graphical interface" "")
("grave" "")
("greater" "")
("greater or equal" "")
("greek" "")
("greek letter" "")
("green" "녹색")
("grey" "회색")
("group" "")
("h modifier" "")
("happy typing" "")
("has been aborted" "취소되었습니다")
("has completed its task" "완료하였습니다")
("hat" "")
("header" "머리글")
("header and footer" "머리글과 바닥글")
("hebrew" "")
("height" "높이")
("height is exactly the specified height" "")
("height is maximum of specified height and box height" "")
("height is minimum of specified height and box height" "")
("height magnification" "")
("help" "도움말")
("help me" "")
("help us" "도와주세요")
("here" "")
("hidden" "")
("home" "홈")
("homepage" "홈페이지")
("horizontal" "")
("horizontal cell alignment" "")
("horizontal ink separation" "")
("horizontal part" "")
("horizontal position" "")
("horizontal space" "")
("horizontal table alignment" "")
("horizontally align cell to the base" "")
("horizontally center the cell" "")
("how much longer may pages become" "")
("how much shorter may pages become" "")
("huge" "")
("hungarian" "헝가리어")
("hybrid command" "")
("hyperlink" "하이퍼링크")
("hyphenation" "하이픈처리")
("icelandic" "")
("if" "")
("image" "그림")
("image links" "")
("implementation" "")
("import" "가져오기")
("improving the current implementation" "")
("inactive" "")
("include" "")
("include a document" "문서 불러들이기")
("include file" "파일 불러들이기")
("inclusion into TeXmacs" "")
("inclusions" "")
("indent" "들여쓰기")
("indentation flag" "들여쓰기")
("index" "색인")
("index entry" "")
("index level" "")
("informative flags" "")
("inline arguments" "")
("input" "입력")
("input mode" "입력 모드")
("insert" "삽입")
("insert Pr" "")
("insert a TeXmacs symbol" "")
("insert a big operator" "")
("insert a binary operation" "")
("insert a binary relation" "")
("insert a blackboard bold character" "")
("insert a bold calligraphic character" "")
("insert a bold character" "")
("insert a calligraphic character" "")
("insert a condition" "")
("insert a control flow instruction" "")
("insert a fraction" "")
("insert a fraktur character" "")
("insert a greek character" "")
("insert a large left delimiter" "")
("insert a large right delimiter" "")
("insert a large separator" "")
("insert a left subscript" "")
("insert a link" "")
("insert a miscellaneous symbol" "")
("insert a new branch" "")
("insert a new item" "")
("insert a numerical operation" "")
("insert a picture" "")
("insert a square root" "")
("insert a table" "")
("insert a table or a matrix" "")
("insert a textual operation" "")
("insert a wide symbol above" "")
("insert a wide symbol below" "")
("insert an" "")
("insert an accent" "")
("insert an arrow" "")
("insert an environment" "")
("insert an n" "")
("insert an operation on tuples" "")
("insert appendix" "")
("insert arccos" "")
("insert arcsin" "")
("insert arctan" "")
("insert arg" "")
("insert argument" "")
("insert author" "")
("insert automatically generated content" "")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "")
("insert big intersection" "")
("insert big logical and" "")
("insert big logical or" "")
("insert big product" "")
("insert big square union" "")
("insert big summation" "")
("insert big tensor product" "")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "")
("insert chapter" "")
("insert column" "")
("insert column to the left" "")
("insert column to the right" "")
("insert cos" "")
("insert cosh" "")
("insert cot" "")
("insert coth" "")
("insert csc" "")
("insert deg" "")
("insert det" "")
("insert dim" "")
("insert dollar" "")
("insert equation" "")
("insert executable markup" "")
("insert exp" "")
("insert fields" "")
("insert footnote" "")
("insert formula" "")
("insert gcd" "")
("insert hom" "")
("insert horizontal interword space" "")
("insert image" "")
("insert inactive markup" "")
("insert inf" "")
("insert input field above" "")
("insert input field below" "")
("insert ker" "")
("insert lg" "")
("insert lim" "")
("insert liminf" "")
("insert limsup" "")
("insert ln" "")
("insert log" "")
("insert macro" "")
("insert mathematics" "")
("insert max" "")
("insert medium horizontal space" "")
("insert medium vertical space" "")
("insert min" "")
("insert negative horizontal space" "")
("insert new item or number" "")
("insert new rows or columns" "")
("insert or delete rows or columns" "")
("insert row" "")
("insert row above" "")
("insert row below" "")
("insert sec" "")
("insert section" "절(section) 삽입")
("insert sharp" "")
("insert sin" "")
("insert sinh" "")
("insert small horizontal space" "")
("insert small vertical space" "")
("insert structural markup" "")
("insert subsection" "")
("insert subsubsection" "")
("insert sup" "")
("insert tan" "")
("insert tanh" "")
("insert text field" "")
("insert thick horizontal space" "")
("insert title" "")
("insert value" "")
("interactive command" "")
("interfacing" "인터페이스")
("interfacing TeXmacs with other systems" "")
("interjection" "")
("interline separation" "")
("interline space" "")
("internationalization" "")
("interparagraph space" "")
("interrupt execution" "")
("introduction" "")
("invisible" "")
("invisible citation" "")
("irish" "")
("is running" "")
("is tuple" "")
("ispell does not respond" "")
("ispell is already busy" "")
("italian" "이탈리아어")
("italic" "")
("italic right" "")
("itemize" "항목나열")
("january" "1월")
("japanese" "일본어")
("july" "7월")
("june" "6월")
("justified" "좌우정렬")
("justify text" "텍스트 좌우정렬")
("key" "")
("keyboard" "키보드")
("keyboard equivalent" "")
("keyboard modifiers" "")
("keyboard shorthand" "")
("keymaps" "")
("keyword" "주제어")
("keywords" "주제어(들)")
("kill" "")
("known bugs" "")
("korean" "한국어")
("label" "라벨(label)")
("landscape" "")
("language" "언어")
("large" "")
("large closing bracket" "")
("large delimiter" "")
("large opening bracket" "")
("large separator" "")
("last page" "")
("latex command" "")
("latin" "")
("layout" "레이아웃")
("left" "")
("left arrow" "")
("left border" "왼쪽 끝")
("left cell border" "")
("left cell padding" "")
("left margin" "왼쪽 여백")
("left padding" "")
("left prime" "")
("left aligned" "")
("left slanted" "")
("left subscript" "")
("left superscript" "")
("left surrounding" "")
("left table border" "")
("left table padding" "")
("legal" "")
("lemma" "보조정리")
("length" "")
("less" "")
("less or equal" "")
("letter" "편지")
("license" "")
("light" "")
("light grey" "")
("limitations" "")
("limits" "")
("line" "")
("line break" "행 나눔")
("line stretch" "")
("link" "링크")
("link image" "")
("list" "")
("list of figures" "그림 목록")
("list of tables" "표 목록")
("load" "불러오기")
("load LaTeX file" "LaTeX 파일 불러오기")
("load TeX file" "TeX 파일 불러오기")
("load TeXmacs file" "TeXmacs 파일 불러오기")
("load TeXmacs style file" "TeXmacs 스타일 파일 불러오기")
("load a file" "파일 불러오기")
("load buffer" "버퍼 불러오기")
("load file" "")
("load html file" "")
("load image" "이미지 불러오기")
("load in new window" "새 창으로 불러오기")
("load latex file" "")
("load more recent autosave file" "최근 자동저장된 파일 읽어들임")
("load tex file" "TeX 파일 읽어들임")
("load verbatim file" "파일을 verbatim으로 불러오기")
("loaded" "")
("long" "")
("look and feel" "")
("look up" "")
("lower border" "아래쪽 끝")
("m modifier" "")
("macro" "매크로")
("magenta" "마젠타")
("magic" "")
("magnification" "확대")
("magnified" "")
("main" "메인")
("main icon bar" "메인 아이콘 바")
("major changes" "")
("make a page insertion" "")
("make a subscript" "")
("make a superscript" "")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "")
("make grave" "")
("make hat" "")
("make label" "")
("make negation" "")
("make page reference" "")
("make reference" "")
("make square root" "")
("make tilde" "")
("make title" "제목 작성")
("make vector" "")
("making donations" "")
("manual" "매뉴얼")
("map to" "")
("march" "3월")
("margins" "여백")
("margins as on paper" "")
("master" "")
("master file" "")
("math" "수학")
("math font" "수학 글꼴")
("math font family" "")
("math font series" "")
("math font shape" "")
("mathematical" "")
("mathematical and customized input" "")
("mathematical font" "")
("mathematical formulas" "")
("mathematical input" "")
("mathematical typesetting" "")
("mathematics" "수학")
("matrix" "행렬")
("maximal" "")
("maximal number of columns" "")
("maximal number of rows" "")
("maximum mode" "")
("may" "5월")
("medium" "")
("medium skip" "")
("meminfo" "")
("merge" "")
("messy" "")
("meta key" "")
("middle" "")
("minimal" "")
("minimal number of columns" "")
("minimal number of rows" "")
("minimum mode" "")
("minus" "")
("miscellaneous" "")
("miscellaneous features" "")
("mod" "")
("mode" "")
("modifier" "")
("modify cell alignment" "")
("modify cell border" "")
("modify cell padding" "")
("modify cell size" "")
("modify table border" "")
("modify table padding" "")
("mongolian" "")
("more information about GNU TeXmacs can be found in the Help" "더 자세한 사항은 도움말을 찾아보세요")
("mosaic" "")
("move down" "")
("move object" "")
("move to the right when finished" "")
("move up" "")
("multiline input" "")
("mutator tags" "")
("my documents" "")
("n-th" "")
("n-th root" "")
("name" "이름")
("negation" "")
("new" "새로 작성")
("new buffer" "새 버퍼")
("new column" "다음 단")
("new double page" "새 홀수쪽으로 나누기")
("new double page before" "앞에서 새 홀수쪽으로 나누기")
("new item" "새 열거항목")
("new line" "새 줄")
("new number" "")
("new page" "페이지 나누기")
("new page before" "앞에서 페이지 나누기")
("new paragraph" "새 단락")
("new roman" "")
("new row" "")
("new table" "")
("next" "")
("next line" "다음 줄")
("no changes need to be saved" "바뀐 것이 없어 저장할 필요 없습니다.")
("no dictionary for" "해당 사전이 없습니다")
("no first indentation" "첫 단락 들여쓰지 않기")
("no indentation" "들여쓰지 않기")
("no line break" "행 나누지 않기")
("no matches found" "일치 부분이 발견되지 않습니다")
("no matches found for" "")
("no more matches for" "")
("no more redo information available" "")
("no more undo information available" "")
("no name" "")
("no page break after" "뒤에서 페이지 나누지 않기")
("no page break before" "앞에서 페이지 나누지 않기")
("no spelling errors found in text" "")
("no style" "")
("none" "")
("normal" "")
("norwegian" "")
("not" "")
("not equal" "")
("not found" "")
("notation" "")
("note" "노트")
("november" "11월")
("number" "")
("number of columns" "다단")
("number equation" "")
("numbered equation" "")
("numbered equations" "")
("numerator" "분자")
("numeric" "")
("objectives" "")
("occurrences" "")
("october" "10월")
("odd page footer" "홀수쪽 바닥글")
("odd page header" "홀수쪽 머리글")
("odd page margin" "홀수쪽 여백")
("odd page left margin" "홀수쪽 왼쪽 여백")
("odd page right margin" "홀수쪽 오른쪽 여백")
("odd page shift" "")
("odd page text" "")
("off" "")
("ok" "승인(OK)")
("old english" "")
("old slavonic" "")
("old style" "")
("on" "")
("on cells" "")
("on columns" "")
("on entire table" "")
("on rows" "")
("one spelling error has been corrected" "")
("online documentation" "")
("online help" "온라인 도움말")
("only inline tags" "")
("open" "열기")
("open a new buffer" "새 버퍼로 열기")
("open new window" "새 창 열기")
("opening" "오프닝")
("operation on named selection" "")
("operation on primary selection" "")
("operation on secondary selection" "")
("operation on ternary selection" "")
("optical" "")
("option" "옵션")
("options" "옵션(들)")
("or" "")
("orange" "주황색")
("orientation" "")
("origin" "")
("original welcome message" "")
("other" "기타")
("other pages" "")
("other projects" "")
("other style" "")
("outlined roman" "")
("output" "출력")
("output mode" "출력 모드")
("over" "")
("overbrace" "")
("overline" "")
("padding" "")
("page" "페이지")
("page bottom margin" "페이지 하단 여백")
("page break" "페이지 나눔")
("page break before" "")
("page height" "페이지 높이")
("page insertion" "페이지 삽입")
("page layout" "페이지 레이아웃")
("page number text" "")
("page numbering" "페이지 번호붙임")
("page reference" "페이지 참조")
("page right margin" "페이지 오른쪽 여백")
("page setup" "페이지 설정")
("page top margin" "페이지 상단 여백")
("page type" "페이지 유형")
("page width" "페이지 폭")
("paper" "용지")
("paper type" "용지 유형")
("papyrus" "")
("paragraph" "문단")
("paragraph mode" "")
("paragraph width" "")
("part" "")
("past changes" "")
("paste" "붙여넣기")
("paste from" "...에서 붙여넣기")
("paste text" "")
("path" "경로")
("perform operations on cells" "")
("perform operations on columns" "")
("perform operations on entire table" "")
("perform operations on rows" "")
("permanent" "")
("person" "")
("personal dictionary has been modified" "")
("phantasy" "")
("philosophy" "")
("phoenician" "")
("phonetic" "")
("pink" "분홍색")
("plain block" "")
("plain tabular" "")
("planned changes" "")
("plans for the future" "")
("please" "")
("please wait" "기다려주세요")
("plugin" "플러그인")
("plugins" "플러그인")
("plus" "")
("polish" "폴란드어")
("porting TeXmacs to other platforms" "")
("portrait" "")
("portuguese" "포르투갈어")
("position" "")
("position float" "")
("position floating object" "")
("position the table" "")
("postscript" "")
("postscript image" "")
("pre-alpha release" "")
("preamble" "설정영역(preamble)")
("preamble mode" "")
("preferences" "환경설정")
("presentation" "프레젠테이션")
("presentation mode" "프레젠테이션 보기")
("presentation tag" "밑줄과 첨자")
("preview before printing" "")
("preview command" "")
("preview with ghostview" "")
("previous" "")
("primary" "")
("prime" "")
("print" "인쇄")
("print all" "모두 인쇄")
("print all to file" "파일로 인쇄")
("print page selection" "일부만 인쇄")
("print page selection to file" "일부만 파일로 인쇄")
("print to postscript file" "포스트스크립트 파일로 인쇄")
("printer" "프린터")
("printer dpi" "")
("printing command" "")
("problem" "문제")
("professional" "")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "프로그램")
("program font" "프로그램 폰트")
("program mode" "프로그램 모드")
("programming" "")
("progressive" "")
("project" "프로젝트")
("projects" "프로젝트")
("prologue" "")
("prompt on scripts" "")
("prompts and default input" "")
("proof" "증명")
("proportional" "")
("proportional typewriter" "")
("proposition" "명제")
("query replace" "")
("quit" "종료")
("quotation" "")
("quote" "")
("range" "")
("really close it" "")
("really huge" "")
("really quit" "")
("recover autosave file" "자동저장된 파일 복원")
("red" "빨강색")
("redo" "되돌리기")
("redo undone changes" "")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "")
("reduce right margin by" "")
("reduce top margin by" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "참조")
("reference guide" "레퍼런스 가이드")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "")
("regular" "")
("release" "")
("reload" "")
("remark" "리마크")
("remove all output fields" "")
("remove fields" "")
("remove input field" "")
("remove input field above" "")
("remove number" "")
("remove package" "패키지 삭제")
("remove this switch" "")
("renumber this page" "")
("repeat" "반복")
("repeat object" "")
("replace" "바꾸기")
("replace by" "...로 바꾸기")
("replaced" "")
("replaced one occurrence" "")
("reset" "")
("resize object" "")
("resized" "크기조절")
("search results for" "")
("return" "")
("revert" "뒤로")
("revert buffer" "이전 버퍼로")
("right" "")
("right arrow" "")
("right border" "오른쪽 끝")
("right cell border" "")
("right cell padding" "")
("right margin" "오른 여백")
("right padding" "")
("right aligned" "")
("right subscript" "")
("right superscript" "")
("right surrounding" "")
("right table border" "")
("right table padding" "")
("rigid" "")
("rigid horizontal" "")
("rigid space" "")
("roman" "로만(체)")
("romanian" "루마니아어")
("root" "제곱근")
("rotate backward" "")
("rotate forward" "")
("row" "")
("row contains glued items" "")
("runic" "")
("running author" "난외저자명")
("running title" "난외표제")
("russian" "러시아어")
("sample" "")
("sans serif" "산세리프(체)")
("save" "저장")
("save TeXmacs file" "")
("save TeXmacs style file" "")
("save as" "다른 이름으로")
("save as LaTeX" "LaTeX으로 저장")
("save as TeX" "TeX으로 저장")
("save buffer" "버퍼 저장")
("save buffer as" "버퍼를 다른 이름으로 저장")
("save file" "파일 저장")
("save html file" "html파일 저장")
("save image" "이미지 저장")
("save latex file" "LaTeX파일 저장")
("save tex file" "TeX파일 저장")
("save this buffer" "작업 버퍼 저장")
("save verbatim file" "")
("saved" "저장되었습니다")
("scheme command" "")
("screen layout" "화면 레이아웃")
("screen margins" "화면 여백")
("script" "")
("script above" "")
("script below" "")
("script script size" "")
("script size" "")
("scripts not accepted" "")
("search" "찾기")
("search words in my documents" "내 문서에서 찾기")
("search words in the documentation" "")
("search words in the source code" "소스코드에서 찾기")
("searching" "")
("secondary" "")
("section" "절")
("security" "")
("see" "")
("select a document style" "문서 스타일을 선택하세요")
("select a foreground color" "전면 색상을 선택하세요")
("select a language" "언어를 선택하세요")
("selected region" "")
("selection" "선택")
("selections" "선택(들)")
("seminar" "세미나")
("sending commands to TeXmacs" "")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "분리자")
("september" "9월")
("serb" "")
("series" "")
("series|right" "")
("session" "세션")
("session name" "")
("session type" "")
("sessions" "")
("set" "")
("set background color of cell" "")
("set cell mode" "")
("set extension center" "")
("set height" "")
("set height of cell" "")
("set margins" "")
("set n" "")
("set or get environment variables" "")
("set paragraph margins" "")
("set paragraph mode" "")
("set printer dpi" "")
("set printing command" "")
("set span" "")
("set special cell properties" "")
("set special table properties" "")
("set text width" "")
("set width" "")
("set width of cell" "")
("settings" "")
("setup printer" "")
("shape" "")
("shift-down" "")
("shift-right" "")
("short" "")
("show" "")
("show header and footer" "")
("show hidden" "")
("show on screen" "")
("shrinking factor" "축소비율")
("signature" "")
("size" "크기")
("size limits" "")
("slanted" "")
("sloppy" "")
("slovene" "슬로바키아어")
("small" "")
("small caps" "")
("small figure" "작은 그림")
("small skip" "")
("small table" "작은 표")
("source" "소스")
("source code" "소스 코드")
("source tags" "소스(원본)")
("space" "스페이스")
("space between lines" "")
("space between paragraphs" "")
("spacing" "사이띄기")
("spanish" "스페인어")
("special" "")
("special cell properties" "")
("special table properties" "")
("specific" "")
("spell" "철자")
("spell checking complete" "철자 검사 완료")
("spelling error" "")
("spelling errors have been corrected" "")
("split" "")
("split session" "")
("square root" "제곱근")
("standard environment variables" "")
("standard formats" "")
("standard TeXmacs styles" "")
("start" "시작")
("start a new chapter" "")
("start a new section" "")
("start an interactive session" "")
("status bar" "상태 바")
("stretch" "")
("stretchable" "")
("stretchable horizontal" "")
("stretchable vertical" "")
("stretched" "")
("stroke" "")
("strokes" "")
("strong" "")
("structural" "")
("style" "스타일")
("styles" "")
("stylesheet language" "")
("sub" "")
("subparagraph" "")
("subscript" "아래첨자")
("subsection" "소절(sub)")
("subsub" "")
("subsubsection" "소소절(subsub)")
("subtitle" "")
("summary" "")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "위첨자")
("swedish" "스웨덴어")
("swiss" "")
("switch" "")
("switch to first" "")
("switch to formula style" "")
("switch to last" "")
("switch to next" "")
("switch to previous" "")
("switching and folding" "")
("symbol" "")
("system command" "")
("system environment variables" "")
("tab" "")
("table" "표")
("table command" "")
("table of contents" "목차")
("tables" "")
("tabular" "")
("tabular material" "")
("teXmacs as an interface" "")
("teXmacs fonts" "")
("teXmacs notice" "TeXmacs 알림")
("teXmacs plugins" "")
("teXmacs style files" "")
("ternary" "")
("test" "")
("tex" "")
("text" "텍스트")
("text font" "")
("text height correction" "")
("text width" "")
("texts" "텍스트")
("th century bc" "")
("th root" "")
("thai" "")
("the TeXmacs authors" "")
("the TeXmacs format" "")
("the application did not send its usual startup banner" "")
("the application does not reply" "")
("the application is already running" "")
("the boxes produced by the typesetter" "")
("the document has not been saved" "작업 버퍼가 저장되지 않았습니다")
("the graphical user interface" "")
("the leaves of TeXmacs trees" "")
("the mycas example" "")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "")
("theorem" "정리")
("there are unsaved documents" "저장되지 않은 파일이 있습니다")
("this document has not been saved" "현재 버퍼가 저장되지 않았습니다")
("this document has been produced using" "다음을 사용하여 작성되었습니다:")
("this line" "")
("this page" "")
("this page footer" "")
("this page header" "")
("tilda" "")
("tilde" "틸데")
("times" "")
("tiny" "")
("title" "제목")
("to the left" "왼쪽으로")
("to the right" "오른쪽으로")
("today" "오늘")
("tools" "도구")
("top" "")
("top border" "")
("top cell border" "")
("top cell padding" "")
("top level" "")
("top margin" "")
("top padding" "")
("top table border" "")
("top table padding" "")
("translate" "")
("tree" "")
("tuple" "")
("turkish" "")
("tutorial" "튜토리얼")
("type" "")
("type a latex command followed by" "")
("type body" "")
("type denominator" "")
("type numerator" "")
("type script" "")
("typesetted boxes" "")
("typewriter" "타자기(체)")
("typewriter small caps" "")
("typing a simple text" "")
("typing simple texts" "")
("ugaritic" "")
("ukrainian" "우크라이나어")
("underbrace" "")
("underline" "")
("undo" "취소하기")
("undo last changes" "")
("up" "")
("update" "갱신")
("update from web" "")
("update image links" "")
("upper border" "위쪽 끝")
("upright" "")
("use TeXmacs" "")
("use a black color" "")
("use a blue color" "")
("use a bold font" "")
("use a brown color" "")
("use a calligraphic font" "")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "")
("use calligraphical font" "")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "")
("use italic font shape" "")
("use large font size" "")
("use left hand column as border" "")
("use medium font series" "")
("use normal font size" "")
("use package" "")
("use paragraph width" "")
("use really huge font size" "")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "")
("use row above as border" "")
("use row below as border" "")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "")
("use small font size" "")
("use small-caps font shape" "")
("use the blackboard bold font" "")
("use the fraktur font" "")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "")
("user provided icons" "사용자 아이콘")
("users of Cyrillic languages" "")
("value" "")
("variable" "")
("variant" "")
("vector" "")
("verbatim" "그대로보이기(verbatim)")
("verse" "운문(시)")
("vertical" "")
("vertical after" "")
("vertical before" "")
("vertical cell alignment" "")
("vertical part" "")
("vertical position" "")
("vertical space" "")
("vertical table alignment" "")
("vertically align cell to the base" "")
("vertically center the cell" "")
("very large" "")
("very small" "")
("vietnamese" "")
("view" "보기")
("visible" "")
("warning" "경고")
("web" "웹")
("welcome" "환영")
("welcome to GNU TeXmacs" "GNU TeXmacs의 세계에 오신 것을 환영합니다")
("what is new" "")
("when finished" "")
("while" "")
("white" "흰색")
("wide accent" "")
("wide bar" "")
("width" "폭(width)")
("width is exactly the specified width" "")
("width is maximum of specified width and box width" "")
("width is minimum of specified width and box width" "")
("width magnification" "")
("window" "")
("window height" "")
("window width" "")
("windows key" "")
("with" "")
("write a macro" "")
("write a name" "")
("write bold mathematics" "")
("write bold text" "")
("write italic text" "")
("write sample text" "")
("write strong text" "")
("write typewriter text" "")
("write verbatim text" "")
("writing data converters" "")
("writing your own style files" "")
("written with TeXmacs" "TeXmacs로 작성하였습니다")
("yellow" "노랑색")
("you can also obtain" "")
("your document is back in its original state" "")
("your first interface" "")
("your language" "")
