<TeXmacs|1.99.15>

<style|<tuple|source|english>>

<\body>
  <active*|<\src-title>
    <src-package|prefix-enumerations|1.0>

    <\src-purpose>
      Prefix nested enumerations by the outer counter
    </src-purpose>

    <src-copyright|2008--2010|Joris van der Hoeven>

    <\src-license>
      This <TeXmacs> style package falls under the <hlink|GNU general public
      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
      WHATSOEVER. If you don't have this file, then write to the Free
      Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
      02110-1301, USA.
    </src-license>
  </src-title>>

  <assign|prefix-enumerate-1|true>

  <assign|prefix-enumerate-2|true>

  <assign|prefix-enumerate-3|true>

  <assign|prefix-enumerate-4|true>

  \;

  <assign|prefix-enumerate-numeric|true>

  <assign|prefix-enumerate-roman|true>

  <assign|prefix-enumerate-Roman|true>

  <assign|prefix-enumerate-alpha|true>

  <assign|prefix-enumerate-Alpha|true>
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>