("a modifier" "a módosítóbillenty¶")
("a series" "")
("abbreviation" "rövidítés")
("about" "névjegy")
("about menu" "névjegy menü")
("above" "felülre")
("abstract" "kivonat")
("accent" "ékezet")
("accept" "elfogadás")
("accept all scripts" "az összes szkript elfogadása")
("accept no scripts" "szkriptek elutasítása")
("accept script" "szkript elfogadása")
("account" "hozzáférés")
("acknowledgment" "köszönetnyilvánítás")
("acronym" "bet¶szó")
("action" "akció")
("activate" "aktiválás")
("activate once" "aktiválás egy alkalomra")
("activate hidden" "")
("activation" "aktiválás")
("active link types" "aktív hivatkozástípusok")
("acute" "acute")
("add package" "csomag hozzáadása")
("add switch after" "kapcsoló hozzáadása ez után")
("add switch before" "kapcsoló hozzáadása ez elé")
("address" "cím")
("address block" "címblokk")
("advanced" "haladó")
("advanced layout features" "haladó elrendezési beállítások")
("after" "ez után")
("albanian" "albán")
("algorithm" "algoritmus")
("align cell to the bottom" "cella igazítása alulra")
("align cell to the left" "cella igazítása balra")
("align cell to the right" "cella igazítása jobbra")
("align cell to the top" "cella igazítása felülre")
("align table at base of left column" "táblázat bal oldali oszlophoz igazítása")
("align table at base of middle column" "táblázat középs® oszlophoz igazítása")
("align table at base of origin column" "")
("align table at base of right column" "táblázat jobb oldali oszlophoz igazítása")
("align table at fraction bar height" "táblázat igazítása a törtvonal magasságához")
("align table at the base of bottom row" "táblázat alsó sorhoz igazítása")
("align table at the base of middle row" "táblázat középs® sorhoz igazítása")
("align table at the base of origin row" "")
("align table at the base of top row" "táblázat fels® sorhoz igazítása")
("align table at the bottom" "táblázat igazítása alulra")
("align table at the center" "táblázat igazítása középre")
("align table at the horizontal center" "táblázat igazítása vízszintesen középre")
("align table at the left" "táblázat igazítása balra")
("align table at the top" "táblázat igazítása felülre")
("align table to the right" "táblázat igazítása jobbra")
("align text to the left" "szöveg igazítása balra")
("align text to the right" "szöveg igazítása jobbra")
("aligned" "igazított")
("alignment" "igazítás")
("all" "minden oldal")
("allow" "engedélyezés")
("allow for macro definitions in preamble" "makródefiníciók engedélyezése a preamble szakaszban")
("allowed extension" "engedélyezett kiterjesztés")
("allowed reduction" "engedélyezett egyszer¶sítés")
("alpha release" "alfa változat")
("also on paper" "papíron is")
("alt key" "alt billenty¶")
("alternative specification" "alternatív specifikáció")
("always" "mindig")
("american" "amerikai")
("and" "és")
("angular" "angular")
("animation" "animáció")
("appendix" "függelék")
("apply" "alkalmazás")
("apply macro" "makró alkalmazása")
("apply macro once" "makró alkalmazása egyszer")
("april" "április")
("arab" "arab")
("arc" "ív")
("arc cosine" "arkusz koszinusz")
("arc sine" "arkusz szinusz")
("arc tangent" "arkusz tangens")
("arch series" "")
("archaic" "archaikus")
("architecture" "")
("argument" "argumentum")
("arithmetic" "aritmetikai m¶velet")
("armenian" "örmény")
("arrow" "nyíl")
("arrows" "nyilak")
("article" "cikk")
("as on paper" "mint a papíron")
("assign" "")
("at fraction bar height" "törtvonal magasságában")
("at the baseline" "az alapvonalnál")
("at the bottom" "alul")
("at the left" "bal oldalon")
("at the middle" "középen")
("at the right" "jobb oldalon")
("at the top" "felül")
("attach" "csatolás")
("attach buffer to which project" "melyik projekthez csatoljuk a puffert")
("august" "augusztus")
("author" "szerz®")
("authorize" "engedélyezés")
("automatic" "automatikus")
("automatically close brackets" "zárójelek automatikus kiegészítése")
("automatically generated content" "automatikusan el®állított tartalom")
("automatic quotes" "automatikus idéz®jelek")
("autosave" "automatikus mentés")
("axis" "tengely")
("axiom" "axióma")
("b series" "")
("back" "vissza")
("background" "háttér")
("background color" "háttérszín")
("background evaluations" "kiértékelések a háttérben")
("backtrace errors" "hibák visszakövetése")
("backward replace" "csere visszafelé")
("backward search" "keresés visszafelé")
("bad data format" "rossz adatformátum")
("bar" "vízszintes vonás")
("bard" "")
("base level" "alapszint")
("baseline" "alapvonal")
("bashkirian" "baskír")
("basic" "egyszer¶")
("basic communication using pipes" "alapfokú kommunikáció csövek használatával")
("basic data types" "alapvet® adattípusok")
("basic types" "alapvet® típusok")
("be useful" "tegye hasznossá magát")
("become a TeXmacs developer" "lépjen be a TeXmacs fejleszt®i közé")
("before" "elé")
("begin" "kezdés")
("below" "alulra")
("beta release" "béta változat")
("bibliography" "irodalomjegyzék")
("bibliography file" "irodalomjegyzék fájl")
("bibliography style" "irodalomjegyzék stílus")
("bibtex command" "bibtex parancs")
("bidirectional" "kétirányú")
("big" "nagy")
("big figure" "nagy ábra")
("big operator" "nagy operátor")
("big skip" "nagy helykihagyás")
("big table" "nagy táblázat")
("binary operation" "bináris m¶velet")
("binary relation" "bináris reláció")
("black" "fekete")
("blackboard bold" "")
("blackboard math" "")
("blackletter" "")
("blank column" "üres oszlop")
("blank row" "üres sor")
("block content" "blokktartalom")
("blue" "kék")
("body" "test")
("bold" "félkövér")
("book" "könyv")
("border" "keret")
("both" "mindkett®")
("bottom" "alul")
("bottom border" "keret alul")
("bottom cell border" "cellakeret alul")
("bottom cell padding" "cella-helykihagyás alul")
("bottom margin" "alsó margó")
("bottom padding" "helykihagyás alul")
("bottom table border" "alsó táblázatkeret")
("bottom table padding" "táblázat-helykihagyás alul")
("branch" "ág")
("break" "töréspont")
("breaking" "törés")
("breve" "breve")
("british" "brit angol")
("broken white" "törtfehér")
("brown" "barna")
("browse" "böngészés")
("browse web" "a web böngészése")
("browser" "böngész®")
("buffer" "puffer")
("bulgarian" "bolgár")
("bullet" "golyó")
("bullets" "golyók")
("by" "készítette:")
("by typing" "")
("bytes free" "szabad bájt")
("bytes used" "felhasznált bájt")
("calculus" "kalkulus")
("calligraphic" "kalligrafikus")
("cancel" "mégsem")
("caps-lock key" "caps-lock billenty¶")
("cartesian" "descartes-i")
("case" "")
("cc" "")
("cell" "cella")
("cell background color" "cella háttérszíne")
("cell border" "cellakeret")
("cell height" "cellamagasság")
("cell operation mode" "cella m¶ködési mód")
("cell width" "cellaszélesség")
("cells" "cellák")
("center" "középre")
("center text" "szöveg középre zárása")
("centered" "középre zárt")
("centered block" "középre igazított blokk")
("centered tabular" "középre igazított táblázatos környezet")
("change border of cell" "cella keretének megváltoztatása")
("change cell operation mode" "cella m¶ködési módjának megváltoztatása")
("change log" "változásnapló")
("change the border of the table" "táblázat keretének megváltoztatása")
("changes" "változások")
("chapter" "fejezet")
("chat" "csevegés")
("check" "ellen®rzés")
("check text for spelling errors" "helyesírás-ellen®rzés a szövegben")
("chinese" "kínai")
("choice" "választás")
("circle" "kör")
("citation" "idézet")
("cite" "idézés")
("class" "osztály")
("clear" "törlés")
("clear selection" "kijelölés törlése")
("clipped" "levágott")
("clipped and magnified" "levágott és nagyított")
("clipped and resized" "levágott és átméretezett")
("clone" "kett®zés")
("clone window" "ablak duplikálása")
("close" "bezárás")
("close TeXmacs" "a TeXmacs bezárása")
("close buffer" "a puffer bezárása")
("close document" "a dokumentum bezárása")
("close session" "küls® munkamenet bezárása")
("close window" "az ablak bezárása")
("closed spline" "zárt spline")
("closing" "lezárás")
("closing style" "lezáró stílus")
("code" "kód")
("color" "szín")
("column" "oszlop")
("column contains glued items" "")
("column to the left" "oszlop a bal oldalra")
("column to the right" "oszlop a jobb oldalra")
("columns" "oszlop")
("common formats" "oszlopformátumok")
("compact" "tömör")
("compactification" "tömörítés")
("compactify" "tömörítés")
("compatibility with other formats" "más formátumokkal való kompatibilitás")
("compile article" "cikk szerkesztése")
("compile book" "könyv szerkesztése")
("compile buffer" "puffer szerkesztése")
("compile project" "projekt szerkesztése")
("completion" "kiegészítés")
("complex" "komplex")
("concrete" "concrete")
("condensed" "condensed")
("condition" "feltétel")
("configuration" "beállítás")
("connect" "csatlakozás")
("contact" "elérhet®ségek")
("content" "tartalom")
("content tag" "tartalomjelz® címke")
("context dependent icons" "helyzetfügg® ikonok")
("continuation of" "folytatása")
("contract logarithms" "logaritmusok összevonása")
("contribute" "hozzájárulás")
("control the evaluation of expressions" "kifejezések kiértékelésének irányítása")
("convention" "konvenció")
("converters" "átalakítók")
("converters to other data formats" "egyéb adatformátumok átalakítói")
("cosine" "koszinusz")
("copy" "másolás")
("copy text" "szö
veg másolása")
("copy to" "másolás ide")
("copying" "másolás")
("corollary" "következmény")
("correct text" "szöveg javítása")
("create" "létrehozás")
("create a new document" "új dokumentum létrehozása")
("create chatroom" "cseveg®szoba létrehozása")
("create link" "hivatkozás létrehozása")
("create preamble" "preamble szakasz készítése")
("create web site" "weboldal létrehozása")
("cursors" "kurzorok")
("curve" "görbe")
("custom tab" "testreszabott tabulátor")
("customize" "testreszabás")
("customizing TeXmacs" "a TeXmacs testreszabása")
("customizing the TeXmacs styles" "a TeXmacs stílusok testreszabása")
("custum tab" "testreszabott tabulátor")
("cut" "kivágás")
("cut text" "szöveg kivágása")
("cut to" "kivágás ide")
("cypriot" "ciprusi")
("cyrillic" "cirill")
("cyrillic input method" "cirill szövegbevitel")
("cyrillic italic right" "jobbra d®lt cirill")
("czech" "cseh")
("dancers" "")
("danish" "dán")
("dark grey" "sötétszürke")
("dash" "köt®jel")
("dashes" "köt®jelek")
("data conversion" "adatátalakítás")
("data format" "adatformátum")
("date" "dátum")
("deactivate" "inaktiválás")
("deactivate table" "táblázat inaktiválása")
("december" "december")
("decimal comma" "tizedesvessz®")
("decimal dot" "tizedespont")
("decorate atoms" "alapegységek díszítése")
("default" "alapértelmezés")
("default padding" "alapértelmezett helykihagyás")
("definition" "definíció")
("delete" "törlés")
("delete column" "oszlop törlése")
("delete link" "hivatkozás törlése")
("delete row" "sor törlése")
("denominator" "nevez®")
("description" "leírás")
("destination" "cél")
("detach" "leválasztás")
("detailed" "részletes")
("detailed menus" "részletes menük")
("details in menus" "menük részletessége")
("determinant" "determináns")
("devangari" "devangari")
("developers guide" "fejleszt®i kézikönyv")
("differentiate" "differenciálás")
("directory" "könyvtár")
("disable" "nincs")
("disable first indentation" "els® sor behúzásának letiltása")
("disable first indentation after" "els® sor behúzásának letiltása ez után")
("disable first indentation before" "els® sor behúzásának letiltása ez el®tt")
("disable indentation" "behúzás letiltása")
("disable indentation after" "behúzás letiltása ez után")
("disable indentation before" "behúzás letiltása ez el®tt")
("deactivate" "inaktiválás")
("deactivate once" "inaktiválás egyszer")
("disallow" "megtagadás")
("disk" "tele kerek")
("distribute unused space" "kihasználatlan hely elosztása")
("div" "")
("do not remap" "eredeti funkció")
("document" "dokumentum")
("document format" "dokumentumformátum")
("document style" "dokumentumstílus")
("document styles" "dokumentumstílusok")
("documentation" "dokumentáció")
("documents are trees" "a dokumentumok faszerkezet¶ek")
("dot" "pont")
("dots" "pontok")
("double stroke" "dupla vonás")
("down" "le")
("download" "letöltés")
("dpi" "dpi")
("draw image" "ábra rajzolása")
("draw over selection" "rajzolás a kijelölésre")
("duplicate" "kett®zés")
("dutch" "holland")
("dynamic libraries" "dinamikus könyvtárak")
("edit" "szerkesztés")
("edit grid" "rács szerkesztése")
("edit source tree" "forrásfa szerkesztése")
("editing tools" "szerkeszt®eszközök")
("eigenvalues" "sajátértékek")
("email" "e-mail")
("email address" "e-mail cím")
("emphasize" "hangsúlyozás")
("emphasize text" "szöveg hangsúlyozása")
("empty box" "üres doboz")
("enable change" "engedélyezett változtatások")
("enable first indentation" "els® sor behúzásának engedélyezése")
("enable first indentation after" "els® sor behúzásának engedélyezése ez után")
("enable first indentation before" "els® sor behúzásának engedélyezése ez el®tt")
("enable indentation" "behúzás engedélyezése")
("enable indentation after" "behúzás engedélyezése ez után")
("enable indentation before" "behúzás engedélyezése ez el®tt")
("encl" "")
("encoding" "karakterkódolás")
("end" "vége")
("english" "angol")
("enlarge selection" "kijelölés nagyítása")
("enter a title" "adja meg a címet")
("entire table" "teljes táblázat")
("enumerate" "számozás")
("enumerate|Alpha" "")
("enumerate|Roman" "")
("enumerate|alpha" "")
("enumerate|roman" "")
("env" "")
("environment" "környezet")
("epilogue" "utószó")
("equal" "egyenl®")
("equation" "egyenlet")
("equations" "egyenletek")
("equivalent for" "ekvivalens a következ®vel:")
("error" "hiba")
("esperanto" "eszperantó")
("etruscan" "etruszk")
("evaluate" "kiértékelés")
("evaluate scheme expression" "scheme kifejezés kiértékelése")
("evaluation switch" "kiértékelés kapcsoló")
("evaluation tag" "kiértékelés címke")
("even page footer" "páros oldal lábléce")
("even page header" "páros oldal fejléce")
("even page margin" "páros oldal margója")
("even page left margin" "páros oldal bal oldali margója")
("even page shift" "")
("even page text" "szöveg páros oldalon")
("exact" "pontosan")
("exact horizontal" "pontosan vízszintes")
("exact mode" "pontos mód")
("exam" "vizsga")
("example" "példa")
("exclusive" "kizárólagos")
("exclusive or" "kizáró vagy")
("executable" "végrehajtható")
("execute" "végrehajtás")
("execute a TeXmacs command" "TeXmacs parancs végrehajtása")
("execute system command" "rendszerparancs végrehajtása")
("executive" "executive")
("exercise" "gyakorlat")
("expand" "kibontás")
("expand logarithms" "logaritmusok kibontása")
("expand trigonometric functions" "trigonometrikus függvények kibontása")
("expand unrecognized macros" "ismeretlen makrók kibontása")
("expand user-defined macros" "felhasználó által definiált makrók kibontása")
("explained" "magyarázott")
("exponential" "kitev®")
("export" "exportálás")
("export as" "exportálás mint")
("export bibliographies as links" "irodalomjegyzék-bejegyzések exportálása linkként")
("export current file" "aktuális fájl exportálása")
("export formulas as images" "képletek exportálása képként")
("extend or normal" "kiterjesztett vagy normális")
("extents" "kiterjedés")
("extern " "küls®")
("external" "küls®")
("extra" "extra")
("extract format" "formátum kivonatolása")
("factor" "tényez®")
("family" "család")
("february" "február")
("figure" "ábra")
("file" "fájl")
("file information" "fájlinformáció")
("file name" "fájlnév")
("file not found" "a fájl nem található")
("files" "fájlok")
("fill color" "kitöltés színe")
("find next match" "következ® találat")
("find text" "szöveg keresése")
("finnish" "finn")
("first contact" "")
("first indentation" "els® sor behúzása")
("first item" "els® bejegyzés")
("first page" "els® oldal")
("first start" "els® indítás")
("fixed" "rögzített")
("flat" "lapos")
("flexibility" "rugalmasság")
("flexibility factor for vertical spacing" "függ®leges helykihagyás rugalmassági tényez®je")
("floating figure" "lebeg® ábra")
("floating object" "lebeg® objektum")
("floating table" "lebeg® táblázat")
("fold" "letakarás")
("fold input field" "beviteli mez® letakarása")
("folded" "letakart")
("follow external links" "küls® hivatkozások követése")
("follow inverse links" "inverz hivatkozások követése")
("font" "bet¶típus")
("font base size" "bet¶típus alapmérete")
("font dpi" "bet¶típus dpi")
("font family" "bet¶család")
("font name" "bet¶típus neve")
("font series" "bet¶típus sorozat")
("font shape" "bet¶típus alakja")
("font size" "bet¶méret")
("font type" "bet¶típus")
("font variant" "bet¶változat")
("fonts" "bet¶típusok")
("footer" "él®láb")
("footnote" "lábjegyzet")
("for" "")
("foreground" "el®tér")
("foreign" "idegen")
("format" "formátum")
("formatted and structured output" "formázott és szerkesztett kimenet")
("formatted date" "formázott dátum")
("formatting" "formázás")
("formula" "képlet")
("formula style" "képletstílus")
("forward" "el®re")
("forward replace" "csere")
("forward search" "keresés")
("fraction" "tört")
("frame" "keret")
("french" "francia")
("front matter" "címlap")
("full screen mode" "teljesképerny®s mód")
("full manuals" "teljes kézikönyvek")
("full name" "teljes név")
("function" "függvény")
("functional" "funkcionális")
("further customization" "további testreszabás")
("future changes" "jöv®beni változások")
("gNU TeXmacs comes without any form of legal warranty" "a GNU TeXmacs-et nem kíséri semmiféle garancia")
("gNU TeXmacs falls under the GNU general public license" "a GNU TeXmacs a GNU Általános Nyilvános Licenc hatálya alá tartozik")
("gcd" "gcd")
("general architecture of TeXmacs" "a TeXmacs általános felépítése")
("general negation" "általános tagadás")
("general note" "általános megjegyzés")
("generating font file" "a következ® bet¶típusfájl el®készítése folyik:")
("generic" "általános")
("geometry" "geometria")
("georgian" "örmény")
("german" "német")
("getting started" "els® lépések")
("glossary" "szójegyzék")
("glossary entry" "szójegyzék-bejegyzés")
("glue" "")
("glue decorations" "ragadós díszítések")
("go" "ablak")
("gothic" "gót")
("graphical interface" "grafikus felület")
("graphics" "grafika")
("grave" "grave")
("greater" "nagyobb")
("greater or equal" "nagyobb vagy egyenl®")
("greek" "görög")
("greek letter" "görög bet¶")
("green" "zöld")
("grey" "szürke")
("grids" "rácsok")
("group" "csoportosítás")
("h modifier" "h módosítóbillenty¶")
("hang up" "megszakítás")
("happy typing" "kellemes munkát")
("has been aborted" "leállításra került")
("has completed its task" "befejezte feladatát")
("hat" "kalap")
("header" "fejléc")
("header and footer" "fej- és lábléc")
("hebrew" "héber")
("height" "magasság")
("height is exactly the specified height" "a magasság pontosan a megadott érték")
("height is maximum of specified height and box height" "a magasság a megadott érték és a doboz magassága közül a nagyobb")
("height is minimum of specified height and box height" "a magasság a megadott érték és a doboz magassága közül a kisebbik")
("height magnification" "magasság nagyítása")
("help" "segítség")
("help me" "")
("help us" "segítsen nekünk")
("here" "itt")
("hidden" "rejtett")
("home" "saját könyvtár")
("home directory" "saját könyvtár")
("home page" "honlap")
("homepage" "honlap")
("horizontal" "víszintes")
("horizontal alignment" "vízszintes igazítás")
("horizontal cell alignment" "vízszintes cellaigazítás")
("horizontal ink separation" "")
("horizontal part" "vízszintes rész")
("horizontal position" "vízszintes helyzet")
("horizontal space" "vízszintes térköz")
("horizontal table alignment" "vízszintes táblázatigazítás")
("horizontally align cell to the base" "cella vízszintes igazítása az alaphoz")
("horizontally center the cell" "cella középre igazítása vízszintesen")
("how much longer may pages become" "mennyivel lehetnek hosszabbak az oldalak")
("how much shorter may pages become" "mennyivel lehetnek rövidebbek az oldalak")
("huge" "óriási")
("hungarian" "magyar")
("hybrid command" "hibrid parancs")
("hyperlink" "hiperhivatkozás")
("hyphenation" "elválasztás")
("icelandic" "izlandi")
("if" "if")
("if hyphenated" "ha el van választva")
("image" "kép")
("image links" "képhivatkozások")
("implementation" "megvalósítás")
("import" "importálás")
("import current file" "aktuális fájl importálása")
("improving the current implementation" "a jelenlegi implementáció tökéletesítése")
("in popup windows" "felugró ablakokban")
("inactive" "inaktív")
("include" "hivatkozás fájlra")
("include a document" "dokumentum beillesztése")
("include file" "fájl beillesztése")
("inclusion into TeXmacs" "beillesztés a TeXmacs szoftverbe")
("inclusions" "beillesztések")
("indent" "behúzás")
("indentation flag" "behúzásjelz®")
("index" "tárgymutató")
("index entry" "tárgymutató-bejegyzés")
("index level" "tárgymutató szint")
("informative flags" "tájékoztató jelzések")
("inline arguments" "sorközi argumentumok")
("input mode" "beviteli mód")
("insert" "beszúrás")
("insert Pr" "Pr beszúrása")
("insert a TeXmacs symbol" "TeXmacs szimbólum beszúrása")
("insert a big operator" "nagy operátor beszúrása")
("insert a binary operation" "bináris operátor beszúrása")
("insert a binary relation" "bináris reláció beszúrása")
("insert a blackboard bold character" "")
("insert a bold calligraphic character" "félkövér kalligrafikus karakter beszúrása")
("insert a bold character" "félkövér karakter beszúrása")
("insert a calligraphic character" "kalligrafikus karakter beszúrása")
("insert a condition" "feltétel beszúrása")
("insert a control flow instruction" "vezérl®parancs beszúrása")
("insert a fraction" "tört beszúrása")
("insert a fraktur character" "fraktur karakter beszúrása")
("insert a greek character" "görög karakter beszúrása")
("insert a large left delimiter" "")
("insert a large right delimiter" "")
("insert a large separator" "nagy elválasztó beszúrása")
("insert a left subscript" "bal alsó index beszúrása")
("insert a link" "hivatkozás beszúrása")
("insert a miscellaneous symbol" "egyéb szimbólum beszúrása")
("insert a new branch" "új ág beszúrása")
("insert a new item" "új bejegyzés beszúrása")
("insert a numerical operation" "numerikus m¶velet beszúrása")
("insert a picture" "ábra beszúrása")
("insert a square root" "négyzetgyök beszúrása")
("insert a table" "táblázat beszúrása")
("insert a table or a matrix" "táblázat vagy mátrix beszúrása")
("insert a textual operation" "szövegm¶velet beszúrása")
("insert a wide symbol above" "széles szimbólum beszúrása felülre")
("insert a wide symbol below" "széles szimbólum beszúrása alulra")
("insert an" "")
("insert an accent" "ékezet beszúrása")
("insert an arrow" "nyíl beszúrása")
("insert an environment" "környezet beszúrása")
("insert an n" "n beszúrása")
("insert an operation on tuples" "n-eseken végzett m¶velet beszúrása")
("insert appendix" "függelék beszúrása")
("insert arccos" "arccos beszúrása")
("insert arcsin" "arcsin beszúrása")
("insert arctan" "arctan beszúrása")
("insert arg" "arg beszúrása")
("insert argument" "argumentum beszúrása")
("insert author" "szerz® beszúrása")
("insert automatically generated content" "automatikusan el®állított tartalom beszúrása")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "nagy integráljel beszúrása")
("insert big intersection" "")
("insert big logical and" "nagy logikai és beszúrása")
("insert big logical or" "nagy logikai vagy beszúrása")
("insert big product" "nagy szorzásjel beszúrása")
("insert big square union" "")
("insert big summation" "nagy szummajel beszúrása")
("insert big tensor product" "nagy tenzorszorzásjel beszúrása")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "nagy függ®leges térköz beszúrása")
("insert chapter" "fejezet beszúrása")
("insert column" "oszlop beszúrása")
("insert column to the left" "oszlop beszúrása a bal oldalra")
("insert column to the right" "oszlop beszúrása a jobb oldalra")
("insert cos" "cos beszúrása")
("insert cosh" "cosh beszúrása")
("insert cot" "cot beszúrása")
("insert coth" "coth beszúrása")
("insert csc" "csc beszúrása")
("insert deg" "deg beszúrása")
("insert det" "det beszúrása")
("insert dim" "dim beszúrása")
("insert dollar" "dollárjel beszúrása")
("insert equation" "egyenlet beszúrása")
("insert executable markup" "")
("insert exp" "exp beszúrása")
("insert fields" "mez®k beszúrása")
("insert footnote" "lábjegyzet beszúrása")
("insert formula" "képlet beszúrása")
("insert gcd" "gcd beszúrása")
("insert hom" "hom beszúrása")
("insert horizontal interword space" "vízszintes szóköz beszúrása")
("insert image" "kép beszúrása")
("insert inactive markup" "inaktív jelölés beszúrása")
("insert inf" "inf beszúrása")
("insert input field above" "beviteli mez® beszúrása e fölé")
("insert input field below" "beviteli mez® beszúrása ez alá")
("insert ker" "ker beszúrása")
("insert lg" "lg beszúrása")
("insert lim" "lim beszúrása")
("insert liminf" "liminf beszúrása")
("insert limsup" "limsup beszúrása")
("insert ln" "ln beszúrása")
("insert log" "log beszúrása")
("insert macro" "makró beszúrása")
("insert mathematics" "matematikai szöveg beszúrása")
("insert max" "max beszúrása")
("insert medium horizontal space" "közepes vízszintes térköz beszúrása")
("insert medium vertical space" "közepes függ®leges térköz beszúrása")
("insert min" "min beszúrása")
("insert negative horizontal space" "negatív vízszintes térköz beszúrása")
("insert new item or number" "új bejegyzés vagy szám beszúrása")
("insert new rows or columns" "új sorok vagy oszlopok beszúrása")
("insert or delete rows or columns" "sorok vagy oszlopok beszúrása vagy törlése")
("insert row" "sor beszúrása")
("insert row above" "sor beszúrása e fölé")
("insert row below" "sor beszúrása ez alá")
("insert sec" "sec beszúrása")
("insert section" "szakasz beszúrása")
("insert sharp" "kett®skereszt beszúrása")
("insert sin" "sin beszúrása")
("insert sinh" "sinh beszúrása")
("insert small horizontal space" "kis vízszintes térköz beszúrása")
("insert small vertical space" "kis függ®leges térköz beszúrása")
("insert structural markup" "szerkezetjelölés beszúrása")
("insert subsection" "alfejezet beszúrása")
("insert subsubsection" "al-alfejezet beszúrása")
("insert sup" "sup beszúrása")
("insert tan" "tan beszúrása")
("insert tanh" "tanh beszúrása")
("insert text field" "szövegmez® beszúrása")
("insert thick horizontal space" "vastag vízszintes térköz beszúrása")
("insert title" "cím beszúrása")
("insert value" "érték beszúrása")
("integrate" "integrálás")
("interactive command" "interaktív parancs")
("interactive questions" "interaktív kérdések")
("interfacing" "használat felhasználói felületként")
("interfacing TeXmacs with other systems" "TeXmacs összekapcsolása más rendszerekkel")
("interjection" "közbevetés")
("interline separation" "minimális sorköz")
("interline space" "sorköz")
("internationalization" "honosítás")
("interparagraph space" "bekezdésköz")
("interrupt execution" "végrehajtás megszakítása")
("introduction" "bevezetés")
("invert" "invertálás")
("invisible" "láthatatlan")
("invisible citation" "láthatatlan idézés")
("irish" "ír")
("is running" "fut")
("is tuple" "n-es")
("ispell does not respond" "az ispell nem válaszol")
("ispell is already busy" "az ispell már dolgozik")
("italian" "olasz")
("italic" "d®lt")
("italic right" "jobbra d®lt")
("itemize" "felsorolás")
("january" "január")
("japanese" "japán")
("july" "július")
("june" "június")
("justified" "sorkizárt")
("justify text" "szöveg sorkizárttá tétele")
("keep evaluated expressions" "kiértékelt kifejezése meg®rzése")
("key" "billenty¶")
("keyboard" "billenty¶zet")
("keyboard equivalent" "megfelel® billenty¶")
("keyboard modifiers" "billenty¶módosítók")
("keyboard shortcut" "gyorsbillenty¶k")
("keymaps" "billenty¶kiosztások")
("keyword" "kulcsszó")
("keywords" "kulcsszavak")
("kill" "leállítás")
("known bugs" "ismert programhibák")
("korean" "koreai")
("label" "címke")
("landscape" "fekv®")
("language" "nyelv")
("large" "nagy")
("large closing bracket" "nagy záró zárójel")
("large delimiter" "nagy határoló")
("large opening bracket" "nagy nyitó zárójel")
("large separator" "nagy elválasztójel")
("last page" "utolsó oldal")
("latex command" "latex parancs")
("latin" "latin")
("layout" "elrendezés")
("lcm" "lcm")
("left" "bal")
("left arrow" "nyíl balra")
("left border" "bal oldali keret")
("left cell border" "bal oldali cellakeret")
("left cell padding" "bal oldali cella-helykihagyás")
("left margin" "bal oldali margó")
("left padding" "bal oldali helykihagyás")
("left prime" "")
("left aligned" "balra igazítva")
("left slanted" "balra ferde")
("left subscript" "bal alsó index")
("left superscript" "bal fels® index")
("left surrounding" "")
("left table border" "bal oldali táblázatkeret")
("left table padding" "bal oldali táblázat-helykihagyás")
("legal" "legal")
("lemma" "segédtétel")
("length" "hosszúság")
("less" "kisebb")
("less or equal" "kisebb vagy egyenl®")
("letter" "levél")
("license" "licenc")
("light" "vékony")
("light grey" "világosszürke")
("limitations" "")
("limits" "")
("line" "sor")
("line break" "sortörés")
("line properties" "vonal tulajdonságai")
("line stretch" "sor nyújtása")
("line width" "vonalvastagság")
("linear algebra" "lineáris algebra")
("link" "hivatkozás")
("link image" "hivatkozás képre")
("link mode" "hivatkozási mód")
("linking tool" "hivatkozáskezel® eszköz")
("list" "lista")
("list of figures" "ábrajegyzék")
("list of tables" "táblázatok jegyzéke")
("load" "megnyitás")
("load LaTeX file" "LaTeX fájl megnyitása")
("load TeX file" "TeX fájl megnyitása")
("load TeXmacs file" "TeXmacs fájl megnyitása")
("load TeXmacs style file" "TeXmacs stílusfájl megnyitása")
("load a file" "fájl megnyitása")
("load buffer" "puffer megnyitása")
("load file" "fájl megnyitása")
("load html file" "html fájl megnyitása")
("load image" "kép megnyitása")
("load in new window" "megnyitás új ablakban")
("load latex file" "latex fájl megnyitása")
("load more recent autosave file" "újabb automatikus mentés megnyitása")
("load tex file" "tex fájl megnyitása")
("load verbatim file" "verbatim fájl megnyitása")
("loaded" "betöltve")
("locus" "hely")
("logarithm" "logaritmus")
("logarithmic" "logaritmikus")
("logarithms" "logaritmusok")
("login" "bejelentkezés")
("logout" "kijelentkezés")
("long" "hosszú")
("look and feel" "kinézet")
("look up" "keresés")
("lower border" "keret csökkentése")
("m modifier" "m módosítóbillenty¶")
("macro" "makró")
("magenta" "magenta")
("magic" "")
("magnification" "nagyítás")
("magnified" "nagyított")
("main" "f®bejegyzés")
("main icon bar" "f® ikoneszköztár")
("major changes" "f®bb változások")
("make a page insertion" "")
("make a subscript" "alsó index készítése")
("make a superscript" "fels® index készítése")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "tört készítése")
("make grave" "")
("make hat" "kalap készítése")
("make label" "címke készítése")
("make negation" "tagadás készítése")
("make page reference" "oldalhivatkozás készítése")
("make reference" "hivatkozás készítése")
("make square root" "négyzetgyök készítése")
("make tilde" "tilde készítése")
("make title" "cím készítése")
("make vector" "vektor készítése")
("making donations" "adományok")
("manual" "kézikönyv")
("map to" "legyen")
("march" "március")
("margins" "margók")
("margins as on paper" "margók mint a papíron")
("master" "")
("master file" "mesterfájl")
("math" "matematika")
("math font" "matematikai bet¶típus")
("math font family" "matematikai bet¶család")
("math font series" "matematikai bet¶sorozat")
("math font shape" "matamatikai bet¶alak")
("mathematical" "matematikai")
("mathematical and customized input" "matematikai és testreszabott bevitel")
("mathematical font" "matematikai bet¶típus")
("mathematical formulas" "matematikai képletek")
("mathematical input" "matematikai szövegbevitel")
("mathematical typesetting" "matematikai szedés")
("mathematics" "matematika")
("matrices" "mátrixok")
("matrix" "mátrix")
("maximal" "maximális")
("maximal cell height" "maximális cellamagasság")
("maximal cell width" "maximális cellaszélesség")
("maximal number of columns" "maximális oszlopszám")
("maximal number of rows" "maximális sorszám")
("maximal table height" "táblázat maximális magassága")
("maximal table width" "táblázat maximális szélessége")
("maximum mode" "maximum mód")
("may" "május")
("medium" "közepes")
("medium skip" "közepes helykihagyás")
("meminfo" "meminfo")
("memory information" "memóriainformáció")
("merge" "összeolvasztás")
("messy" "")
("meta key" "meta billenty¶")
("middle" "középre")
("minimal" "minimális")
("minimal cell height" "minimális cellamagasság")
("minimal cell width" "minimális cellaszélesség")
("minimal number of columns" "oszlopok minimális száma")
("minimal number of rows" "sorok minimális száma")
("minimal table height" "minimális táblázatmagasság")
("minimal table width" "minimális táblázatszélesség")
("minimum mode" "minimum mód")
("minus" "mínusz")
("miscellaneous" "egyéb")
("miscellaneous features" "egyéb tulajdonságok")
("mod" "mod")
("mode" "mód")
("modifier" "módosító")
("modify cell alignment" "cellaigazítás módosítása")
("modify cell border" "cellakeret módosítása")
("modify cell padding" "cella helykitöltésének módosítása")
("modify cell size" "cellaméret módosítása")
("modify table border" "táblázatkeret módosítása")
("modify table padding" "táblázat helykitöltésének módosítása")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the Help" "A GNU TeXmacs-ról további információ itt: Segítség")
("mosaic" "")
("move" "mozgatás")
("move down" "mozogjon lefelé")
("move object" "objektum mozgatása")
("move to the right when finished" "menjen jobbra, ha kész")
("move up" "mozgatás felfelé")
("multiline input" "többsoros bevitel")
("mutator tags" "módosítócímkék")
("my documents" "saját dokumentumaim")
("n-th" "n-edik")
("n-th root" "n-edik gyök")
("name" "név")
("navigation options" "navigációs opciók")
("negation" "tagadás")
("never" "soha")
("new" "új")
("new account" "új hozzáférés")
("new buffer" "új puffer")
("new column" "új oszlop")
("new document" "új dokumentum")
("new double page" "új dupla lap")
("new double page before" "új dupla lap, ez elé")
("new file" "új fájl")
("new item" "új bejegyzés")
("new line" "új sor")
("new locus" "új hely")
("new number" "új szám")
("new page" "új lap")
("new page before" "új lap, ez elé")
("new paragraph" "új bekezdés")
("new roman" "")
("new row" "új sor")
("new table" "új táblázat")
("next" "következ®")
("next line" "következ® sor")
("nickname" "becenév")
("no changes need to be saved" "nincs mentést igényl® változtatás")
("no dictionary for" "")
("no first indentation" "els® sor behúzásának letiltása")
("no grid" "nincs rács")
("no indentation" "nincs behúzás")
("no line break" "nincs sortörés")
("no matches found" "nincs találat")
("no matches found for" "nincs találat:")
("no more matches for" "nincs több találat:")
("no more redo information available" "nincs több elérhet® visszavonási információ")
("no more undo information available" "nincs több elérhet® visszavonási információ")
("no name" "névtelen")
("no page break after" "")
("no page break before" "")
("no spelling errors found in text" "nem található helyesírási hiba a szövegben")
("no style" "nincs stílus")
("none" "nincs")
("normal" "normális")
("norwegian" "norvég")
("not" "nem")
("not equal" "nem egyenl®")
("not found" "nem található")
("notation" "jelölésmód")
("note" "jegyzet")
("november" "november")
("number" "szám")
("number of columns" "oszlopok száma")
("number equation" "egyenlet számozása")
("numbered equation" "számozott egyenlet")
("numbered equations" "számozott egyenletek")
("numerator" "számláló")
("numeric" "")
("objectives" "célok")
("occurrences" "el®fordulások")
("october" "ektóber")
("odd page footer" "páratlan oldal lábléce")
("odd page header" "páratlan oldal fejléce")
("odd page margin" "páratlan oldal margói")
("odd page left margin" "páratlan oldal bal oldali margója")
("odd page right margin" "páratlan oldal jobb oldali margója")
("odd page shift" "")
("odd page text" "szöveg páratlan oldalon")
("off" "ki")
("ok" "ok")
("old english" "régi angol")
("old slavonic" "régi szláv")
("old style" "régi stílus")
("on" "be")
("on cells" "cellákra")
("on columns" "oszlopokra")
("on entire table" "teljes táblázatra")
("on rows" "sorokra")
("on the footer" "a láblécre")
("one spelling error has been corrected" "javítva egy helyesírási hiba")
("online documentation" "online dokumentáció")
("online help" "online segítség")
("only inline tags" "csak a sorközi címkéket")
("open" "megnyitás")
("open a new buffer" "új puffer megnyitása")
("open new window" "új ablak megnyitása")
("opening" "megnyitás")
("operation mode" "m¶ködési mód")
("operation on named selection" "")
("operation on primary selection" "m¶velet els®dleges kiválasztáson")
("operation on secondary selection" "m¶velet másodlagos kiválasztáson")
("operation on ternary selection" "m¶velet harmadlagos kiválasztáson")
("optical" "optikai")
("option" "opció")
("options" "opciók")
("or" "vagy")
("orange" "narancs")
("orientation" "tájolás")
("origin" "")
("original welcome message" "eredeti üdvözl®szöveg")
("other" "egyéb")
("other pages" "másik oldalon")
("other projects" "egyéb projektek")
("other style" "egyéb stílus")
("outlined roman" "")
("over" "felülre")
("overbrace" "kapcsos zárójel felülre")
("overline" "felülvonás")
("overview of the scheme extension language" "a Scheme kiegészít® programnyelv áttekintése")
("owner" "tulajdonos")
("padding" "helykitöltés")
("page" "oldal")
("page bottom margin" "oldal alsó margója")
("page break" "oldaltörés")
("page break before" "oldaltörés ez elé")
("page height" "oldalmagasság")
("page insertion" "beszúrás az oldalra")
("page layout" "oldal elrendezése")
("page number text" "oldalszám szövege")
("page numbering" "oldalszámozás")
("page reference" "oldalhivatkozás")
("page right margin" "oldal jobb margója")
("page setup" "oldalbeállítás")
("page top margin" "oldal fels® margója")
("page type" "oldaltípus")
("page width" "oldalszélesség")
("paper" "papír")
("paper type" "papírtípus")
("papyrus" "papirusztekercs")
("paragraph" "bekezdés")
("paragraph mode" "bekezdésmód")
("paragraph width" "bekezdés szélessége")
("parametric curve" "paraméteres görbe")
("parametric surface" "paraméteres felszín")
("part" "rész")
("past changes" "korábbi változtatások")
("paste" "beillesztés")
("paste from" "beillesztés innen")
("paste text" "szöveg beillesztése")
("path" "útvonal")
("perform operations on cells" "m¶veletek végrehajtása cellákon")
("perform operations on columns" "m¶veletek végrehajtása oszlopokon")
("perform operations on entire table" "m¶veletek végrehajtása a teljes táblázaton")
("perform operations on rows" "m¶veletek végrehajtása sorokon")
("permanent" "állandó")
("permissions" "engedélyek")
("person" "személy")
("personal dictionary has been modified" "a személyes szótár módosult")
("phantasy" "fantázia")
("philosophy" "filozófia")
("phoenician" "föníciai")
("phonetic" "fonetikus")
("pink" "rózsaszín")
("plain block" "sima blokk")
("plain tabular" "sima táblázatos környezet")
("planned changes" "tervezett változtatások")
("plans for the future" "tervek a jöv®re nézve")
("please" "kérem")
("please wait" "kérem, várjon")
("plot" "ábra")
("plugin" "b®vítmény")
("plugins" "b®vítmények")
("plus" "plusz")
("point" "pont")
("point style" "pontstílus")
("polar" "poláris")
("polish" "lengyel")
("polygon" "sokszög")
("porting TeXmacs to other platforms" "a TeXmacs más platformokra történ® portolása")
("portrait" "álló")
("portuguese" "portugál")
("position" "pozíció")
("position float" "lebeg® objektum elhelyezése")
("position floating object" "lebeg® objektum elhelyezése")
("position the table" "táblázat elhelyezése")
("postscript" "postscript")
("postscript image" "postscript kép")
("pre-alpha release" "alfa el®tti változat")
("preamble" "el®szó")
("preamble mode" "preamble mód")
("preferences" "beállítások")
("presentation" "bemutató")
("presentation mode" "bemutatómód")
("presentation tag" "díszítésjelz® címke")
("preview before printing" "nyomtatási el®nézet")
("preview command" "el®nézeti parancs")
("preview with ghostview" "el®nézet ghostview-val")
("previous" "el®z®")
("primary" "els®dleges")
("prime" "")
("print" "nyomtatás")
("print all" "minden kinyomtatása")
("print all to file" "minden kinyomtatása fájlba")
("print page selection" "kiválasztott oldalok nyomtatása")
("print page selection to file" "kiválasztott oldalak nyomtatása fájlba")
("print to postscript file" "nyomtatás postscript fájlba")
("printer" "nyomtató")
("printer dpi" "nyomtató dpi")
("printing command" "nyomtatási parancs")
("problem" "probléma")
("professional" "professzionális")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "program")
("program font" "")
("program mode" "")
("programming" "programozás")
("progressive" "")
("project" "projekt")
("projects" "projektek")
("prologue" "el®szó")
("prompt on scripts" "rákérdezés")
("prompts and default input" "promptok és alapértelmezett bemenet")
("proof" "bizonyítás")
("properties" "tulajdonságok")
("proportional" "arányos")
("proportional typewriter" "arányos írógép")
("proposition" "")
("query replace" "")
("quit" "kilépés")
("quotation" "idézet")
("quote" "")
("range" "tartomány")
("rank" "rang")
("read" "olvasás")
("really close it" "Biztosan be akarja zárni")
("really huge" "igazán óriási")
("really quit" "valóban ki szeretne lépni")
("really tiny" "igazán apró")
("recover autosave file" "Visszaállítsuk a fájlt az automatikus mentésb®l")
("red" "piros")
("redo" "mégis")
("redo undone changes" "visszavont változtatások újraalkalmazása")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "margók csökkentése")
("reduce right margin by" "")
("reduce top margin by" "")
("reduce trigonometric functions" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "hivatkozás")
("reference guide" "hivatkozási kézikönyv")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "")
("regular" "")
("release" "")
("reload" "újratöltés")
("remark" "megjegyzés")
("remote" "távoli")
("remote connections" "távoli kapcsolatok")
("remove" "eltávolítás")
("remove all output fields" "")
("remove fields" "mez®k eltávolítása")
("remove input field" "beviteli mez® eltávolítása")
("remove input field above" "")
("remove number" "szám eltávolítása")
("remove package" "csomag eltávolítása")
("remove this switch" "")
("renumber this page" "a lap újraszámozása")
("repeat" "ismétlés")
("repeat object" "")
("replace" "csere")
("replace by" "")
("replace unrecognized styles" "ismeretlen stílusok cseréje")
("replaced" "")
("replaced one occurrence" "egy el®fordulás cserélve")
("reset" "")
("resize object" "objektum átméretezése")
("resized" "átméretezve")
("search results for" "keresési eredmények:")
("return" "")
("revert" "visszaállítás")
("revert buffer" "puffer visszaállítása")
("right" "jobb")
("right arrow" "nyíl jobbra")
("right border" "jobb oldali keret")
("right cell border" "jobb oldali cellakeret")
("right cell padding" "jobb oldali cella helykitöltés")
("right margin" "jobb oldali margó")
("right padding" "jobb oldali helykitöltés")
("right aligned" "jobbra igazítva")
("right subscript" "jobb alsó index")
("right superscript" "jobb fels® index")
("right surrounding" "")
("right table border" "jobb oldali táblázatkeret")
("right table padding" "jobb oldali táblázat helykitöltés")
("rigid" "merev")
("rigid horizontal" "")
("rigid space" "nem törhet® szóköz")
("romanian" "román")
("root" "gyök")
("rotate backward" "forgatás visszafelé")
("rotate forward" "forgatás el®re")
("round" "üres kerek")
("row" "sor")
("row above" "sor felülre")
("row below" "sor alulra")
("row contains glued items" "")
("rows" "sorok")
("runic" "rovásírásos")
("running author" "")
("running title" "")
("russian" "orosz")
("sample" "minta")
("sans serif" "sans serif")
("save" "mentés")
("save TeXmacs file" "TeXmacs fájl mentése")
("save TeXmacs style file" "TeXmacs stílusfájl mentése")
("save as" "mentés másként")
("save as LaTeX" "mentés LaTeX-ként")
("save as TeX" "mentés TeX-ként")
("save buffer" "puffer mentése")
("save buffer as" "puffer mentése másként")
("save file" "fájl mentése")
("save html file" "html fájl mentése")
("save image" "kép mentése")
("save latex file" "latex fájl mentése")
("save tex file" "tex fájl mentése")
("save this buffer" "az aktuális puffer mentése")
("save verbatim file" "verbatim fájl mentése")
("saved" "elmentve")
("scheme command" "scheme parancs")
("scheme extensions" "scheme kiterjesztések")
("screen layout" "elrendezés a képerny®n")
("screen margins" "margók a képerny®n")
("script" "index")
("script above" "index felülre")
("script below" "index alulra")
("script script size" "index indexének mérete")
("script size" "index mérete")
("scripts" "szkriptek")
("scripts not accepted" "a szkriptek nincsenek engedélyezve")
("search" "keresés")
("search words in my documents" "szavak keresése a saját dokumentumaimban")
("search words in the documentation" "szavak keresése a dokumentációban")
("search words in the source code" "szavak keresése a forráskódban")
("searching" "keresés")
("secondary" "másodlagos")
("section" "szekció")
("security" "biztonság")
("see" "lásd")
("select a document style" "válasszon dokumentumstílust")
("select a foreground color" "válasszon el®térszínt")
("select a language" "válasszon nyelvet")
("selected region" "kiválasztott terület")
("selection" "kijelölés")
("selections" "kijelölések")
("seminar" "")
("sending commands to TeXmacs" "parancsok küldése a TeXmacs-nak")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "elválasztó")
("september" "szeptember")
("serb" "szerb")
("series" "sorozat")
("series|right" "")
("session" "küls® munkamenet")
("session name" "küls® munkamenet neve")
("session type" "küls® munkamenet típusa")
("sessions" "küls® munkamenetek")
("set" "")
("set background color of cell" "cella háttérszínének beállítása")
("set cell mode" "cella módjának beállítása")
("set extension center" "")
("set height" "magasság beállítása")
("set height of cell" "cella magasságának beállítása")
("set margins" "margók beállítása")
("set n" "n beállítása")
("set or get environment variables" "környezeti változók beállítása vagy lekérdezése")
("set paragraph margins" "bekezdésmargók beállítása")
("set paragraph mode" "bekezdésmód beállítása")
("set printer dpi" "nyomtatási felbontás (dpi) beállítása")
("set printing command" "nyomtatási parancs beállítása")
("set span" "")
("set special cell properties" "speciális cellatulajdonságok beállítása")
("set special table properties" "speciális táblázattulajdonságok beállítása")
("set text width" "szövegszélesség beállítása")
("set width" "szélesség beállítása")
("set width of cell" "cellaszélesség beállítása")
("settings" "beállítások")
("setup printer" "nyomtató beállítása")
("shape" "alak")
("shift-down" "shift-le")
("shift-right" "shift-jobbra")
("short" "rövid")
("show" "")
("show all parts" "összes rész mutatása")
("show header and footer" "fejléc és lábléc mutatása")
("show hidden" "rejtettek mutatása")
("show on screen" "megmutatás képerny®n")
("show one part" "egy rész mutatása")
("show several parts" "néhány rész mutatása")
("shrinking factor" "nagyítási tényez®")
("signature" "aláírás")
("simple" "egyszer¶")
("simplify" "egyszer¶sítés")
("simplification" "egyszer¶sítés")
("simplified evaluation of formulas" "képletek egyszer¶sített kiértékelése")
("simplified menus" "egyszer¶sített menük")
("sine" "szinusz")
("size" "méret")
("size limits" "mérethatárok")
("size tag" "méretjelz® címke")
("slanted" "ferde")
("sloppy" "")
("slovene" "szlovén")
("small" "kicsi")
("small caps" "kiskapitális")
("small figure" "kis ábra")
("small skip" "kis helykihagyás")
("small table" "kis táblázat")
("sound" "hang")
("source" "forrás")
("source code" "forráskód")
("source tags" "forráskód-címkék")
("space" "térköz")
("space between lines" "sortávolság")
("space between paragraphs" "bekezdések közti távolság")
("spacing" "térközök")
("spanish" "spanyol")
("special" "speciális")
("special cell properties" "speciális cellatulajdonságok")
("special functions" "speciális függvények")
("special properties" "speciális tulajdonságok")
("special table properties" "speciális táblázattulajdonságok")
("specific" "specific parancs")
("specify the size of the table" "adja meg a táblázat méretét")
("spell" "helyesírás")
("spell checking complete" "a helyesírás ellen®rzése befejez®dött")
("spelling error" "helyesírási hiba")
("spelling errors have been corrected" "helyesírási hiba javítva")
("split" "")
("split session" "")
("square" "szögletes")
("square root" "négyzetgyök")
("standard environment variables" "standard környezeti változók")
("standard formats" "standard formátumok")
("standard TeXmacs styles" "standard TeXmacs stílusok")
("start" "")
("start a new chapter" "új fejezet kezdése")
("start a new section" "új szekció kezdése")
("start an interactive session" "interaktív munkamenet kezdése")
("status bar" "lábléc")
("stretch" "nyújtás")
("stretchable" "nyújtható")
("stretchable horizontal" "vízszintesen nyújtható")
("stretchable vertical" "függ®legesen nyújtható")
("stretched" "nyújtott")
("stroke" "vonás")
("strokes" "vonás")
("strong" "vastagított")
("structural" "")
("style" "stílus")
("styles" "stílusok")
("stylesheet language" "stíluslap-nyelv")
("sub" "albejegyzés")
("subparagraph" "albekezdés")
("subscript" "alsó index")
("subsection" "alszekció")
("subsub" "al-albejegyzés")
("subsubsection" "al-alszekció")
("subtable" "altáblázat")
("subtitle" "alcím")
("summary" "összefoglalás")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "fels® index")
("surface" "felszín")
("swedish" "svéd")
("swiss" "svájci")
("switch" "váltás")
("switch to first" "váltás az els®re")
("switch to formula style" "váltás képletstílusra")
("switch to last" "váltás az utolsóra")
("switch to next" "váltás a következ®re")
("switch to previous" "váltás az el®z®re")
("switching and folding" "")
("symbol" "szimbólum")
("system command" "rendszerparancs")
("system environment variables" "környezeti változók")
("tab" "tabulátor")
("table" "táblázat")
("table command" "táblázatparancs")
("table height" "tablázat magassága")
("table of contents" "tartalomjegyzék")
("table width" "táblázatszélesség")
("tables" "táblázatok")
("tabular" "táblázatos környezet")
("tabular material" "táblázatok")
("taiwanese" "taiwani")
("tangent" "tangens")
("target" "cél")
("teXmacs as an interface" "a texmacs mint felhasználói felület")
("teXmacs fonts" "teXmacs bet¶típusok")
("teXmacs notice" "")
("teXmacs plugins" "teXmacs b®vítmények")
("teXmacs primitives" "a TeXmacs alapvet® épít®elemei")
("teXmacs style files" "teXmacs stílusfájlok")
("ternary" "harmadlagos")
("test" "tesztelés")
("tex" "tex")
("TeXmacs fonts" "TeXmacs bet¶típusok")
("text" "szöveg")
("text box" "szövegdoboz")
("text box alignment" "szövegdoboz igazítása")
("text box horizontal alignment" "szövegdoboz vízszintes igazítása")
("text box vertical alignment" "szöegdoboz függ®leges igazítása")
("text font" "szöveg bet¶típusa")
("text height correction" "szövegmagasság korrigálása")
("text width" "szövegszélesség")
("texts" "texts könyvtár")
("th century bc" " század Kr. e.")
("th root" "-ik gyök")
("thai" "thai")
("the TeXmacs authors" "a TeXmacs szerz®i")
("the TeXmacs format" "a TeXmacs formátuma")
("the application did not send its usual startup banner" "az alkalmazás nem küldte el a szokásos bejelentkez® üzenetét")
("the application does not reply" "az alkalmazás nem válaszol")
("the application is already running" "az alkalmazás már fut")
("the boxes produced by the typesetter" "a szed® által készített dobozok")
("the document has not been saved" "a puffer nincs elmentve")
("the graphical user interface" "a grafikus felhasználói felület")
("the leaves of TeXmacs trees" "")
("the mycas example" "a mycas példa")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "a standard TeXmacs stílusok")
("theorem" "tétel")
("there are unsaved documents" "vannak mentésre váró fájlok")
("this document has not been saved" "ez a puffer még nincs elmentve")
("this column" "ez az oszlop")
("this document has been produced using" "")
("this line" "ezt a sort")
("this page" "ezt az oldalt")
("this page footer" "ezt az él®lábat")
("this page header" "ezt az él®fejet")
("this row" "ezt a sort")
("thumbnails" "el®nézeti képek")
("tilda" "tilda")
("tilde" "tilde")
("times" "times")
("timings" "id®zítések")
("tiny" "apró")
("title" "cím")
("to the left" "balra")
("to the right" "jobbra")
("today" "ma")
("tools" "eszközök")
("top" "felül")
("top border" "keret felül")
("top cell border" "cellakeret felül")
("top cell padding" "")
("top level" "")
("top margin" "margó felül")
("top padding" "")
("top table border" "táblázatkeret felül")
("top table padding" "")
("transfer" "transzfer")
("translate" "elfordítás")
("transpose" "transzponálás")
("tree" "fa")
("triangularize" "háromszögelés")
("trigonometric" "trigonometrikus")
("trigonometry" "trigonometria")
("tuple" "n-es")
("turkish" "török")
("tutorial" "bevezet®")
("type" "típus")
("type 1 only" "csak Type 1")
("type a latex command followed by" "")
("type body" "")
("type denominator" "adja meg a nevez®t")
("type numerator" "adja meg a számlálót")
("type script" "")
("typesetted boxes" "")
("typewriter" "írógép")
("typewriter small caps" "írógép kiskapitális")
("typing a simple text" "egyszer¶ szöveg gépelése")
("typing simple texts" "egyszer¶ szövegek gépelése")
("ugaritic" "")
("ukrainian" "ukrán")
("underbrace" "kapcsos zárójel alulra")
("underline" "aláhúzás")
("undo" "visszavonás")
("undo last changes" "utolsó változtatások visszavonása")
("ungroup" "csoport felbontása")
("unit" "mértékegység")
("unzoom" "kicsinyítés")
("up" "fel")
("update" "aktualizálás")
("update from web" "")
("update image links" "képhivatkozások aktualizálása")
("upper border" "")
("upright" "egyenes")
("url" "url")
("use MathML" "MathML használata")
("use TeXmacs" "használja a TeXmacs-et")
("use a black color" "")
("use a blue color" "")
("use a bold font" "")
("use a brown color" "")
("use a calligraphic font" "")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "sans serif bet¶típus használata")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "félkövér bet¶sorozat használata")
("use calligraphical font" "kalligrafikus bet¶típus használata")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "óriási bet¶méret használata")
("use italic font shape" "d®lt bet¶alak használata")
("use large font size" "nagy bet¶méret használata")
("use left hand column as border" "")
("use medium font series" "")
("use normal font size" "")
("use package" "csomag használata")
("use paragraph width" "")
("use really huge font size" "tényleg óriási bet¶méret használata")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "roman bet¶család használata")
("use row above as border" "")
("use row below as border" "az alsó sor használata keretként")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "kiskapitális használata")
("use small font size" "")
("use small-caps font shape" "")
("use the blackboard bold font" "")
("use the fraktur font" "")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "felhasználói kézikönyv")
("user provided icons" "felhasználói ikonok")
("users of Cyrillic languages" "cirillbet¶s nyelvek")
("users of oriental languages" "keleti nyelvek")
("utilities" "segédeszközök")
("value" "érték")
("variable" "változó")
("variant" "változat")
("vector" "vektor")
("verbatim" "")
("verse" "versszak")
("vertical" "függ®leges")
("vertical after" "függ®leges, ez után")
("vertical alignment" "függ®leges igazítás")
("vertical before" "függ®leges, ez elé")
("vertical cell alignment" "függ®leges cellaigazítás")
("vertical part" "függ®leges rész")
("vertical position" "függ®leges pozíció")
("vertical space" "függ®leges térköz")
("vertical table alignment" "függ®leges táblázatigazítás")
("vertically align cell to the base" "")
("vertically center the cell" "cella középre igazítása függ®legesen")
("very large" "nagyon nagy")
("very small" "nagyon kicsi")
("vietnamese" "vietnámi")
("view" "nézet")
("visible" "látható")
("warning" "figyelmeztetés")
("web" "web")
("welcome" "üdvözlet")
("welcome to GNU TeXmacs" "Üdvözli a GNU TeXmacs")
("what is new" "újdonságok")
("when finished" "ha kész")
("while" "while")
("white" "fehér")
("wide accent" "széles hangsúlyjel")
("wide bar" "")
("width" "szélesség")
("width is exactly the specified width" "a szélesség pontosan a meghatározott érték¶")
("width is maximum of specified width and box width" "a szélesség a meghatározott érték és a doboz szélessége közül a nagyobb")
("width is minimum of specified width and box width" "a szélesség a meghatározott érték és a dboz szélessége közül a kisebbik")
("width magnification" "szélesség nagyítása")
("window" "ablak")
("window height" "ablakmagasság")
("window width" "ablakszélesség")
("windows key" "windows billenty¶")
("with" "")
("wrap lines" "sortörés")
("write" "írás")
("write a macro" "makró készítése")
("write a name" "")
("write bold mathematics" "d®lt matematikai szöveg készítése")
("write bold text" "félkövér szöveg")
("write italic text" "d®lt szöveg")
("write sample text" "")
("write strong text" "")
("write typewriter text" "")
("write verbatim text" "")
("writing data converters" "adatátalakítók készítése")
("writing your own style files" "saját stílusfájlok készítése")
("written with TeXmacs" "készült a TeXmacs szoftverrel")
("yellow" "sárga")
("you can also obtain" "")
("your document is back in its original state" "megtörtént a dokumentum eredeti állapotba visszaállítása")
("your first interface" "")
("your language" "az Ön nyelve")
("zoom" "nagyítás")
