("A modifier" "A модификатор")
("GNU" "GNU")
("H modifier" "H модификатор")
("LaTeX" "LaTeX")
("M modifier" "M модификатор")
("TeX" "TeX")
("abbreviation" "съкращение")
("about" "за")
("about menu" "меню за")
("above" "отгоре")
("abstract" "абстракт")
("accent" "accent")
("accept" "допусни")
("accept all scripts" "допусни всички скриптове")
("accept no scripts" "не допускай никакви скриптове")
("accept script" "допусни скрипт")
("acknowledgment" "благодарност")
("acronym" "акроним")
("action" "действие")
("activate" "активиране")
("acute" "acute")
("add switch after" "добави превключвател след")
("add switch before" "добави превключвател преди")
("address" "адрес")
("address block" "адресен блок")
("advanced" "за експерти")
("advanced layout features" "layout за експерти")
("after" "след")
("albanian" "албански")
("algorithm" "алгоритъм")
("align cell to the bottom" "изравни клетката отдолу")
("align cell to the left" "изравни клетката отляво")
("align cell to the right" "изравни клетката отдясно")
("align cell to the top" "изравни клетката отгоре")
("align table at base of left column" "изравни таблицата по основното ниво на лявата колона")
("align table at base of middle column" "изравни таблицата по основното ниво на средната колона")
("align table at base of origin column" "изравни таблицата по основното ниво на исходната колона")
("align table at base of right column" "изравни таблицата по основното ниво на дясната колона")
("align table at fraction bar height" "изравни таблицата по височината на дробната черта")
("align table at the base of bottom row" "изравни таблицата по основното ниво на долния ред")
("align table at the base of middle row" "изравни таблицата по основното ниво на средния ред")
("align table at the base of origin row" "изравни таблицата по основното ниво на исходния ред")
("align table at the base of top row" "изравни таблицата по основното ниво на горния ред")
("align table at the bottom" "изравни таблицата отдолу")
("align table at the center" "изравни таблицата по центъра")
("align table at the horizontal center" "изравни таблицата по центъра хоризонтално")
("align table at the left" "изравни таблицата отляво")
("align table at the top" "изравни таблицата отгоре")
("align table to the right" "изравни таблицата отдясно")
("align text to the left" "изравни текста отляво")
("align text to the right" "изравни текста отдясно")
("alignment" "изравняване")
("all" "всички")
("allow" "разреши")
("allowed extension" "разрешено разширяване")
("allowed reduction" "разрешено намаляване")
("alpha release" "алфа версия")
("alt key" "клавиш alt")
("and" "и")
("appendix" "приложение")
("apply" "приложи")
("april" "април")
("arab" "арабски")
("archaic" "древен")
("architecture" "архитектура")
("argument" "аргумент")
("arithmetic" "аритметически")
("armenian" "арменски")
("arrow" "стрелка")
("arrows" "стрелки")
("article" "статия")
("as on paper" "като на хартия")
("assign" "присвои")
("at fraction bar height" "на височината на дробната черта")
("at the baseline" "на основното ниво")
("at the bottom" "отдолу")
("at the left" "отляво")
("at the middle" "в центъра")
("at the right" "отдясно")
("at the top" "отгоре")
("attach" "присъедини")
("attach buffer to which project" "присъедини буфер към кой проект")
("august" "август")
("author" "автор")
("authorize" "авторизирай")
("automatic" "автоматичен")
("automatically generated content" "автоматично генерирано съдържание")
("axiom" "аксиома")
("background" "фон")
("background color" "цвят на фона")
("backward replace" "замяна назад")
("backward search" "търсене назад")
("bad data format" "лош формат на данните")
("bar" "черта")
("bard" "bard")
("base level" "основното ниво")
("bashkirian" "башкирски")
("basic" "основен")
("basic data types" "основни типове данни")
("basic types" "основни типове")
("be useful" "да бъде полезен")
("become a TeXmacs developer" "станете разработчик на TeXmacs")
("before" "пред")
("begin" "начало")
("below" "отдолу")
("beta release" "бета версия")
("bibliography" "литература")
("bibliography file" "файл на литературата")
("bibliography style" "стил на литературта")
("big" "голям")
("big figure" "голяма фигура")
("big operator" "голям оператор")
("big skip" "голям интервал")
("big table" "голяма таблица")
("binary operation" "двоична операция")
("binary relation" "двоично отношение")
("black" "черен")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard math")
("blackletter" "blackletter")
("blue" "син")
("body" "тяло")
("bold" "bold")
("book" "книга")
("border" "граница")
("both" "и двете")
("bottom" "отдолу")
("bottom border" "долна граница")
("bottom margin" "долно поле")
("bottom padding" "долен запълнител")
("branch" "клон")
("break" "разрив")
("breaking" "прекъсване")
("breve" "breve")
("british" "британски")
("brown" "кафяв")
("browse" "browse")
("browse web" "browse web")
("browser" "browser")
("buffer" "буфер")
("bulgarian" "български")
("bullet" "bullet")
("bullets" "bullets")
("by" "от")
("by typing" "въвеждайки")
("bytes free" "bytes free")
("bytes used" "bytes used")
("calligraphic" "ръкописен")
("cancel" "cancel")
("caps-lock key" "caps-lock клавиш")
("case" "случай")
("cc" "копия")
("cell" "клетка")
("cell background color" "цвят на фона на клетката")
("cell border" "граница на клетката")
("cell height" "височина на клетката")
("cell operation mode" "режим на операция над клетката")
("cell width" "ширина на клетката")
("center" "център")
("center text" "центрирай текста")
("centered" "центриран")
("centered block" "центриран блок")
("centered tabular" "центрирана таблица")
("change border of cell" "измени границата на клетката")
("change cell operation mode" "измени режима на операция над клетката")
("change log" "журнал на измененията")
("changes" "изменения")
("chapter" "глава")
("check" "check")
("check text for spelling errors" "провери текста за правописни грешки")
("chinese" "китайски")
("choice" "избор")
("citation" "цитат")
("cite" "цитирай")
("class" "клас")
("clear" "изчисти")
("clear selection" "изчисти избраното")
("clipped" "изрязан")
("clipped and magnified" "изрязан и увеличен")
("clipped and resized" "изрязан и с изменен размер")
("clone" "дублирай")
("clone window" "дублирай прозореца")
("close" "затвори")
("close TeXmacs" "затвори TeXmacs")
("close buffer" "затвори буфера")
("close session" "затвори сесията")
("close window" "затвори прозореца")
("closing" "затваряне")
("code" "код")
("color" "цвят")
("column" "колона")
("column contains glued items" "колоната съдържа слепени елементи")
("compatibility with other formats" "съвместимост с други формати")
("compile article" "компилирай статия")
("compile book" "компилирай книга")
("compile buffer" "компилирай буфер")
("compile project" "компилирай проект")
("complex" "комплексен")
("concrete" "concrete")
("condensed" "condensed")
("condition" "условие")
("configuration" "конфигурация")
("content tag" "таг от съдържанието")
("context dependent icons" "икони, зависещи от контекста")
("continuation of" "продължение на")
("convention" "конвенция")
("converters to other data formats" "преобразователи в други формати на данни")
("copy" "копирай")
("copy text" "копирай текст")
("copy to" "копирай в")
("copying" "копиране")
("corollary" "следствие")
("correct text" "корегирай текстта")
("cursors" "курсори")
("custom tab" "custom tab")
("customizing TeXmacs" "настройка на TeXmacs")
("customizing the TeXmacs styles" "настройка на стиловете на TeXmacs")
("custum tab" "custum tab")
("cut" "изрежи")
("cut text" "изрежи текст")
("cut to" "изрежи до")
("cypriot" "кипърски")
("cyrillic" "кирилица")
("cyrillic input method" "метод на въвеждане на кирилица")
("cyrillic italic right" "курсив на кирилица")
("czech" "чешки")
("dancers" "танцуващи човечета")
("danish" "датски")
("dash" "тире")
("dashes" "тирета")
("data conversion" "преобразуване на данните")
("data format" "формат на данните")
("date" "дата")
("deactivate" "деактивирай")
("deactivate table" "деактивирай таблица")
("december" "декември")
("decorate atoms" "декорирай атомите")
("default" "по подразбиране")
("default padding" "запълнител по подразбиране")
("definition" "определение")
("delete" "изтрий")
("delete column" "изтрий колоната")
("delete row" "изтрий реда")
("denominator" "знаменател")
("description" "списък с описания")
("destination" "предназначение")
("detach" "отсъедини")
("determinant" "детерминанта")
("devangari" "деванагари")
("developers guide" "ръководство за разработчици")
("directory" "директория")
("disable first indentation" "забрани първия отстъп")
("disable first indentation after" "забрани първия отстъп след")
("disable first indentation before" "забрани първия отстъп преди")
("disable indentation" "забрани отстъпа")
("disable indentation after" "забрани отстъпа след")
("disable indentation before" "забрани отстъпа преди")
("disable last indentation" "забрани последния отстъп")
("disable last indentation after" "забрани последния отстъп след")
("disable last indentation before" "забрани последния отстъп преди")
("disallow" "забрани")
("distribute unused space" "разпредели свободното място")
("div" "div")
("document" "документ")
("document format" "формат на документа")
("document style" "стил на документа")
("document styles" "стилове на документите")
("documentation" "документация")
("documents are trees" "документите са дървета")
("dot" "точка")
("dots" "точки")
("double stroke" "двоен")
("down" "надолу")
("dpi" "dpi")
("duplicate" "дублирай")
("dutch" "холандски")
("dynamic libraries" "динамически библиотеки")
("edit" "редактирай")
("editing tools" "инструменти за редактиране")
("email" "email")
("emphasize" "подчертай")
("emphasize text" "emphasize текст")
("empty box" "празен бокс")
("enable first indentation" "разреши първия отстъп")
("enable first indentation after" "разреши първия отстъп след")
("enable first indentation before" "разреши първия отстъп преди")
("enable indentation" "разреши отстъп")
("enable indentation after" "разреши отстъп след")
("enable indentation before" "разреши отстъп преди")
("enable last indentation" "разреши последния отстъп")
("enable last indentation after" "разреши последния отстъп след")
("enable last indentation before" "разреши последния отстъп преди")
("encl" "вложение")
("end" "край")
("english" "английски")
("enter a title" "въведете заглавие")
("enumerate" "номерирай")
("enumerate|Alpha" "номерирай|Alpha")
("enumerate|Roman" "номерирай|Roman")
("enumerate|alpha" "номерирай|alpha")
("enumerate|roman" "номерирай|roman")
("env" "env")
("environment" "обкръжение")
("epilogue" "епилог")
("equal" "равно")
("equation" "уравнение")
("equations" "уравнения")
("equivalent for" "еквивалент за")
("error" "грешка")
("esperanto" "есперанто")
("etruscan" "етруски")
("evaluate" "изчисли")
("evaluate scheme expression" "изчисли scheme израз")
("even page footer" "footer на четните страници")
("even page header" "header на четните страници")
("even page margin" "поле на четните страници")
("even page text" "текст на четните страници")
("exact horizontal" "точен хоризонтален")
("exact mode" "точен режим")
("exam" "изпит")
("example" "пример")
("exclusive" "изключителен")
("exclusive or" "изключващо или")
("executable" "изпълним")
("execute" "изпълни")
("execute a TeXmacs command" "изпълни команда на TeXmacs")
("execute system command" "изпълни системна команда")
("executive" "executive")
("exercise" "упражнение")
("expand" "разкрий")
("explained" "обяснено")
("export" "експортирай")
("export as" "експортирай като")
("extend or normal" "разтегнат или нормален")
("extern " "вънешен")
("extra" "допълнителен")
("extract format" "екстрахирай формата")
("family" "семейство")
("february" "февруари")
("figure" "фигура")
("file" "файл")
("file name" "име на файла")
("file not found" "файлът не е намерен")
("find next match" "намери следващото съвпадиние")
("find text" "намери текст")
("finnish" "фински")
("first contact" "първи контакт")
("first indentation" "първи отстъп")
("first item" "първи елемент")
("first page" "първа страница")
("first start" "първи старт")
("flat" "flat")
("flexibility" "гъвкавост")
("flexibility factor for vertical spacing" "фактор на гъвкавост за вертикалния интервал")
("floating figure" "плаваща фигура")
("floating object" "плаващ объект")
("floating table" "плаваща таблица")
("fold" "свиване")
("folded" "свит")
("font" "шрифт")
("font base size" "основен размер на шрифта")
("font dpi" "dpi на шрифта")
("font family" "семейство на шрифта")
("font name" "име на шрифта")
("font series" "серии на шрифтове")
("font shape" "форма на шрифта")
("font size" "размер на шрифта")
("font variant" "вариант на шрифта")
("fonts" "шрифтове")
("footer" "footer")
("footnote" "бележка под черта")
("for" "за")
("foreground" "цвят на текста")
("foreign" "чуждестранен")
("format" "формат")
("formatted date" "форматирана дата")
("formula" "формула")
("formula style" "стил на формулата")
("forward replace" "замяна наперед")
("forward search" "търсене наперед")
("fraction" "дроб")
("french" "френски")
("full manuals" "пълни ръководства")
("function" "функция")
("further customization" "понататъшна настройка")
("future changes" "бъдещи изменения")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs не се сопровожда от никакви юридически гаранции")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs подпада под GNU - Общ Публичен Лиценз")
("general architecture of TeXmacs" "обща архитектура на TeXmacs")
("general negation" "общо отрицание")
("generating font file" "генерира се файлът на шрифта")
("generic" "общ")
("georgian" "грузински")
("german" "германски")
("getting started" "увод")
("glossary" "речник")
("glossary entry" "пункт в речника")
("glue" "лепило")
("glue decorations" "слепени украшения")
("go" "отивай")
("gothic" "готически")
("graphical interface" "графичен интерфейс")
("grave" "grave")
("greater" "по-голямо")
("greater or equal" "по-голямо или равно")
("greek" "гръцки")
("greek letter" "гръцка буква")
("green" "зелен")
("grey" "сив")
("group" "група")
("happy typing" "приятно писане")
("has been aborted" "е бил прекъснат")
("has completed its task" "е свършил своята работа")
("hat" "шапка")
("header" "header")
("header and footer" "header и footer")
("hebrew" "еврейски")
("height" "височина")
("height is exactly the specified height" "височината е точно зададената височина")
("height is maximum of specified height and box height" "височината е по-голямата от зададената и височината на бокса")
("height is minimum of specified height and box height" "височината е по-малката от зададената и височината на бокса")
("height magnification" "разтягане на височината")
("help" "помощ")
("help me" "помогнете ми")
("help us" "помогнете ни")
("here" "тук")
("home" "вкъщи")
("horizontal" "хоризонтален")
("horizontal cell alignment" "хорозинтално изравняване на клетката")
("horizontal ink separation" "horizontal ink separation")
("horizontal part" "хоризонтална част")
("horizontal position" "хоризонтално положение")
("horizontal space" "хоризонтален интервал")
("horizontal table alignment" "хоризонтално изравняване на таблица")
("horizontally align cell to the base" "хоризонтално изравни клетката по основното ниво")
("horizontally center the cell" "хоризонтално центрирай клетката")
("how much longer may pages become" "колко дълги могат да станат страниците")
("how much shorter may pages become" "колко къси могат да станат страниците")
("huge" "огромен")
("hungarian" "унгарски")
("hyperlink" "хиперлинк")
("hyphenation" "пренос")
("icelandic" "исландски")
("if" "ако")
("image" "изображение")
("image links" "изображения-линкове")
("implementation" "реализация")
("import" "импортирай")
("improving the current implementation" "подобряване на текущата реализация")
("inactive" "неактивен")
("include" "включи")
("include a document" "включи документ")
("include file" "включи файл")
("inclusion into TeXmacs" "включение в TeXmacs")
("inclusions" "включения")
("indent" "отстъп")
("indentation flag" "флаг за отстъп")
("index" "указател")
("index entry" "пункт в индекса")
("index level" "ниво в индекса")
("insert" "вмъкни")
("insert Pr" "вмъкни Pr")
("insert a TeXmacs symbol" "вмъкни TeXmacs символ")
("insert a big operator" "вмъкни голям оператор")
("insert a binary operation" "вмъкни двоична операция")
("insert a binary relation" "вмъкни двоично отношение")
("insert a blackboard bold character" "вмъкни blackboard bold символ")
("insert a bold calligraphic character" "вмъкни bold calligraphic символ")
("insert a bold character" "вмъкни bold символ")
("insert a calligraphic character" "вмъкни calligraphic символ")
("insert a fraction" "вмъкни дроб")
("insert a fraktur character" "вмъкни fraktur символ")
("insert a greek character" "вмъкни гръцка буква")
("insert a large left delimiter" "вмъкни голям ляв ограничител")
("insert a large right delimiter" "вмъкни голям десен ограничител")
("insert a large separator" "вмъкни голям разделител")
("insert a left subscript" "вмъкни ляв долен индекс")
("insert a link" "вмъкни линк")
("insert a miscellaneous symbol" "вмъкни разнообразен символ")
("insert a new branch" "вмъкни нов клон")
("insert a new item" "вмъкни нов елемент")
("insert a picture" "вмъкни картинка")
("insert a square root" "вмъкни квадратен корен")
("insert a table" "вмъкни таблица")
("insert a table or a matrix" "вмъкни таблица или матрица")
("insert an" "вмъкни")
("insert an accent" "вмъкни accent")
("insert an arrow" "вмъкни стрелка")
("insert an environment" "вмъкни обкръжение")
("insert an n" "вмъкни n")
("insert appendix" "вмъкни приложение")
("insert arccos" "вмъкни arccos")
("insert arcsin" "вмъкни arcsin")
("insert arctan" "вмъкни arctan")
("insert arg" "вмъкни arg")
("insert argument" "вмъкни аргумент")
("insert automatically generated content" "вмъкни автоматично генерирано съдържание")
("insert big contour integral" "вмъкни голям контурен интеграл")
("insert big coproduct" "вмъкни голямо копроизведение")
("insert big direct sum" "вмъкни голяма пряка сума")
("insert big dotted point" "вмъкни голям кръг с точка")
("insert big integral" "вмъкни голям интеграл")
("insert big intersection" "вмъкни голямо пресичане")
("insert big logical and" "вмъкни голямо логическо и")
("insert big logical or" "вмъкни голямо логическое или")
("insert big product" "вмъкни голямо произведение")
("insert big square union" "вмъкни голямо квадратно обединение")
("insert big summation" "вмъкни голяма сума")
("insert big tensor product" "вмъкни голямо тензорно произведение")
("insert big union" "вмъкни голямо обединение")
("insert big union sum" "вмъкни голяма сума-обединение")
("insert big vertical space" "вмъкни голям вертикален интервал")
("insert chapter" "вмъкни глава")
("insert column" "вмъкни колона")
("insert column to the left" "вмъкни колона отляво")
("insert column to the right" "вмъкни колона отдясно")
("insert cos" "вмъкни cos")
("insert cosh" "вмъкни cosh")
("insert cot" "вмъкни cot")
("insert coth" "вмъкни coth")
("insert csc" "вмъкни csc")
("insert deg" "вмъкни deg")
("insert det" "вмъкни det")
("insert dim" "вмъкни dim")
("insert dollar" "вмъкни долар")
("insert equation" "вмъкни уравнение")
("insert executable markup" "вмъкни изпълним markup")
("insert exp" "вмъкни exp")
("insert footnote" "вмъкни бележка под черта")
("insert formula" "вмъкни формула")
("insert gcd" "вмъкни gcd")
("insert hom" "вмъкни hom")
("insert horizontal interword space" "вмъкни хоризонтален интервал между думите")
("insert image" "вмъкни изображение")
("insert inactive markup" "вмъкни неактивен markup")
("insert inf" "вмъкни inf")
("insert ker" "вмъкни ker")
("insert lg" "вмъкни lg")
("insert lim" "вмъкни lim")
("insert liminf" "вмъкни liminf")
("insert limsup" "вмъкни limsup")
("insert ln" "вмъкни ln")
("insert log" "вмъкни log")
("insert mathematics" "вмъкни математика")
("insert max" "вмъкни max")
("insert medium horizontal space" "вмъкни среден хоризонтален интервал")
("insert medium vertical space" "вмъкни среден вертикален интервал")
("insert min" "вмъкни min")
("insert negative horizontal space" "вмъкни отрицателен хоризонтален интервал")
("insert new item or number" "вмъкни нов елемент или номер")
("insert new rows or columns" "вмъкни нови редове или колони")
("insert or delete rows or columns" "вмъкни или изтрий редове или колони")
("insert row" "вмъкни ред")
("insert row above" "вмъкни ред над")
("insert row below" "вмъкни ред под")
("insert sec" "вмъкни sec")
("insert section" "вмъкни параграф")
("insert sharp" "вмъкни решетка")
("insert sin" "вмъкни sin")
("insert sinh" "вмъкни sinh")
("insert small horizontal space" "вмъкни малък хоризонтален интервал")
("insert small vertical space" "вмъкни малък вертикален интервал")
("insert structural markup" "вмъкни структурен markup")
("insert subsection" "вмъкни подпараграф")
("insert subsubsection" "вмъкни подподпараграф")
("insert sup" "вмъкни sup")
("insert tan" "вмъкни tan")
("insert tanh" "вмъкни tanh")
("insert thick horizontal space" "вмъкни голям хоризонтален интервал")
("interfacing" "взаимодействие")
("interfacing TeXmacs with other systems" "взаимодействие на TeXmacs с други системи")
("interjection" "възклицание")
("interline separation" "разделение между редовете")
("interline space" "междуредово разстояние")
("internationalization" "интернационализация")
("interparagraph space" "разстояние между абзаците")
("interrupt execution" "прекъсни изпълнението")
("introduction" "увод")
("invisible" "невидим")
("invisible citation" "невидим цитат")
("irish" "ирландски")
("is running" "се изпълнява в момента")
("is tuple" "is tuple")
("ispell does not respond" "ispell не отговаря")
("ispell is already busy" "ispell вече е зает")
("italian" "италиански")
("italic" "italic")
("italic right" "italic right")
("itemize" "налрави на списък")
("january" "януари")
("japanese" "японски")
("july" "юли")
("june" "юни")
("justified" "подравнен")
("justify text" "подравни текста")
("key" "клавиш")
("keyboard" "клавиатура")
("keyboard equivalent" "клавиатурен еквивалент")
("keyboard modifiers" "клавиатурни модификатори")
("keyboard shorthand" "клавиатурно съкращение")
("keymaps" "keymaps")
("keyword" "ключова дума")
("keywords" "ключови думи")
("kill" "убий")
("known bugs" "известни грешки")
("label" "етикет")
("landscape" "ландшафт")
("language" "език")
("large" "голям")
("large closing bracket" "голяма затваряща скоба")
("large delimiter" "голям ограничител")
("large opening bracket" "голяма отваряща скоба")
("large separator" "голям разделител")
("last indentation" "последен отстъп")
("last page" "последна страница")
("latex command" "latex команда")
("latin" "латински")
("layout" "разположение")
("left" "ляв")
("left border" "ляв край")
("left margin" "ляво поле")
("left padding" "ляво запълване")
("left prime" "left prime")
("left aligned" "назъбен ляв край")
("left slanted" "left slanted")
("left subscript" "ляв долен индекс")
("left superscript" "ляв горен индекс")
("left surrounding" "ляво обкръжение")
("legal" "legal")
("lemma" "лема")
("length" "дължина")
("less" "по-малко")
("less or equal" "по-малко или равно")
("letter" "писмо")
("license" "лиценз")
("light" "light")
("limitations" "ограничения")
("limits" "граници")
("line" "ред")
("line break" "line break")
("line stretch" "растягане на реда")
("link" "линк")
("link image" "изображение на линк")
("list" "списък")
("list of figures" "списък на фигурите")
("list of tables" "список на таблиците")
("load" "зареди")
("load LaTeX file" "зареди LaTeX файл")
("load TeX file" "зареди TeX файл")
("load TeXmacs file" "зареди TeXmacs файл")
("load TeXmacs style file" "зареди TeXmacs стилов файл")
("load a file" "зареди файл")
("load buffer" "зареди буфер")
("load file" "зареди файл")
("load html file" "зареди html файл")
("load image" "зареди изображение")
("load in new window" "зареди в нов прозорец")
("load latex file" "зареди LaTeX файл")
("load more recent autosave file" "зареди по-нов autosave файл")
("load tex file" "зареди TeX файл")
("load verbatim file" "зареди буквален файл")
("loaded" "зареден")
("long" "long")
("look and feel" "вид и поведение")
("look up" "найти")
("lower border" "долна рамка")
("macro" "макрос")
("magenta" "магента")
("magic" "магически")
("magnification" "увеличение")
("magnified" "увеличен")
("main" "главен")
("main icon bar" "заглавна ивица с икони")
("major changes" "основни изменения")
("make a page insertion" "направи вмъкване на страница")
("make a subscript" "направи долен индекс")
("make a superscript" "направи горен индекс")
("make acute" "направи acute")
("make bar" "направи черта")
("make check" "направи check")
("make fraction" "направи дроб")
("make grave" "направи grave")
("make hat" "направи шлапка")
("make label" "направи етикет")
("make negation" "направи отрицание")
("make page reference" "направи препратка към страница")
("make reference" "направи препратка")
("make square root" "направи квадратен корен")
("make tilde" "направи тилда")
("make title" "направи заглавие")
("make vector" "направи вектор")
("making donations" "даренияния")
("manual" "справочник")
("map to" "изобразит в")
("march" "март")
("margins" "полета")
("margins as on paper" "полета като на хартия")
("master" "главен")
("master file" "главен файл")
("math" "математически")
("math font" "математический шрифт")
("math font family" "семейство на математическия шрифт")
("math font series" "серия на математическия шрифт")
("math font shape" "форма на математическия шрифт")
("mathematical" "математически")
("mathematical formulas" "математически формули")
("mathematical typesetting" "математически набор")
("mathematics" "математика")
("matrix" "матрица")
("maximal number of columns" "максимален брой на колоните")
("maximal number of rows" "максимален брой на редовете")
("maximum mode" "максимален режим")
("may" "май")
("medium" "medium")
("medium skip" "среден интервал")
("meminfo" "meminfo")
("merge" "merge")
("messy" "messy")
("meta key" "клавиш meta")
("middle" "среден")
("minimal number of columns" "минимален брой на колоните")
("minimal number of rows" "минимален брой на редовете")
("minimum mode" "минимален режим")
("minus" "минус")
("miscellaneous" "разнообразни")
("mod" "mod")
("mode" "режим")
("modifier" "модификатор")
("modify cell alignment" "промени изравняването на клетката")
("modify cell border" "промени границите на клетката")
("modify cell padding" "промени запълването на клетката")
("modify cell size" "промени размера на клетката")
("modify table border" "промени границите на таблицата")
("modify table padding" "промени запълването на таблицата")
("mongolian" "монголски")
("more information about GNU TeXmacs can be found in the help" "повече информация за GNU TeXmacs може да намери в помощта")
("mosaic" "мозайка")
("move down" "премести надолу")
("move object" "премести обект")
("move to the right when finished" "премести надясно когато е готово")
("move up" "премести нагоре")
("n-th" "n-ти")
("n-th root" "n-ти корен")
("name" "име")
("negation" "отрицание")
("new" "нов")
("new buffer" "нов буфер")
("new column" "нова колона")
("new item" "нов елемент")
("new line" "нов ред")
("new number" "нов номер")
("new page" "нова страница")
("new page before" "нова страница преди")
("new paragraph" "нов абзац")
("new roman" "new roman")
("new row" "нов ред")
("new table" "нова таблица")
("next line" "следващ ред")
("no changes need to be saved" "няма изменения, които е необходимо се съхранят")
("no dictionary for" "няма речник за")
("no first indentation" "без първи отстъп")
("no indentation" "без отстъп")
("no last indentation" "без последен отстъп")
("no line break" "без line break")
("no matches found" "не са намерени съвпадения")
("no more matches for" "не са намерени повече съвпадения за")
("no more redo information available" "няма повече redo информация")
("no more undo information available" "няма повече undo информация")
("no name" "без име")
("no page break after" "без page break след")
("no page break before" "без page break преди")
("no spelling errors found in text" "не са намерени правописни грешки в текста")
("no style" "няма стил")
("none" "никакви")
("normal" "нормален")
("norwegian" "норвежки")
("not" "не")
("not equal" "не равно")
("not found" "не е намерен")
("notation" "обозначение")
("note" "бележка")
("november" "ноември")
("number" "число")
("number equation" "номерирай уравнението")
("number of columns" "брой на колоните")
("numbered equation" "номерано уравнение")
("numbered equations" "номерани уравнения")
("numerator" "числител")
("numeric" "числен")
("objectives" "цели")
("occurrences" "occurrences")
("october" "октомври")
("odd page footer" "footer за нечетните страници")
("odd page header" "header за нечетните страници")
("odd page margin" "полета за нечетните страници")
("odd page text" "текст за нечетните страници")
("off" "изкл")
("ok" "ok")
("old english" "староанглийски")
("old slavonic" "старославянски")
("old style" "стар стил")
("on" "вкл")
("on cells" "над клетките")
("on columns" "над колоните")
("on entire table" "над цялата таблица")
("on rows" "над редовете")
("one spelling error has been corrected" "една правописна грешка е поправена")
("online documentation" "онлайн документация")
("online help" "онлайн помощ")
("open" "отвори")
("open a new buffer" "отвори нов буфер")
("open new window" "отвори нов прозорец")
("opening" "отваране")
("operation on named selection" "операция над наименован избор")
("operation on primary selection" "операция над главен избор")
("operation on secondary selection" "операция над вторичен избор")
("operation on ternary selection" "операция над третичен избор")
("optical" "оптически")
("option" "опция")
("options" "опции")
("or" "или")
("orange" "оранжев")
("orientation" "ориентация")
("origin" "произхд")
("original welcome message" "оригинално приветствие")
("other" "друг")
("other pages" "други страници")
("other projects" "други проекти")
("other style" "друг стил")
("outlined roman" "outlined roman")
("over" "над")
("padding" "запълване")
("page" "страница")
("page bottom margin" "долно поле на страницата")
("page break" "page break")
("page break before" "page break преди")
("page height" "височина на на страницата")
("page insertion" "вмъкване на страница")
("page layout" "разположение на страницата")
("page number text" "текст на номера на страницата")
("page numbering" "номерация на страниците")
("page reference" "препратка към страница")
("page right margin" "дясно поле на страницата")
("page top margin" "горно поле на страницата")
("page type" "тип на страницата")
("page width" "ширина на страницата")
("paper" "хартия")
("paper type" "тип на хартията")
("papyrus" "папирус")
("paragraph" "абзац")
("paragraph mode" "режим на абзаца")
("paragraph width" "ширина на абзаца")
("part" "част")
("past changes" "предходни изменения")
("paste" "вмъкни")
("paste from" "вмъкни от")
("paste text" "вмъкни текст")
("path" "път")
("perform operations on cells" "изпълни операции над клетките")
("perform operations on columns" "изпълни операции над колоните")
("perform operations on entire table" "изпълни операции над цялата таблица")
("perform operations on rows" "изпълни операции над редовете")
("permanent" "постоянен")
("person" "персона")
("personal dictionary has been modified" "личният речник е модифициран")
("phantasy" "измислен")
("philosophy" "философия")
("phoenician" "финикийски")
("phonetic" "фонетичен")
("pink" "розов")
("plain block" "прост блок")
("plain tabular" "проста таблица")
("planned changes" "планирани изменения")
("plans for the future" "планове за бъдещето")
("please" "моля")
("please wait" "моля почакайте")
("plus" "плюс")
("polish" "полски")
("porting TeXmacs to other platforms" "перенос на TeXmacs на други платформи")
("portrait" "портрет")
("portuguese" "португалски")
("position" "положение")
("position float" "позиционирай плаващия")
("position floating object" "позиционирай плаващия обект")
("position the table" "позиционирай таблицата")
("postscript" "postscript")
("postscript image" "postscript image")
("pre-alpha release" "пре-алфа версия")
("preamble" "преамбул")
("preamble mode" "режим на преамбула")
("preferences" "предпочитания")
("presentation mode" "режим на презентация")
("preview before printing" "преглед преди печат")
("preview with ghostview" "прегледай с ghostview")
("primary" "първичен")
("prime" "prime")
("print" "печатай")
("print all" "печатай всичко")
("print all to file" "печатай всичко във файл")
("print page selection" "печатай избраните страници")
("print page selection to file" "печатай избраните страници във файл")
("print to postscript file" "печатай в postscript файл")
("printer" "принтер")
("printer dpi" "dpi на принтера")
("printing command" "команда за печат")
("problem" "задача")
("professional" "професионално")
("prog" "прог")
("prog font" "програмен шрифт")
("prog font family" "семейство на програмния шрифт")
("prog font series" "серия на програмния шрифт")
("prog font shape" "форма на програмния шрифт")
("program" "програма")
("program mode" "програмен режим")
("programming" "програмиране")
("progressive" "прогресивен")
("project" "проект")
("projects" "проекти")
("prologue" "пролог")
("prompt on scripts" "питай за скриптовете")
("proof" "доказателство")
("proportional" "proportional")
("proportional typewriter" "пропорционален typewriter")
("proposition" "предложение")
("query replace" "замени с въпроси")
("quit" "изход")
("quotation" "цитат")
("quote" "цитирай")
("range" "диапазон")
("really close it" "действително ли го затваряте")
("really huge" "действително огромен")
("really quit" "действително ли приключвате")
("red" "червен")
("redo" "redo")
("redo undone changes" "redo undone changes")
("reduce bottom margin by" "намали долното поле с")
("reduce left margin by" "намали лявото поле с")
("reduce margins" "намали полетата")
("reduce right margin by" "намали дясното поле с")
("reduce top margin by" "намали горното поле с")
("reduction even page margin" "намаляване на полтата на четните страници")
("reduction odd page margin" "намаляване на полтата на нечетните страници")
("reduction page bottom margin" "намаляване на долното поле на страницата")
("reduction page right margin" "намаляване на дясното поле на страницата")
("reduction page top margin" "намаляване на горното поле на страницата")
("reference" "препратка")
("references" "препратки")
("regular" "регулярен")
("release" "версия")
("reload" "перезареди")
("remark" "забележка")
("remove number" "премахни номера")
("remove this switch" "премахни този превключвател")
("renumber this page" "переномерирай тази страница")
("repeat object" "повтори объекта")
("replace" "замени")
("replace by" "замени с")
("replaced" "заменено")
("replaced one occurrence" "заменено е един път")
("reset" "переустанови")
("resize object" "измени размера на обекта")
("resized" "размерът е изменен")
("return" "return")
("revert" "revert")
("revert buffer" "възстанови буфера")
("right" "right")
("right border" "десен край")
("right margin" "дясно поле")
("right padding" "дясно запълване")
("right aligned" "назъбен десен край")
("right subscript" "десен долен индекс")
("right superscript" "десен горен индекс")
("right surrounding" "дясно обкръжение")
("rigid" "твърд")
("rigid horizontal" "твърд хоризонтален")
("rigid space" "твърд интервал")
("romanian" "румънски")
("root" "корен")
("rotate backward" "върти назад")
("rotate forward" "върти напред")
("row" "ред")
("row contains glued items" "редът съдържа слепени елементи")
("runic" "рунически")
("running author" "текущ автор")
("running title" "текущо заглавие")
("russian" "руски")
("russian and Ukrainian users" "руски и украински потребитили")
("sample" "образец")
("sans serif" "sans serif")
("save" "съхрани")
("save TeXmacs file" "съхрани TeXmacs файл")
("save TeXmacs style file" "съхрани TeXmacs стилов файл")
("save as" "съхрани като")
("save as LaTeX" "съхрани като LaTeX")
("save as TeX" "съхрани като TeX")
("save buffer" "съхрани буфера")
("save buffer as" "съхрани буфера като")
("save file" "съхрани файл")
("save html file" "съхрани html файл")
("save image" "съхрани изображение")
("save latex file" "съхрани latex файл")
("save tex file" "съхрани tex файл")
("save this buffer" "съхрани този буфер")
("save verbatim file" "съхрани буквален файл")
("saved" "съхранен")
("screen layout" "разположение на екрана")
("screen margins" "екранни полета")
("script" "индекс")
("script above" "индекс над")
("script below" "индекс под")
("script script size" "размер на индекса в индекс")
("script size" "размер на индекса")
("scripts not accepted" "скриптове не се допускат")
("search" "търси")
("searching" "търсене")
("secondary" "вторичнен")
("section" "параграф")
("security" "сигурност")
("see" "виж")
("select a document style" "изберете стил на документа")
("select a foreground color" "изберете цвят за преден план")
("select a language" "изберете език")
("selected region" "избрана област")
("selection" "селекция")
("selections" "селекции")
("seminar" "семинар")
("separation between lines" "разстояние между редовете")
("separation between paragraphs" "разстояние между абзаците")
("separator" "сепаратор")
("september" "септември")
("serb" "сръбски")
("series" "серия")
("series|right" "series|right")
("session" "сесия")
("session name" "име на сесията")
("session type" "тип на сесията")
("sessions" "сесии")
("set" "настрой")
("set background color of cell" "задай цвета на фона на клетката")
("set cell mode" "задай режима на клетката")
("set extension center" "задай центъра на разширението")
("set height" "задай височина")
("set height of cell" "задай височината на клетката")
("set margins" "задай полета")
("set n" "задай n")
("set paragraph margins" "задай полетата на абзаца")
("set paragraph mode" "задай режима на абзаца")
("set printer dpi" "задай (dpi) на принтера ")
("set printing command" "задай командата за печат")
("set span" "задай span")
("set special cell properties" "задай специалните свойства на клетката")
("set special table properties" "задай специалните свойства таблицата")
("set text width" "задай ширина на текста")
("set width" "задай ширина")
("set width of cell" "задай ширина на клетката")
("settings" "задайки")
("setup printer" "настрой принтера")
("shape" "форма")
("shift-down" "shift-down")
("shift-right" "shift-right")
("show" "покажи")
("show header and footer" "покажи header и footer")
("show on screen" "покажи на екрана")
("shrinking factor" "фактор на свиване")
("signature" "подпис")
("size" "размер")
("size limits" "граници на размера")
("slanted" "slanted")
("sloppy" "sloppy")
("small" "малък")
("small caps" "small caps")
("small figure" "малка фигура")
("small skip" "малък интервал")
("small table" "малка таблица")
("source code" "source code")
("space" "интервал")
("space between lines" "разстояние между редовете")
("space between paragraphs" "расстояние между абзаците")
("spacing" "spacing")
("spanish" "испански")
("special" "специален")
("special cell properties" "специални свойства на клетката")
("special table properties" "специални свойства на таблицата")
("specific" "специфичен")
("spell" "правопис")
("spell checking complete" "проверката на правописа е завършена")
("spelling error" "правописна грешка")
("spelling errors have been corrected" "правописните грешки са поправени")
("split" "split")
("square root" "квадратен корен")
("start" "начало")
("start a new chapter" "започни нова глава")
("start a new section" "започни нов параграф")
("start an interactive session" "започни интерактивна сесия")
("status bar" "status bar")
("stretchable" "разтеглим")
("stretchable horizontal" "разтеглим хоризонтален")
("stretchable vertical" "разтеглим вертикален")
("stroke" "stroke")
("strokes" "strokes")
("strong" "силен")
("structural" "структурен")
("style" "стил")
("styles" "стилове")
("sub" "под")
("subparagraph" "подабзац")
("subscript" "долен индекс")
("subsection" "подпараграф")
("subsub" "подпод")
("subsubsection" "подподпараграф")
("summary" "резюме")
("summary of the principal TeXmacs tags" "резюме на главните тагове на TeXmacs")
("superpose" "наложи")
("superposed" "наложен")
("superscript" "горен индекс")
("swedish" "шведски")
("switch" "превключвател")
("switch to first" "превключи на първия")
("switch to formula style" "превключи на стил за формули")
("switch to last" "превключи на последния")
("switch to next" "превключи на следващия")
("switch to previous" "превключи на предишния")
("switching and folding" "перевключване и пренавиване")
("symbol" "символ")
("system environment variables" "системни променливи на обкръжението")
("tab" "tab")
("table" "таблица")
("table command" "таблична команда")
("table of contents" "съдържание")
("tables" "таблици")
("tabular" "табличен")
("tabular material" "табличен материал")
("teXmacs as an interface" "teXmacs като интерфейс")
("teXmacs fonts" "шрифтове на TeXmacs")
("teXmacs notice" "забележка на TeXmacs")
("teXmacs style files" "стилови файлове на TeXmacs")
("ternary" "третичен")
("test" "тест")
("tex" "tex")
("text" "текст")
("text font" "шрифт на текста")
("text height correction" "поправка на височината на текста")
("text width" "ширина на текста")
("texts" "текстове")
("th century bc" "века до н.е.")
("th root" "ти корен")
("thai" "тайски")
("the TeXmacs authors" "авторите на TeXmacs")
("the application did not send its usual startup banner" "приложението не изпрати своя обичаен startup banner")
("the application does not reply" "приложението не отговаря")
("the application is already running" "приложението вече се изпълнява")
("the boxes produced by the typesetter" "боксовете създадени от наборчика")
("the graphical user interface" "графичен потребителски интерфейс")
("the leaves of TeXmacs trees" "листата от дърветата на TeXmacs")
("the mycas example" "примерът mycas")
("the primitive TeXmacs constructs" "примитивните конструкции на TeXmacs")
("the standard TeXmacs styles" "стандартните стилове на TeXmacs")
("theorem" "теорема")
("there are unsaved documents" "има несъхранени файлове")
("this document has not been saved" "този буфер не е бил съхранен")
("this document has been produced using" "този документ е създаден използвайки")
("this line" "този ред")
("this page" "тази страница")
("tilda" "tilda")
("tilde" "tilde")
("times" "умножи")
("tiny" "tiny")
("title" "заглавие")
("to the left" "наляво")
("to the right" "надясно")
("today" "днес")
("tools" "инструменти")
("top" "горе")
("top border" "горен край")
("top level" "горно ниво")
("top margin" "горено поле")
("top padding" "горено запълване")
("translate" "преведи")
("tree" "дърво")
("tuple" "tuple")
("turkish" "турски")
("tutorial" "самоучител")
("type" "тип")
("type a latex command followed by" "въведете latex команда последвана от")
("type body" "въведете тяло")
("type denominator" "въведете знаменател")
("type numerator" "въведете числител")
("type script" "въведете индекс")
("typesetted boxes" "набрани боксове")
("typewriter" "typewriter")
("typewriter small caps" "typewriter small caps")
("typing a simple text" "въвеждане на прост текст")
("typing simple texts" "въвеждане на прости текстове")
("ugaritic" "угаритски")
("ukrainian" "украински")
("undo" "undo")
("undo last changes" "undo последните изменения")
("up" "нагоре")
("update" "обнови")
("update from web" "обнови от web")
("update image links" "обнови линкковете на изображенията")
("upper border" "горна рамка")
("use TeXmacs" "исползвайте TeXmacs")
("use a black color" "използвай черен цвят")
("use a blue color" "използвай син цвят")
("use a bold font" "използвай bold шрифт")
("use a brown color" "използвай кафяв цвят")
("use a calligraphic font" "използвай шрифт calligraphic")
("use a green color" "използвай зелен цвят")
("use a grey color" "използвай сив цвят")
("use a magenta color" "използвай магента цвят")
("use a orange color" "използвай оранжев цвят")
("use a pink color" "използвай розов цвят")
("use a red color" "използвай червен цвят")
("use a sans serif font" "използвай шрифт sans serif")
("use a typewriter font" "използвай шрифт typewriter")
("use a white color" "използвай бял цвят")
("use a yellow color" "използвай жълт цвят")
("use blackboard bold font" "използвай шрифт blackboard bold")
("use bold font series" "използвай серия на шрифта bold")
("use calligraphical font" "използвай шрифт calligraphical")
("use footnote font size" "използвай размер на шрифта footnote")
("use fraktur font" "използвай шрифт fraktur")
("use huge font size" "използвай размер на шрифта huge")
("use italic font shape" "използвай форма на шрифта italic")
("use large font size" "използвай размер на шрифта large")
("use left hand column as border" "използвай лвата колона като граница")
("use medium font series" "използвай серия на шрифта medium")
("use normal font size" "използвай размер на шрифта normal")
("use package" "използвай пакет")
("use paragraph width" "използвай ширината на абзаца")
("use really huge font size" "използвай размер на шрифта really huge")
("use right font shape" "използвай форма на шрифта right")
("use right hand column as border" "използвай дясната колона като граница")
("use roman font family" "използвай семейство шрифтове roman")
("use row above as border" "използвай погорния ред като граница")
("use row below as border" "използвай подолния ред като граница")
("use sans serif font family" "използвай семейство шрифтове sans serif")
("use script font size" "използвай размер на шрифта script")
("use slanted font shape" "използвай форма на шрифта slanted")
("use small capitals" "използвай small capitals")
("use small font size" "използвай размер на шрифта small")
("use small-caps font shape" "използвай форма на шрифта small-caps")
("use the blackboard bold font" "използвай шрифт blackboard bold")
("use the fraktur font" "използвай шрифт fraktur")
("use tiny font font size" "използвай размер на шрифта tiny")
("use typewriter font family" "използвай семейство на шрифта typewriter")
("use very large font size" "използвай размер на шрифта very large")
("user manual" "ръководство на потребителя")
("user provided icons" "икони, предоставени от потребителя")
("value" "стойност")
("variable" "променлива")
("variant" "вариант")
("vector" "вектор")
("verbatim" "буквално")
("verse" "стихотворение")
("vertical" "вертикален")
("vertical after" "вертикален след")
("vertical before" "вертикален преди")
("vertical cell alignment" "вертикално изравняване на клетката")
("vertical part" "вертикална част")
("vertical position" "вертикално положение")
("vertical space" "вертикален интервал")
("vertical table alignment" "вертикално изравняване на таблицата")
("vertically align cell to the base" "вертикално изравни клетката по основното ниво")
("vertically center the cell" "вертикално центрирай клетката")
("very large" "много голям")
("very small" "много малък")
("vietnamese" "виетнамски")
("view" "вид")
("visible" "видим")
("warning" "предупреждение")
("welcome" "добре дошли")
("welcome to GNU TeXmacs" "добре дошли в GNU TeXmacs")
("what is new" "какво е ново")
("when finished" "когато е готово")
("while" "докато")
("white" "бял")
("wide accent" "широк accent")
("width" "ширина")
("width is exactly the specified width" "ширината е точно зададената ширина")
("width is maximum of specified width and box width" "ширината е по-голямата от зададената ширина и ширината на бокса")
("width is minimum of specified width and box width" "ширината е по-малката от зададената ширина и ширината на бокса")
("width magnification" "разтягане на ширината")
("window" "прозорец")
("window height" "височина на прозореца")
("window width" "ширина на прозореца")
("windows key" "клавиш windows")
("with" "с")
("write a name" "пиши име")
("write bold mathematics" "пиши bold математика")
("write bold text" "пиши bold текст")
("write italic text" "пиши italic текст")
("write sample text" "пиши sample текст")
("write strong text" "пиши strong текст")
("write typewriter text" "пиши typewriter текст")
("write verbatim text" "пиши verbatim текст")
("writing data converters" "създаване на конвертори на данни")
("writing your own style files" "създаване на собствени стилови файлове")
("yellow" "жълт")
("you can also obtain" "вие можете също да получите")
("your document is back in its original state" "вашият документ е върнат в исходно състояние")
("your first interface" "вашият първи интерфейс")
