;; Cork characters which have no unicode equivalent

;; (C) 2003  David Allouche
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.


("#18"  	"0")            ; perthousand zero
("#1A"          "j")		; dotless j
("#DF"          "SS")           ; latin capital letter sharp s
("<comma>"      ",")            ; decimal comma
