("\"encryption\" features from the preference panel" "\x13шифрування\x14 функції на панелі налаштувань")
("(Re)Build autocompletion index" "(Re) Побудувати індекс автозаповнення")
("a modifier" "модифікатор")
("a series" "серія")
("a.C.M. computing class" "класів обчислювальної техніки в США")
("a.M.S. subject class" "предметний клас у США")
("abbreviated authors" "скорочених авторів")
("abreviated authors" "скорочених авторів")
("accent above" "акцент вище")
("accent below" "акцент нижче")
("accept during this pass" "прийняти під час пропуску")
("acknowledgments" "визнань")
("activate hidden" "активувати приховане")
("activate once" "активувати один раз")
("activation" "активація")
("active link types" "активних типів посилань")
("add" "додати")
("add abstract information" "додати абстрактну інформацію")
("add author information" "додати інформацію про автора")
("add branch after" "Додати гілку після")
("add branch before" "додати гілку до")
("add other package" "додати інший пакет")
("add package" "додати пакет")
("add style package" "Додати пакет стилю")
("add title information" "додати інформацію про назву")
("addition" "додаток")
("adjust" "коригування")
("adjust limits" "коригування меж")
("advanced font customization" "розширена настройка шрифту")
("affiliation" "приналежність")
("albanian" "албанська")
("align cell to the decimal comma" "вирівняти комірку до десяткової коми")
("align cell to the decimal dot" "вирівняти комірку до десяткової крапки")
("align table at axis" "вирівнювання таблиці по осі")
("aligned" "вирівняно")
("alignment of balloon" "вирівнювання кулі")
("all cells" "усі клітини")
("all data attached to this identity will be lost" "усі дані, пов'язані з цією особою, будуть втрачені")
("all saved passphrases will be lost forever" "усі збережені парольні фрази будуть втрачені назавжди")
("allow for macro definitions in preamble" "дозволити визначення макросів у преамбулі")
("allowed page height extension" "Дозволене розширення по висоті сторінки")
("allowed page height reduction" "дозволене зменшення висоти сторінки")
("allowed positions" "дозволені позиції")
("allowed positions of floating object" "Дозволені позиції плаваючого об'єкта")
("alpha transparency" "прозорість альфа")
("also on paper" "також на папері")
("alter" "alter")
("alternate" "альтернативних")
("alternate except here" "альтернативні, крім тут")
("alternate from here on" "чергуються звідси далі")
("alternate only here" "чергувати лише тут")
("alternate until here" "чергувати, поки тут")
("alternative specification" "альтернативна специфікація")
("always" "завжди")
("american" "американців")
("amplified" "посилено")
("and perform casual settings from the \"Encryption\" tab" "та виконайте випадкові налаштування на вкладці \x13Шифрування\x14")
("angular" "кутових")
("animate" "анімація")
("animate folding" "анімова складання")
("animate unfolding" "розгортання анімації")
("animated" "анімовані")
("animation" "анімація")
("animation toolbar" "панель інструментів для анімації")
("annotate" "примітка")
("answer" "відповідь")
("answer field" "поле відповіді")
("answer to question" "відповідь на питання")
("answers only" "Лише відповідей")
("any" "будь-який")
("appear" "з'явитися")
("apply macro" "застосувати макрос")
("apply macro once" "застосувати макрос один раз")
("approximate" "приблизний")
("arc" "дуга")
("arc cosine" "дуговий косинус")
("arc sine" "дуга")
("arc tangent" "дотична дуга")
("arch series" "аркова серія")
("are you sure you want to delete collected public keys" "Ви впевнені, що хочете видалити зібрані відкриті ключі")
("are you sure you want to delete selected public keys" "Ви впевнені, що хочете видалити вибрані відкриті ключі")
("are you sure you want to delete selected secret keys" "Ви впевнені, що хочете видалити вибрані секретні ключі")
("are you sure you want to destroy the wallet" "Ви впевнені, що хочете знищити гаманець")
("art frame" "художні рамки")
("arxiv category" "категорія арксів")
("as visual grid" "як візуальна сітка")
("aspect" "аспект")
("attach master" "приєднати майстра")
("auto" "авто")
("auto-save file" "файл автоматичного збереження")
("automatic brackets" "автоматичні дужки")
("automatic content generation" "автоматичне створення вмісту")
("automatic program brackets" "автоматичні дужки програми")
("automatic quotes" "автоматичні котирування")
("automatically close brackets" "автоматично закрити дужки")
("automatically import bibliographies when opening files" "автоматично імпортує бібліографії при відкритті файлів")
("automatically remember all passphrases in the wallet" "автоматично запам'ятовує всі парольні фрази в гаманці")
("automatically save" "автоматично зберегти")
("autosave" "автозбереження")
("axis" "вісь")
("b series" "b серія")
("back" "назад")
("background evaluations" "фонові оцінки")
("backtrace errors" "зворотних помилок")
("base" "баз")
("baseline" "базовий рівень")
("basic communication using pipes" "базовий зв'язок за допомогою труб")
("beamer" "промінь")
("beamer formats" "форматів променів")
("beamer theme" "тема променів")
("bench" "лавка")
("bend bottom" "зігнутий низ")
("bend corner" "вигин кут")
("bend diagonal" "діагоналі вигину")
("bend in" "згин")
("bend out" "вигин")
("bezier" "Безьє")
("bibTeX command" "команда bibTeX")
("bidirectional" "двонаправлений")
("big environment box" "великий екологічний ящик")
("big focus" "великий фокус")
("binary operator" "двійковий оператор")
("bitmap resolution (dpi)" "роздільна здатність растрових зображень (dpi)")
("black floral I" "чорний квітковий І")
("black floral II" "чорний квітковий II")
("blackboard embold" "чорна дошка")
("blank column" "порожній стовпець")
("blank row" "порожній рядок")
("block" "блок")
("block content" "блокувати вміст")
("block of code" "блок коду")
("blur" "розмиття")
("both versions" "обидві версії")
("bottom baseline" "нижня база")
("bottom cell border" "нижня межа комірки")
("bottom cell padding" "нижня клітинка")
("bottom table border" "нижня межа столу")
("bottom table padding" "нижня підкладка столу")
("bottom tools" "нижніх інструментів")
("box" "коробка")
("broken white" "зламаний білий")
("browse back" "перегляд назад")
("browse forward" "переглянути вперед")
("browse modules documentation" "перегляд документації модулів")
("buffer management" "управління буфером")
("buffer must be on disk" "буфер повинен бути на диску")
("buffer must have a name" "буфер повинен мати ім'я")
("build buffer" "буфер збірки")
("build buffer in" "вбудований буфер в")
("build directory" "довідників збірки")
("build directory in" "створення каталогу в")
("build link pages" "створення посилань")
("build-all" "все для складання")
("bulgarian" "болгарка")
("bump" "шишка")
("busy" "зайнятих")
("cJK" "cJK")
("cJK spacing" "cJK інтервал")
("calculus" "обчислення")
("cancelled" "скасовано")
("cannot download directory to file" "Неможливо завантажити каталог у файл")
("cannot rename across different servers" "не можна перейменувати на різних серверах")
("cannot upload directory to file" "Неможливо завантажити каталог у файл")
("cartesian" "декартовий")
("carved wood" "різьблене дерево")
("case-insensitive search" "нечутливий до регістру пошук")
("categories" "категорій")
("category" "категорія")
("cell properties" "властивості комірок")
("cells" "комірок")
("change default unit" "змінити стандартну одиницю")
("change passphrase" "зміни парольної фрази")
("change step-size" "змінити розмір кроку")
("change tags" "зміни тегів")
("change the TeXmacs preferences" "зміни налаштувань TeXmacs")
("change the border of the table" "змінити межу таблиці")
("change the style of mathematical formulas" "зміни стилю математичних формул")
("character contraction" "стиснення символів")
("character encoding" "кодування символів")
("character expansion" "розширення символів")
("check for updates" "перевірка на оновлення")
("checkable field" "поле, яке можна перевірити")
("cipher algorithm for passphrase encryption" "алгоритм шифрування для шифрування парольної фрази")
("circle" "коло")
("classification" "класифікація")
("clean slate" "чистий шифер")
("clear all fields" "очистити всі поля")
("clear local information" "чітка місцева інформація")
("clear menu" "чітке меню")
("clear undo history" "ясна історія скасування")
("click Ok button twice to discard this warning" "двічі натисніть кнопку ОК, щоб відхилити це попередження")
("clip" "кліп")
("clipboard image format" "формат зображення буфера обміну")
("close animation tool" "інструмент закриття анімації")
("close document" "закритий документ")
("close program" "Закрити програму")
("close replace tool" "інструмент закрити заміну")
("close search tool" "Закрити інструмент пошуку")
("close spell tool" "інструмент закриття орфографії")
("close translations to rebuild" "закритих перекладів для відновлення")
("closed bezier" "закритий безьє")
("closed curve" "закрита крива")
("closed smooth" "закритий гладкий")
("closed spline" "закритий сплайн")
("closing style" "стиль закриття")
("cluster by affiliation" "кластер за приналежністю")
("collect garbage" "збирай сміття")
("collected keys" "зібраних ключів")
("color of the axes" "колір осей")
("color of the subunits" "колір підрозділів")
("color of the units" "колір одиниць")
("colors" "кольорів")
("column to the left" "стовпець зліва")
("column to the right" "стовпець праворуч")
("columns" "стовпців")
("column separation" "розділення стовпців")
("commit file" "файл фіксації")
("common" "звичайних")
("common formats" "загальних форматів")
("commutative diagram" "комутативна схема")
("compact" "компактний")
("compactification" "ущільнення")
("compactify" "ущільнити")
("complete bibliographic reference" "повна бібліографічна довідка")
("completion" "завершення")
("complex actions" "складних дій")
("compose" "скласти")
("compound" "з'єднання")
("compress" "компрес")
("compress into toolbar" "стиснення на панелі інструментів")
("compressed" "стиснутий")
("conceal" "приховувати")
("configure look and feel" "Налаштувати зовнішній вигляд")
("confirm database entry" "підтвердити введення бази даних")
("confirm entry" "підтвердити запис")
("confirm selected database entries" "підтвердити вибрані записи бази даних")
("confirm selected entries" "підтвердити вибрані записи")
("conservative conversion options" "консервативні варіанти перетворення")
("consoles" "консолей")
("constellation" "сузір'я")
("contact" "контакт")
("content" "вміст")
("context aids" "контекстні посібники")
("contextual hints" "контекстуальні підказки")
("continue" "продовжити")
("continued fraction" "продовження дробу")
("contour" "контур")
("contract logarithms" "логарифми контрактів")
("contribute" "сприяти")
("control flow" "контрольний потік")
("control the evaluation of expressions" "контроль оцінки виразів")
("convert" "конвертувати")
("converters" "перетворювачі")
("convertible" "кабріолет")
("copyright" "авторських прав")
("cork charset with TeX catcode definition in preamble" "пробкова набір з визначенням коду TeX у преамбулі")
("correct" "правильно")
("correct all" "виправити все")
("correct formula" "правильна формула")
("correct manually" "виправити вручну")
("correct mathematical formulas" "правильні математичні формули")
("correction" "виправлення")
("cosine" "косинус")
("count characters" "кількість символів")
("count lines" "кількість ліній")
("count words" "рахувати слова")
("create a new document" "створити новий документ")
("create link" "створити посилання")
("create preamble" "створити преамбулу")
("create remote directory" "створити віддалений каталог")
("create remote file" "створити віддалений файл")
("create subprogram" "створити підпрограму")
("create subsession" "створити субсесію")
("create table macro" "створити макрос таблиці")
("create web site" "Створити веб-сайт")
("creating new account" "створення нового облікового запису")
("creating technical pictures" "створення технічних зображень")
("crop" "врожай")
("crop marks" "урожайних знаків")
("cross" "хрест")
("crossed boxes" "перекреслені коробки")
("crossed circles" "схрещені кола")
("current user version" "поточна версія користувача")
("current version" "поточна версія")
("cursor" "курсор")
("curve" "крива")
("curve intersections" "криві перехрестя")
("curve points" "кривих точок")
("customizations" "налаштування")
("customizing and extending the user interface" "налаштування та розширення інтерфейсу користувача")
("danish" "датський")
("dark grey" "темно-сірий")
("data" "дані")
("database entry" "запис бази даних")
("database tool" "інструмент бази даних")
("database toolbar" "панель інструментів бази даних")
("deactivate once" "деактивувати один раз")
("dead" "мертвих")
("debug" "налагодження")
("debugging console" "консоль налагодження")
("debugging tool" "інструмент налагодження")
("decimal comma" "десяткова кома")
("decimal dot" "десяткова крапка")
("decomposed" "розкладено")
("decorated" "прикрашений")
("decorated wood" "прикрашена деревина")
("decrease size" "зменшити розмір")
("decrypt" "розшифрувати")
("default size" "типовий розмір")
("degrade" "погіршити")
("degraded" "деградовано")
("delete documentation cache" "видалити кеш документації")
("delete entries" "видалити записи")
("delete link" "видалити посилання")
("deleted" "видалено")
("describe" "описати")
("describe tag" "описувати тег")
("destroy" "знищити")
("detach master" "майстер відриву")
("detailed" "детально")
("detailed menus" "докладні меню")
("details in menus" "подробиці в меню")
("determine margins from text width" "визначити поля від ширини тексту")
("developer" "розробник")
("developer tool" "інструмент для розробників")
("device" "пристрій")
("diamond" "алмаз")
("differentiate" "диференціювати")
("dilate" "розширити")
("direction of progression" "напрямок прогресування")
("direction of translation" "напрямок перекладу")
("disable" "відключити")
("disable coloring on paper" "відключити забарвлення на папері")
("disable encryption" "відключити шифрування")
("disappear" "зникнути")
("disk" "диск")
("display style" "стиль відображення")
("displayed formula" "відображена формула")
("dissociate joined cells" "дисоціативні об'єднані клітини")
("distort" "спотворень")
("distorted" "спотворено")
("division" "поділ")
("do not remap" "не переробляти")
("document font selector" "Вибір шрифту документа")
("document language" "мова документа")
("document page format" "формат сторінки документа")
("document paragraph format" "формат абзацу документа")
("document updates run" "Оновлення документа запущено")
("download" "завантажити")
("downwards" "вниз")
("dragging" "перетягування")
("draw image" "намалювати зображення")
("draw over" "намалювати")
("draw over selection" "намалюй вибір")
("drop" "краплі")
("due to" "завдяки")
("dynamic" "динамічний")
("eRROR" "eRROR")
("edit animation" "редагування анімації")
("edit groups of objects" "редагування груп об'єктів")
("edit macro" "редагувати макрос")
("edit macros" "редагувати макроси")
("edit preamble" "редагувати преамбулу")
("edit source" "редагування джерела")
("edit source tree" "редагувати вихідне дерево")
("edit style" "стиль редагування")
("edit translations file" "редагувати файл перекладів")
("education" "освіта")
("effect pen" "ефектна ручка")
("eigenvalues" "власних значень")
("eighth" "восьмий")
("embold" "рельєф")
("emboss" "тиснення")
("enable page breaking" "включити розрив сторінки")
("encoding" "кодування")
("encrypt" "шифрування")
("encryption" "шифрування")
("encryption facilities are not currently available" "засоби шифрування наразі недоступні")
("encryption facilities have not been enabled for TeXmacs" "засоби шифрування не ввімкнено для TeXmacs")
("enforce brackets to match" "примусові дужки у відповідність")
("engrave" "гравюра")
("enter data" "ввести дані")
("enter graphics" "введіть графіку")
("enter graphics mode" "введіть графічний режим")
("enter new passphrase for encryption" "введіть нову парольну фразу для шифрування")
("enter passphrase for decryption" "введіть пароль для розшифровки")
("enter passphrase for identity" "введіть пароль для ідентичності")
("enter title information" "Введіть інформацію про назву")
("entire table" "вся таблиця")
("entry up to date in database" "введення в базу даних")
("enunciation" "вимова")
("environment variable" "змінна середовище")
("environments" "середовища")
("erode" "розмивати")
("error messages" "повідомлення про помилки")
("error output" "помилка виводу")
("error status report" "звіт про стан помилок")
("error: bracket does not match" "помилка: дужка не відповідає")
("error: cyclic or missing chunks detected" "помилка: виявлені циклічні чи відсутні фрагменти")
("error: file not found" "помилка: файл не знайдено")
("error: ghostview does not seem to be installed on your system" "помилка: ghostview, здається, не встановлений у вашій системі")
("error: one of the alternatives should be filled out" "помилка: одна з альтернатив має бути заповнена")
("error: only one alternatives should be filled out" "помилка: потрібно заповнити лише одну альтернативу")
("error: should fill out name for referencing" "помилка: має заповнити ім'я для посилання")
("error: should fill out required field" "помилка: має заповнити обов'язкове поле")
("esperanto" "есперанто")
("evaluable field" "поле, що оцінюється")
("evaluate above" "оцінити вище")
("evaluate all" "оцінити все")
("evaluate below" "оцінити нижче")
("evaluate fields" "Оцінити поля")
("evaluate fields in order" "Оцінити поля за порядком")
("evaluate script" "оцінка сценарію")
("evaluation" "оцінка")
("evaluation switch" "перемикач оцінки")
("evaluation tag" "тег оцінки")
("even page" "рівна сторінка")
("even page left margin" "рівний запас сторінки")
("even page shift" "рівномірне змінення сторінки")
("even pages" "рівних сторінок")
("events" "події")
("exact" "точно")
("execution of scripts" "виконання сценаріїв")
("exit graphics" "графіка виходу")
("exit graphics mode" "вихідний графічний режим")
("exit left" "вихід ліворуч")
("exit right" "виїзд праворуч")
("exit tag on the left" "тег виходу зліва")
("exit tag on the right" "тег виходу праворуч")
("expand TeXmacs macros with no LaTeX equivalents" "розширити макроси TeXmacs без еквівалентів LaTeX")
("expand beamer slides" "розгортання слайдів променя")
("expand inclusions" "розширення включень")
("expand logarithms" "розширити логарифми")
("expand trigonometric functions" "розширити тригонометричні функції")
("expand unrecognized macros" "розширити невпізнані макроси")
("expand user-defined macros" "розгорнути визначені користувачем макроси")
("expanded" "розширено")
("experimental features (to be used with care)" "експериментальні функції (використовувати обережно)")
("explain" "поясніть")
("explanatory item" "пояснювальний предмет")
("explicit keystroke" "явний натиск клавіші")
("explicit margins" "явні поля")
("exponential" "експоненціальна")
("export bibliographies as links" "експортні бібліографії як посилання")
("export bibliography" "експортна бібліографія")
("export entries in buffer" "Експортні записи в буфері")
("export file" "експортний файл")
("export formulas as images" "формули експорту у вигляді зображень")
("export mathematical formulas as MathML" "експорт математичних формул як MathML")
("export mathematical formulas as images" "експорт математичних формул у вигляді зображень")
("export selected entries" "експорт вибраних записів")
("export selection" "вибір експорту")
("export selection as image" "Вибір експорту як зображення")
("export selections as" "Вибір експорту як")
("export sessions" "експортних сесій")
("exported bibliographic entries" "експортованих бібліографічних записів")
("exported bibliographic references" "експортованих бібліографічних довідок")
("extend" "продовжити")
("extended" "розширено")
("extensible left arrow" "ліва стрілка, що розширюється")
("extensible right arrow" "розширювана стрілка праворуч")
("extern" "екстерн")
("external" "зовнішні")
("extra branch" "додаткова галузь")
("extra interline space" "додатковий міжрядковий простір")
("extra name" "додаткова назва")
("extract" "екстракт")
("extract style file" "файл стилю вилучення")
("extract style package" "пакунок стилю екстракту")
("factor" "фактор")
("fade" "згасає")
("fade in" "зникає")
("fade out" "згасає")
("fast" "швидка")
("fast decrease" "швидке зменшення")
("fast environments" "швидке середовище")
("fast increase" "швидке зростання")
("field reference" "посилання на поле")
("fifth" "п'ятий")
("file saved" "файл збережено")
("fill color" "колір заливки")
("fill out" "заповнити")
("filter" "фільтр")
("find file" "знайти файл")
("finished collecting symbols documentation" "Готові документи збору символів")
("finnish" "фінських")
("first" "перший")
("first chunk" "перший шматок")
("first difference" "перша різниця")
("first error" "перша помилка")
("first field" "перше поле")
("first occurrence" "перша поява")
("first similar" "перший подібний")
("fit to screen" "підходить до екрану")
("fit to screen width" "підходить до ширини екрана")
("five columns" "п'ять стовпців")
("fixed" "виправлено")
("flag is off" "прапор вимкнено")
("flag is on" "прапор увімкнено")
("flatten" "сплющити")
("floating algorithm" "плаваючий алгоритм")
("floating phantom" "плаваючий фантом")
("focus" "фокус")
("focus dependent icons" "піктограми, що залежать від фокусу")
("fold all" "скласти всі")
("fold all fields" "скласти всі поля")
("fold back" "скласти назад")
("fold input field" "складне поле введення")
("follow external links" "перейти на зовнішні посилання")
("follow inverse links" "перейти на зворотні посилання")
("font effects" "шрифтові ефекти")
("font selector" "селектор шрифту")
("font type" "тип шрифту")
("for each" "для кожного")
("force reloading of translations" "примусове перезавантаження перекладів")
("formatted and structured output" "відформатований та структурований вихід")
("formatting" "форматування")
("forward" "вперед")
("four columns" "чотири стовпці")
("four dots" "чотири крапки")
("fourth" "четвертий")
("fraktur" "фрактури")
("framed" "обрамлено")
("from" "від")
("from center" "від центру")
("front matter" "передня справа")
("full" "повний")
("full author list" "повний список авторів")
("full screen mode" "повноекранний режим")
("functional" "функціональних")
("gap" "пробіл")
("garbage collection" "вивезення сміття")
("gaussian" "гауссів")
("gcd" "gcd")
("general" "загальний")
("general note" "загальна примітка")
("generated LaTeX document contains no errors" "згенерований документ LaTeX не містить помилок")
("generated field" "генероване поле")
("geometry" "геометрія")
("get arity" "отримати арність")
("get label" "отримати етикетку")
("get list with remote versions" "отримати список із віддаленими версіями")
("glyphs" "гліфи")
("gnaw" "гризуть")
("gnawed" "гризе")
("gnuPG command" "команда gnuPG")
("gnuPG error: buffer encryption failed" "помилка gnuPG: помилка шифрування буфера")
("gnuPG error: cannot find suitable secret key to decrypt" "помилка gnuPG: не вдалося знайти відповідний секретний ключ для розшифрування")
("gnuPG requires name and email to have at least 5 characters" "gnuPG вимагає, щоб ім'я та електронна адреса містили принаймні 5 символів")
("go to anchor" "піти на якір")
("go to anchor or float" "йти на якір або плавати")
("go to anchor or footnote" "Перейти до якіря чи виноски")
("go to first similar tag" "перейти до першого подібного тегу")
("go to float" "піти плавати")
("go to footnote" "перейти до виноски")
("go to last similar tag" "перейти до останнього подібного тегу")
("go to next similar tag" "перейти до наступного подібного тегу")
("go to previous similar tag" "перейти до попереднього подібного тегу")
("go to section" "перейти до розділу")
("grain" "зерна")
("granite" "граніт")
("graphical effects" "графічні ефекти")
("graphical interface font scale" "шрифт графічного інтерфейсу")
("graphics" "графіка")
("graphics geometry" "графічна геометрія")
("graphics grids" "графічних сіток")
("greyed" "сірий")
("grid" "сітка")
("grid curves" "криві сітки")
("grid points" "точок сітки")
("grid-curve intersections" "перехрестя кривої сітки")
("group of objects" "група об'єктів")
("group/ungroup" "група / розгрупа")
("grouped" "згруповано")
("guarantee transparent source tracking" "гарантія прозорого відстеження джерела")
("h modifier" "h модифікатор")
("half wide" "наполовину шириною")
("hand drawn" "намальований")
("headers" "заголовків")
("hidden" "прихованих")
("history" "історія")
("homepage" "домашня сторінка")
("homoglyph substitutions" "заміни гомогліфів")
("horizontal alignment" "горизонтальне вирівнювання")
("horizontal collapse distance" "горизонтальна відстань згортання")
("horizontal margins" "горизонтальні поля")
("hybrid command" "гібридна команда")
("hyphenate as" "дефіс як")
("icon" "ікона")
("if hyphenated" "якщо дефіс")
("ignore" "ігнорувати")
("impact" "вплив")
("import bibliography" "імпортна бібліографія")
("import database entry" "Введення бази даних імпорту")
("import entries in buffer" "імпортних записів у буфері")
("import entry" "імпортний запис")
("import file" "файл імпорту")
("import selected database entries" "імпорт вибраних записів бази даних")
("import selected entries" "імпортувати вибрані записи")
("import selections as" "вибір імпорту як")
("import sessions" "сеанс імпорту")
("import sophisticated objects as pictures" "імпортувати складні об'єкти як зображення")
("imported bibliographic entries" "імпортовані бібліографічні записи")
("in popup windows" "у спливаючих вікнах")
("inanimated" "неживих")
("inch" "дюймів")
("incomplete entries found to be filled out" "виявлено незавершені записи")
("increase size" "збільшити розмір")
("indent paragraphs" "абзаци з абзацами")
("indentation" "відступ")
("indication" "вказівка")
("informative flags" "інформаційних прапорів")
("initialize" "ініціалізувати")
("ink here" "чорнило тут")
("ink in" "чорнило в")
("ink out" "чорнило")
("inline" "вбудований")
("inline arguments" "вбудованих аргументів")
("inline code" "вбудований код")
("inline content" "вбудований вміст")
("inline formula" "вбудована формула")
("inner bottom" "внутрішнє дно")
("inner left" "внутрішній лівий")
("inner right" "внутрішній правий")
("inner top" "внутрішній верх")
("input command" "команда введення")
("input field" "поле введення")
("input mode" "режим введення")
("input options" "параметри введення")
("insert a computer program" "вставити комп'ютерну програму")
("insert a condition" "вставити умову")
("insert a control flow instruction" "Вставити інструкцію управління потоком")
("insert a gap" "вставити проміжок")
("insert a list" "вставити список")
("insert a multiple choice" "вставити декілька варіантів")
("insert a negation" "вставити заперечення")
("insert a new entry" "вставити новий запис")
("insert a note or a floating object" "Вставити примітку або плаваючий об'єкт")
("insert a numerical operation" "вставити числову операцію")
("insert a prominent piece of text" "вставити видатний фрагмент тексту")
("insert a question" "вставити запитання")
("insert a root" "вставити корінь")
("insert a script" "вставити сценарій")
("insert a section block" "вставити блок розділу")
("insert a textual operation" "вставити текстову операцію")
("insert a textual operator" "вставити текстовий оператор")
("insert a wide symbol above" "вставити широкий символ вгорі")
("insert a wide symbol below" "вставити широкий символ внизу")
("insert above" "вставити вище")
("insert abstract" "вставити реферат")
("insert an answer" "вставити відповідь")
("insert an enunciation" "вставити програму")
("insert an operation on tuples" "Вставити операцію на кортежі")
("insert annotation" "вставити анотацію")
("insert author" "вставити автора")
("insert below" "вставити внизу")
("insert copyright and license information" "вставити інформацію про авторські права та ліцензії")
("insert explanatory item" "вставити пояснювальний елемент")
("insert field above" "вставити поле вгорі")
("insert field below" "вставити поле внизу")
("insert fields" "вставити поля")
("insert input field above" "вставити поле введення вище")
("insert input field below" "вставити поле введення нижче")
("insert large delimiters" "вставити великі роздільники")
("insert last name" "вставити прізвище")
("insert left" "вставити ліворуч")
("insert macro" "вставити макрос")
("insert missing invisible operators" "вставити пропущені невидимі оператори")
("insert more names" "вставити більше імен")
("insert particle" "вставити частинку")
("insert plain text" "вставити звичайний текст")
("insert right" "вставити право")
("insert similar above" "вставити подібне вище")
("insert similar below" "вставити подібне внизу")
("insert similar block above" "вставити подібний блок вище")
("insert similar block below" "вставити подібний блок внизу")
("insert subtable" "вставити підзарядний")
("insert symbol documentation" "вставити символьну документацію")
("insert template" "вставити шаблон")
("insert text field" "вставити текстове поле")
("insert text field above" "вставити текстове поле вгорі")
("insert text field below" "вставити текстове поле внизу")
("insert title" "вставити заголовок")
("insert title after name" "вставити заголовок після імені")
("insert user interface related markup" "вставити розмітку, пов'язану з користувальницьким інтерфейсом")
("insert value" "значення вставки")
("inserting control points" "Вставлення контрольних точок")
("integrate" "інтегрувати")
("interactive command" "інтерактивна команда")
("interactive questions" "інтерактивних питань")
("intercharacter compression" "міжчастовий стиснення")
("intercharacter stretching" "міжчастовий розтягнення")
("interrupted" "перервано")
("invalid multi-paragraph selection" "недійсний вибір кількох абзаців")
("invalid renaming" "недійсне перейменування")
("invert" "інвертування")
("inverted breve" "перевернута брева")
("invisible ending" "невидиме закінчення")
("invisible newline" "невидимий новий рядок")
("invisible opening" "невидимий отвір")
("join selected cells" "приєднати вибрані комірки")
("jump in" "стрибок")
("junior" "молодший")
("keep evaluated expressions" "зберігати оцінені вирази")
("keep local" "зберігати місцеве")
("keep remote" "тримати віддалений")
("keep track of source code" "слідкувати за вихідним кодом")
("keep unfolded" "тримати розгорнутий")
("keyboard configuration" "конфігурація клавіатури")
("laptop presentations" "презентації ноутбуків")
("large cells" "великих комірок")
("large displayed" "великий показ")
("large displayed fraction" "великий відображений дріб")
("large tables" "великих столиків")
("last" "останніх")
("last difference" "остання різниця")
("last error" "остання помилка")
("last field" "останнє поле")
("last name" "прізвище")
("last occurrence" "остання поява")
("last similar" "останній подібний")
("lcm" "lcm")
("left arrow" "стрілка вліво")
("left axis" "ліва вісь")
("left baseline" "ліва базова лінія")
("left bottom" "ліве дно")
("left cell border" "ліва межа клітинки")
("left cell padding" "ліва клітинка")
("left center" "лівий центр")
("left click: add point; Right click: undo" "лівий клік: додайте крапку; клацніть правою кнопкою миші: скасувати")
("left click: finish; Right click: undo" "лівий клік: закінчити; клацніть правою кнопкою миші: скасувати")
("left click: new object" "клацання лівою кнопкою миші: новий об'єкт")
("left click: operate" "клацання лівою кнопкою миші: дія")
("left down" "ліворуч")
("left on even pages" "залишено на рівних сторінках")
("left table border" "ліва межа столу")
("left table padding" "набивання лівого столу")
("left top" "лівий верх")
("left up" "ліворуч")
("left-right arrow" "стрілка вліво-вправо")
("leftwards" "зліва")
("let the environment float" "нехай середовище пливе")
("light grey" "світло-сірий")
("line breaking" "розрив лінії")
("line wrapping" "обертання рядків")
("linear 2D" "лінійний 2D")
("linear algebra" "лінійна алгебра")
("lines around" "рядків навколо")
("link image and copies as" "посилання на зображення та копії як")
("link image as" "зображення посилання як")
("link mode" "режим зв'язку")
("link to URL" "посилання на URL")
("linking tool" "інструмент для з'єднання")
("live" "наживо")
("live input-output" "живий вхід-вихід")
("load help file" "завантажити довідковий файл")
("load remote file" "завантажити віддалений файл")
("loading" "завантаження")
("local entries" "місцеві записи")
("loci" "локусів")
("locus" "локус")
("locus rendering" "локусування")
("logarithm" "логарифм")
("logarithmic" "логарифмічний")
("logarithmic base" "логарифмічна основа")
("logarithms" "логарифми")
("logging in" "вхід")
("logical and" "логічно і")
("logical implication" "логічний вплив")
("logical not" "логічно не")
("logical or" "логічний або")
("login" "вхід")
("logout" "вихід")
("long macro" "довгий макрос")
("long text" "довгий текст")
("look for more fonts" "шукати більше шрифтів")
("loops" "петель")
("m modifier" "м модифікатор")
("macro argument" "макроаргумент")
("macro definition" "визначення макросу")
("macro name" "ім'я макросу")
("macros" "макроси")
("magnify horizontally" "збільшувати по горизонталі")
("magnify vertically" "збільшити вертикально")
("main presentation style" "основний стиль викладу")
("make a letter environment" "зробити буквене середовище")
("make a multi-slide presentation" "зробити багатопозиційну презентацію")
("make floating" "зробити плаваючим")
("make link" "зробити посилання")
("make non floating" "зробити неплаваючим")
("manila paper" "маніла папір")
("map arguments" "аргументи карти")
("marginal note" "гранична нота")
("margins from width" "поля від ширини")
("margins on paper" "поля на папері")
("margins on screen" "поля на екрані")
("marked" "позначено")
("material" "матеріал")
("mathematical and customized input" "математичний та індивідуальний вхід")
("mathematical font" "математичний шрифт")
("mathematical input" "математичний вклад")
("mathematical output" "математичний вихід")
("matrices" "матриці")
("maximal" "максимальний")
("maximal cell height" "максимальна висота комірки")
("maximal clustering" "максимальна кластеризація")
("maximal table height" "максимальна висота столу")
("maximal table width" "максимальна ширина столу")
("maximum" "максимум")
("meander" "меандр")
("memory" "пам'ять")
("memory usage" "використання пам'яті")
("menu" "меню")
("merge lines into paragraphs unless separated by blank lines" "рядки злиття в абзаци, якщо не розділені порожніми рядками")
("messages" "повідомлень")
("meta data" "метаданих")
("metadata" "метадані")
("metal" "метал")
("middle baseline" "середня база")
("minimal" "мінімальних")
("minimal cell height" "мінімальна висота комірки")
("minimal cell width" "мінімальна ширина комірки")
("minimal line separation" "мінімальний відрив лінії")
("minimal table height" "мінімальна висота столу")
("minimal table width" "мінімальна ширина столу")
("minimum" "мінімум")
("mirror" "дзеркало")
("miscellaneous features" "різні функції")
("miscellanous" "різне")
("mode dependent icons" "значки, залежні від режиму")
("modify remote live document" "змінити віддалений живий документ")
("module" "модуль")
("monospaced" "односхилих")
("more information about GNU TeXmacs can be found in the Help" "Більше інформації про GNU TeXmacs можна знайти у довідці")
("more information about GNU TeXmacs can be found in the Help->About menu" "більше інформації про GNU TeXmacs можна знайти в довідці-> про меню")
("motion" "рух")
("mouse over object" "миша над об'єктом")
("move" "переміщення")
("move objects" "переміщення об'єктів")
("move over object on which to operate" "переміщення над об'єктом, над яким працювати")
("multiline" "багаторядковий")
("multiline input" "багаторядковий вхід")
("multiple choice" "множинний вибір")
("multiple root" "кілька коренів")
("multiplication" "множення")
("mutator tags" "тегів мутаторів")
("my documents" "мої документи")
("navigation options" "опції навігації")
("never" "ніколи")
("new account" "новий рахунок")
("new bibliography dialogue" "новий бібліографічний діалог")
("new document" "новий документ")
("new double page" "нова подвійна сторінка")
("new double page before" "нова подвійна сторінка раніше")
("new entry" "новий запис")
("new identity" "нова ідентичність")
("new locus" "новий локус")
("new macro" "новий макрос")
("new passphrase" "нова парольна фраза")
("new remote directory" "новий віддалений каталог")
("new remote file" "новий віддалений файл")
("new style fonts" "шрифти нового стилю")
("new style page breaking" "Розрив сторінки нового стилю")
("new version" "нова версія")
("new window" "нове вікно")
("newer version" "новіша версія")
("next" "далі")
("next chunk" "наступний шматок")
("next difference" "наступна різниця")
("next error" "наступна помилка")
("next field" "наступне поле")
("next occurrence" "наступне виникнення")
("next screen" "наступний екран")
("next similar" "Наступний подібний")
("no clustering" "немає кластеризації")
("no completions" "без завершень")
("no errors have been corrected" "жодних помилок не виправлено")
("no grid" "немає сітки")
("no matches found for" "не знайдено відповідностей")
("no new public key in document" "немає нового відкритого ключа в документі")
("no page break" "немає розриву сторінки")
("no page numbers" "немає номерів сторінок")
("no parent" "немає батьків")
("no selection" "немає вибору")
("no spelling errors" "немає орфографічних помилок")
("normal loci" "нормальних локусів")
("norwegian" "норвезька")
("not allowed to remove home directory" "заборонено видаляти домашній каталог")
("not connected to server" "не підключено до сервера")
("not yet implemented" "ще не реалізовано")
("notebook" "зошит")
("number equation" "рівняння числа")
("number of polar steps" "кількість полярних кроків")
("number of subunit steps" "кількість кроків підрозділу")
("numbering" "нумерація")
("numeric spreadsheet" "числова таблиця")
("odd page" "непарна сторінка")
("odd page left margin" "ліва межа непарної сторінки")
("odd page right margin" "непарна сторінка права межа")
("odd page shift" "зміна непарної сторінки")
("odd pages" "непарні сторінки")
("of fingerprint" "відбитка пальця")
("old version" "стара версія")
("older version" "старіша версія")
("on the footer" "у нижньому колонтитулі")
("on your system and set it up from the \"Security\" tab" "у вашій системі та встановіть її на вкладці \x13Безпека\x14")
("one column" "один стовпчик")
("one error has been corrected" "одна помилка виправлена")
("one lower case letter, one non alpha-numeric symbol" "одна маленька літера, один не буквено-цифровий символ")
("one numeric character, one upper case letter" "один цифровий символ, одна велика літера")
("only convert changes when re-importing" "конвертувати зміни лише при повторному імпорті")
("only convert changes with respect to imported version" "конвертувати зміни лише щодо імпортованої версії")
("only convert changes with respect to tracked version" "конвертувати зміни лише щодо відстежуваної версії")
("only implemented for complete subtrees" "реалізовано лише для повних підрядів")
("only inline tags" "лише вбудовані теги")
("only keep folded" "зберігати лише складеними")
("only keep unfolded" "зберігати лише розгорнутим")
("only show semantic focus" "показують лише смисловий фокус")
("opacity" "непрозорість")
("open bibliography" "відкрита бібліографія")
("open identities" "відкриті ідентичності")
("open in new window" "відкрити в новому вікні")
("open key manager" "менеджер відкритих ключів")
("open licence agreement" "відкрита ліцензійна угода")
("open mailbox" "відкрита поштова скринька")
("open module browser" "браузер із відкритим модулем")
("open symbol browser" "браузер відкритих символів")
("open tool in separate window" "відкрити інструмент в окремому вікні")
("operation mode" "режим роботи")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "або дайте повний шлях команді \x13gpg\x14 або \x13gpg2\x14")
("order" "замовлення")
("ordinary symbol" "звичайний символ")
("ornamented" "орнаментовані")
("other login" "інший логін")
("other package" "інший пакет")
("outer bottom" "зовнішнє дно")
("outer left" "зовнішній лівий")
("outer right" "зовнішній правий")
("outer top" "зовнішній верх")
("outline" "контур")
("outlined" "окреслено")
("outlined emboss" "окреслений рельєф")
("outlined engrave" "окреслена гравюра")
("output options" "параметри виводу")
("oval" "овал")
("overbrace" "переборщик")
("overlap" "перекриття")
("overlay" "накладення")
("overlays" "накладки")
("overline" "перекреслення")
("overlined" "накреслений")
("overview of the scheme extension language" "огляд мови розширення схеми")
("padded" "підкладки")
("page background" "фон сторінки")
("page break after" "перерву сторінки після")
("page breaking algorithm" "алгоритм розбиття сторінки")
("page number" "номер сторінки")
("page number rendering" "надання номера сторінки")
("page number text" "текст номера сторінки")
("page numbering" "нумерація сторінок")
("page rendering" "візуалізація сторінки")
("page setup" "налаштування сторінки")
("palette" "палітра")
("panorama" "панорама")
("paragraphs" "абзаців")
("parametric curve" "параметрична крива")
("parametric surface" "параметрична поверхня")
("parenthesis" "дужки")
("parenthesized" "в скобках")
("particle" "частинка")
("passphrase encryption" "шифрування парольної фрази")
("passphrase wallet facilities are not currently available" "засоби для гаманця із фразою наразі недоступні")
("passphrases are expected to have at least: 8 characters" "Очікується, що у парольних фразах буде не менше 8 символів")
("passphrases mismatch" "невідповідність паролів")
("pastel" "пастель")
("pattern" "візерунок")
("pause" "пауза")
("pen width" "ширина ручки")
("permanent footer" "постійний колонтитул")
("permanent header" "постійний заголовок")
("permanently add to dictionary" "назавжди додати до словника")
("permanently insert into dictionary" "постійно вставити в словник")
("permissions" "дозволи")
("phantom" "фантом")
("phantoms" "фантоми")
("physics and astronomy class" "клас фізики та астрономії")
("picture" "малюнок")
("pine" "сосна")
("plain" "рівнина")
("plain boxes" "простих ящиків")
("plain circles" "прості кола")
("play" "відтворення")
("play animation" "відтворити анімацію")
("please install GnuPG software from https://www.gnupg.org" "встановіть програмне забезпечення GnuPG з https://www.gnupg.org")
("plot" "сюжет")
("plug-ins" "плагіни")
("plugin" "плагін")
("plugins" "плагінів")
("plural" "множина")
("point" "балів")
("polar" "полярний")
("polygon" "багатокутник")
("pop server settings" "налаштування поп-сервера")
("position of marginal note" "позиція граничної ноти")
("poster formats" "формати плакатів")
("poster theme" "Тема плаката")
("postfix" "постфікс")
("preferences for editing mathematical formulas" "налаштування для редагування математичних формул")
("preferences for tag" "налаштування тегу")
("prefix" "префікс")
("presentation" "презентація")
("presentation tag" "тег презентації")
("presentation tool" "інструмент презентації")
("preserve" "заповідник")
("preserve tags" "зберегти теги")
("pretty tree output" "гарне дерево")
("preview" "попередній перегляд")
("preview command" "команда попереднього перегляду")
("previous" "попередній")
("previous difference" "попередня різниця")
("previous error" "попередня помилка")
("previous field" "попереднє поле")
("previous occurrence" "попереднє виникнення")
("previous screen" "попередній екран")
("previous similar" "попередній аналогічний")
("primitive or macro" "примітивний або макрос")
("print buffer" "буфер друку")
("print buffer to file" "буфер друку у файл")
("print to file" "друк у файл")
("printer setup" "налаштування принтера")
("program bracket matching" "відповідність дужок програми")
("program bracket selections" "Вибір програмних дужок")
("program commands" "програмні команди")
("program font" "шрифт програми")
("program interface for buffer management" "програмний інтерфейс для управління буфером")
("programming routines for editing documents" "програми програмування для редагування документів")
("prominent" "видатний")
("prompts and default input" "підказки та введення за замовчуванням")
("provoke C++ error" "спровокувати помилку C ++")
("provoke menu error" "спровокувати помилку меню")
("provoke scheme error" "спровокувати помилку схеми")
("pseudo code" "псевдокод")
("public key encryption" "шифрування відкритого ключа")
("public keys" "відкриті ключі")
("pulse" "пульс")
("qt GUI only, sorry. Use \"Export selection\"" "лише графічний інтерфейс qt, вибачте. Використовуйте \x13Вибір експорту\x14")
("qt-widgets" "qt-віджетів")
("quantifier" "кількісний показник")
("quasi" "квазі")
("question" "питання")
("questions only" "Лише запитання")
("questions with answers" "запитання з відповідями")
("quick evaluation of formulas" "швидка оцінка формул")
("rank" "ранг")
("raw" "сирих")
("really close it" "дійсно закрий його")
("really delete user identity" "дійсно видалити особу користувача")
("really tiny" "дійсно крихітний")
("rebuild translations file" "файл відновлення перекладів")
("recent" "останніх")
("recent documents" "останні документи")
("recipients" "одержувачів")
("recognize" "визнати")
("recover autosave file" "відновити файл автоматичного збереження")
("rectangular" "прямокутний")
("reduce" "зменшити")
("reduce trigonometric functions" "зменшити тригонометричні функції")
("reduced margins" "знижена маржа")
("reference guide" "довідник")
("reference guide for the TeXmacs primitives" "довідник для примітивів TeXmacs")
("reference guide for the standard TeXmacs styles" "довідник для стандартних стилів TeXmacs")
("regenerate" "відновити")
("register file" "реєстраційний файл")
("relate" "відновити")
("relation" "відношення")
("release left button: finish editing" "відпустити ліву кнопку: закінчити редагування")
("remote" "віддалений")
("remote connections" "віддалених з'єднань")
("remote control" "пульт")
("remote controllers with keyboard simulation" "дистанційних контролерів з моделюванням клавіатури")
("remote directory" "віддалений каталог")
("remote servers" "віддалені сервери")
("remote tool" "віддалений інструмент")
("remove" "видалити")
("remove all output fields" "видалити всі вихідні поля")
("remove banner" "видалити банер")
("remove database entry" "видалити запис бази даних")
("remove downwards" "прибрати вниз")
("remove entries" "видалити записи")
("remove entry" "видалити запис")
("remove field above" "видалити поле вище")
("remove field below" "видалити поле внизу")
("remove fields" "видалити поля")
("remove folded" "видалити складене")
("remove input field" "видалити поле введення")
("remove input field above" "видалити поле введення вище")
("remove last field" "видалити останнє поле")
("remove leftwards" "видалити зліва")
("remove link" "видалити посилання")
("remove next field" "видалити наступне поле")
("remove number" "видалити номер")
("remove package" "видалити пакет")
("remove previous field" "видалити попереднє поле")
("remove rightwards" "видалити направо")
("remove selected database entries" "видалити вибрані записи бази")
("remove selected entries" "видалити вибрані записи")
("remove superfluous invisible operators" "видалити зайві невидимі оператори")
("remove tag" "видалити тег")
("remove this branch" "видалити цю гілку")
("remove unfolded" "видалити розгорнуто")
("remove upwards" "прибрати вгору")
("removed entries from database" "видалено записи з бази даних")
("removed entry from database" "видалено запис із бази даних")
("rename" "перейменувати")
("rename section" "перейменувати розділ")
("renumber this page" "перенумеруйте цю сторінку")
("repeat" "повторення")
("replace TeXmacs styles with no LaTeX equivalents" "замінити стилі TeXmacs без еквівалентів LaTeX")
("replace all further occurrences" "замінити всі подальші події")
("replace one occurrence" "замінити одну подію")
("replace toolbar" "Замінити панель інструментів")
("replace unrecognized styles" "замінити нерозпізнані стилі")
("reset error counters" "скидання лічильників помилок")
("resize" "зміни розміру")
("resize objects" "зміни розміру об'єктів")
("restart TeXmacs in order to let changes take effect" "перезавантажте TeXmacs для того, щоб зміни набули чинності")
("restart in order to let the new look and feel take effect" "перезапустити для того, щоб новий вигляд і відчуття набули чинності")
("retain" "зберегти")
("retime" "сітка")
("retina settings" "налаштування сітківки")
("retrieve email" "отримання електронної пошти")
("retrieve remote live document" "отримати віддалений живий документ")
("retrieved contents" "завантажений вміст")
("reverse" "зворотний")
("reverse ordering" "зворотне замовлення")
("ridged paper" "рельєфний папір")
("right arrow" "стрілка вправо")
("right baseline" "права база")
("right cell border" "права межа осередку")
("right cell padding" "правильна клітинка")
("right down" "прямо вниз")
("right on even pages" "прямо на рівних сторінках")
("right table border" "права межа межі таблиці")
("right table padding" "правильна набивка столу")
("right up" "праворуч")
("rightwards" "праворуч")
("rigid box" "жорстка коробка")
("rotate" "обертати")
("rotate objects" "обертання об'єктів")
("rough" "грубо")
("rough paper" "чорновий папір")
("round" "раунд")
("round overbrace" "кругла перенапруга")
("round underbrace" "круглий підвісок")
("row above" "рядок вище")
("row below" "рядок внизу")
("rows" "рядків")
("run" "пробіг")
("run current file" "запустити поточний файл")
("same names" "однойменних імен")
("same screen margins as on paper" "ті ж поля екрану, що і на папері")
("sample text" "зразок тексту")
("save auxiliary data" "зберегти допоміжні дані")
("save entries" "зберегти записи")
("save entry" "зберегти запис")
("save image as" "зберегти зображення як")
("save position" "зберегти позицію")
("save remote file" "зберегти віддалений файл")
("saved modifications in database" "збережені зміни в базі даних")
("scheme command" "командна схема")
("scheme developers guide" "Посібник для розробників схем")
("scheme extensions" "розширення схеми")
("scheme interface for the graphical mode" "Інтерфейс схеми для графічного режиму")
("screen" "екран")
("screen rendering" "візуалізація екрана")
("screens" "екранів")
("screenshot" "скріншот")
("scripting language" "сценарій мови")
("scripts" "сценаріїв")
("search and replace" "пошук і заміна")
("search results for" "результати пошуку для")
("search toolbar" "панель інструментів пошуку")
("search words in my documents" "пошукові слова в моїх документах")
("search words in the documentation" "пошукові слова в документації")
("search words in the source code" "пошукові слова у вихідному коді")
("second" "секунда")
("secret keys" "секретні ключі")
("sections" "розділів")
("see documentation" "див. Документацію")
("select pen" "ручка вибору")
("select the action to be undertaken for each conflict" "виберіть дії, які слід здійснити для кожного конфлікту")
("select view mode" "вибрати режим перегляду")
("semantic correctness" "смислова правильність")
("semantic editing" "семантичне редагування")
("semantic selections" "смислові виділення")
("semantics" "семантика")
("sending commands to TeXmacs" "надсилання команд TeXmacs")
("senior" "старший")
("serb" "серб")
("serif" "серіф")
("server" "сервер")
("session commands" "сеансові команди")
("set default" "встановити за замовчуванням")
("set difference" "задана різниця")
("set intersection" "встановити перехрестя")
("set number of columns" "встановити кількість стовпців")
("set number of rows" "встановити кількість рядків")
("set or get environment variables" "встановити або отримати змінні середовища")
("set properties" "встановити властивості")
("set union" "встановити союз")
("set user information" "встановити інформацію про користувача")
("seventh" "сьомий")
("several equations" "кілька рівнянь")
("shadow" "тінь")
("shadowed" "тіньовий")
("shadowed raise" "тіньовий підйом")
("shift" "зміна")
("short" "короткий")
("show all parts" "показати всі частини")
("show current focus" "показати поточний фокус")
("show full context" "показати весь контекст")
("show hidden" "показати приховано")
("show key presses" "показати натискання клавіш")
("show main document" "показати основний документ")
("show memory usage" "показати використання пам'яті")
("show one part" "показати одну частину")
("show panorama" "показати панораму")
("show preamble" "показати преамбулу")
("show several parts" "показати кілька деталей")
("show subunits" "показати субодиниці")
("show table cells" "показати клітинки таблиці")
("show timings" "показати таймінги")
("side tools" "бічні інструменти")
("simple" "простий")
("simplification" "спрощення")
("simplified evaluation of formulas" "спрощена оцінка формул")
("simplified menus" "спрощені меню")
("simplify" "спростити")
("sine" "синус")
("sixth" "шостий")
("size tag" "розмір тегів")
("skew" "косий")
("skip all" "пропустити все")
("slant" "косий")
("slashed fraction" "розрізана частка")
("slides" "слайдів")
("slovene" "словен")
("slow" "повільний")
("slow decrease" "повільне зменшення")
("slow increase" "повільне зростання")
("small capitals" "малі столиці")
("small environment box" "невелика коробка навколишнього середовища")
("small focus" "малий фокус")
("small inline" "маленький рожевий")
("small inline fraction" "мала вбудована частка")
("smash" "удар")
("smooth" "гладкий")
("smooth end" "гладкий кінець")
("smooth extremities" "гладкі кінцівки")
("smooth start" "плавний старт")
("snap" "оснащення")
("snap distance" "відстань оснащення")
("snap to curves" "прив'язка до кривих")
("snap to grid" "приєднання до сітки")
("snap to grid curve" "прив'язка до кривої сітки")
("snap to intersections of curves" "прив'язка до перетинів кривих")
("snap to text borders" "прив'язка до меж тексту")
("snap to text corners" "прив'язка до кутів тексту")
("solution" "рішення")
("solution to exercise" "рішення вправи")
("solution to problem" "рішення проблеми")
("solutions" "рішення")
("sound" "звук")
("source" "джерело")
("source macros tool" "інструмент макросів джерел")
("source tags" "вихідні теги")
("south" "південь")
("south east" "південний схід")
("space bar in math mode" "пробіл у математичному режимі")
("space bar in text mode" "пробіл у текстовому режимі")
("space stretchability" "розтяжність простору")
("span" "проліт")
("span over all columns" "проміжок по всіх стовпцях")
("special functions" "спеціальні функції")
("special properties" "особливі властивості")
("specific baseline" "конкретна базова лінія")
("specify color alternation" "вказати чергування кольорів")
("specify how to traverse the manual" "вкажіть, як пройти інструкцію")
("specify semantics of a symbol or formula" "вкажіть семантику символу чи формули")
("specify the size of the table" "вказати розмір таблиці")
("spell check" "перевірка орфографії")
("spline" "сплайн")
("split program" "спліт-програма")
("split session" "розділений сеанс")
("square" "квадрат")
("square overbrace" "квадратний перебір")
("square underbrace" "квадратний підвісок")
("stack" "стек")
("standard" "стандарт")
("standard Output" "стандартний вихід")
("standard TeXmacs styles" "стандартні стилі TeXmacs")
("standard environment variables" "стандартні змінні середовища")
("standard formats" "стандартні формати")
("standard fraction" "стандартна фракція")
("star" "зірка")
("start server" "запуску сервера")
("statement" "заява")
("statistics" "статистика")
("status" "статус")
("stop server" "стоп-сервер")
("storage" "сховище")
("store tracking information in LaTeX files" "зберігання інформації відстеження у файлах LaTeX")
("stretch" "розтяжка")
("stretch factor" "коефіцієнт розтягування")
("stretched" "розтягнутий")
("strict Ascii" "суворий Ассій")
("strike through" "простріл")
("structured insert above" "структурована вставка вище")
("structured insert at the left" "структурована вставка зліва")
("structured insert at the right" "структурована вставка праворуч")
("structured insert below" "структурована вставка нижче")
("structured remove downwards" "структуровано видалити вниз")
("structured remove leftwards" "структуровано видалити зліва")
("structured remove rightwards" "структуровано видалити направо")
("structured remove upwards" "структуровано видалити вгору")
("structured variant" "структурований варіант")
("style options" "варіанти стилю")
("style parameters" "параметри стилю")
("stylesheet language" "мова таблиці стилів")
("subject" "предмет")
("submenu" "підменю")
("subscript below" "підписка нижче")
("subsubmenu" "підпункт")
("subsubsubmenu" "підсубменю")
("subsubsubsubmenu" "sububsubsubmenu")
("subtable" "підтаблиця")
("subtitle" "підзаголовок")
("subtraction" "віднімання")
("summarized" "узагальнено")
("summary of the principal TeXmacs tags" "резюме основних тегів TeXmacs")
("superscript above" "надпис вище")
("supported plug-ins" "підтримувані додатки")
("surface" "поверхня")
("inflate" "набряк")
("swiss" "швейцарський")
("switch to buffer" "перехід на буфер")
("symbol properties not found" "властивості символу не знайдено")
("symbols" "символів")
("synchronize" "синхронізувати")
("synchronize bibliographic references" "синхронізувати бібліографічні посилання")
("synchronize with remote server" "синхронізувати з віддаленим сервером")
("synopsis" "конспект")
("system command" "системна команда")
("tab-completion" "заповнення вкладки")
("tabbed" "вкладка")
("table breaking" "розбиття столу")
("table height" "висота столу")
("table properties" "властивості таблиці")
("table width" "ширина столу")
("tags with special rendering" "тегів зі спеціальним відображенням")
("tangent" "дотична")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Очікується буфера TeXmacs")
("teXmacs buffer on disk expected" "очікуваний буфер TeXmacs на диску")
("teXmacs extensions to scheme and utilities" "розширення TeXmacs на схему та утиліти")
("teXmacs macro" "макрос TeXmacs")
("teXmacs package" "пакет TeXmacs")
("teXmacs plugins" "плагін TeXmacs")
("teXmacs primitives" "примітивів TeXmacs")
("teXmacs style" "стиль TeXmacs")
("teXmacs style files" "файли стилю TeXmacs")
("test routine" "тестовий розпорядок")
("testing tree-view" "тестування дерева")
("text borders" "межі тексту")
("text box style" "стиль текстового поля")
("text corners" "куточки тексту")
("textual" "текстовий")
("textual operator" "текстовий оператор")
("textual spreadsheet" "текстова таблиця")
("the TeXmacs format" "формат TeXmacs")
("the TeXmacs plug-in system" "плагін-система TeXmacs")
("the document has not been saved" "документ не збережено")
("theme parameters" "параметри теми")
("these collected public keys will be definitely lost" "ці зібрані відкриті ключі будуть точно втрачені")
("these public keys will be definitely lost" "ці відкриті ключі будуть точно втрачені")
("these secret keys will be definitely lost" "ці секретні ключі будуть точно втрачені")
("thicken" "р. Згущується")
("third" "третій")
("this" "це")
("this column" "цей стовпець")
("this document has not been saved" "цей документ не збережено")
("this page footer" "колонтитул цієї сторінки")
("this page header" "заголовок цієї сторінки")
("this page number" "номер цієї сторінки")
("this row" "цей рядок")
("this style specifies page margins in the TeX way" "Цей стиль визначає поля сторінок способом TeX")
("three columns" "три колони")
("three dots" "три крапки")
("through popup windows" "через спливаючі вікна")
("through the menus" "через меню")
("thumbnails" "ескізи")
("time evolution" "еволюція часу")
("timings" "таймінги")
("title presentation options" "Варіанти презентації заголовка")
("title style" "стиль заголовку")
("title suffix" "суфікс заголовка")
("titled block" "титульний блок")
("toggle cell wrapping mode" "тумблерний режим обгортання комірок")
("toggle here" "тумблер тут")
("toggle off" "вимкнення")
("toggle on" "включення")
("tolerant" "толерантний")
("top baseline" "верхній базовий рівень")
("top cell border" "верхня межа клітинки")
("top cell padding" "верхня клітинка")
("top table border" "межа верхньої таблиці")
("top table padding" "підкладка верхнього столу")
("transform" "перетворення")
("transform cell into subtable" "перетворити клітинку в підзарядну")
("translations" "переклади")
("translations loaded" "переклади завантажено")
("transpose" "р. Перенести")
("traversal" "обхід")
("traverse" "траверс")
("triangle" "трикутник")
("triangularize" "р. Тріангуляризація")
("trigonometric" "тригонометричний")
("trigonometry" "р. Тригонометрія")
("turn off" "вимкнути")
("turn on" "увімкнути")
("two columns" "дві колонки")
("two dots" "дві крапки")
("type a latex command followed by return" "введіть команду латексу з подальшим поверненням")
("underbrace" "р. Підпірок")
("underline" "підкреслити")
("underlined" "підкреслено")
("unevaluated argument" "неоцінений аргумент")
("unevaluated value" "неоцінене значення")
("unfold" "розгорнути")
("unfold all" "розгорнути все")
("unfold all fields" "розгорнути всі поля")
("unit" "одиниця")
("unit length" "одиниця довжини")
("unknown secret key fingerprint" "невідомий відбиток секретного ключа")
("unregistered file" "незареєстрований файл")
("unroll" "розкрутити")
("unsecure script refused" "незахищений сценарій відмовлено")
("unsupported link mode" "непідтримуваний режим зв'язку")
("until" "до")
("untitled block" "без назви блоку")
("up to date" "актуально")
("update buffer" "буфер оновлення")
("update this buffer" "оновити цей буфер")
("update web site" "веб-сайт оновлення")
("upight" "вертикальний")
("upload" "Завантажити")
("upright" "вертикально")
("upwards" "вгору")
("use CSS for more advanced formatting" "використовувати CSS для більш розширеного форматування")
("use MathML" "використовувати MathML")
("use as master" "використання як майстра")
("use extensible brackets" "використовувати розтяжні дужки")
("use line wrapping for lines which are longer than 80 characters" "використовувати обертання рядків для ліній довжиною більше 80 символів")
("use margin kerning (protrusion)" "використовувати кернінг поля (protrusion)")
("use protrusion" "використовувати випинання")
("use relative path" "використовувати відносний шлях")
("user interface" "інтерфейс користувача")
("user interface language" "мова інтерфейсу користувача")
("user preferences" "налаштування користувачів")
("users of Cyrillic languages" "користувачів кирилицьких мов")
("users of oriental languages" "користувачів східних мов")
("utf-8 with inputenc LaTeX package" "utf-8 з пакетом inputenc LaTeX")
("utilities" "комунальні послуги")
("vanish" "р. Зник")
("verbose" "багатослівний")
("version" "версія")
("versioning tool" "інструмент для версії")
("vertical alignment" "вертикальне вирівнювання")
("vertical margins" "вертикальні поля")
("vertical space after" "вертикальний простір після")
("vertical space before" "вертикальний простір до")
("vertical space stretchability" "вертикальна розтяжність простору")
("visible except here" "р. Видимо, крім тут")
("visible from here on" "видно звідси")
("visible only here" "видно лише тут")
("visible until here" "видно доти тут")
("visited loci" "відвідали локуси")
("wallet" "гаманець")
("wave" "хвиля")
("web" "веб")
("weight" "вага")
("when line wrapping" "при обгортанні рядків")
("whitespace" "пробіл")
("wide" "широкий")
("wide bar" "широкий брусок")
("wide block" "широкий блок")
("wide colored" "широкий кольоровий")
("wide float" "широкий поплавок")
("wide footnote" "широка виноска")
("wide tabular" "широких табличних")
("widescreen" "широкоекранний")
("wrap lines" "лінії обгортання")
("write a macro" "написати макрос")
("writing TeXmacs bibliography styles" "написання стилів бібліографії TeXmacs")
("writing documentation" "письмова документація")
("written with TeXmacs" "написано з TeXmacs")
("wrong empty passphrase" "неправильна порожня парольна фраза")
("wrong passphrase" "неправильна парольна фраза")
("year" "рік")
("you are attempting to open an encrypted file while" "Ви намагаєтесь відкрити зашифрований файл під час")
("you might consider enabling the experimental" "Ви можете розглянути можливість включення експериментального")
("you must add a bibliography file" "Ви повинні додати файл бібліографії")
("you should also make sure that GnuPG is installed" "Ви також повинні переконатися, що GnuPG встановлений")
("your language" "ваша мова")
("your personal dictionary has been modified" "ваш особистий словник змінено")
("zoom" "збільшення")
("zoom in" "збільшення")
("zoom out" "зменшення масштабу")
