("\"encryption\" features from the preference panel" "\"²ifriranje\" funkcije s prednostne plo²£e")
("(Re)Build autocompletion index" "(ponovno) sestavite indeks samodejnega dokon£anja")
("a series" "serija")
("a.C.M. computing class" "ra£unalni²ki razred a.C.M.")
("a.M.S. subject class" "predmetni razred M.S.")
("abbreviated authors" "skraj²ani avtorji")
("abreviated authors" "okraj²anih avtorjev")
("accent above" "naglas zgoraj")
("accent below" "naglas spodaj")
("accept during this pass" "sprejme med tem dovoljenjem")
("acknowledgments" "priznanj")
("activate hidden" "aktiviranje skritih")
("activate once" "enkrat aktiviraj")
("activation" "aktiviranje")
("active link types" "aktivnih vrst povezav")
("add" "dodaj")
("add abstract information" "dodaj abstraktne podatke")
("add author information" "dodaj podatke o avtorju")
("add branch after" "doda podruºnico za")
("add branch before" "doda podruºnico pred")
("add other package" "dodaj drug paket")
("add style package" "dodaj slog paket")
("add title information" "dodajte podatke o naslovu")
("addition" "dodatek")
("adjust" "prilagodi")
("adjust limits" "prilagodi omejitve")
("advanced font customization" "napredna prilagoditev pisave")
("affiliation" "pripadnost")
("align cell to the decimal comma" "poravnajte celico v decimalni vejici")
("align cell to the decimal dot" "poravnajte celico z decimalno piko")
("align table at axis" "poravnava tabele na osi")
("alignment of balloon" "poravnava balona")
("all cells" "vse celice")
("all data attached to this identity will be lost" "vsi podatki, priloºeni tej identiteti, bodo izgubljeni")
("all saved passphrases will be lost forever" "vsi shranjeni gesli bodo za vedno izgubljeni")
("allow for macro definitions in preamble" "omogo£ajo makro opredelitve v preambuli")
("allowed page height extension" "dovoljeno podalj²anje vi²ine strani")
("allowed page height reduction" "dovoljeno zmanj²anje vi²ine strani")
("allowed positions" "dovoljenih mest")
("allowed positions of floating object" "dovoljeni poloºaji plavajo£ega predmeta")
("alpha transparency" "transparentnost alfa")
("also on paper" "tudi na papirju")
("alter" "alter")
("alternate" "nadomestnih")
("alternate except here" "nadomestni, razen tukaj")
("alternate from here on" "nadomestni od tu naprej")
("alternate only here" "nadomestni samo tukaj")
("alternate until here" "nadomestite do tukaj")
("always" "vedno")
("amplified" "okrepljeno")
("and perform casual settings from the \"Encryption\" tab" "in izvedite priloºnostne nastavitve na zavihku \"²ifriranje\"")
("angular" "kotnih")
("animate" "animirani")
("animate folding" "animirano zlaganje")
("animate unfolding" "animirano odvijanje")
("animated" "animiranih")
("animation" "animacija")
("animation toolbar" "Orodna vrstica za animacijo")
("annotate" "opomba")
("answer" "odgovor")
("answer field" "polje odgovora")
("answer to question" "odgovor na vpra²anje")
("answers only" "samo odgovorov")
("any" "poljubno")
("appear" "pojaviti")
("apply macro" "uporabi makro")
("apply macro once" "uporabi makro enkrat")
("approximate" "pribliºno")
("arc" "lok")
("arc cosine" "arc kosinus")
("arc sine" "lo£ni sinus")
("arc tangent" "lo£na tangenta")
("arch series" "lo£na serija")
("are you sure you want to delete collected public keys" "ste prepri£ani, da ºelite izbrisati zbrane javne klju£e")
("are you sure you want to delete selected public keys" "ste prepri£ani, da ºelite izbrisati izbrane javne klju£e")
("are you sure you want to delete selected secret keys" "ste prepri£ani, da ºelite izbrisati izbrane skrivne klju£e")
("are you sure you want to destroy the wallet" "ste prepri£ani, da ºelite uni£iti denarnico")
("art frame" "umetni²ki okvir")
("arxiv category" "kategorija arxiv")
("as visual grid" "kot vizualna mreºa")
("aspect" "vidik")
("attach master" "priloºi glavni")
("auto" "samodejno")
("auto-save file" "samodejno shranjevanje datoteke")
("automatic brackets" "samodejnih oklepajev")
("automatic content generation" "samodejno ustvarjanje vsebine")
("automatic program brackets" "samodejnih nosilcev programa")
("automatic quotes" "samodejnih ponudb")
("automatically import bibliographies when opening files" "samodejno uvozi bibliografije pri odpiranju datotek")
("automatically remember all passphrases in the wallet" "samodejno zapomni vse gesle v denarnici")
("automatically save" "samodejno shranjevanje")
("axis" "os")
("b series" "b serija")
("back" "nazaj")
("backtrace errors" "povratnih napak")
("base" "baz")
("baseline" "izhodi²£na vrednost")
("beamer" "ºarek")
("beamer formats" "formati snopov")
("beamer theme" "tema snopa")
("bench" "klop")
("bend bottom" "upognjeno dno")
("bend corner" "ovinek v ovinku")
("bend diagonal" "diagonala upogiba")
("bend in" "upogniti")
("bend out" "upognite")
("bezier" "bezier")
("bibTeX command" "ukaz bibTeX")
("bidirectional" "dvosmerno")
("big environment box" "velika okoljska ²katla")
("big focus" "velik fokus")
("binary operator" "binarni operater")
("bitmap resolution (dpi)" "lo£ljivost bitne slike (dpi)")
("black floral I" "£rna cvetli£na I")
("black floral II" "£rna cvetna II")
("blackboard embold" "tabla iz embalaºe")
("blank column" "prazen stolpec")
("blank row" "prazna vrstica")
("block" "blok")
("block content" "blokiranje vsebine")
("block of code" "blok kode")
("blur" "zameglitev")
("both versions" "obe razli£ici")
("bottom baseline" "spodnja osnova")
("bottom cell border" "meja spodnje celice")
("bottom cell padding" "oblazinjenje spodnjih celic")
("bottom table border" "rob spodnje mize")
("bottom table padding" "oblazinjenje spodnje mize")
("bottom tools" "spodnje orodje")
("box" "²katla")
("broken white" "zlomljeno belo")
("browse back" "brskaj nazaj")
("browse forward" "brskaj naprej")
("browse modules documentation" "brskanje po dokumentaciji modulov")
("buffer management" "upravljanje medpomnilnikov")
("buffer must be on disk" "medpomnilnik mora biti na disku")
("buffer must have a name" "medpomnilnik mora imeti ime")
("build buffer" "vmesnik za gradnjo")
("build buffer in" "vgradite medpomnilnik v")
("build directory" "graditi imenik")
("build directory in" "imenik za gradnjo v")
("build link pages" "ustvari povezavne strani")
("build-all" "vse vgrajeno")
("bump" "udarcev")
("busy" "zaseden")
("cJK" "cJK")
("cJK spacing" "razmikov cJK")
("calculus" "izra£un")
("cancelled" "preklicano")
("cannot download directory to file" "ni mogo£e prenesti imenika v datoteko")
("cannot rename across different servers" "ni mogo£e preimenovati na razli£nih streºnikih")
("cannot upload directory to file" "ni mogo£e naloºiti imenika v datoteko")
("cartesian" "kartezijanski")
("carved wood" "izrezljani les")
("case-insensitive search" "neob£utljivo iskanje")
("categories" "kategorij")
("category" "kategorija")
("cell properties" "lastnosti celic")
("cells" "celic")
("change default unit" "spremeni privzeto enoto")
("change passphrase" "spremeni geslo")
("change step-size" "spremeni velikost korakov")
("change tags" "sprememba oznak")
("change the TeXmacs preferences" "sprememba nastavitev TeXmacs")
("change the border of the table" "spremeni mejo tabele")
("change the style of mathematical formulas" "spremeni slog matemati£nih formul")
("character contraction" "kr£enje znakov")
("character encoding" "kodiranje znakov")
("character expansion" "raz²iritev znakov")
("check for updates" "preverjanje posodobitev")
("checkable field" "polje, ki ga je mogo£e preveriti")
("cipher algorithm for passphrase encryption" "²ifrirni algoritem za ²ifriranje gesla")
("circle" "krog")
("classification" "razvrstitev")
("clean slate" "£istih skrilavcev")
("clear all fields" "po£isti vsa polja")
("clear local information" "jasnih lokalnih informacij")
("clear menu" "jasen meni")
("clear undo history" "jasno razveljavi zgodovino")
("click Ok button twice to discard this warning" "dvakrat kliknite gumb V redu, da zavrnete to opozorilo")
("clip" "posnetek")
("clipboard image format" "format slike odloºi²£a")
("close animation tool" "tesno orodje za animacijo")
("close document" "zapri dokument")
("close program" "Zapri program")
("close replace tool" "orodje za zamenjavo")
("close search tool" "tesno orodje za iskanje")
("close spell tool" "tesno £rkovalno orodje")
("close translations to rebuild" "tesnih prevodov za obnovo")
("closed bezier" "zaprti bezier")
("closed curve" "zaprta krivulja")
("closed smooth" "zaprto gladko")
("closed spline" "zaprt utor")
("cluster by affiliation" "grozd po pripadnosti")
("collect garbage" "zbiranje smeti")
("collected keys" "zbranih klju£ev")
("color of the axes" "barva osi")
("color of the subunits" "barva podenot")
("color of the units" "barva enot")
("colors" "barv")
("column to the left" "stolpec na levi")
("column to the right" "stolpec na desni")
("columns" "stolpcev")
("column separation" "lo£itev stolpcev")
("commit file" "datoteke za zagon")
("common" "navadnih")
("common formats" "obi£ajnih formatov")
("commutative diagram" "komutacijski diagram")
("compactify" "kompaktno")
("complete bibliographic reference" "popolna bibliografska referenca")
("complex actions" "zapletenih ukrepov")
("compose" "sestavi")
("compound" "spojina")
("compress" "stiskanje")
("compress into toolbar" "stiskanje v orodno vrstico")
("compressed" "stisnjeno")
("conceal" "prikriti")
("configure look and feel" "konfigurirajte videz in ob£utek")
("confirm database entry" "potrditev vnosa v bazo podatkov")
("confirm entry" "potrdi vnos")
("confirm selected database entries" "potrdi izbrane vnose v bazo")
("confirm selected entries" "potrdi izbrane vnose")
("conservative conversion options" "konzervativne moºnosti pretvorbe")
("consoles" "konzole")
("constellation" "ozvezdje")
("context aids" "kontekstni pripomo£ki")
("contextual hints" "kontekstualni namigi")
("continue" "nadaljuj")
("continued fraction" "nadaljevanje frakcije")
("contour" "kontura")
("contract logarithms" "pogodbeni logaritmi")
("control the evaluation of expressions" "nadzor nad ocenjevanjem izrazov")
("convert" "pretvori")
("converters" "pretvorniki")
("convertible" "kabriolet")
("copyright" "avtorske pravice")
("cork charset with TeX catcode definition in preamble" "plutovinasti predal z oznako kode TeX v preambuli")
("correct" "pravilno")
("correct all" "popravi vse")
("correct formula" "pravilna formula")
("correct manually" "ro£no popravi")
("correct mathematical formulas" "pravilnih matemati£nih formul")
("correction" "popravek")
("cosine" "kosinus")
("count characters" "²tetje znakov")
("count lines" "²tetje vrstic")
("count words" "pre²tej besede")
("create a new document" "ustvari nov dokument")
("create link" "ustvari povezavo")
("create preamble" "ustvari preambulo")
("create remote directory" "ustvari oddaljeni imenik")
("create remote file" "ustvari oddaljeno datoteko")
("create subprogram" "ustvari podprogram")
("create subsession" "ustvari podnajem")
("create table macro" "ustvari makro tabele")
("creating new account" "ustvarjanje novega ra£una")
("creating technical pictures" "ustvarjanje tehni£nih slik")
("crop" "obrezovanje")
("crop marks" "znamk")
("cross" "kriº")
("crossed boxes" "prekriºane ²katle")
("crossed circles" "prekriºanih krogov")
("current user version" "trenutna uporabni²ka razli£ica")
("current version" "trenutna razli£ica")
("cursor" "kurzor")
("curve" "krivulja")
("curve intersections" "kriºi²£a krivin")
("curve points" "krivuljskih to£k")
("customizations" "prilagoditve")
("customizing and extending the user interface" "prilagajanje in raz²iritev uporabni²kega vmesnika")
("data" "podatkov")
("database entry" "vnos v bazo podatkov")
("database tool" "orodje zbirke podatkov")
("database toolbar" "Orodna vrstica baze podatkov")
("deactivate once" "enkrat izklju£i")
("dead" "mrtvih")
("debug" "odpravljanje napak")
("debugging console" "konzola za odpravljanje napak")
("debugging tool" "orodje za odpravljanje napak")
("decimal comma" "decimalna vejica")
("decimal dot" "decimalna pika")
("decomposed" "razpadlo")
("decorated" "okra²enih")
("decorated wood" "okra²en les")
("decrease size" "zmanj²anje velikosti")
("decrypt" "de²ifriranje")
("default size" "privzeta velikost")
("degrade" "razgradi")
("degraded" "degradirano")
("delete documentation cache" "brisanje predpomnilnika dokumentacije")
("delete entries" "brisanje vnosov")
("delete link" "brisanje povezave")
("deleted" "izbrisano")
("describe" "opi²ite")
("describe tag" "opis oznake")
("destroy" "uni£iti")
("detach master" "mojster samostojnosti")
("detailed menus" "podrobnih menijev")
("details in menus" "podrobnosti v menijih")
("determine margins from text width" "dolo£itev robov od ²irine besedila")
("developer" "razvijalec")
("developer tool" "orodje za razvijalce")
("device" "naprava")
("diamond" "diamant")
("differentiate" "razlikovati")
("dilate" "dilata")
("direction of progression" "smer napredovanja")
("direction of translation" "smer prevajanja")
("disable coloring on paper" "onemogo£i barvanje na papirju")
("disable encryption" "onemogo£i ²ifriranje")
("disappear" "izgine")
("disk" "disk")
("display style" "slog zaslona")
("displayed formula" "prikazana formula")
("dissociate joined cells" "disociirane pridruºene celice")
("distort" "izkrivljanje")
("distorted" "popa£eno")
("division" "divizija")
("document font selector" "izbira pisave dokumenta")
("document language" "jezika dokumenta")
("document page format" "oblika strani dokumenta")
("document paragraph format" "format odstavka dokumenta")
("document updates run" "posodobitve dokumentov te£ejo")
("download" "prenos")
("downwards" "navzdol")
("dragging" "vle£enje")
("draw image" "nari²ite sliko")
("draw over" "povleci")
("draw over selection" "pripravi izbor")
("drop" "kapljic")
("due to" "zaradi")
("dynamic" "dinami£nih")
("eRROR" "eRROR")
("edit animation" "uredi animacijo")
("edit groups of objects" "urejanje skupin predmetov")
("edit macro" "uredi makro")
("edit macros" "urejanje makrov")
("edit preamble" "uredi preambulo")
("edit source" "uredi vir")
("edit style" "slog urejanja")
("edit translations file" "urejanje prevodne datoteke")
("education" "izobraºevanje")
("effect pen" "efektno pero")
("eigenvalues" "lastne vrednosti")
("eighth" "osmica")
("embold" "embold")
("emboss" "emboss")
("enable page breaking" "omogo£i prelom strani")
("encoding" "kodiranje")
("encrypt" "²ifriranje")
("encryption" "²ifriranje")
("encryption facilities are not currently available" "²ifrirne naprave trenutno niso na voljo")
("encryption facilities have not been enabled for TeXmacs" "²ifriranje ni omogo£eno za TeXmacs")
("enforce brackets to match" "uveljavi oklepaje, da se ujemajo")
("engrave" "graviranje")
("enter data" "vnesite podatke")
("enter graphics" "vnesite grafiko")
("enter graphics mode" "vstopite v grafi£ni na£in")
("enter new passphrase for encryption" "vnesite novo geslo za ²ifriranje")
("enter passphrase for decryption" "vnesite geslo za de²ifriranje")
("enter passphrase for identity" "vnesite geslo za identiteto")
("enter title information" "vnesite podatke o naslovu")
("entire table" "celotna tabela")
("entry up to date in database" "posodobljen vnos v zbirko podatkov")
("enunciation" "izgovor")
("environment variable" "spremenljivka okolja")
("environments" "okolij")
("erode" "erode")
("error messages" "sporo£ila o napakah")
("error output" "izhod napake")
("error status report" "poro£ilo o napaki")
("error: bracket does not match" "napaka: oklepaj se ne ujema")
("error: cyclic or missing chunks detected" "napaka: odkriti cikli£ni ali manjkajo£i deli")
("error: file not found" "napaka: datoteke ni mogo£e najti")
("error: ghostview does not seem to be installed on your system" "napaka: zdi se, da ghostview ni name²£en v va²em sistemu")
("error: one of the alternatives should be filled out" "napaka: eno od drugih moºnosti je treba izpolniti")
("error: only one alternatives should be filled out" "napaka: izpolniti je treba le eno moºnost")
("error: should fill out name for referencing" "napaka: mora izpolniti ime za sklicevanje")
("error: should fill out required field" "napaka: izpolnite obvezno polje")
("evaluable field" "ocenjevalno polje")
("evaluate above" "zgoraj oceni")
("evaluate all" "oceni vse")
("evaluate below" "oceni spodaj")
("evaluate fields" "oceni polja")
("evaluate fields in order" "oceni polja po vrstnem redu")
("evaluate script" "oceni skript")
("evaluation switch" "stikalo za ocenjevanje")
("evaluation tag" "ocenjevalna oznaka")
("even page" "enakomerna stran")
("even page shift" "enakomerna premika strani")
("even pages" "enakomernih strani")
("events" "dogodkov")
("exact" "natan£no")
("execution of scripts" "izvedba skriptov")
("exit graphics" "izhodna grafika")
("exit graphics mode" "izhodni grafi£ni na£in")
("exit left" "izstop levo")
("exit right" "izstop desno")
("exit tag on the left" "izhodna oznaka na levi")
("exit tag on the right" "izhodna oznaka na desni")
("expand TeXmacs macros with no LaTeX equivalents" "raz²irite makroe TeXmacs brez LaTeX ekvivalentov")
("expand beamer slides" "raz²iritev diapozitivov")
("expand inclusions" "raz²iritev vklju£kov")
("expand logarithms" "raz²irite logaritme")
("expand trigonometric functions" "raz²irite trigonometri£ne funkcije")
("expand unrecognized macros" "raz²irite neprepoznane makre")
("expand user-defined macros" "raz²iritev uporabni²ko definiranih makrov")
("expanded" "raz²irjeno")
("experimental features (to be used with care)" "eksperimentalne funkcije (uporabljati previdno)")
("explain" "pojasni")
("explanatory item" "pojasnjevalna postavka")
("explicit keystroke" "izrecna tipka")
("explicit margins" "eksplicitne marºe")
("exponential" "eksponentno")
("export bibliographies as links" "izvozne bibliografije kot povezave")
("export bibliography" "izvozna bibliografija")
("export entries in buffer" "izvozni vnosi v medpomnilniku")
("export file" "izvozna datoteka")
("export formulas as images" "izvozne formule kot slike")
("export mathematical formulas as MathML" "izvoz matemati£nih formul kot MathML")
("export mathematical formulas as images" "izvoz matemati£nih formul kot slik")
("export selected entries" "izvoz izbranih vnosov")
("export selection" "izbor izvoza")
("export selection as image" "izbira izvoza kot slike")
("export selections as" "izbire izvoza kot")
("export sessions" "izvoznih sej")
("exported bibliographic entries" "izvoºenih bibliografskih vnosov")
("exported bibliographic references" "izvoºenih bibliografskih referenc")
("extend" "podalj²aj")
("extended" "raz²irjeno")
("extensible left arrow" "raztegljiva pu²£ica levo")
("extensible right arrow" "raz²irljiva desna pu²£ica")
("external" "zunanji")
("extra branch" "dodatna podruºnica")
("extra interline space" "dodatni linijski prostor")
("extra name" "dodatno ime")
("extract" "ekstrakt")
("extract style file" "datoteka ekstraktnega sloga")
("extract style package" "paket izvle£ka v slogu")
("factor" "faktor")
("fade" "zbledi")
("fade in" "zbledi")
("fade out" "zbledi")
("fast" "hitra")
("fast decrease" "hitro zmanj²anje")
("fast environments" "hitra okolja")
("fast increase" "hitro pove£anje")
("field reference" "referenca polja")
("fifth" "peta")
("file saved" "datoteka shranjena")
("fill color" "barva za polnjenje")
("fill out" "izpolni")
("filter" "filter")
("finished collecting symbols documentation" "Kon£ana dokumentacija za zbiranje simbolov")
("first" "prvi")
("first chunk" "prvi kos")
("first difference" "prva razlika")
("first error" "prva napaka")
("first field" "prvo polje")
("first occurrence" "prvi pojav")
("first similar" "prvi podobni")
("fit to screen" "prilega zaslonu")
("fit to screen width" "prilega ²irini zaslona")
("five columns" "pet stolpcev")
("fixed" "fiksno")
("flag is off" "zastava je izklopljena")
("flag is on" "zastava je vklopljena")
("flatten" "splo²£iti")
("floating algorithm" "plavajo£i algoritem")
("floating phantom" "plavajo£i fantom")
("focus" "fokus")
("focus dependent icons" "ikone, odvisne od ostrenja")
("fold all" "zloºite vse")
("fold all fields" "zloºite vsa polja")
("fold back" "zloºite nazaj")
("follow external links" "sledite zunanjim povezavam")
("follow inverse links" "sledite obratnim povezavam")
("font effects" "u£inki pisave")
("font selector" "izbirnik pisave")
("for each" "za vsakega")
("force reloading of translations" "prisilno ponovno nalaganje prevodov")
("formatted and structured output" "oblikovan in strukturiran izhod")
("forward" "naprej")
("four columns" "²tirje stolpci")
("four dots" "²tiri pike")
("fourth" "£etrti")
("fraktur" "fraktur")
("framed" "uokvirjeno")
("from" "od")
("from center" "od sredi²£a")
("front matter" "sprednja zadeva")
("full" "polno")
("full author list" "celotni seznam avtorjev")
("functional" "funkcionalno")
("gap" "vrzel")
("garbage collection" "zbiranje smeti")
("gaussian" "gausovcev")
("gcd" "gcd")
("general" "splo²no")
("generated LaTeX document contains no errors" "ustvarjen dokument LaTeX ne vsebuje napak")
("generated field" "ustvarjeno polje")
("geometry" "geometrija")
("get arity" "dobili arity")
("get label" "zasluºi oznako")
("get list with remote versions" "dobite seznam z oddaljenimi razli£icami")
("glyphs" "glifov")
("gnaw" "grizenje")
("gnawed" "grizeno")
("gnuPG command" "ukaz gnuPG")
("gnuPG error: buffer encryption failed" "napaka gnuPG: ²ifriranje medpomnilnika ni uspelo")
("gnuPG error: cannot find suitable secret key to decrypt" "napaka gnuPG: ni mogo£e najti ustreznega tajnega klju£a za de²ifriranje")
("gnuPG requires name and email to have at least 5 characters" "gnuPG zahteva ime in e-po²tni naslov vsaj 5 znakov")
("go to anchor" "pojdi na sidro")
("go to anchor or float" "pojdite na sidro ali plovec")
("go to anchor or footnote" "pojdite na sidro ali sprotno opombo")
("go to first similar tag" "pojdi na prvo podobno oznako")
("go to float" "pojdite plavat")
("go to footnote" "pojdi v opombo")
("go to last similar tag" "pojdi na zadnjo podobno oznako")
("go to next similar tag" "pojdi na naslednjo podobno oznako")
("go to previous similar tag" "pojdi na prej²njo podobno oznako")
("go to section" "pojdite na oddelek")
("grain" "ºito")
("granite" "granit")
("graphical effects" "grafi£ni u£inki")
("graphical interface font scale" "lestvica pisave grafi£nega vmesnika")
("graphics" "grafika")
("graphics geometry" "grafi£na geometrija")
("graphics grids" "grafi£nih mreº")
("greyed" "pohlepno")
("grid" "mreºa")
("grid curves" "krivulje mreºe")
("grid points" "mreºne to£ke")
("grid-curve intersections" "kriºi²£a kriºnih mreº")
("group of objects" "skupina predmetov")
("group/ungroup" "skupina / razvezava skupino")
("grouped" "zdruºenih")
("guarantee transparent source tracking" "zagotavljanje preglednega sledenja virom")
("half wide" "na pol ²irok")
("hand drawn" "ro£no vle£eno")
("headers" "glave")
("history" "zgodovina")
("homoglyph substitutions" "homoglifne substitucije")
("horizontal alignment" "vodoravna poravnava")
("horizontal collapse distance" "vodoravna razdalja strnitve")
("horizontal margins" "vodoravni robi")
("hyphenate as" "vezati kot")
("icon" "ikona")
("if hyphenated" "£e je vezana")
("ignore" "prezreti")
("impact" "vpliv")
("import bibliography" "uvozna bibliografija")
("import database entry" "uvoz podatkovne baze")
("import entries in buffer" "uvozni vnosi v medpomnilniku")
("import entry" "uvozni vnos")
("import file" "uvozna datoteka")
("import selected database entries" "uvoz izbranih vnosov v bazo")
("import selected entries" "uvoz izbranih vnosov")
("import selections as" "uvozi izbire kot")
("import sessions" "uvoznih sej")
("import sophisticated objects as pictures" "uvozi sofisticirane predmete kot slike")
("imported bibliographic entries" "uvoºeni bibliografski vnosi")
("in popup windows" "v pojavnih oknih")
("inanimated" "neºivih")
("inch" "pal£ni")
("incomplete entries found to be filled out" "najdenih je nepopolnih vnosov")
("increase size" "pove£aj velikost")
("indent paragraphs" "alinea")
("indentation" "vdolbina")
("indication" "indikacija")
("initialize" "inicializirati")
("ink here" "£rnilo tukaj")
("ink in" "£rnilo v")
("ink out" "£rnilo ven")
("inline" "inline")
("inline arguments" "vgrajenih argumentov")
("inline code" "vdelana koda")
("inline content" "vdelana vsebina")
("inline formula" "vgrajena formula")
("inner bottom" "notranje dno")
("inner left" "notranja leva")
("inner right" "notranja desna")
("inner top" "notranji vrh")
("input command" "ukazni ukaz")
("input field" "vhodno polje")
("input options" "moºnosti vnosa")
("insert a computer program" "vstavite ra£unalni²ki program")
("insert a condition" "vstavite pogoj")
("insert a control flow instruction" "vstavite navodilo za regulacijo pretoka")
("insert a gap" "vstavite vrzel")
("insert a list" "vstavi seznam")
("insert a multiple choice" "vstavite ve£ moºnosti")
("insert a negation" "vstavite negacijo")
("insert a new entry" "vstavite nov vnos")
("insert a note or a floating object" "vstavite opombo ali plavajo£i predmet")
("insert a numerical operation" "vstavite ²tevil£no operacijo")
("insert a prominent piece of text" "vstavite viden del besedila")
("insert a question" "vstavite vpra²anje")
("insert a root" "vstavite koren")
("insert a script" "vstavite skript")
("insert a section block" "vstavite blok odseka")
("insert a textual operation" "vstavite besedilno operacijo")
("insert a textual operator" "vstavite besedilni operater")
("insert above" "vstavite zgoraj")
("insert abstract" "vstavi izvle£ek")
("insert an answer" "vstavite odgovor")
("insert an enunciation" "vstavite izgovor")
("insert an operation on tuples" "vstavite operacijo na tuple")
("insert annotation" "vstavite pripis")
("insert below" "vstavite spodaj")
("insert copyright and license information" "vstavite podatke o avtorskih pravicah in licencah")
("insert explanatory item" "vstavite pojasnilo")
("insert field above" "vstavite polje zgoraj")
("insert field below" "vstavite polje spodaj")
("insert large delimiters" "vstavite velike lo£ilnike")
("insert last name" "vstavite priimek")
("insert left" "vstavite levo")
("insert missing invisible operators" "vstavite manjkajo£e nevidne operaterje")
("insert more names" "vstavite ve£ imen")
("insert particle" "vstavite delce")
("insert plain text" "vstavite navadno besedilo")
("insert right" "vstavite desno")
("insert similar above" "vstavite podobno zgoraj")
("insert similar below" "spodaj vstavite podobno")
("insert similar block above" "zgoraj vstavite podoben blok")
("insert similar block below" "vstavite podoben blok spodaj")
("insert subtable" "vstavi podmetivo")
("insert symbol documentation" "vstavite simboli£no dokumentacijo")
("insert template" "vstavi predlogo")
("insert text field above" "vstavite besedilno polje zgoraj")
("insert text field below" "vstavite besedilno polje spodaj")
("insert title after name" "vstaviti naslov za imenom")
("insert user interface related markup" "vstavite oznako, povezano z uporabni²kim vmesnikom")
("inserting control points" "Vstavljanje kontrolnih to£k")
("integrate" "vklju£i")
("interactive command" "interaktivni ukaz")
("interactive questions" "interaktivna vpra²anja")
("intercharacter compression" "medosredna kompresija")
("intercharacter stretching" "medsebojno raztezanje")
("interrupted" "prekinjeno")
("invalid multi-paragraph selection" "neveljaven izbor ve£ odstavkov")
("invalid renaming" "neveljavno preimenovanje")
("invert" "invert")
("inverted breve" "obrnjen breve")
("invisible ending" "neviden konec")
("invisible newline" "nevidna nova vrstica")
("invisible opening" "nevidna odprtina")
("join selected cells" "pridruºi izbranim celicam")
("jump in" "skok v")
("junior" "mlaj²ih")
("keep evaluated expressions" "obdrºi ocenjene izraze")
("keep local" "ohranjaj lokalno")
("keep remote" "ohranjaj oddaljeno")
("keep track of source code" "spremljanje izvorne kode")
("keep unfolded" "ohrani razprto")
("keyboard configuration" "konfiguracija tipkovnice")
("laptop presentations" "predstavitve prenosnikov")
("large cells" "velikih celic")
("large displayed" "velik prikaz")
("large displayed fraction" "velik prikazan ulomek")
("large tables" "velikih miz")
("last" "zadnji")
("last difference" "zadnja razlika")
("last error" "zadnja napaka")
("last field" "zadnje polje")
("last name" "priimek")
("last occurrence" "zadnji pojav")
("last similar" "zadnji podoben")
("lcm" "lcm")
("left axis" "leva os")
("left baseline" "leva osnovna £rta")
("left bottom" "levo dno")
("left cell border" "leva celi£na meja")
("left cell padding" "obloga leve celice")
("left center" "levi center")
("left click: add point; Right click: undo" "levi klik: dodaj to£ko; desni klik: razveljavi")
("left click: finish; Right click: undo" "levi klik: zaklju£i; desni klik: razveljavi")
("left click: new object" "levi klik: nov predmet")
("left click: operate" "levi klik: deluje")
("left down" "levo navzdol")
("left on even pages" "levo na enakomernih straneh")
("left table border" "leva meja mize")
("left table padding" "obloga leve mize")
("left top" "levi vrh")
("left up" "levo navzgor")
("left-right arrow" "pu²£ica levo-desno")
("leftwards" "levo")
("let the environment float" "naj oko plava")
("line breaking" "prekinitev vrstice")
("line wrapping" "zavijanje vrstic")
("linear 2D" "linearni 2D")
("linear algebra" "linearna algebra")
("lines around" "vrstic")
("link image and copies as" "povezava slike in kopiranje kot")
("link image as" "povezava slike kot")
("link mode" "na£in povezave")
("link to URL" "povezava do URL-ja")
("linking tool" "povezovalno orodje")
("live" "v ºivo")
("live input-output" "vhod-izhod v ºivo")
("load help file" "Naloºi datoteko pomo£i")
("load remote file" "naloºi oddaljeno datoteko")
("loading" "nakladanje")
("local entries" "lokalni vnosi")
("loci" "loci")
("locus" "lokus")
("locus rendering" "upodabljanje lokusa")
("logarithm" "logaritem")
("logarithmic" "logaritmi£no")
("logarithmic base" "logaritmi£na osnova")
("logarithms" "logaritmi")
("logging in" "prijava")
("logical and" "logi£no in")
("logical implication" "logi£na implikacija")
("logical not" "logi£no ni")
("logical or" "logi£no ali")
("login" "prijava")
("logout" "odjava")
("long macro" "dolg makro")
("long text" "dolgo besedilo")
("look for more fonts" "poi²£ite ve£ pisav")
("loops" "zank")
("macro argument" "makro argument")
("macro definition" "makro opredelitev")
("macro name" "ime makra")
("macros" "makrov")
("magnify horizontally" "pove£aj vodoravno")
("magnify vertically" "pove£ava navpi£no")
("main presentation style" "glavni slog predstavitve")
("make a letter environment" "ustvari £rko okolje")
("make a multi-slide presentation" "pripravi ve£ diapozitivov")
("make floating" "da plava²")
("make link" "vzpostavi povezavo")
("make non floating" "da ne plava")
("manila paper" "papir iz manile")
("map arguments" "argumentov na zemljevidu")
("marginal note" "obrobna nota")
("margins from width" "robovi od ²irine")
("margins on paper" "marºe na papirju")
("margins on screen" "robove na zaslonu")
("marked" "ozna£eno")
("material" "gradiva")
("mathematical and customized input" "matemati£ni in prilagojeni vnos")
("mathematical output" "matemati£ni izhod")
("matrices" "matrice")
("maximal cell height" "najve£ja vi²ina celice")
("maximal clustering" "najve£je zdruºevanje")
("maximal table height" "najve£ja vi²ina mize")
("maximal table width" "najve£ja ²irina mize")
("maximum" "najve£")
("meander" "meander")
("memory" "spomin")
("memory usage" "poraba pomnilnika")
("menu" "meni")
("merge lines into paragraphs unless separated by blank lines" "Zdruºite vrstice v odstavke, razen £e jih lo£ite s praznimi £rtami")
("messages" "sporo£il")
("meta data" "metapodatki")
("metadata" "metapodatki")
("metal" "kovin")
("middle baseline" "srednja osnovna £rta")
("minimal cell height" "minimalna vi²ina celice")
("minimal cell width" "minimalna ²irina celice")
("minimal line separation" "minimalna lo£itev vrstice")
("minimal table height" "minimalna vi²ina mize")
("minimal table width" "minimalna ²irina mize")
("minimum" "najmanj")
("mirror" "ogledalo")
("miscellaneous features" "razne funkcije")
("miscellanous" "razno")
("mode dependent icons" "ikone, ki so odvisne od na£ina")
("modify remote live document" "spreminjanje oddaljenega dokumenta v ºivo")
("module" "modul")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help" "Ve£ informacij o GNU TeXmacs najdete v pomo£i")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "")
("more information about GNU TeXmacs can be found in the Help-<less>gtr<gtr>About menu" "ve£ informacij o GNU TeXmacs najdete v meniju Pomo£ - <less>gtr<gtr> Vizitka")
("motion" "gibanje")
("mouse over object" "mi²ka nad objektom")
("move" "premakni")
("move objects" "premikanje predmetov")
("move over object on which to operate" "premik nad objektom, na katerem naj deluje")
("multiline" "ve£ vrstic")
("multiple choice" "ve£ moºnosti")
("multiple root" "ve£ korenin")
("multiplication" "mnoºenje")
("mutator tags" "mutatorskih oznak")
("navigation options" "moºnosti navigacije")
("never" "nikoli")
("new account" "nov ra£un")
("new bibliography dialogue" "novi bibliografski dialog")
("new document" "nov dokument")
("new double page" "nova dvojna stran")
("new double page before" "nova dvojna stran pred")
("new entry" "nov vnos")
("new identity" "nova identiteta")
("new locus" "novi lokus")
("new macro" "novi makro")
("new passphrase" "nova gesla")
("new remote directory" "novi oddaljeni imenik")
("new remote file" "nova oddaljena datoteka")
("new style fonts" "pisav novega sloga")
("new style page breaking" "novo slogovno prebijanje strani")
("new version" "nova razli£ica")
("new window" "novo okno")
("newer version" "novej²a razli£ica")
("next chunk" "naslednji kos")
("next difference" "naslednja razlika")
("next error" "naslednja napaka")
("next field" "naslednje polje")
("next occurrence" "naslednji pojav")
("next screen" "naslednji zaslon")
("next similar" "naslednji podobni")
("no clustering" "brez zdruºevanja")
("no completions" "brez dopolnitev")
("no errors have been corrected" "napake niso bile odpravljene")
("no grid" "brez omreºja")
("no new public key in document" "v dokumentu ni novega javnega klju£a")
("no page break" "brez preloma strani")
("no page numbers" "brez ²tevilk strani")
("no parent" "brez star²ev")
("no selection" "ni izbire")
("no spelling errors" "ni £rkovalnih napak")
("normal loci" "normalnih lokusov")
("not allowed to remove home directory" "ni dovoljeno odstraniti doma£ega imenika")
("not connected to server" "ni povezan s streºnikom")
("not yet implemented" "²e ni izvedeno")
("notebook" "zvezek")
("number of polar steps" "²tevilo polarnih korakov")
("number of subunit steps" "²tevilo podenotnih korakov")
("numbering" "o²tevil£evanje")
("numeric spreadsheet" "²tevil£na preglednica")
("odd page" "liha stran")
("odd page right margin" "desni rob z liho stranjo")
("odd page shift" "nenavadno premik strani")
("odd pages" "£udnih strani")
("of fingerprint" "prstnega odtisa")
("old version" "stara razli£ica")
("older version" "starej²a razli£ica")
("on the footer" "na nogi")
("on your system and set it up from the \"Security\" tab" "v va²em sistemu in ga nastavite na zavihku \"Varnost\"")
("one column" "en stolpec")
("one error has been corrected" "ena napaka je bila odpravljena")
("one lower case letter, one non alpha-numeric symbol" "ena mala £rka, en ne²tevil£no numeri£ni simbol")
("one numeric character, one upper case letter" "en numeri£ni znak, ena velika £rka")
("only convert changes when re-importing" "pretvori spremembe samo pri ponovnem uvozu")
("only convert changes with respect to imported version" "pretvori samo spremembe glede na uvoºeno razli£ico")
("only convert changes with respect to tracked version" "pretvori samo spremembe v zvezi z gosenico")
("only implemented for complete subtrees" "izvedeno samo za celotne podtlake")
("only inline tags" "samo vmesnih oznak")
("only keep folded" "samo zloºeno")
("only keep unfolded" "samo sprostite")
("only show semantic focus" "kaºejo le semanti£no osredoto£enost")
("opacity" "motnost")
("open bibliography" "odprta bibliografija")
("open identities" "odprte identitete")
("open in new window" "odpri v novem oknu")
("open key manager" "upravitelj odprtih tipk")
("open licence agreement" "odprta licen£na pogodba")
("open mailbox" "odprti nabiralnik")
("open module browser" "brskalnik odprtega modula")
("open symbol browser" "brskalnik odprtih simbolov")
("open tool in separate window" "odprto orodje v lo£enem oknu")
("operation mode" "na£in delovanja")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ali podajte celotno pot do ukaza \"gpg\" ali \"gpg2\"")
("order" "naro£ilo")
("ordinary symbol" "navadni simbol")
("ornamented" "okra²enih")
("other login" "druga prijava")
("other package" "drugi paket")
("outer bottom" "zunanje dno")
("outer left" "zunanja leva")
("outer right" "zunanja desna")
("outer top" "zunanji vrh")
("outline" "oris")
("outlined" "orisana")
("outlined emboss" "obrisan relief")
("outlined engrave" "obrisano graviranje")
("output options" "moºnosti izhoda")
("oval" "oval")
("overlap" "prekrivanje")
("overlay" "prekrivanje")
("overlays" "prekrivanja")
("overlined" "poudarjeno")
("overview of the scheme extension language" "pregled jezika raz²iritve sheme")
("padded" "oblazinjeno")
("page background" "ozadje strani")
("page break after" "prelom strani po")
("page breaking algorithm" "algoritem lomljenja strani")
("page number" "²tevilka strani")
("page number rendering" "upodabljanje ²tevilke strani")
("page rendering" "upodabljanje strani")
("palette" "paleta")
("panorama" "panorama")
("paragraphs" "odstavkov")
("parametric curve" "parametri£na krivulja")
("parametric surface" "parametri£na povr²ina")
("parenthesis" "oklepaji")
("parenthesized" "oklepaj")
("particle" "delcev")
("passphrase encryption" "²ifriranje gesla")
("passphrase wallet facilities are not currently available" "zmogljivosti denarnice z geslom trenutno ni na voljo")
("passphrases are expected to have at least: 8 characters" "gesli naj bi imeli vsaj 8 znakov")
("passphrases mismatch" "neskladje med gesli")
("pastel" "pastel")
("pattern" "vzorec")
("pause" "pavza")
("pen width" "²irina pisala")
("permanent footer" "stalna noga")
("permanent header" "stalna glava")
("permanently add to dictionary" "trajno dodaj v slovar")
("permanently insert into dictionary" "trajno vstaviti v slovar")
("permissions" "dovoljenj")
("phantom" "fantom")
("phantoms" "fantomi")
("physics and astronomy class" "razred fizike in astronomije")
("picture" "slika")
("pine" "bor")
("plain" "navadnih")
("plain boxes" "navadnih ²katel")
("plain circles" "navadnih krogov")
("play" "predvajaj")
("play animation" "predvajaj animacijo")
("please install GnuPG software from https://www.gnupg.org" "namestite programsko opremo GnuPG s https://www.gnupg.org")
("plot" "parcela")
("plug-ins" "vti£niki")
("plural" "mnoºina")
("point" "to£ka")
("polar" "polarnih")
("polygon" "poligon")
("pop server settings" "nastavitve pop streºnika")
("position of marginal note" "poloºaj mejne note")
("poster formats" "formati plakatov")
("poster theme" "tema plakatov")
("postfix" "postfix")
("preferences for editing mathematical formulas" "nastavitve za urejanje matemati£nih formul")
("preferences for tag" "nastavitve za oznako")
("prefix" "predpona")
("presentation tool" "predstavitveno orodje")
("preserve" "rezervat")
("preserve tags" "shrani oznake")
("pretty tree output" "lepo drevesni rezultat")
("preview" "predogled")
("previous difference" "prej²nja razlika")
("previous error" "prej²nja napaka")
("previous field" "prej²nje polje")
("previous occurrence" "prej²nji pojav")
("previous screen" "prej²nji zaslon")
("previous similar" "prej²nji podobni")
("primitive or macro" "primitivni ali makro")
("print buffer" "medpomnilnik tiskanja")
("print buffer to file" "medpomnilnik za tiskanje v datoteko")
("print to file" "natisni v datoteko")
("printer setup" "nastavitev tiskalnika")
("program bracket matching" "ujemanje programskega oklepaja")
("program bracket selections" "izbire nosilcev programa")
("program commands" "ukazi programa")
("program interface for buffer management" "programski vmesnik za upravljanje medpomnilnika")
("programming routines for editing documents" "programiranje rutin za urejanje dokumentov")
("prominent" "vidnih")
("prompts and default input" "pozive in privzeti vnos")
("provoke C++ error" "izzove napako C ++")
("provoke menu error" "sproºi napako v meniju")
("provoke scheme error" "napaka v shemi")
("pseudo code" "psevdo koda")
("public key encryption" "²ifriranje javnega klju£a")
("public keys" "javnih klju£ev")
("pulse" "utrip")
("qt GUI only, sorry. Use \"Export selection\"" "Samo qt GUI, oprosti. Uporabi \"Izvozi izbor\"")
("qt-widgets" "qt-widgets")
("quantifier" "koli£nik")
("quasi" "kvazi")
("question" "vpra²anje")
("questions only" "samo vpra²anja")
("questions with answers" "vpra²anja z odgovori")
("quick evaluation of formulas" "hitro ocenjevanje formul")
("rank" "£in")
("raw" "surovih")
("really delete user identity" "resni£no izbri²ite identiteto uporabnika")
("rebuild translations file" "datoteka za obnovitev prevodov")
("recent" "nedavnih")
("recent documents" "nedavnih dokumentov")
("recipients" "prejemnikov")
("recognize" "prepozna")
("rectangular" "pravokotne")
("reduce" "zmanj²ati")
("reduce trigonometric functions" "zmanj²a trigonometri£ne funkcije")
("reduced margins" "zniºane marºe")
("reference guide for the TeXmacs primitives" "referen£ni priro£nik za primitivce TeXmacs")
("reference guide for the standard TeXmacs styles" "referen£ni priro£nik za standardne sloge TeXmacs")
("regenerate" "regeneracija")
("register file" "registrska datoteka")
("relate" "relate")
("relation" "zveza")
("release left button: finish editing" "sprostite levi gumb: zaklju£ite urejanje")
("remote" "daljinski")
("remote connections" "oddaljenih povezav")
("remote control" "daljinski upravljalnik")
("remote controllers with keyboard simulation" "daljinski upravljalniki s simulacijo tipkovnice")
("remote directory" "oddaljeni imenik")
("remote servers" "oddaljenih streºnikov")
("remote tool" "oddaljeno orodje")
("remove" "odstrani")
("remove banner" "odstrani pasico")
("remove database entry" "odstrani vnos baze podatkov")
("remove downwards" "odstrani navzdol")
("remove entries" "odstrani vnose")
("remove entry" "odstrani vnos")
("remove field above" "odstrani polje zgoraj")
("remove field below" "odstrani polje spodaj")
("remove folded" "odstrani zloºeno")
("remove last field" "odstrani zadnje polje")
("remove leftwards" "odstrani levo")
("remove link" "odstrani povezavo")
("remove next field" "odstrani naslednje polje")
("remove previous field" "odstrani prej²nje polje")
("remove rightwards" "odstrani desno")
("remove selected database entries" "odstrani izbrane vnose v bazo")
("remove selected entries" "odstrani izbrane vnose")
("remove superfluous invisible operators" "odstrani odve£ne nevidne operaterje")
("remove tag" "odstrani oznako")
("remove this branch" "odstrani to vejo")
("remove unfolded" "odstrani razvit")
("remove upwards" "odstrani navzgor")
("removed entries from database" "odstranjenih vnosov iz baze podatkov")
("removed entry from database" "odstranjen vnos iz baze podatkov")
("rename" "preimenovanje")
("rename section" "preimenovanje odseka")
("repeat" "ponovitev")
("replace TeXmacs styles with no LaTeX equivalents" "zamenjaj sloge TeXmacs brez ekvivalentov LaTeX")
("replace all further occurrences" "nadomesti vse nadaljnje pojave")
("replace one occurrence" "zamenjaj en pojav")
("replace toolbar" "zamenjaj orodno vrstico")
("replace unrecognized styles" "zamenjaj neprepoznane sloge")
("reset error counters" "ponastavitev ²tevcev napak")
("resize" "velikost")
("resize objects" "spreminjanje velikosti predmetov")
("restart TeXmacs in order to let changes take effect" "znova zaºenite TeXmacs, da bi spremembe za£ele veljati")
("restart in order to let the new look and feel take effect" "znova zaºenite, da bi nov videz in ob£utek za£el veljati")
("retain" "obdrºi")
("retime" "mreºnica")
("retina settings" "nastavitve mreºnice")
("retrieve email" "pridobivanje e-po²te")
("retrieve remote live document" "pridobivanje oddaljenega dokumenta v ºivo")
("retrieved contents" "najdenih vsebin")
("reverse" "obratno")
("reverse ordering" "obratno naro£anje")
("ridged paper" "greben papir")
("right baseline" "desno izhodi²£e")
("right cell border" "desna celi£na meja")
("right cell padding" "desno oblazinjenje celic")
("right down" "desno navzdol")
("right on even pages" "desno na enakomernih straneh")
("right table border" "desna meja mize")
("right table padding" "desna obloga za mizo")
("right up" "desno navzgor")
("rightwards" "desno")
("rigid box" "togi okvir")
("rotate" "zasuka")
("rotate objects" "zasukanih predmetov")
("rough" "grobo")
("rough paper" "hrapav papir")
("round" "krog")
("round overbrace" "okroglo prekrivanje")
("round underbrace" "okrogla podloga")
("row above" "vrstica zgoraj")
("row below" "vrstica spodaj")
("rows" "vrstic")
("run" "te£i")
("run current file" "zaºeni trenutno datoteko")
("same names" "enakih imen")
("same screen margins as on paper" "enake robove zaslona kot na papirju")
("sample text" "vzor£no besedilo")
("save auxiliary data" "shrani pomoºne podatke")
("save entries" "shrani vnose")
("save entry" "shrani vnos")
("save image as" "shrani sliko kot")
("save position" "shrani poloºaj")
("save remote file" "shrani oddaljeno datoteko")
("saved modifications in database" "shranjenih sprememb v bazi")
("scheme command" "ukaz ukaza")
("scheme developers guide" "Vodnik za razvijalce shem")
("scheme extensions" "raz²iritve sheme")
("scheme interface for the graphical mode" "vmesnik sheme za grafi£ni na£in")
("screen rendering" "upodabljanje zaslona")
("screens" "zaslonov")
("screenshot" "posnetek zaslona")
("scripting language" "skriptni jezik")
("scripts" "skript")
("search and replace" "iskanje in zamenjava")
("search toolbar" "orodna vrstica za iskanje")
("second" "sekund")
("secret keys" "tajnih klju£ev")
("sections" "odsekov")
("see documentation" "glej dokumentacijo")
("select pen" "izberite pisalo")
("select the action to be undertaken for each conflict" "izberite ukrepe, ki jih je treba izvesti za vsak konflikt")
("select view mode" "izberi na£in pogleda")
("semantic correctness" "pomenska korektnost")
("semantic editing" "pomensko urejanje")
("semantic selections" "pomenske izbire")
("semantics" "semantika")
("senior" "starej²ih")
("serif" "serif")
("server" "streºnik")
("session commands" "ukazi seje")
("set default" "nastavi privzeto")
("set difference" "nastavljena razlika")
("set intersection" "nastavljeno kriºi²£e")
("set number of columns" "nastavi ²tevilo stolpcev")
("set number of rows" "nastavi ²tevilo vrstic")
("set or get environment variables" "nastavite ali dobite spremenljivke okolja")
("set properties" "nastavite lastnosti")
("set union" "nastavljena zveza")
("set user information" "nastavi podatke o uporabniku")
("seventh" "sedma")
("several equations" "ve£ ena£b")
("shadow" "senca")
("shadowed" "zasen£eno")
("shadowed raise" "sen£ni dvig")
("shift" "premik")
("show all parts" "pokaºi vse dele")
("show current focus" "prikaºi trenutni fokus")
("show full context" "prikaºi celoten kontekst")
("show key presses" "prikaºi pritiskanje tipk")
("show main document" "prikaºi glavni dokument")
("show memory usage" "prikaºi porabo pomnilnika")
("show one part" "prikaºi en del")
("show panorama" "prikaºi panoramo")
("show preamble" "prikaºi preambulo")
("show several parts" "pokaºi ve£ delov")
("show subunits" "prikaºi podenote")
("show table cells" "prikaºi celice tabele")
("show timings" "prikazovanje £asov")
("side tools" "stransko orodje")
("simple" "enostavno")
("simplification" "poenostavitev")
("simplified evaluation of formulas" "poenostavljeno ocenjevanje formul")
("simplified menus" "poenostavljeni meniji")
("simplify" "poenostavite")
("sine" "sinus")
("sixth" "²esti")
("skew" "nagnjen")
("skip all" "presko£i vse")
("slant" "nagnjen")
("slashed fraction" "zdrobljen del")
("slides" "diapozitivov")
("slow" "po£asno")
("slow decrease" "po£asno zmanj²anje")
("slow increase" "po£asno pove£anje")
("small capitals" "majhnih prestolnic")
("small environment box" "majhna ²katla za okolje")
("small focus" "majhen fokus")
("small inline" "majhen rolaj")
("small inline fraction" "majhen inline frakcija")
("smash" "razbiti")
("smooth" "gladkih")
("smooth end" "gladek konec")
("smooth extremities" "gladke okon£ine")
("smooth start" "gladek za£etek")
("snap" "snap")
("snap distance" "razdalja zapor")
("snap to curves" "zaskok do krivulj")
("snap to grid" "pripenjanje na mreºo")
("snap to grid curve" "prislon na krivuljo omreºja")
("snap to intersections of curves" "zasko£itev kriºi²£")
("snap to text borders" "pripenjanje na meje besedila")
("snap to text corners" "priklop na vogale besedila")
("solution" "re²itev")
("solution to exercise" "re²itev za vadbo")
("solution to problem" "re²itev problema")
("solutions" "re²itev")
("sound" "zvok")
("source" "vir")
("source macros tool" "izvorno makro orodje")
("source tags" "izvorne oznake")
("south" "juºno")
("south east" "jugovzhodno")
("space bar in math mode" "preslednica v matemati£nem na£inu")
("space bar in text mode" "preslednica v besedilnem na£inu")
("space stretchability" "raztezljivost prostora")
("span" "razpon")
("span over all columns" "razpon £ez vse stolpce")
("special functions" "posebne funkcije")
("special properties" "posebne lastnosti")
("specific baseline" "specifi£na izhodi²£na vrednost")
("specify color alternation" "dolo£ite izmeni£no barvo")
("specify how to traverse the manual" "dolo£ite, kako prebrati ro£ni priro£nik")
("specify semantics of a symbol or formula" "dolo£ite semantiko simbola ali formule")
("specify the size of the table" "dolo£ite velikost tabele")
("spell check" "£rkovanje")
("spline" "spline")
("split program" "split program")
("square" "kvadrat")
("square overbrace" "kvadratni previs")
("square underbrace" "kvadratna spodnjica")
("stack" "sklad")
("standard" "standard")
("standard Output" "standardni izhod")
("standard formats" "standardnih formatov")
("standard fraction" "standardni del")
("star" "zvezdic")
("start server" "zagonski streºnik")
("statement" "izjava")
("statistics" "statistika")
("status" "status")
("stop server" "zaustavitveni streºnik")
("storage" "shramba")
("store tracking information in LaTeX files" "shranjevanje podatkov o sledenju v datoteke LaTeX")
("stretch" "razteºaj")
("stretch factor" "faktor raztezanja")
("stretched" "raztegnjeno")
("strict Ascii" "strogi Ascii")
("strike through" "stavka skozi")
("structured insert above" "strukturiran vloºek zgoraj")
("structured insert at the left" "strukturiran vloºek na levi")
("structured insert at the right" "strukturiran vloºek na desni")
("structured insert below" "strukturiran vloºek spodaj")
("structured remove downwards" "strukturirano odstranjevanje navzdol")
("structured remove leftwards" "strukturirano odstrani levo")
("structured remove rightwards" "strukturirano odstrani desno")
("structured remove upwards" "strukturirano odstranjevanje navzgor")
("structured variant" "strukturirana varianta")
("style options" "moºnosti sloga")
("style parameters" "parametri sloga")
("stylesheet language" "jezik tabele slogov")
("subject" "predmet")
("submenu" "podmeni")
("subscript below" "spodaj naveden podpis")
("subsubmenu" "podmenija")
("subsubsubmenu" "sububsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtraction" "od²tevanje")
("summarized" "povzeto")
("superscript above" "nadkript zgoraj")
("supported plug-ins" "podprti vti£niki")
("surface" "povr²ina")
("inflate" "nabrekne")
("swiss" "²vic")
("switch to buffer" "preklopite na medpomnilnik")
("symbol properties not found" "lastnosti simbolov ni mogo£e najti")
("symbols" "simbolov")
("synchronize" "sinhroniziraj")
("synchronize bibliographic references" "sinhroniziranje bibliografskih referenc")
("synchronize with remote server" "sinhronizacija z oddaljenim streºnikom")
("synopsis" "sinopsis")
("system command" "sistemski ukaz")
("tab-completion" "Dokon£anje zavihkov")
("tabbed" "na zavihkih")
("table breaking" "razbijanje mize")
("table height" "vi²ina mize")
("table properties" "lastnosti tabel")
("table width" "²irina mize")
("tags with special rendering" "oznake s posebnim upodabljanjem")
("tangent" "tangenta")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Pri£akovano medpomnilnika TeXmacs")
("teXmacs buffer on disk expected" "pri£akovani medpomnilnik TeXmacs na disku")
("teXmacs extensions to scheme and utilities" "raz²iritve teXmacs na shemo in pripomo£ke")
("teXmacs macro" "max TeXmacs")
("teXmacs package" "paket TeXmacs")
("teXmacs style" "slog TeXmacs")
("test routine" "testna rutina")
("testing tree-view" "preizku²anje pogleda na drevo")
("text borders" "meje besedila")
("text box style" "slog besedilnega polja")
("text corners" "vogali besedila")
("textual" "besedilno")
("textual operator" "besedilni operater")
("textual spreadsheet" "besedilna preglednica")
("the TeXmacs plug-in system" "vti£ni sistem TeXmacs")
("theme parameters" "parametri teme")
("these collected public keys will be definitely lost" "ti zbrani javni klju£i bodo zagotovo izgubljeni")
("these public keys will be definitely lost" "ti javni klju£i bodo zagotovo izgubljeni")
("these secret keys will be definitely lost" "ti skrivni klju£i bodo zagotovo izgubljeni")
("thicken" "zgostiti")
("third" "tretji")
("this" "to")
("this column" "ta stolpec")
("this document has not been saved" "ta dokument ni bil shranjen")
("this page footer" "podnoºje te strani")
("this page header" "glava te strani")
("this page number" "²tevilka te strani")
("this row" "ta vrstica")
("this style specifies page margins in the TeX way" "ta slog na teX na£in dolo£a robove strani")
("three columns" "trije stolpci")
("three dots" "tri pike")
("through popup windows" "skozi pojavna okna")
("through the menus" "skozi menije")
("thumbnails" "sli£ice")
("time evolution" "£asovna evolucija")
("timings" "£asovne omejitve")
("title presentation options" "moºnosti predstavitve naslova")
("title style" "slog naslova")
("title suffix" "pripona naslova")
("titled block" "naslovljeni blok")
("toggle cell wrapping mode" "preklopni na£in zavijanja celic")
("toggle here" "preklopite sem")
("toggle off" "izklop")
("toggle on" "vklop")
("tolerant" "strpen")
("top baseline" "zgornja osnovna £rta")
("top cell border" "zgornja meja celice")
("top cell padding" "zgornje oblazinjenje celic")
("top table border" "zgornja meja mize")
("top table padding" "oblazinjenje zgornje mize")
("transform" "preoblikovanje")
("transform cell into subtable" "preoblikovanje celice v podloºljivo")
("translations" "prevodov")
("translations loaded" "prevodov je naloºenih")
("transpose" "prestaviti")
("traversal" "pre£kanje")
("traverse" "pre£kanje")
("triangle" "trikotnik")
("triangularize" "triangularize")
("trigonometric" "trigonometri£ni")
("trigonometry" "trigonometrija")
("turn off" "izklopi")
("turn on" "vklopi")
("two columns" "dva stolpca")
("two dots" "dve piki")
("type a latex command followed by return" "vnesite ukaz lateksa, ki mu sledi vrnitev")
("underlined" "pod£rtano")
("unfold all" "razgrni vse")
("unfold all fields" "raz²iri vsa polja")
("unit" "enota")
("unit length" "dolºina enote")
("unknown secret key fingerprint" "prstni odtis neznanega tajnega klju£a")
("unregistered file" "neregistrirana datoteka")
("unroll" "odvij")
("unsecure script refused" "neza²£iten scenarij zavrnjen")
("unsupported link mode" "nepodprti na£in povezave")
("until" "do")
("untitled block" "blok brez naslova")
("up to date" "posodobljeno")
("update buffer" "posodobitev medpomnilnika")
("update this buffer" "posodobi ta medpomnilnik")
("update web site" "posodobitev spletnega mesta")
("upight" "navzgor")
("upload" "nalaganje")
("upright" "pokonci")
("upwards" "navzgor")
("use CSS for more advanced formatting" "uporabi CSS za naprednej²e oblikovanje")
("use MathML" "uporabi MathML")
("use as master" "uporaba kot glavni")
("use extensible brackets" "uporabite raztegljive oklepaje")
("use line wrapping for lines which are longer than 80 characters" "uporabite zavijanje vrstic za vrstice, dalj²e od 80 znakov")
("use margin kerning (protrusion)" "uporabi marning kerning (protrusion)")
("use protrusion" "uporabi ²trle£")
("use relative path" "uporabi relativno pot")
("user interface" "uporabni²ki vmesnik")
("user interface language" "jezik uporabni²kega vmesnika")
("user preferences" "nastavitve uporabnikov")
("users of oriental languages" "uporabniki orientalskih jezikov")
("utf-8 with inputenc LaTeX package" "utf-8 s paketom inputenc LaTeX")
("utilities" "pripomo£ki")
("vanish" "izgine")
("verbose" "besedno")
("version" "razli£ica")
("versioning tool" "orodje za razli£ico")
("vertical alignment" "navpi£na poravnava")
("vertical margins" "navpi£ni robi")
("vertical space after" "navpi£ni prostor za")
("vertical space before" "navpi£ni presledek pred")
("vertical space stretchability" "navpi£na raztegljivost prostora")
("visible except here" "vidno razen tukaj")
("visible from here on" "vidno od tu naprej")
("visible only here" "vidno samo tukaj")
("visible until here" "vidno do tukaj")
("visited loci" "obiskani loki")
("wallet" "denarnica")
("wave" "val")
("weight" "teºa")
("when line wrapping" "pri zavijanju vrstic")
("whitespace" "beli prostor")
("wide" "²iroko")
("wide block" "²irok blok")
("wide colored" "²iroko obarvan")
("wide float" "²irok plovec")
("wide footnote" "²iroka opomba")
("wide tabular" "²iroka tabela")
("widescreen" "²irokozaslonski")
("wrap lines" "ovijalnih linij")
("write a macro" "napi²i makro")
("writing TeXmacs bibliography styles" "pisanje slogov bibliografije TeXmacs")
("writing documentation" "pisna dokumentacija")
("wrong empty passphrase" "napa£na prazna gesla")
("wrong passphrase" "napa£na gesla")
("year" "leto")
("you are attempting to open an encrypted file while" "medtem ko posku²ate odpreti ²ifrirano datoteko, medtem ko")
("you might consider enabling the experimental" "boste morda ºeleli omogo£iti poskus")
("you must add a bibliography file" "dodati morate bibliografsko datoteko")
("you should also make sure that GnuPG is installed" "preverite tudi, ali je name²£en GnuPG")
("your personal dictionary has been modified" "va² osebni slovar je bil spremenjen")
("zoom" "zoom")
("zoom in" "pove£ava")
("zoom out" "pomanj²anje")
