;; Conversions between Unicode and LaTeX ascii code

;; (C) 2012 Francois Poulain
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;; Inspired from utf8enc.dfu

("#A"  "\n")
("#2018" "`")
("#2019" "'")
("#201C" "``")
("#201D" "''")
