("(Re)Build autocompletion index" "(Ri)Crea indice di completamento automatico")
("A modifier" "modificatore A")
("GNU" "GNU")
("H modifier" "modificatore H")
("LaTeX" "LaTeX")
("M modifier" "modificatore M")
("TeX" "TeX")
("a modifier" "modificatore A")
("a series" "serie a")
("a.C.M. computing class" "classe informatica A.C.M.")
("a.M.S. subject class" "classe tematica A.M.S.")
("abbreviated authors" "autori abbreviati")
("abbreviation" "abbreviazione")
("about" "informazioni su TeXmacs")
("about menu" "menu informazioni")
("above" "sopra")
("abstract" "riassunto")
("accent" "accento")
("accent above" "accento sopra")
("accent below" "accento sotto")
("accept" "accetta")
("accept all scripts" "accetta tutti gli script")
("accept during this pass" "accetta in questo passaggio")
("accept no scripts" "non accettare gli scripts")
("accept script" "accetta script")
("acknowledgment" "riconoscimento")
("acknowledgments" "riconoscimenti")
("acronym" "acronimo")
("action" "azione")
("activate" "attiva")
("activate hidden" "attiva nascosto")
("activate once" "attiva una volta")
("activation" "attivazione")
("active link types" "tipi di link attivi")
("acute" "acuto")
("add" "aggiungi")
("add abstract information" "aggiungi informazioni sul riassunto")
("add author information" "aggiungi informazioni sull'autore")
("add branch after" "aggiungi ramo dopo")
("add branch before" "aggiungi ramo prima")
("add other package" "aggiungi altro pacchetto")
("add package" "aggiungi pacchetto")
("add style package" "aggiungi pacchetto di stile")
("add switch after" "aggiungi switch dopo")
("add switch before" "aggiungi switch prima")
("add title information" "aggiungi informazioni sul titolo")
("addition" "aggiunta")
("address" "indirizzo")
("address block" "blocco indirizzo")
("adjust" "regola")
("adjust limits" "regola i limiti")
("advanced" "avanzato")
("advanced font customization" "personalizzazione avanzata dei caratteri")
("advanced layout features" "caratteristiche di impaginazione avanzate")
("affiliation" "affiliazione")
("after" "dopo")
("albanian" "albanese")
("algorithm" "algoritmo")
("algorithms" "algoritmi")
("align cell to the bottom" "allinea la cella sul fondo")
("align cell to the decimal comma" "allinea la cella alla virgola decimale")
("align cell to the decimal dot" "allinea la cella al punto decimale")
("align cell to the left" "allinea la cella a sinistra")
("align cell to the right" "allinea la cella a destra")
("align cell to the top" "alinea la cella in alto")
("align table at axis" "allinea tabella all'asse")
("align table at base of left column" "allinea la tabella alla base della colonna sinistra")
("align table at base of middle column" "allinea la tabella alla base della colonna centrale")
("align table at base of origin column" "allinea la tabella alla base della colonna d'origine")
("align table at base of right column" "allinea la tabella alla base della colonna di destra")
("align table at fraction bar height" "allinea la tabella all'altezza della linea di frazione")
("align table at the base of bottom row" "allinea la tabella alla base della riga inferiore")
("align table at the base of middle row" "allinea la tabella alla base della riga centrale")
("align table at the base of origin row" "allinea la tabella alla base della riga d'origine")
("align table at the base of top row" "allinea la tabella alla base della riga superiore")
("align table at the bottom" "allinea la tabella al fondo")
("align table at the center" "allinea la tabella al centro")
("align table at the horizontal center" "allinea la tabella al centro orizzontale")
("align table at the left" "allinea la tabella a sinistra")
("align table at the top" "allinea la tabella in alto")
("align table to the right" "allinea la tabella a destra")
("align text to the left" "allinea il testo a sinistra")
("align text to the right" "allinea il testo a destra")
("aligned" "allineato")
("alignment" "allineamento")
("all" "tutto")
("all cells" "tutte le celle")
("all data attached to this identity will be lost" "tutti i dati associati a questa identità andranno persi")
("all saved passphrases will be lost forever" "tutte le passphrase salvate andranno perse per sempre")
("allow" "permetti")
("allow for macro definitions in preamble" "permetti le definizioni di macro nel preambolo")
("allow multiple spaces" "permetti più spazi")
("allow spurious spaces" "permetti spazi spuri")
("allowed extension" "estensione permessa")
("allowed page height extension" "estensione permessa dell'altezza della pagina")
("allowed page height reduction" "riduzione permessa dell'altezza della pagina")
("allowed positions" "posizioni permesse")
("allowed reduction" "riduzione permessa")
("alpha release" "versione alfa")
("alpha transparency" "trasparenza alfa")
("also on paper" "anche su carta")
("alt key" "tasto Alt")
("alter" "altera")
("alternate" "alternativa")
("alternate except here" "alternativa tranne qui")
("alternate from here on" "alternativa da qui in poi")
("alternate only here" "alternativa solo qui")
("alternate until here" "alternativa fino a qui")
("alternative colors" "colori alternativi")
("alternative specification" "specifica alternativa")
("always" "sempre")
("american" "americano")
("amplified" "amplificato")
("ancient" "antico")
("and" "e")
("angular" "angolare")
("animate" "anima")
("animate object" "anima oggetto")
("animate objects" "anima oggetti")
("animated" "animato")
("animation" "animazione")
("animation toolbar" "barra degli strumenti animazione")
("annotate" "annota")
("answer" "risposta")
("answer field" "campo di risposta")
("answer to question" "risposta alla domanda")
("answers only" "solo risposte")
("any" "qualsiasi")
("appear" "fai apparire")
("appendix" "appendice")
("apply" "applica")
("apply macro" "applica macro")
("apply macro once" "applica macro una volta")
("approximate" "approssima")
("april" "aprile")
("arab" "arabo")
("arc" "arco")
("arc cosine" "arcocoseno")
("arc sine" "arcoseno")
("arc tangent" "arcotangente")
("archaic" "arcaico")
("architecture" "architettura")
("are you sure you want to delete collected public keys" "sei sicuro di voler eliminare le chiavi pubbliche raccolte")
("are you sure you want to delete selected public keys" "sei sicuro di voler eliminare le chiavi pubbliche selezionate")
("are you sure you want to delete selected secret keys" "sei sicuro di voler eliminare le chiavi segrete selezionate")
("are you sure you want to destroy the wallet" "sei sicuro di voler distruggere il portafoglio")
("argument" "argomento")
("arithmetic" "aritmetica")
("armenian" "armeno")
("arrow" "freccia")
("arrows" "frecce")
("article" "articolo")
("arxiv category" "categoria arxiv")
("as on paper" "come sul foglio")
("as visual grid" "come griglia visuale")
("aspect" "aspetto")
("assign" "assegna")
("at fraction bar height" "all'altezza della linea di frazione")
("at the baseline" "in linea con la base")
("at the bottom" "sul fondo")
("at the left" "a sinistra")
("at the middle" "al centro")
("at the right" "a destra")
("at the top" "in alto")
("attach" "collega")
("attach buffer to which project" "collega il buffer a quale progetto")
("attach master" "collega master")
("attached" "allegato")
("august" "agosto")
("author" "autore")
("authorize" "autorizza")
("auto" "auto")
("auto-save file" "file di salvataggio automatico")
("automatic" "automatico")
("automatic brackets" "parentesi automatiche")
("automatic content generation" "generazione automatica di contenuti")
("automatic program brackets" "parentesi automatiche nei programmi")
("automatic quotes" "virgolette automatiche")
("automatically close brackets" "chiudi automaticamente le parentesi")
("automatically generated content" "contenuto generato in modo automatico")
("automatically import bibliographies when opening files" "importa automaticamente le bibliografie all'apertura dei file")
("automatically remember all passphrases in the wallet" "ricorda automaticamente tutte le passphrase nel portafoglio")
("automatically save" "salva automaticamente")
("autosave" "salvataggio automatico")
("avoid spurious spaces" "evita spazi spuri")
("axiom" "assioma")
("axioms" "assiomi")
("axis" "asse")
("b series" "serie b")
("back" "indietro")
("background" "sfondo")
("background color" "colore di sfondo")
("background picture selector" "selettore di immagini di sfondo")
("backtrace errors" "errori di backtrace")
("backward replace" "sostituisci all'indietro")
("backward search" "cerca all'indietro")
("bad data format" "formato dei dati errato")
("bar" "barra")
("bard" "bardo")
("base" "base")
("base level" "livello della base")
("baseline" "linea di base")
("bashkirian" "bashkiriano")
("basic" "fondamentale")
("basic communication using pipes" "comunicazione di base tramite pipe")
("basic data types" "tipi fondamentali di dati")
("basic types" "tipi fondamentali")
("be useful" "rendersi utile")
("beamer formats" "formati beamer")
("beamer theme" "tema del proiettore")
("become a TeXmacs developer" "diventa uno sviluppatore TeXmacs")
("before" "prima")
("begin" "inizio")
("below" "sotto")
("beta release" "versione beta")
("bibTeX command" "comando bibTeX")
("bibliography" "bibliografia")
("bibliography file" "file della bibliografia")
("bibliography style" "stile della bibliografia")
("bidirectional" "bidirezionale")
("big" "grande")
("big figure" "figura grande")
("big operator" "operatore grande")
("big skip" "salto grande")
("big table" "tabella grande")
("binary operation" "operazione binaria")
("binary operator" "operatore binario")
("binary relation" "relazione binaria")
("bitmap resolution (dpi)" "risoluzione bitmap (dpi)")
("black" "nero")
("black floral I" "nero floreale I")
("black floral II" "nero floreale II")
("blackboard bold" "grassetto da lavagna")
("blackboard math" "matematica da lavagna")
("blackletter" "blackletter")
("blank column" "colonna vuota")
("blank row" "riga vuota")
("block" "blocco")
("block content" "contenuto del blocco")
("block of code" "blocco di codice")
("blue" "blu")
("blur" "sfoca")
("body" "corpo")
("bold" "grassetto")
("book" "libro")
("border" "bordo")
("both" "entrambi")
("both versions" "entrambe le versioni")
("bottom" "inferiore")
("bottom baseline" "linea di base inferiore")
("bottom border" "bordo inferiore")
("bottom cell border" "bordo inferiore della cella")
("bottom cell padding" "spaziatura inferiore della cella")
("bottom margin" "margine inferiore")
("bottom padding" "spaziatura inferiore")
("bottom table border" "bordo inferiore della tabella")
("bottom table padding" "spaziatura inferiore della tabella")
("box" "scatola")
("branch" "ramo")
("break" "interrompi")
("breaking" "interruzioni")
("breve" "breve")
("british" "britannico")
("brown" "marrone")
("browse" "naviga")
("browse back" "sfoglia indietro")
("browse forward" "sfoglia in avanti")
("browse modules documentation" "sfoglia la documentazione dei moduli")
("browse web" "naviga sul web")
("browser" "browser")
("buffer" "buffer")
("buffer management" "gestione buffer")
("buffer must be on disk" "il buffer deve essere su disco")
("buffer must have a name" "il buffer deve avere un nome")
("build directory" "crea directory")
("build directory in" "crea directory in")
("build link pages" "crea pagine di link")
("bulgarian" "bulgaro")
("bullet" "puntina")
("bullets" "puntine")
("busy" "occupato")
("by" "di")
("by typing" "scrivendo")
("bytes free" "byte liberi")
("bytes used" "byte usati")
("cJK spacing" "spaziatura cJK")
("calculus" "calcolo")
("calligraphic" "calligrafico")
("cancel" "cancella")
("cancelled" "cancellato")
("cannot download directory to file" "impossibile scaricare la directory nel file")
("cannot rename across different servers" "impossibile rinominare tra server diversi")
("cannot upload directory to file" "impossibile caricare la directory nel file")
("caps-lock key" "tasto Caps-lock")
("cartesian" "cartesiano")
("carved wood" "legno intagliato")
("case" "caso")
("case-insensitive search" "ricerca senza distinzione tra maiuscole e minuscole")
("categories" "categorie")
("category" "categoria")
("cc" "p.c.")
("cell" "cella")
("cell background color" "colore di sfondo della cella")
("cell border" "bordo della cella")
("cell height" "altezza della cella")
("cell operation mode" "modo operativo della cella")
("cell properties" "proprietà della cella")
("cell width" "larghezza della cella")
("cells" "celle")
("center" "centro")
("center baseline" "linea di base al centro")
("center text" "centra il testo")
("centered" "centrato")
("centered block" "blocco centrato")
("centered tabular" "tabella centrata")
("chalk" "gesso")
("change border of cell" "modifica il bordo della cella")
("change cell operation mode" "cambia il modo operativo della cella")
("change default unit" "cambia unità predefinita")
("change log" "change log")
("change passphrase" "cambia passphrase")
("change permissions" "modifica autorizzazioni")
("change step-size" "modifica lunghezza dell'incremento")
("change tags" "cambia tag")
("change the TeXmacs preferences" "modifica le preferenze di TeXmacs")
("change the border of the table" "cambia il bordo della tabella")
("change the style of mathematical formulas" "cambia lo stile delle formule matematiche")
("change wallet passphrase" "cambia passphrase del portafoglio")
("changes" "cambiamenti")
("chapter" "capitolo")
("character contraction" "contrazione del carattere")
("character encoding" "codifica dei caratteri")
("character expansion" "espansione del carattere")
("check" "controlla")
("check exported Pdf files for correctness" "controlla la correttezza dei file Pdf esportati")
("check for automatic updates" "controlla aggiornamenti automatici")
("check for updates" "controlla aggiornamenti")
("check text for spelling errors" "controllo ortografico")
("chinese" "cinese")
("choice" "scelta")
("choose background" "scegli sfondo")
("choose color" "scegli il colore")
("cipher algorithm for passphrase encryption" "algoritmo di cifratura per crittare la passphrase")
("circle" "cerchio")
("citation" "citazione")
("cite" "cita")
("class" "classe")
("classification" "classificazione")
("clean slate" "tabula rasa")
("clear" "elimina")
("clear all fields" "cancella tutti i campi")
("clear local information" "cancella le informazioni locali")
("clear menu" "cancella menu")
("clear selection" "elimina selezione")
("clear undo history" "cancella cronologia annullamenti")
("click Ok button twice to discard this warning" "fai clic due volte sul pulsante OK per eliminare questo avviso")
("clip" "ancora")
("clipboard image format" "formato immagine degli appunti")
("clipped" "ancorato")
("clipped and magnified" "ancorato e ampliato")
("clipped and resized" "ancorato e ridimensionato")
("clone" "duplica")
("clone window" "duplica la finestra")
("close" "chiudi")
("close TeXmacs" "chiudi TeXmacs")
("close animation tool" "chiudi lo strumento di animazione")
("close buffer" "chiudi il buffer")
("close document" "chiudi il documento")
("close program" "chiudi il programma")
("close replace tool" "chiudi lo strumento di sostituzione")
("close search tool" "chiudi lo strumento di ricerca")
("close session" "chiudi la sessione")
("close spell tool" "strumento il controllo ortografico")
("close translations to rebuild" "chiudi le traduzioni per ricostruire")
("close window" "chiudi la finestra")
("closed bezier" "bezier chiusa")
("closed curve" "curva chiusa")
("closed smooth" "chiusa liscia")
("closed spline" "spline chiusa")
("closing" "chiusura")
("closing style" "stile di chiusura")
("cluster by affiliation" "raggruppa per affiliazione")
("code" "codice")
("collected keys" "chiavi raccolte")
("color" "colore")
("color of the axes" "colore degli assi")
("color of the subunits" "colore delle subunità")
("color of the units" "colore delle unità")
("colors" "colori")
("column" "colonna")
("column contains glued items" "la colonna contiene elementi appiccicati")
("column separation" "separazione delle colonne")
("column to the left" "colonna a sinistra")
("column to the right" "colonna a destra")
("columns" "colonne")
("commit file" "file di commit")
("common" "comune")
("common formats" "formati comuni")
("commutative diagram" "diagramma commutativo")
("compact" "compatto")
("compactification" "compattificazione")
("compactify" "compatta")
("compare" "confronta")
("compare with" "confronta con")
("compatibility with other formats" "compatibilità con altri formati")
("compile article" "compila articolo")
("compile book" "compila libro")
("compile buffer" "compila il buffer")
("compile project" "compila il progetto")
("complete bibliographic reference" "riferimento bibliografico completo")
("completion" "completamento")
("complex" "complesso")
("complex actions" "azioni complesse")
("compose" "componi")
("compound" "composto")
("compress" "comprimi")
("compress into toolbar" "comprimi nella barra degli strumenti")
("compressed" "compresso")
("conceal" "nascondi")
("concrete" "concreto")
("condensed" "condensato")
("condition" "condizione")
("configuration" "configurazione")
("configure look and feel" "configura aspetto grafico")
("confirm collected public key deletion" "conferma l'eliminazione della chiave pubblica raccolta")
("confirm database entry" "conferma immissione database")
("confirm entry" "conferma immissione")
("confirm public key deletion" "conferma l'eliminazione della chiave pubblica")
("confirm secret key deletion" "conferma cancellazione chiave segreta")
("confirm selected database entries" "conferma voci di database selezionate")
("confirm selected entries" "conferma voci selezionate")
("confirm wallet destruction" "conferma la distruzione del portafoglio")
("conjecture" "congettura")
("conjectures" "congetture")
("conservative conversion options" "opzioni di conversione conservativa")
("consoles" "console")
("constellation" "costellazione")
("contact" "contatto")
("content" "contenuto")
("content tag" "content tag")
("context aids" "aiuti contestuali")
("context dependent icons" "icone dipendenti dal contesto")
("contextual hints" "suggerimenti contestuali")
("continuation of" "continuazione di")
("continue" "continua")
("continued fraction" "frazione continua")
("contour" "contorno")
("contract logarithms" "semplifica i logaritmi")
("contribute" "contribuisci")
("control flow" "flusso di controllo")
("control the evaluation of expressions" "controlla la valutazione delle espressioni")
("convention" "convenzione")
("conventions" "convenzioni")
("convert" "converti")
("converters" "convertitori")
("converters to other data formats" "convertitori per altri formati")
("convertible" "convertibile")
("copy" "copia")
("copy new objects to all frames" "copia nuovi oggetti in tutti i frame")
("copy new objects to previous frames" "copia nuovi oggetti nei frame precedenti")
("copy new objects to subsequent frames" "copia nuovi oggetti nei frame successivi")
("copy text" "copia testo")
("copy to" "copia in")
("copy to all frames after" "copia in tutti i frame successivi")
("copy to all frames before" "copia in tutti i frame precedenti")
("copy to all other frames" "copia in tutti gli altri frame")
("copying" "copiando")
("copyright" "copyright")
("cork charset with TeX catcode definition in preamble" "caratteri Cork (T1) con definizione del catcode TeX nel preambolo")
("cork with catcodes" "Cork (T1) con catcode")
("corollaries" "corollari")
("corollary" "corollario")
("correct" "correggi")
("correct all" "correggi tutto")
("correct formula" "correggi formula")
("correct manually" "correggi manualmente")
("correct mathematical formulas" "correggi formule matematiche")
("correct text" "correggi il testo")
("correction" "correzione")
("cosine" "coseno")
("count characters" "conta i caratteri")
("count lines" "conta le righe")
("count words" "conta le parole")
("create a new document" "crea un nuovo documento")
("create link" "crea collegamento")
("create preamble" "crea preambolo")
("create remote account" "crea account remoto")
("create remote directory" "crea directory remota")
("create remote file" "crea file remoto")
("create subprogram" "crea sottoprogramma")
("create subsession" "crea sottosessione")
("create table macro" "crea macro tabella")
("create web site" "crea sito web")
("creating new account" "creazione di un nuovo account")
("creating technical pictures" "creazione di immagini tecniche")
("crop" "ritaglio")
("crop marks" "crocini di registro")
("cross" "croce")
("crossed boxes" "scatole incrociate")
("crossed circles" "cerchi incrociati")
("current user version" "versione dell'utente attuale")
("current version" "versione attuale")
("cursor" "cursore")
("cursors" "cursori")
("curve" "curva")
("curve intersections" "intersezioni della curva")
("curve points" "punti della curva")
("custom tab" "tabulazione personalizzata")
("customizations" "personalizzazioni")
("customizing TeXmacs" "personalizzare TeXmacs")
("customizing and extending the user interface" "personalizzazione ed estensione dell'interfaccia utente")
("customizing the TeXmacs styles" "personalizzare gli stili di TeXmacs")
("cut" "taglia")
("cut text" "taglia testo")
("cut to" "taglia in")
("cyan" "ciano")
("cypriot" "cipriota")
("cyrillic" "cirillico")
("cyrillic input method" "metodo di input cirillico")
("cyrillic italic right" "cirillico corsivo a destra")
("czech" "ceco")
("dancers" "ballerini")
("danish" "danese")
("dark grey" "grigio scuro")
("dash" "trattino")
("dashes" "trattini")
("data" "dati")
("data conversion" "conversione di dati")
("data format" "formato dei dati")
("database entry" "voce del database")
("database tool" "strumento database")
("database toolbar" "barra degli strumenti database")
("date" "data")
("deactivate" "disattiva")
("deactivate once" "disattiva una volta")
("deactivate table" "disattiva tabella")
("dead" "morto")
("debugging console" "console di debug")
("debugging tool" "strumento di debug")
("december" "dicembre")
("decimal comma" "virgola decimale")
("decimal dot" "punto decimale")
("decomposed" "decomposto")
("decorate atoms" "decora atomi")
("decorated" "decorato")
("decorated wood" "legno decorato")
("decorative" "decorativo")
("decrease size" "riduci dimensioni")
("decrypt" "decritta")
("decrypted" "decrittato")
("decryption" "deccrittazione")
("default" "predefinito")
("default padding" "spaziatura predefinita")
("default size" "dimensione predefinita")
("definition" "definizione")
("definitions" "definizioni")
("degrade" "degrada")
("degraded" "degradato")
("delete" "cancella")
("delete column" "cancella colonna")
("delete documentation cache" "svuota cache documentazione")
("delete entries" "elimina voci")
("delete link" "elimina collegamento")
("delete row" "cancella riga")
("delete selected entries in wallet" "elimina le voci selezionate nel portafoglio")
("delete user identity" "elimina identità utente")
("deleted" "cancellato")
("denominator" "denominatore")
("describe" "descrivi")
("describe tag" "descrivi tag")
("description" "descrizione")
("destination" "destinazione")
("destroy" "distruggi")
("detach" "scollega")
("detach master" "scollega master")
("detailed" "dettagliato")
("detailed menus" "menu dettagliati")
("details in menus" "dettagli nei menu")
("determinant" "determinante")
("determine margins from text width" "determina i margini dalla larghezza del testo")
("devangari" "devanagari")
("developer" "sviluppatore")
("developer tool" "strumento per gli sviluppatori")
("developers guide" "guida per gli sviluppatori")
("device" "dispositivo")
("diamond" "diamante")
("differentiate" "differenzia")
("digital" "digitale")
("dilate" "dilata")
("direction of progression" "direzione della progressione")
("direction of translation" "direzione della traslazione")
("directory" "directory")
("disable" "disabilita")
("disable coloring on paper" "disabilita colorazione su carta")
("disable encryption" "disabilita crittografia")
("disable first indentation" "disabilita prima indentazione")
("disable first indentation after" "disabilita prima indentazione successiva")
("disable first indentation before" "disabilita prima indentazione precedente")
("disable indentation" "disabilita indentazione")
("disable indentation after" "disabilita indentazione successiva")
("disable indentation before" "disabilita indentazione precedente")
("disable last indentation" "disabilita l'ultima indentazione")
("disable last indentation after" "disabilita l'ultima indentazione successiva")
("disable last indentation before" "disabilita l'ultima indentazione precedente")
("disabled" "disabilitato")
("disallow" "proibisci")
("disappear" "fai sparire")
("disk" "disco")
("display style" "stile di visualizzazione")
("displayed formula" "formula visualizzata")
("dissociate joined cells" "separa celle unite")
("distill encapsulated Pdf files" "distilla file Pdf incapsulati")
("distort" "distorci")
("distorted" "distorto")
("distribute unused space" "distribuisci spazio inutilizzato")
("div" "div")
("division" "divisione")
("do not remap" "non rimappare")
("document" "documento")
("document colors" "colori del documento")
("document font selector" "selettore font del documento")
("document format" "formato del documento")
("document language" "lingua del documento")
("document metadata" "metadati del documento")
("document page format" "formato pagina del documento")
("document paragraph format" "formato paragrafo del documento")
("document source tree preferences" "preferenze dell'albero sorgente del documento")
("document style" "stile del documento")
("document styles" "stili di documento")
("document updates run" "aggiorna il documento")
("documentation" "documentazione")
("documents are trees" "i documenti sono alberi")
("documents in separate windows" "documenti in finestre separate")
("dot" "punto")
("dots" "puntini")
("double stroke" "tratto doppio")
("down" "sotto")
("download" "scarica")
("download file or directory" "scarica file o directory")
("downwards" "verso il basso")
("dpi" "dpi")
("dragging" "trascinamento")
("draw" "disegna")
("draw graphics" "disegna grafici")
("draw image" "disegna immagine")
("draw over" "disegna sopra")
("draw over selection" "disegna sopra la selezione")
("due to" "dovuto a")
("duplicate" "duplica")
("dutch" "olandese")
("dynamic" "dinamico")
("dynamic libraries" "librerie dinamiche")
("eRROR" "ERRORE")
("edit" "modifica")
("edit animation" "modifica animazione")
("edit groups of objects" "modifica gruppi di oggetti")
("edit macro" "modifica macro")
("edit macros" "modifica macro")
("edit object properties" "modifica le proprietà dell'oggetto")
("edit preamble" "modifica il preambolo")
("edit source" "modifica il sorgente")
("edit source tree" "modifica l'albero sorgente")
("edit style" "modifica stile")
("edit translations file" "modifica il file delle traduzioni")
("editing tools" "strumenti di editing")
("education" "istruzione")
("eigenvalues" "autovalori")
("eighth" "ottavo")
("email" "email")
("embold" "metti in grassetto")
("emboss" "metti in rilievo")
("emphasize" "enfatizza")
("emphasize text" "scrivi testo enfatizzato")
("empty box" "box vuoto")
("enable first indentation" "abilita prima indentazione")
("enable first indentation after" "abilita prima indentazione successiva")
("enable first indentation before" "abilita prima indentazione precedente")
("enable indentation" "abilita indentazione")
("enable indentation after" "abilita indentazione precedente")
("enable indentation before" "abilita indentazione successiva")
("enable last indentation" "abilita l'ultima indentazione")
("enable last indentation after" "abilita l'ultima indentazione successiva")
("enable last indentation before" "abilita l'ultima indentazione precedente")
("enable page breaking" "abilita interruzione di pagina")
("enabled" "abilitato")
("encl" "encl")
("encoding" "codifica")
("encrypt" "critta")
("encrypted" "crittato")
("encrypted buffer" "buffer crittato")
("encryption" "crittografia")
("encryption error" "errore di crittografia")
("encryption facilities are not currently available" "le funzionalità crittografiche non sono attualmente disponibili")
("encryption facilities have not been enabled for TeXmacs" "Le funzionalità crittografiche non sono state abilitate per TeXmacs")
("end" "fine")
("enforce brackets to match" "imponi che le parentesi corrispondano")
("english" "inglese")
("engrave" "incidi")
("enter a title" "inserisci un titolo")
("enter data" "inserisci dati")
("enter graphics" "inserisci grafici")
("enter graphics mode" "entra in modalità grafica")
("enter new passphrase for encryption" "inserisci una nuova passphrase per la crittazione")
("enter passphrase for decryption" "inserisci passphrase per la decrittazione")
("enter passphrase for identity" "inserisci passphrase per l'identità")
("enter title information" "inserisci informazioni sul titolo")
("entire table" "tabella intera")
("entry up to date in database" "voce aggiornata nel database")
("enumerate" "lista numerata")
("enumerate|Alpha" "numerazione|Alfa")
("enumerate|Roman" "numerazione|Romano")
("enumerate|alpha" "numerazione|alfa")
("enumerate|roman" "numerazione|romano")
("enunciation" "enunciato")
("env" "env")
("environment" "ambiente")
("environment variable" "variabile d'ambiente")
("environments" "ambienti")
("epilogue" "epilogo")
("equal" "uguale")
("equation" "equazione")
("equations" "equazioni")
("equivalent for" "equivalente per")
("erode" "erodi")
("error" "errore")
("error messages" "messaggi di errore")
("error output" "errore in uscita")
("error status report" "rapporto sullo stato dell'errore")
("error: bracket does not match" "errore: la parentesi non corrisponde")
("error: cyclic or missing chunks detected" "errore: rilevati blocchi ciclici o mancanti")
("error: file not found" "errore: file non trovato")
("error: ghostview does not seem to be installed on your system" "errore: ghostview sembra non essere installato sul tuo sistema")
("error: one of the alternatives should be filled out" "errore: una delle alternative dovrebbe essere compilata")
("error: only one alternatives should be filled out" "errore: compila solo un'alternativa")
("error: should fill out name for referencing" "errore: va inserito il nome per il riferimento")
("error: should fill out required field" "errore: va compilato il campo richiesto")
("escape" "Esc")
("esperanto" "esperanto")
("etruscan" "etrusco")
("evaluable field" "campo valutabile")
("evaluate" "valuta")
("evaluate above" "valuta sopra")
("evaluate all" "valuta tutto")
("evaluate below" "valuta sotto")
("evaluate fields" "valuta i campi")
("evaluate fields in order" "valuta i campi in ordine")
("evaluate scheme expression" "valuta espressione scheme")
("evaluate script" "valuta lo script")
("evaluation" "valutazione")
("evaluation switch" "interruttore di valutazione")
("evaluation tag" "tag di valutazione")
("even page" "pagina pari")
("even page footer" "piè di pagina (pagine pari)")
("even page header" "intestazione (pagine pari)")
("even page left margin" "margine sinistro (pagine pari)")
("even page margin" "margine (pagine pari)")
("even page shift" "spostamento (pagine pari)")
("even page text" "testo (pagine pari)")
("even pages" "pagine pari")
("events" "eventi")
("exact" "esatto")
("exact horizontal" "orizzontale esatta")
("exact mode" "modo esatto")
("exam" "esame")
("example" "esempio")
("exclusive" "esclusivo")
("exclusive or" "o esclusivo")
("executable" "eseguibile")
("execute" "esegui")
("execute a TeXmacs command" "esegui un comando TeXmacs")
("execute system command" "esegui un comando di sistema")
("execution of scripts" "esecuzione di script")
("executive" "esecutivo")
("exercise" "esercizio")
("exercises" "esercizi")
("exit graphics" "esci dai grafici")
("exit graphics mode" "esci dalla modalità grafica")
("exit left" "esci a sinistra")
("exit right" "esci a destra")
("exit tag on the left" "esci dal tag verso sinistra")
("exit tag on the right" "esci dal tag verso destra")
("expand" "espandi")
("expand TeXmacs macros with no LaTeX equivalents" "espandi le macro TeXmacs senza equivalenti in LaTeX")
("expand beamer slides" "espandi le diapositive beamer")
("expand inclusions" "espandi le inclusioni")
("expand logarithms" "espandi i logaritmi")
("expand trigonometric functions" "espandi le funzioni trigonometriche")
("expand unrecognized macros" "espandi le macro non riconosciute")
("expand user-defined macros" "espandi le macro definite dall'utente")
("expanded" "espanso")
("experimental features (to be used with care)" "caratteristiche sperimentali (da usare con prudenza)")
("explain" "spiega")
("explained" "spiegato")
("explanatory item" "punto esplicativo")
("explicit margins" "margini espliciti")
("exponential" "esponenziale")
("export" "esporta")
("export as" "esporta come")
("export bibliographies as links" "esporta bibliografie come link")
("export bibliography" "esporta bibliografia")
("export entries in buffer" "esporta voci nel buffer")
("export file" "esporta file")
("export formulas as images" "esporta formule come immagini")
("export mathematical formulas as MathML" "esporta formule matematiche come MathML")
("export mathematical formulas as images" "esporta formule matematiche come immagini")
("export selected entries" "esporta voci selezionate")
("export selection" "esporta selezione")
("export selection as image" "esporta selezione come immagine")
("export selections as" "esporta selezioni come")
("export sessions" "sessioni di esportazione")
("exported bibliographic entries" "voci bibliografiche esportate")
("exported bibliographic references" "riferimenti bibliografici esportati")
("extend" "estendi")
("extend or normal" "esteso o normale")
("extend table to full paragraph width" "estendi la tabella alla larghezza del paragrafo")
("extended" "esteso")
("extensible left arrow" "freccia sinistra estensibile")
("extensible right arrow" "freccia destra estensibile")
("extern" "esterno")
("external" "esterno")
("extra" "extra")
("extra branch" "ramo extra")
("extra interline space" "spazio interlinea extra")
("extra name" "nome extra")
("extract" "estrai")
("extract format" "estrai formato")
("extract style file" "estrai file di stile")
("extract style package" "estrai pacchetto di stile")
("factor" "fattore")
("fade" "dissolvenza")
("fade in" "dissolvenza in entrata")
("fade out" "dissolvenza in uscita")
("family" "famiglia")
("fast" "veloce")
("fast decrease" "riduci rapidamente")
("fast environments" "ambienti veloci")
("fast increase" "aumenta rapidamente")
("february" "febbraio")
("fifth" "quinto")
("figure" "figura")
("figures" "figure")
("file" "file")
("file name" "nome del file")
("file not found" "file non trovato")
("file saved" "file salvato")
("fill color" "colore di riempimento")
("fill out" "compila")
("filter" "filtra")
("find file" "trova file")
("find next match" "trova la prossima occorrenza")
("find text" "trova testo")
("finished collecting symbols documentation" "documentazione sulla raccolta dei simboli completata")
("finnish" "finlandese")
("first" "primo")
("first chunk" "primo pezzo")
("first contact" "primo contatto")
("first difference" "prima differenza")
("first error" "primo errore")
("first field" "primo campo")
("first indentation" "prima indentazione")
("first item" "primo elemento")
("first occurrence" "prima occorrenza")
("first page" "prima pagina")
("first similar" "primo simile")
("first start" "primo avvio")
("fit" "adatta")
("fit to height" "adatta all'altezza")
("fit to screen" "adatta allo schermo")
("fit to screen width" "adatta alla larghezza dello schermo")
("fit to width" "adatta alla larghezza")
("five columns" "cinque colonne")
("fixed" "fisso")
("flag is off" "flag disattivata")
("flag is on" "flag attivata")
("flat" "piatto")
("flatten" "appiattisci")
("flexibility" "flessibilità")
("flexibility factor for vertical spacing" "fattore di flessibilità per la spaziatura verticale")
("floating algorithm" "algoritmo fluttuante")
("floating figure" "figura fluttuante")
("floating object" "oggetto fluttuante")
("floating phantom" "fantasma fluttuante")
("floating table" "tabella fluttuante")
("focus" "focus")
("focus dependent icons" "icone dipendenti dal focus")
("fold" "arrotola")
("fold all" "arrotola tutto")
("fold all fields" "arrotola tutti i campi")
("fold back" "riarrotola")
("fold input field" "arrotola campo di input")
("folded" "arrotolato")
("follow external links" "segui link esterni")
("follow inverse links" "segui collegamenti inversi")
("font" "carattere")
("font base size" "dimensione di base del carattere")
("font customization" "personalizzazione del carattere")
("font dpi" "risoluzione del carattere (dpi)")
("font effects" "effetti del carattere")
("font family" "famiglia del carattere")
("font name" "nome del carattere")
("font selector" "selettore del carattere")
("font series" "serie del carattere")
("font shape" "forma del carattere")
("font size" "dimensione del carattere")
("font type" "tipo del carattere")
("font variant" "variante del carattere")
("fonts" "tipi di carattere")
("footer" "piè di pagina")
("footnote" "nota a piè di pagina")
("for" "per")
("for each" "per ciascuno")
("force reloading of translations" "imponi un nuovo caricamento delle traduzioni")
("foreground" "primo piano")
("foreign" "straniero")
("format" "formato")
("formatted and structured output" "output formattato e strutturato")
("formatted date" "data formattata")
("formatting" "formattazione")
("formula" "formula")
("formula style" "stile della formula")
("forward" "avanti")
("forward replace" "sostituisci in avanti")
("forward search" "cerca in avanti")
("four columns" "quattro colonne")
("four dots" "quattro punti")
("fourth" "quarto")
("fraction" "frazione")
("fraktur" "fraktur")
("framed" "incorniciato")
("framed theorems" "teoremi con cornice")
("french" "francese")
("from" "da")
("from center" "dal centro")
("front matter" "materiale iniziale")
("full" "pieno")
("full author list" "elenco completo degli autori")
("full manuals" "manuali completi")
("full screen mode" "modalità schermo intero")
("function" "funzione")
("functional" "funzionale")
("further customization" "ulteriore personalizzazione")
("future changes" "cambiamenti futuri")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs viene distribuito senza alcuna forma di garanzia legale")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs è distribuito sotto i termini della GNU general public license (GNU GPL)")
("gap" "scarto")
("garbage collection" "garbage collection")
("gaussian" "gaussiano")
("gcd" "mcd")
("general" "generale")
("general architecture of TeXmacs" "architettura generale di TeXmacs")
("general negation" "negazione generale")
("general note" "nota generale")
("generate GnuPG key" "genera chiave GnuPG")
("generated LaTeX document contains no errors" "il documento LaTeX generato non contiene errori")
("generated field" "campo generato")
("generating font file" "sto generando il file del font")
("generic" "generico")
("geometry" "geometria")
("georgian" "georgiano")
("german" "tedesco")
("get arity" "ottieni arity")
("get label" "ottieni etichetta")
("get list with remote versions" "ottieni elenco con versioni remote")
("getting started" "primi passi")
("global log" "registro globale")
("global status" "stato globale")
("glossary" "glossario")
("glossary entry" "voce del glossario")
("glue" "appiccica")
("glue decorations" "appiccica le decorazioni")
("glue multiple spaces" "appiccica più spazi")
("glyphs" "glifi")
("gnaw" "rosicchia")
("gnawed" "rosicchiato")
("gnuPG command" "comando gnuPG")
("gnuPG decryption error" "errore di decrittazione gnuPG")
("gnuPG error: buffer encryption failed" "Errore gnuPG: crittazione buffer non riuscita")
("gnuPG error: cannot find suitable secret key to decrypt" "errore gnuPG: impossibile trovare la chiave segreta adatta per decrittare")
("gnuPG requires name and email to have at least 5 characters" "gnuPG richiede che il nome e l'e-mail abbiano almeno 5 caratteri")
("go" "vai")
("go to anchor" "vai all'ancoraggio")
("go to anchor or float" "vai all'ancoraggio o al fluttuante")
("go to anchor or footnote" "vai all'ancoraggio o alla nota")
("go to first similar tag" "vai al primo tag simile")
("go to float" "vai al fluttuante")
("go to footnote" "vai alla nota")
("go to last similar tag" "vai all'ultimo tag simile")
("go to next similar tag" "vai al prossimo tag simile")
("go to previous similar tag" "vai al precedente tag simile")
("go to section" "vai alla sezione")
("gothic" "gotico")
("grain" "sgranatura")
("granite" "granito")
("graphical effects" "effetti grafici")
("graphical interface" "interfaccia grafica")
("graphical interface font scale" "riscalamento dei caratteri dell'interfaccia grafica")
("graphical overlays" "overlay grafici")
("graphical slides and overlays" "diapositive e overlay grafici")
("graphics" "grafica")
("graphics geometry" "geometria della grafica")
("graphics grids" "griglie grafiche")
("grave" "grave")
("greater" "maggiore")
("greater or equal" "maggiore o uguale")
("greek" "greco")
("greek letter" "lettera greca")
("green" "verde")
("grey" "grigio")
("greyed" "in grigio")
("grid" "griglia")
("grid curves" "curve della griglia")
("grid points" "punti della griglia")
("grid-curve intersections" "intersezioni griglia-curva")
("group" "raggruppa")
("group of objects" "gruppo di oggetti")
("group/ungroup" "raggruppa/separa")
("group/ungroup objects" "raggruppa/separa oggetti")
("grouped" "raggruppati")
("guarantee transparent source tracking" "garantisci tracciamento trasparente del sorgente")
("h modifier" "modificatore h")
("half wide" "media larghezza")
("hand drawn" "disegnati a mano")
("handwritten" "scritto a mano")
("hangul" "hangul")
("happy typing" "buona scrittura")
("has been aborted" "è stato interrotto")
("has completed its task" "ha completato il suo compito")
("hat" "cappello")
("header" "intestazione")
("header and footer" "intestazione e piè di pagina")
("headers" "intestazioni")
("hebrew" "ebraico")
("height" "altezza")
("height is exactly the specified height" "l'altezza è esattamente quella specificata")
("height is maximum of specified height and box height" "l'altezza è la massima tra l'altezza specificata e l'altezza del box")
("height is minimum of specified height and box height" "l'altezza è la minima tra l'altezza specificata e l'altezza del box")
("height magnification" "moltiplicatore dell'altezza")
("help" "aiuto")
("help me" "aiutami")
("help us" "aiutaci")
("here" "qui")
("hidden" "nascosto")
("high resolution settings" "impostazioni per alta risoluzione")
("history" "cronologia")
("home" "inizio")
("homepage" "homepage")
("homoglyph substitutions" "sostituzioni di omoglifi")
("horizontal" "orizzontale")
("horizontal alignment" "allineamento orizzontale")
("horizontal cell alignment" "allineamento orizzontale della cella")
("horizontal ink separation" "separazione orizzontale dell'inchiostro")
("horizontal margins" "margini orizzontali")
("horizontal part" "parte orizzontale")
("horizontal position" "posizione orizzontale")
("horizontal space" "spazio orizzontale")
("horizontal table alignment" "allineamento orizzontale della tabella")
("horizontally align cell to the base" "allinea la cella orizzontalmente con la base")
("horizontally center the cell" "centra la cella orizzontalmente")
("how much longer may pages become" "quanto più lunghe potrebbero diventare le pagine")
("how much shorter may pages become" "quanto più corte potrebbero diventare le pagine")
("huge" "enorme")
("hungarian" "ungherese")
("hybrid command" "comando ibrido")
("hyperlink" "collegamento ipertestuale")
("hyphenate as" "sillaba come")
("hyphenation" "sillabazione")
("icelandic" "islandese")
("icon" "icona")
("if" "se")
("if hyphenated" "se sillabato")
("ignore" "ignora")
("image" "immagine")
("image links" "inserisci un'immagine (collegamento)")
("implementation" "implementazione")
("import" "importa")
("import bibliography" "importa bibliografia")
("import database entry" "importa voce del database")
("import entries in buffer" "importa voci nel buffer")
("import entry" "importa voce")
("import file" "importa file")
("import public keys from buffer" "importa chiavi pubbliche dal buffer")
("import selected database entries" "importa le voci del database selezionate")
("import selected entries" "importa le voci selezionate")
("import selections as" "importa selezioni come")
("import sessions" "importa sessioni")
("import sophisticated objects as pictures" "importa oggetti sofisticati come immagini")
("imported bibliographic entries" "voci bibliografiche importate")
("improving the current implementation" "migliorare l'implementazione attuale")
("in popup windows" "nelle finestre popup")
("inactive" "inattivo")
("inanimated" "inanimato")
("inch" "pollice")
("inches" "pollici")
("include" "includi")
("include a document" "includi un documento")
("include a file" "includi un file")
("include file" "includi file")
("inclusion into TeXmacs" "inclusione in TeXmacs")
("inclusions" "inclusioni")
("incomplete entries found to be filled out" "trovate voci incomplete da compilare")
("increase size" "aumenta dimensioni")
("indent" "indenta")
("indent paragraphs" "indenta i paragrafi")
("indentation" "rientro")
("indentation flag" "simbolo di indentazione")
("index" "indice analitico")
("index entry" "voce dell'indice analitico")
("index level" "livello dell'indice analitico")
("indication" "indicazione")
("inflate" "gonfia")
("informative flags" "flag informative")
("initialize" "inizializza")
("initialize wallet" "inizializza portafoglio")
("initials" "iniziali")
("ink here" "disegna qui")
("ink in" "ricalca")
("ink out" "rimuovi inchiostro")
("inline" "in linea")
("inline args" "inline args")
("inline arguments" "argomenti in linea")
("inline code" "codice in linea")
("inline content" "contenuto in linea")
("inline formula" "formula in linea")
("inner bottom" "interno inferiore")
("inner left" "interno sinistro")
("inner right" "interno destro")
("inner top" "interno superiore")
("input command" "comando di input")
("input field" "campo di input")
("input mode" "modalità input")
("input options" "opzioni di input")
("insert" "inserisci")
("insert Pr" "inserisci Pr")
("insert a TeXmacs symbol" "inserisci un simbolo di TeXmacs")
("insert a big operator" "inserisci un operatore grande")
("insert a binary operation" "inserisci un'operazione binaria")
("insert a binary relation" "inserisci una relazione binaria")
("insert a blackboard bold character" "inserisci un carattere lavagna grassetto")
("insert a bold calligraphic character" "inserisci un carattere calligrafico grassetto")
("insert a bold character" "inserisci un carattere grassetto")
("insert a calligraphic character" "inserisci un carattere calligrafico")
("insert a computer program" "inserisci un programma per computer")
("insert a condition" "inserisci una condizione")
("insert a control flow instruction" "inserisci un'istruzione di flusso di controllo")
("insert a fraction" "inserisci una frazione")
("insert a fraktur character" "inserisci un carattere fraktur")
("insert a gap" "inserisci uno spazio")
("insert a greek character" "inserisci un carattere greco")
("insert a large left delimiter" "inserisci un delimitatore sinistro grande")
("insert a large right delimiter" "inserisci un delimitatore destro grande")
("insert a large separator" "inserisci un separatore grande")
("insert a left subscript" "inserisci pedice sinistro")
("insert a link" "inserisci un collegamento")
("insert a list" "inserisci un elenco")
("insert a miscellaneous symbol" "inserisci un simbolo (altro...)")
("insert a multiple choice" "inserisci una scelta multipla")
("insert a negation" "inserisci una negazione")
("insert a new branch" "inserisci un nuovo ramo")
("insert a new entry" "inserisci una nuova voce")
("insert a new item" "inserisci un nuovo elemento")
("insert a note or a floating object" "inserisci una nota o un oggetto fluttuante")
("insert a numerical operation" "inserisci un'operazione numerica")
("insert a picture" "inserisci un'immagine")
("insert a prominent piece of text" "inserisci un pezzo di testo in evidenza")
("insert a question" "inserisci una domanda")
("insert a root" "inserisci una radice")
("insert a script" "inserisci uno script")
("insert a section block" "inserisci un blocco di sezione")
("insert a square root" "inserisci una radice quadrata")
("insert a table" "inserisci una tabella")
("insert a table or a matrix" "inserisci una tabella o una matrice")
("insert a textual operation" "inserisci un'operazione testuale")
("insert a textual operator" "inserire un operatore testuale")
("insert a wide symbol above" "inserisci un simbolo largo sopra")
("insert a wide symbol below" "inserisci un simbolo largo sotto")
("insert above" "inserisci sopra")
("insert abstract" "inserisci riassunto")
("insert an" "inserisci un/a")
("insert an accent" "inserisci un accento")
("insert an answer" "inserisci una risposta")
("insert an arrow" "inserisci una freccia")
("insert an enunciation" "inserisci un enunciato")
("insert an environment" "inserisci un nuovo ambiente")
("insert an n" "inserisci un/a n")
("insert an operation on tuples" "inserisci un'operazione su tuple")
("insert annotation" "inserisci annotazione")
("insert appendix" "inserisci appendice")
("insert arccos" "inserisci arcocoseno")
("insert arcs" "inserisci archi")
("insert arcsin" "inserisci arcoseno")
("insert arctan" "inserisci arcotangente")
("insert arg" "inserisci arg")
("insert argument" "inserisci argomento")
("insert argument after" "inserisci argomento dopo")
("insert argument before" "inserisci argomento prima")
("insert author" "inserisci autore")
("insert automatically generated content" "inserisci contenuto generato automaticamente")
("insert below" "inserisci sotto")
("insert bibliography" "inserisci bibliografia")
("insert big contour integral" "inserisci integrale curvilineo grande")
("insert big coproduct" "inserisci coproduttoria grande")
("insert big direct sum" "inserisci somma diretta grande")
("insert big dotted point" "inserisci punto-prodotto grande")
("insert big integral" "inserisci integrale grande")
("insert big intersection" "inserisci intersezione grande")
("insert big logical and" "inserisci AND logico grande")
("insert big logical or" "inserisci OR logico grande")
("insert big product" "inserisci produttoria grande")
("insert big square union" "inserisci unione quadrata grande")
("insert big summation" "inserisci grande sommatoria")
("insert big tensor product" "inserisci prodotto tensoriale grande")
("insert big union" "inserisci unione grande")
("insert big union sum" "inserisci somma unione grande")
("insert big vertical space" "inserisci spazio verticale grande")
("insert chapter" "inserisci capitolo")
("insert circles" "inserisci cerchi")
("insert closed splines" "inserisci spline chiuse")
("insert column" "inserisci colonna")
("insert column to the left" "inserisci colonna a sinistra")
("insert column to the right" "inserisci colonna a destra")
("insert copyright and license information" "inserisci informazioni sul copyright e sulla licenza")
("insert cos" "inserisci cos")
("insert cosh" "inserisci cosh")
("insert cot" "inserisci cot")
("insert coth" "inserisci coth")
("insert csc" "inserisci csc")
("insert deg" "inserisci deg")
("insert det" "inserisci det")
("insert dim" "inserisci dim")
("insert dollar" "inserisci dollaro")
("insert equation" "inserisci equazione")
("insert executable markup" "inserisci marcatura eseguibile")
("insert exp" "inserisci exp")
("insert explanatory item" "inserisci punto esplicativo")
("insert field above" "inserisci campo sopra")
("insert field below" "inserisci campo sotto")
("insert fields" "inserisci campi")
("insert footnote" "inserisci nota a piè di pagina")
("insert formula" "inserisci formula")
("insert gcd" "inserisci mcd")
("insert hand drawn curves" "inserisci curve disegnate a mano")
("insert hom" "inserisci hom")
("insert horizontal interword space" "inserisci spazio orizzontale tra le parole")
("insert image" "inserisci immagine")
("insert inactive markup" "inserisci marcatura inattiva")
("insert inf" "inserisci inf")
("insert input field above" "inserisci campo di input sopra")
("insert input field below" "inserisci campo di input sotto")
("insert ker" "inserisci ker")
("insert large delimiters" "inserisci delimitatori grandi")
("insert last name" "inserisci cognome")
("insert left" "inserisci a sinistra")
("insert lg" "inserisci lg")
("insert lim" "inserisci lim")
("insert liminf" "inserisci liminf")
("insert limsup" "inserisci limsup")
("insert lines" "inserisci righe")
("insert ln" "inserisci ln")
("insert log" "inserisci log")
("insert macro" "inserisci macro")
("insert mathematics" "inserisci matematica")
("insert max" "inserisci max")
("insert medium horizontal space" "inserisci spazio orizzontale medio")
("insert medium vertical space" "inserisci spazio verticale medio")
("insert min" "inserisci min")
("insert missing invisible operators" "inserisci operatori invisibili mancanti")
("insert more names" "inserisci più nomi")
("insert multiple paragraphs" "inserisci più paragrafi")
("insert negative horizontal space" "inserisci spazio orizzontale negativo")
("insert new item or number" "inserisci nuovo elemento o numero")
("insert new rows or columns" "inserisci nuove righe o colonne")
("insert or delete rows or columns" "inserisci o cancella righe o colonne")
("insert overlay after" "inserisci overlay dopo")
("insert overlay before" "inserisci overlay prima")
("insert particle" "inserisci particella")
("insert plain text" "inserisci testo semplice")
("insert points" "inserisci punti")
("insert polygons" "inserisci poligoni")
("insert right" "inserisci a destra")
("insert row" "inserisci riga")
("insert row above" "inserisci riga sopra")
("insert row below" "inserisci riga sotto")
("insert sec" "inserisci sec")
("insert section" "inserisci sezione")
("insert sharp" "inserisci diesis")
("insert similar above" "inserisci simile sopra")
("insert similar below" "inserisci simile sotto")
("insert similar block above" "inserisci blocco simile sopra")
("insert similar block below" "inserisci blocco simile sotto")
("insert sin" "inserisci sin")
("insert sinh" "inserisci sinh")
("insert slide after" "inserisci diapositiva dopo")
("insert slide before" "inserisci diapositiva prima")
("insert small horizontal space" "inserisci spazio orizzontale piccolo")
("insert small vertical space" "inserisci spazio verticale piccolo")
("insert splines" "inserisci spline")
("insert structural markup" "inserisci marcatura strutturale")
("insert subscript" "inserisci pedice")
("insert subsection" "inserisci sotto-sezione")
("insert subsubsection" "inserisci sotto-sotto-sezione")
("insert subtable" "inserisci sottotabella")
("insert sup" "inserisci sup")
("insert superscript" "inserisci apice")
("insert symbol documentation" "inserisci la documentazione dei simboli")
("insert tan" "inserisci tan")
("insert tanh" "inserisci tanh")
("insert template" "inserisci modello")
("insert text" "inserisci testo")
("insert text field" "inserisci campo di testo")
("insert text field above" "inserisci campo di testo sopra")
("insert text field below" "inserisci campo di testo sotto")
("insert thick horizontal space" "inserisci spazio orizzontale spesso")
("insert title" "inserisci titolo")
("insert title after name" "inserisci titolo dopo nome")
("insert user interface related markup" "inserisci markup relativo all'interfaccia utente")
("insert value" "inserisci valore")
("inserting control points" "inserimento punti di controllo")
("inside mathematics" "in modalità matematica")
("integrate" "integra")
("interactive command" "comando interattivo")
("interactive questions" "domande interattive")
("intercharacter compression" "compressione tra caratteri")
("intercharacter stretching" "allargamento tra caratteri")
("interfacing" "interfacciare")
("interfacing TeXmacs with other systems" "interfacciare TeXmacs con altri sistemi")
("interjection" "interiezione")
("interline separation" "separazione interlinea")
("interline space" "spaziatura interlinea")
("internationalization" "internazionalizzazione")
("interparagraph space" "spaziatura tra paragrafi")
("interrupt execution" "interrompi esecuzione")
("interrupted" "interrotto")
("introduction" "introduzione")
("invalid multi-paragraph selection" "selezione multiparagrafo non valida")
("invalid renaming" "ridenominazione non valida")
("invert" "inverti")
("inverted breve" "breve inverso")
("invisible" "invisibile")
("invisible citation" "citazione invisibile")
("invisible ending" "finale invisibile")
("invisible newline" "a capo invisibile")
("invisible opening" "apertura invisibile")
("inwards" "verso l'interno")
("irish" "irlandese")
("is running" "è in esecuzione")
("is tuple" "è una tupla")
("ispell does not respond" "ispell non risponde")
("ispell is already busy" "ispell è già in esecuzione")
("italian" "italiano")
("italic" "corsivo")
("italic right" "corsivo a destra")
("itemize" "lista puntata")
("january" "gennaio")
("japanese" "giapponese")
("join selected cells" "unisci le celle selezionate")
("july" "luglio")
("june" "giugno")
("junior" "junior")
("justified" "giustificato")
("justify" "giustifica")
("justify text" "giustifica il testo")
("keep evaluated expressions" "mantieni le espressioni valutate")
("keep local" "mantieni locale")
("keep remote" "mantieni remoto")
("keep track of source code" "tieni traccia del codice sorgente")
("keep unfolded" "mantieni aperto")
("key" "chiave")
("key manager" "gestore chiavi")
("keyboard" "tastiera")
("keyboard configuration" "configurazione della tastiera")
("keyboard equivalent" "equivalente da tastiera")
("keyboard modifiers" "modificatori da tastiera")
("keyboard shortcut" "scorciatoia da tastiera")
("keymaps" "mappe di tastiera")
("keyword" "parola chiave")
("keywords" "parole chiave")
("kill" "uccidi")
("known bugs" "bug noti")
("laTeX errors" "errori laTeX")
("label" "etichetta")
("landscape" "orizzontale")
("language" "lingua")
("laptop presentations" "presentazioni per laptop")
("large" "grande")
("large brackets" "parentesi grandi")
("large cells" "celle grandi")
("large closing bracket" "parentesi chiusa grande")
("large delimiter" "delimitatore grande")
("large displayed" "visualizzata grande")
("large displayed fraction" "frazione visualizzata grande")
("large opening bracket" "parentesi aperta grande")
("large separator" "separatore grande")
("large tables" "tabelle grandi")
("last" "ultimo")
("last check" "ultimo controllo")
("last difference" "ultima differenza")
("last error" "ultimo errore")
("last field" "ultimo campo")
("last indentation" "ultima indentazione")
("last name" "cognome")
("last occurrence" "ultima occorrenza")
("last page" "ultima pagina")
("last similar" "ultimo simile")
("latex command" "comando LaTeX")
("latin" "latino")
("layout" "impaginazione")
("lcm" "mcm")
("left" "sinistra")
("left aligned" "allineato a sinistra")
("left arrow" "freccia sinistra")
("left axis" "asse sinistro")
("left baseline" "linea di base a sinistra")
("left border" "bordo sinistro")
("left bottom" "in basso a sinistra")
("left cell border" "bordo sinistro della cella")
("left cell padding" "spaziatura sinistra della cella")
("left center" "a sinistra al centro")
("left click: add point; Right click: undo" "clic sinistro: aggiungi punto; clic destro: annulla")
("left click: finish; Right click: undo" "clic sinistro: fine; clic destro: annulla")
("left click: new object" "clic sinistro: nuovo oggetto")
("left click: operate" "click sinistro: opera")
("left down" "a sinistra in basso")
("left margin" "margine sinistro")
("left on even pages" "a sinistra sulle pagine pari")
("left padding" "spaziatura sinistra")
("left prime" "primo a sinistra")
("left slanted" "inclinato a sinistra")
("left subscript" "pedice a sinistra")
("left superscript" "apice a sinistra")
("left surrounding" "surrounding a sinistra")
("left table border" "bordo sinistro della tabella")
("left table padding" "spaziatura sinistra della tabella")
("left top" "in alto a sinistra")
("left up" "a sinistra in alto")
("left-right arrow" "freccia sinistra-destra")
("leftwards" "verso sinistra")
("legal" "legale")
("lemma" "lemma")
("length" "lunghezza")
("less" "minore")
("less or equal" "minore o uguale")
("let the environment float" "lascia fluttuare l'ambiente")
("letter" "lettera")
("license" "licenza")
("light" "leggero")
("light grey" "grigio chiaro")
("limitations" "limitazioni")
("limits" "limiti")
("line" "linea")
("line arrows" "frecce linea")
("line break" "interruzione di riga")
("line breaking" "interruzione di riga")
("line dashes" "trattini di linea")
("line portion" "porzione di linea")
("line stretch" "elasticità della linea")
("line style" "stile della linea")
("line width" "larghezza della linea")
("line wrapping" "a capo automatico")
("line wrapping inside cell" "a capo automatico nella cella")
("linear 2D" "lineare 2D")
("linear algebra" "algebra lineare")
("lines around" "linee sopra e sotto")
("link" "collegamento")
("link image" "inserisci immagine (collegamento)")
("link image and copies as" "collega immagine e copie come")
("link image as" "collega immagine come")
("link mode" "modalità collegamento")
("link to URL" "collegamento all'URL")
("linking tool" "strumento di collegamento")
("list" "lista")
("list of figures" "lista delle figure")
("list of tables" "lista delle tabelle")
("live" "live")
("load" "carica")
("load LaTeX file" "carica file LaTeX")
("load TeX file" "carica file TeX")
("load TeXmacs file" "carica file TeXmacs")
("load TeXmacs style file" "carica file di stile di TeXmacs")
("load a file" "carica un file")
("load buffer" "carica buffer")
("load file" "carica file")
("load help file" "carica file di aiuto")
("load html file" "carica file html")
("load image" "carica immagine")
("load in new window" "carica in una nuova finestra")
("load latex file" "carica file latex")
("load more recent autosave file" "carica ultimo file salvato automaticamente")
("load remote file" "carica file remoto")
("load tex file" "carica file tex")
("load verbatim file" "carica file di testo semplice")
("loaded" "caricato")
("loading" "caricamento")
("local entries" "voci locali")
("loci" "loci")
("locus" "locus")
("locus rendering" "rendering del locus")
("logarithm" "logaritmo")
("logarithmic" "logaritmico")
("logarithmic base" "base logaritmica")
("logarithms" "logaritmi")
("logging in" "accesso in corso")
("logical and" "E logico")
("logical implication" "implicazione logica")
("logical not" "NON logico")
("logical or" "O logico")
("login" "accedi")
("logout" "esci")
("long" "lungo")
("long macro" "macro lunga")
("long text" "testo lungo")
("look and feel" "aspetto")
("look for more fonts" "cerca più caratteri")
("look up" "cerca")
("loops" "loop")
("lower border" "bordo inferiore")
("m modifier" "modificatore m")
("macro" "macro")
("macro argument" "argomento della macro")
("macro definition" "definizione della macro")
("macro editor" "editor della macro")
("macro name" "nome della macro")
("macros" "macro")
("macros editor" "editor delle macro")
("magenta" "magenta")
("magic" "magico")
("magnification" "ingrandimento")
("magnified" "ingrandito")
("magnify horizontally" "ingrandisci orizzontalmente")
("magnify vertically" "ingrandisci verticalmente")
("main" "principale")
("main icon bar" "barra delle icone principale")
("main presentation style" "stile di presentazione principale")
("major changes" "cambiamenti principali")
("make a letter environment" "crea un ambiente lettera")
("make a multi-slide presentation" "crea una presentazione con più diapositive")
("make a page insertion" "fai un inserimento di pagina")
("make a subscript" "crea un pedice")
("make a superscript" "crea un apice")
("make acute" "crea un acuto")
("make bar" "crea una barra")
("make block wide" "allarga blocco")
("make check" "crea controllo")
("make float wide" "allarga il fluttuante")
("make floating" "rendi fluttuante")
("make footnote wide" "allarga la nota a piè di pagina")
("make fraction" "crea frazione")
("make grave" "crea grave")
("make hat" "crea cappello")
("make label" "crea etichetta")
("make link" "crea collegamento")
("make negation" "crea negazione")
("make non floating" "rendi non fluttuante")
("make page reference" "crea referenza ad una pagina")
("make reference" "crea referenza")
("make square root" "crea radice quadrata")
("make tilde" "crea tilde")
("make title" "crea titolo")
("make vector" "crea vettore")
("make wide" "rendi largo")
("making donations" "come fare donazioni")
("manual" "manuale")
("map to" "rimappa in")
("march" "marzo")
("marginal note" "nota a margine")
("margins" "margini")
("margins as on paper" "margini come sul foglio")
("margins from width" "margini dalla larghezza")
("margins on paper" "margini sul foglio")
("margins on screen" "margini sullo schermo")
("marked" "contrassegnato")
("marker" "marker")
("master" "master")
("master file" "file master")
("material" "materiale")
("math" "matematica")
("math Extra" "matematica extra")
("math Letters" "lettere matematiche")
("math Symbols" "simboli matematici")
("math font" "carattere matematico")
("math font family" "famiglia del carattere matematico")
("math font series" "serie del carattere matematico")
("math font shape" "forma del carattere matematico")
("mathematical" "matematico")
("mathematical and customized input" "input matematici e personalizzati")
("mathematical font" "carattere matematico")
("mathematical formulas" "formule matematiche")
("mathematical input" "input matematici")
("mathematical output" "output matematico")
("mathematical typesetting" "composizione tipografica matematica")
("mathematics" "matematica")
("matrices" "matrici")
("matrix" "matrice")
("maximal" "massimo")
("maximal cell height" "altezza massima della cella")
("maximal clustering" "raggruppamento massimo")
("maximal number of columns" "numero massimo di colonne")
("maximal number of rows" "numero massimo di righe")
("maximal table height" "altezza massima della tabella")
("maximal table width" "larghezza massima della tabella")
("maximum" "massimo")
("maximum mode" "modo massimo")
("may" "maggio")
("meander" "meandro")
("medieval" "medievale")
("medium" "medio")
("medium skip" "salto medio")
("meminfo" "meminfo")
("memory" "memoria")
("memory usage" "utilizzo della memoria")
("menu" "menu")
("merge" "unisci")
("merge lines into paragraphs unless separated by blank lines" "unisci righe in paragrafi se non separate da righe vuote")
("messages" "messaggi")
("messy" "confusa")
("meta data" "metadati")
("meta key" "tasto Meta")
("metadata" "metadati")
("metal" "metallo")
("middle" "mediano")
("middle baseline" "linea di base centrale")
("minimal" "minimo")
("minimal cell height" "altezza minima della cella")
("minimal cell width" "larghezza minima della cella")
("minimal line separation" "separazione minima delle linee")
("minimal number of columns" "numero minimo di colonne")
("minimal number of rows" "numero minimo di righe")
("minimal table height" "altezza minima della tabella")
("minimal table width" "larghezza minima della tabella")
("minimum" "minimo")
("minimum mode" "modo minimo")
("minus" "meno")
("mirror" "specchio")
("miscellaneous" "miscellanea")
("miscellaneous features" "caratteristiche varie")
("mixed" "misto")
("mod" "mod")
("mode" "modo")
("mode dependent icons" "icone dipendenti dalla modalitÃČÂă")
("modifier" "modificatore")
("modify bibliography" "modifica bibliografia")
("modify cell alignment" "modifica l'allineamento della cella")
("modify cell border" "modifica il bordo della cella")
("modify cell padding" "modifica la spaziatura della cella")
("modify cell size" "modifica le dimensioni della cella")
("modify remote live document" "modifica documento live remoto")
("modify table border" "modifica il bordo della tabella")
("modify table padding" "modifica la spaziatura della tabella")
("module" "modulo")
("module browser" "browser del modulo")
("mongolian" "mongolo")
("monospaced" "monospaziato")
("more information about GNU TeXmacs can be found in the Help" "maggiori informazioni su GNU TeXmacs possono essere trovate nel menu Aiuto")
("more information about GNU TeXmacs can be found in the Help->About menu" "maggiori informazioni su GNU TeXmacs possono essere trovate nel menu Aiuto-> Informazioni")
("more information about GNU TeXmacs can be found in the help" "maggiori informazioni su GNU TeXmacs possono essere trovate nel menu aiuto")
("mosaic" "mosaico")
("motion" "movimento")
("mouse over object" "mouse sull'oggetto")
("move" "sposta")
("move down" "sposta in basso")
("move object" "sposta oggetto")
("move objects" "sposta oggetti")
("move over object on which to operate" "sposta sopra l'oggetto su cui operare")
("move to the right when finished" "muovi a destra quando hai finito")
("move up" "sposta in alto")
("multiline" "multilinea")
("multiline input" "input multilinea")
("multiple choice" "scelta multipla")
("multiple documents share window" "più documenti condividono la finestra")
("multiple root" "radice multipla")
("multiplication" "moltiplicazione")
("mutator tags" "tag mutatore")
("my documents" "i miei documenti")
("n-th" "ennesima")
("n-th root" "radice ennesima")
("name" "nome")
("named" "nominato")
("navigation options" "opzioni di navigazione")
("negation" "negazione")
("never" "mai")
("new" "nuovo")
("new account" "nuovo account")
("new bibliography dialogue" "nuovo dialogo bibliografico")
("new buffer" "nuovo buffer")
("new column" "nuova colonna")
("new document" "nuovo documento")
("new double page" "nuova pagina doppia")
("new double page before" "nuova pagina doppia prima")
("new entry" "nuova voce")
("new identity" "nuova identità")
("new item" "nuovo elemento")
("new line" "nuova linea")
("new locus" "nuovo locus")
("new macro" "nuova macro")
("new number" "nuovo numero")
("new page" "nuova pagina")
("new page before" "nuova pagina prima")
("new paragraph" "nuovo paragrafo")
("new passphrase" "nuova passphrase")
("new remote directory" "nuova directory remota")
("new remote file" "nuovo file remoto")
("new roman" "new roman")
("new row" "nuova riga")
("new style fonts" "caratteri con nuovo stile")
("new style page breaking" "interruzione di pagina con nuovo stile")
("new table" "nuova tabella")
("new version" "nuova versione")
("new window" "nuova finestra")
("newer version" "versione più recente")
("next" "successivo")
("next chunk" "prossimo pezzo")
("next difference" "prossima differenza")
("next error" "prossimo errore")
("next field" "campo successivo")
("next line" "prossima linea")
("next occurrence" "prossima occorrenza")
("next screen" "schermata successiva")
("next similar" "prossimo simile")
("no" "no")
("no animation" "nessuna animazione")
("no changes need to be saved" "non ci sono cambiamenti da salvare")
("no clustering" "nessun raggruppamento")
("no completions" "nessun completamento")
("no dictionary for" "non c'è un dizionario per")
("no errors have been corrected" "nessun errore è stato corretto")
("no first indentation" "nessuna prima indentazione")
("no grid" "nessuna griglia")
("no indentation" "nessuna indentazione")
("no last indentation" "nessuna ultima indentazione")
("no line break" "nessuna interruzione di riga")
("no matches found" "non sono stati trovati risultati")
("no matches found for" "nessuna corrispondenza trovata per")
("no more matches for" "non ci sono altri risultati per la ricerca di")
("no more redo information available" "non ci sono più informazioni per rifare")
("no more undo information available" "non ci sono più informazioni per annullare")
("no multiple spaces" "nessuno spazio multiplo")
("no name" "senza nome")
("no new public key in document" "nessuna nuova chiave pubblica nel documento")
("no page break" "nessuna interruzione di pagina")
("no page break after" "nessuna interruzione di pagina dopo")
("no page break before" "nessuna interruzione di pagina prima")
("no page numbers" "nessun numero di pagina")
("no parent" "nessun genitore")
("no selection" "nessuna selezione")
("no spelling errors" "nessun errore di ortografia")
("no spelling errors found in text" "non sono stati trovati errori di ortografia nel testo")
("no spurious spaces" "nessuno spazio spurio")
("no style" "nessuno stile")
("none" "nessuno")
("normal" "normale")
("normal loci" "loci normali")
("norwegian" "norvegese")
("not" "no")
("not allowed to remove home directory" "rimozione della home directory non autorizzata")
("not connected to server" "non connesso al server")
("not equal" "non uguale")
("not found" "non trovato")
("not yet implemented" "non ancora implementato")
("notation" "notazione")
("note" "nota")
("notebook" "notebook")
("november" "novembre")
("number" "numero")
("number equation" "equazione numerata")
("number of columns" "numero di colonne")
("number of polar steps" "numero di passi polari")
("number of subunit steps" "numero di passaggi della subunità")
("numbered" "numerato")
("numbered equation" "equazione numerata")
("numbered equations" "equazioni numerate")
("numbering" "numerazione")
("numerator" "numeratore")
("numeric" "numerico")
("numeric spreadsheet" "foglio di calcolo numerico")
("objectives" "obiettivi")
("oblique" "obliquo")
("occurrences" "occorrenze")
("october" "ottobre")
("odd page" "pagina dispari")
("odd page footer" "piè di pagina (pagine dispari)")
("odd page header" "intestazione (pagine dispari)")
("odd page left margin" "margine sinistro (pagine dispari)")
("odd page margin" "margine (pagine dispari)")
("odd page right margin" "margine destro (pagine dispari)")
("odd page shift" "spostamento (pagine dispari)")
("odd page text" "testo (pagine dispari)")
("odd pages" "pagine dispari")
("of fingerprint" "di impronta digitale")
("off" "disattivato")
("ok" "ok")
("old english" "inglese antico")
("old slavonic" "slavo antico")
("old style" "vecchio stile")
("old version" "versione precedente")
("older version" "versione precedente")
("on" "attivato")
("on cells" "sulle celle")
("on columns" "sulle colonne")
("on entire table" "su tutta la tabella")
("on rows" "sulle righe")
("on the footer" "a piè di pagina")
("once" "una volta")
("one column" "una colonna")
("one error has been corrected" "un errore è stato corretto")
("one lower case letter, one non alpha-numeric symbol" "una lettera minuscola, un simbolo non alfanumerico")
("one numeric character, one upper case letter" "un carattere numerico, una lettera maiuscola")
("one spelling error has been corrected" "un errore di ortografia è stato corretto")
("online documentation" "documentazione in linea")
("online help" "aiuto in linea")
("only convert changes when re-importing" "converti le modifiche solo durante la reimportazione")
("only convert changes with respect to imported version" "converti solo le modifiche rispetto alla versione importata")
("only convert changes with respect to tracked version" "converti solo le modifiche rispetto alla versione tracciata")
("only implemented for complete subtrees" "implementato solo per sottoalberi completi")
("only inline tags" "solo tag in linea")
("only show paragraphs with hits" "mostra solo i paragrafi con risultati")
("only show semantic focus" "mostra solo focus semantico")
("opacity" "opacità")
("open" "apri")
("open a new buffer" "apri un nuovo buffer")
("open bibliography" "apri la bibliografia")
("open identities" "apri le identità")
("open in new window" "apri in una nuova finestra")
("open key manager" "apri gestore chiavi")
("open licence agreement" "mostra contratto di licenza")
("open mailbox" "accedi alla casella di posta")
("open module browser" "apri il browser dei moduli")
("open new window" "apri una nuova finestra")
("open symbol browser" "apri il browser dei simboli")
("open tool in separate window" "apri lo strumento in una finestra separata")
("opening" "apertura")
("operation mode" "modalità operativa")
("operation on named selection" "operazione sulla selezione indicata")
("operation on primary selection" "operazione sulla selezione primaria")
("operation on secondary selection" "operazione sulla selezione secondaria")
("operation on ternary selection" "operazione sulla selezione terziaria")
("optical" "ottica")
("option" "opzione")
("options" "opzioni")
("or" "o")
("orange" "arancione")
("order" "ordina")
("ordinary symbol" "simbolo ordinario")
("orientation" "orientazione")
("origin" "origine")
("original welcome message" "messaggio originale di benvenuto")
("ornamented" "ornato")
("other" "altro")
("other login" "altro accesso")
("other package" "altro pacchetto")
("other pages" "altre pagine")
("other projects" "altri progetti")
("other style" "altri stili")
("outer bottom" "parte inferiore esterno")
("outer left" "esterno sinistro")
("outer right" "esterno destro")
("outer top" "parte superiore esterna")
("outline" "contorni")
("outlined" "delineato")
("outlined emboss" "rilievo delineato")
("outlined engrave" "incisione delineata")
("outlined roman" "outlined roman")
("output options" "opzioni di output")
("outwards" "verso l'esterno")
("oval" "ovale")
("over" "diviso")
("overbrace" "overbrace")
("overlap" "sovrapposizione")
("overlay" "overlay")
("overlay mode" "modalità overlay")
("overlays" "overlay")
("overline" "soprallinea")
("overlined" "soprallineato")
("overview of the scheme extension language" "panoramica del linguaggio di estensione Scheme")
("padded" "spaziato")
("padding" "spaziatura")
("page" "pagina")
("page background" "sfondo della pagina")
("page bottom margin" "margine inferiore di pagina")
("page break" "interruzione di pagina")
("page break after" "interruzione di pagina dopo")
("page break before" "interruzione di pagina prima")
("page breaking algorithm" "algoritmo di interruzione di pagina")
("page format" "formato della pagina")
("page height" "altezza della pagina")
("page insertion" "inserimento di pagina")
("page layout" "imaginazione della pagina")
("page number" "numero di pagina")
("page number rendering" "rendering del numero di pagina")
("page number text" "testo del numero di pagina")
("page numbering" "numerazione di pagina")
("page reference" "referenza di pagina")
("page rendering" "rendering della pagina")
("page right margin" "margine destro della pagina")
("page setup" "impostazione della pagina")
("page top margin" "margine superiore della pagina")
("page type" "tipo di pagina")
("page width" "larghezza della pagina")
("pagedown" "pagina giù")
("pageup" "pagina su")
("palette" "palette")
("panorama" "panorama")
("paper" "foglio")
("paper type" "tipo di foglio")
("papyrus" "papiro")
("paragraph" "paragrafo")
("paragraph format" "formato del paragrafo")
("paragraph mode" "modo del paragrafo")
("paragraph width" "larghezza del paragrafo")
("paragraphs" "paragrafi")
("parametric curve" "curva parametrica")
("parametric surface" "superficie parametrica")
("parenthesis" "parentesi")
("parenthesized" "tra parentesi")
("part" "parte")
("passphrase decryption" "decrittazione passphrase")
("passphrase encryption" "crittazione passphrase")
("passphrase wallet facilities are not currently available" " servizi di portafoglio passphrase non sono attualmente disponibili")
("passphrases are expected to have at least: 8 characters" "le passphrase dovrebbero contenere almeno: 8 caratteri")
("passphrases mismatch" "mancata corrispondenza delle passphrase")
("past changes" "cambiamenti precedenti")
("paste" "incolla")
("paste from" "incolla da")
("paste text" "incolla testo")
("pastel" "pastello")
("path" "percorso")
("pattern" "motivo")
("pattern selector" "selettore di motivi")
("pause" "pausa")
("pdf version number" "numero di versione pdf")
("pen" "penna")
("pen width" "larghezza della penna")
("perform operations on cells" "esegui operazioni sulle celle")
("perform operations on columns" "esegui operazioni sulle colonne")
("perform operations on entire table" "esegui operazioni sull'intera tabella")
("perform operations on rows" "esegui operazioni sulle righe")
("permanent" "permanente")
("permanent footer" "piè di pagina permanente")
("permanent header" "intestazione permanente")
("permanently add to dictionary" "aggiungi permanentemente al dizionario")
("permanently insert into dictionary" "inserisci permanentemente nel dizionario")
("permissions" "autorizzazioni")
("person" "persona")
("personal dictionary has been modified" "il dizionario personale è stato modificato")
("phantasy" "fantasia")
("phantom" "fantasma")
("phantoms" "fantasmi")
("philosophy" "filosofia")
("phoenician" "fenicio")
("phonetic" "fonetico")
("physics and astronomy class" "classe di fisica e astronomia")
("picture" "immagine")
("pine" "pino")
("pink" "rosa")
("plain" "semplice")
("plain block" "blocco semplice")
("plain boxes" "scatole semplici")
("plain circles" "cerchi semplici")
("plain tabular" "tabella semplice")
("planned changes" "cambiamenti previsti")
("plans for the future" "programmi per il futuro")
("play" "riproduci")
("play all animations" "riproduci tutte le animazioni")
("play animation" "riproduci animazione")
("please" "per favore")
("please install GnuPG software from https://www.gnupg.org" "installa il software GnuPG da https://www.gnupg.org")
("please wait" "per favore, attendi")
("plot" "traccia")
("plug-ins" "plugin")
("plugin" "plugin")
("plugins" "plugin")
("plural" "plurale")
("plus" "più")
("point" "punto")
("point border" "bordo del punto")
("point size" "dimensione del punto")
("point style" "stile del punto")
("polar" "polare")
("polish" "polacco")
("polygon" "poligono")
("pop server settings" "impostazioni del server pop")
("porting TeXmacs to other platforms" "porting di TeXmacs ad altre piattaforme")
("portion" "porzione")
("portrait" "verticale")
("portuguese" "portoghese")
("position" "posizione")
("position float" "posiziona fluttuante")
("position floating object" "posiziona oggetto fluttuante")
("position of marginal note" "posizione della nota a margine")
("position the table" "posiziona la tabella")
("poster formats" "formati di poster")
("poster theme" "tema poster")
("postfix" "suffisso")
("postscript" "postscript")
("postscript image" "immagine postscript")
("pre-alpha release" "versione pre-alfa")
("preamble" "preambolo")
("preamble mode" "modo preambolo")
("preferences" "preferenze")
("preferences for editing mathematical formulas" "preferenze per la modifica di formule matematiche")
("preferences for tag" "preferenze per tag")
("prefix" "prefisso")
("presentation" "presentazione")
("presentation mode" "modo presentazione")
("presentation tag" "tag presentazione")
("presentation tool" "strumento di presentazione")
("preserve" "mantieni")
("preserve tags" "mantieni tag")
("pretty" "carino")
("preview" "anteprima")
("preview before printing" "anteprima prima di stampare")
("preview command" "comando di anteprima")
("preview with ghostview" "anteprima con ghostview")
("previous" "precedente")
("previous difference" "differenza precedente")
("previous error" "errore precedente")
("previous field" "campo precedente")
("previous occurrence" "occorrenza precedente")
("previous screen" "schermata precedente")
("previous similar" "precedente simile")
("primary" "primario")
("prime" "primo")
("primitive or macro" "primitiva o macro")
("print" "stampa")
("print all" "stampa tutto")
("print all to file" "stampa tutto su file")
("print buffer" "stampa buffer")
("print buffer to file" "stampa buffer su file")
("print document" "stampa documento")
("print page selection" "stampa le pagine selezionate")
("print page selection to file" "stampa le pagine selezionate su file")
("print to file" "stampa su file")
("print to postscript file" "stampa su file postscript")
("printer" "stampante")
("printer dpi" "risoluzione della stampante (dpi)")
("printer setup" "impostazione stampante")
("printing command" "comando di stampa")
("problem" "problema")
("produce Pdf using native export filter" "crea Pdf usando il filtro di esportazione nativo")
("produce Postscript using native export filter" "crea Postscript usando il filtro di esportazione nativo")
("professional" "professionale")
("prog" "prog")
("prog font" "carattere prog")
("prog font family" "famiglia del carattere prog")
("prog font series" "stile del carattere prog")
("prog font shape" "forma del carattere prog")
("program" "programma")
("program commands" "comandi del programma")
("program font" "font del programma")
("program interface for buffer management" "interfaccia del programma per la gestione del buffer")
("program mode" "modo programma")
("programming" "programmazione")
("programming routines for editing documents" "routine di programmazione per la modifica di documenti")
("progressive" "progressivo")
("project" "progetto")
("projects" "progetti")
("prologue" "prologo")
("prominent" "prominente")
("prompt on scripts" "chiedi per script")
("prompts and default input" "prompt e input predefiniti")
("proof" "dimostrazione")
("proportional" "proporzionale")
("proportional typewriter" "macchina da scrivere proporzionale")
("proposition" "proposizione")
("provoke C++ error" "provoca errore C++")
("provoke menu error" "provoca errore di menu")
("provoke scheme error" "provoca errore Scheme")
("pseudo code" "pseudo codice")
("public key encryption" "crittografia a chiave pubblica")
("public keys" "chiavi pubbliche")
("qt-widgets" "widget qt")
("quantifier" "quantificatore")
("quasi" "quasi")
("query replace" "sostituisci")
("question" "domanda")
("questions only" "solo domande")
("questions with answers" "domande con risposte")
("quick evaluation of formulas" "valutazione rapida delle formule")
("quit" "esci")
("quotation" "citazione (più paragrafi)")
("quote" "citazione")
("range" "rango")
("rank" "rango")
("raw" "grezzo")
("really close it" "chiudi per davvero")
("really delete user identity" "elimina davvero l'identità dell'utente")
("really huge" "gigante")
("really quit" "sicuro di voler uscire")
("really tiny" "davvero minuscolo")
("rebuild translations file" "ricostruisci il file delle traduzioni")
("recent" "recente")
("recent documents" "documenti recenti")
("recipients" "destinatari")
("recognize" "riconosci")
("recolor" "ricolora")
("recover autosave file" "recupera file di salvataggio automatico")
("rectangular" "rettangolare")
("red" "rosso")
("redo" "rifai")
("redo undone changes" "rifai azioni annullate")
("reduce" "riduci")
("reduce bottom margin by" "riduci il margine superiore di")
("reduce left margin by" "riduci il margine sinistro di")
("reduce margins" "riduci i margini")
("reduce right margin by" "riduci il margine destro di")
("reduce top margin by" "riduci il margine superiore di")
("reduce trigonometric functions" "riduci funzioni trigonometriche")
("reduced margins" "margini ridotti")
("reduction even page margin" "riduci il margine delle pagine pari")
("reduction odd page margin" "riduci il margine delle pagine dispari")
("reduction page bottom margin" "riduci il margine inferiore della pagina")
("reduction page right margin" "riduci il margine destro della pagina")
("reduction page top margin" "riduci il margine superiore della pagina")
("reference" "referenza")
("reference guide" "guida di riferimento")
("reference guide for the TeXmacs primitives" "guida di riferimento per le primitive TeXmacs")
("reference guide for the standard TeXmacs styles" "guida di riferimento per gli stili TeXmacs standard")
("references" "referenze")
("regenerate" "rigenera")
("register" "registra")
("register file" "file di registro")
("regular" "regolare")
("relate" "metti in relazione")
("relation" "relazione")
("release" "versione")
("release left button: finish editing" "rilascia pulsante sinistro: termina modifica")
("reload" "ricarica")
("remark" "osservazione")
("remote" "remoto")
("remote connections" "connessioni remote")
("remote control" "telecomando")
("remote controllers with keyboard simulation" "telecomandi con simulazione tastiera")
("remote directory" "directory remota")
("remote login" "accesso remoto")
("remote servers" "server remoti")
("remote tool" "strumento remoto")
("remove" "rimuovi")
("remove all output fields" "rimuovi tutti i campi di output")
("remove animation" "rimuovi animazione")
("remove argument after" "rimuovi argomento dopo")
("remove argument before" "rimuovi argomento prima")
("remove banner" "rimuovi banner")
("remove database entry" "rimuovi la voce del database")
("remove downwards" "rimuovi verso il basso")
("remove entries" "rimuovi voci")
("remove entry" "rimuovi voce")
("remove field above" "rimuovi campo sopra")
("remove field below" "rimuovi campo sotto")
("remove fields" "rimuovi campi")
("remove from previous frames" "rimuovi dai frame precedenti")
("remove from subsequent frames" "rimuovi dai frame successivi")
("remove input field" "rimuovi campo di input")
("remove input field above" "rimuovi il campo di input sopra")
("remove last field" "rimuovi ultimo campo")
("remove leftwards" "rimuovi verso sinistra")
("remove link" "rimuovi collegamento")
("remove next field" "rimuovi campo successivo")
("remove number" "rimuovi numero")
("remove overlay after" "rimuovi overlay dopo")
("remove overlay before" "rimuovi overlay prima")
("remove package" "rimuovi pacchetto")
("remove previous field" "rimuovi campo precedente")
("remove rightwards" "rimuovi verso destra")
("remove selected database entries" "rimuovi voci di database selezionate")
("remove selected entries" "rimuovi voci selezionate")
("remove slide after" "rimuovi diapositiva dopo")
("remove slide before" "rimuovi diapositiva prima")
("remove superfluous invisible operators" "rimuovi operatori invisibili superflui")
("remove tag" "rimuovi tag")
("remove this branch" "rimuovi questo ramo")
("remove this frame" "rimuovi questo frame")
("remove this switch" "rimuovi questo switch")
("remove upwards" "rimuovi verso l'alto")
("removed entries from database" "voci rimosse dal database")
("removed entry from database" "voce rimossa dal database")
("rename" "rinomina")
("rename section" "rinomina sezione")
("rendering" "rendering")
("rendering options for tag" "opzioni di rendering per tag")
("renumber this page" "rinumera questa pagina")
("repeat" "ripeti")
("repeat object" "ripeti oggetto")
("replace" "sostituisci")
("replace TeXmacs styles with no LaTeX equivalents" "sostituisci gli stili TeXmacs senza equivalenti LaTeX")
("replace all further occurrences" "sostituisci tutte le altre occorrenze")
("replace by" "sostituisci con")
("replace one occurrence" "sostituisci un'occorrenza")
("replace toolbar" "sostituisci barra degli strumenti")
("replace unrecognized styles" "sostituisci stili non riconosciuti")
("replaced" "sostituito")
("replaced one occurrence" "un'occorrenza è stata sostituita")
("reset" "azzera")
("reset error counters" "azzera i contatori di errori")
("resize" "ridimensiona")
("resize object" "ridimensiona oggetto")
("resize objects" "ridimensiona oggetti")
("resized" "oggetto ridimensionato")
("restart TeXmacs in order to let changes take effect" "riavvia TeXmacs per rendere effettive le modifiche")
("restart in order to let the new look and feel take effect" "riavvia per rendere effettivo il nuovo aspetto")
("retain" "conserva")
("retina settings" "impostazioni retina")
("retrieve email" "recupera email")
("retrieve remote live document" "recupera documento live remoto")
("retrieved contents" "contenuti recuperati")
("retro" "retro")
("return" "invio")
("reverse" "inverti")
("reverse ordering" "ordine inverso")
("revert" "ritorna all'originale")
("revert buffer" "ripristina il buffer")
("right" "destra")
("right aligned" "allineato a destra")
("right arrow" "freccia destra")
("right baseline" "linea di base a destra")
("right border" "bordo destro")
("right cell border" "bordo destro della cella")
("right cell padding" "spaziatura destra della cella")
("right down" "a destra in basso")
("right margin" "margine destro")
("right on even pages" "a sinistra sulle pagine pari")
("right padding" "spaziatura destra")
("right subscript" "pedice a destra")
("right superscript" "apice a destra")
("right surrounding" "surrounding a destra")
("right table border" "bordo destro della tabella")
("right table padding" "spaziatura destra della tabella")
("right up" "a destra in alto")
("rightwards" "verso destra")
("rigid" "rigido")
("rigid box" "scatola rigida")
("rigid horizontal" "orizzontale rigida")
("rigid space" "spazio rigido")
("romanian" "rumeno")
("root" "radice")
("rotate" "ruota")
("rotate backward" "ruota all'indietro")
("rotate forward" "ruota in avanti")
("rotate objects" "ruota oggetti")
("rough" "grezzo")
("rough paper" "carta ruvida")
("round" "rotondo")
("round overbrace" "overbrace tondo")
("round underbrace" "underbrace tondo")
("row" "riga")
("row above" "riga sopra")
("row below" "riga sotto")
("row contains glued items" "la riga contiene elementi appiccicati")
("rows" "righe")
("run" "esegui")
("run current file" "esegui file corrente")
("runic" "runico")
("running author" "autore attuale")
("running title" "titolo attuale")
("russian" "russo")
("russian and Ukrainian users" "utenti russi ed ucraini")
("same names" "stessi nomi")
("same screen margins as on paper" "stessi margini sullo schermo come sulla carta")
("sample" "campione")
("sample text" "testo di esempio")
("sans serif" "sans serif")
("save" "salva")
("save TeXmacs file" "salva file TeXmacs")
("save TeXmacs style file" "salva file di stile TeXmacs")
("save as" "salva come")
("save as LaTeX" "salva come LaTeX")
("save as TeX" "salva come TeX")
("save auxiliary data" "salva dati ausiliari")
("save buffer" "salva buffer")
("save buffer as" "salva il buffer come")
("save entries" "salva voci")
("save entry" "salva voce")
("save file" "salva file")
("save html file" "salva file html")
("save image" "salva immagine")
("save image as" "salva immagine come")
("save latex file" "salva file latex")
("save position" "salva posizione")
("save remote file" "salva file remoto")
("save tex file" "salva file tex")
("save this buffer" "salva questo buffer")
("save verbatim file" "salva file di testo semplice")
("saved" "salvato")
("saved modifications in database" "modifiche salvate nel database")
("scheme command" "comando Scheme")
("scheme developers guide" "guida per sviluppatori in Scheme")
("scheme extensions" "estensioni in Scheme")
("scheme interface for the graphical mode" "interfaccia Scheme per la modalità grafica")
("screen" "schermo")
("screen layout" "impaginazione su schermo")
("screen margins" "margini dello schermo")
("screen rendering" "rendering dello schermo")
("screens" "schermi")
("screenshot" "screenshot")
("script" "script")
("script above" "script sopra")
("script below" "script sotto")
("script script size" "script script size")
("script size" "dimensione dello script")
("scripting language" "linguaggio di scripting")
("scripts" "script")
("scripts not accepted" "gli script non sono accettati")
("search" "cerca")
("search and replace" "cerca e sostituisci")
("search in database" "cerca nel database")
("search results for" "risultati della ricerca per")
("search toolbar" "barra degli strumenti di ricerca")
("search words in my documents" "cerca parole nei miei documenti")
("search words in the documentation" "cerca parole nella documentazione")
("search words in the source code" "cerca parole nel codice sorgente")
("searching" "cercando")
("second" "secondo")
("secondary" "secondario")
("secret keys" "chiavi segrete")
("section" "sezione")
("sections" "sezioni")
("security" "sicurezza")
("see" "vedi")
("see documentation" "vedi documentazione")
("select GnuPG recipients" "seleziona destinatari GnuPG")
("select a document style" "seleziona uno stile di documento")
("select a foreground color" "seleziona un colore di primo piano")
("select a language" "seleziona una lingua")
("select background picture" "seleziona immagine di sfondo")
("select document style" "seleziona lo stile del documento")
("select pen" "seleziona penna")
("select the action to be undertaken for each conflict" "seleziona l'azione da intraprendere per ogni conflitto")
("select view mode" "seleziona modalità di visualizzazione")
("selected region" "regione selezionata")
("selection" "selezione")
("selections" "selezioni")
("semantic correctness" "correttezza semantica")
("semantic editing" "editing semantico")
("semantic selections" "selezioni semantiche")
("semantics" "semantica")
("seminar" "seminario")
("sending commands to TeXmacs" "invio comandi a TeXmacs")
("senior" "senior")
("separation between lines" "separazione tra le righe")
("separation between paragraphs" "separazione tra i paragrafi")
("separator" "separatore")
("september" "settembre")
("serb" "serbo")
("series" "serie")
("series|right" "serie|destra")
("serif" "grazie")
("server" "server")
("server licence agreement" "accordo di licenza del server")
("session" "sessione")
("session commands" "comandi di sessione")
("session name" "nome della sessione")
("session type" "tipo di sessione")
("sessions" "sessioni")
("set" "imposta")
("set background color of cell" "imposta colore di sfondo della cella")
("set cell mode" "imposta il modo della cella")
("set default" "imposta predefinito")
("set difference" "differenza tra insiemi")
("set extension center" "imposta il centro dell'estensione")
("set height" "imposta altezza")
("set height of cell" "imposta l'altezza della cella")
("set intersection" "intersezione")
("set margins" "imposta i margini")
("set n" "imposta n")
("set number of columns" "imposta il numero di colonne")
("set number of rows" "imposta il numero di righe")
("set or get environment variables" "imposta o ottieni variabili d'ambiente")
("set paragraph margins" "imposta i margini del paragrafo")
("set paragraph mode" "imposta il modo del paragrafo")
("set printer dpi" "imposta la risoluzione della stampante (dpi)")
("set printing command" "imposta il comando di stampa")
("set properties" "imposta proprietà")
("set span" "imposta span")
("set special cell properties" "imposta proprietà speciali della cella")
("set special table properties" "imposta proprietà speciali della tabella")
("set text width" "imposta la larghezza del testo")
("set union" "unione")
("set user information" "imposta informazioni utente")
("set width" "imposta larghezza")
("set width of cell" "imposta la larghezza della cella")
("settings" "impostazioni")
("setup printer" "configura la stampante")
("seventh" "settimo")
("several equations" "diverse equazioni")
("shadow" "ombreggia")
("shadowed" "ombreggiato")
("shadowed raise" "rilievo ombreggiato")
("shape" "forma")
("shift" "shift")
("shift-down" "shift-giù")
("shift-right" "shift-destra")
("short" "corto")
("show" "mostra")
("show all parts" "mostra tutte le parti")
("show current focus" "mostra lo stato attuale")
("show full context" "mostra contesto completo")
("show header and footer" "mostra intestazione e piè di pagina")
("show hidden" "mostra nascosta")
("show key presses" "mostra i tasti premuti")
("show main document" "mostra documento principale")
("show memory usage" "mostra utilizzo memoria")
("show on screen" "mostra sullo schermo")
("show one part" "mostra una parte")
("show panorama" "mostra panorama")
("show preamble" "mostra il preambolo")
("show several parts" "mostra più parti")
("show subunits" "mostra subunità")
("show table cells" "mostra celle della tabella")
("show timings" "mostra tempi")
("shrinking factor" "fattore di riduzione")
("side tools" "strumenti laterali")
("signature" "firma")
("simple" "semplice")
("simple form" "form semplice")
("simple widget" "widget semplice")
("simplification" "semplificazione")
("simplified evaluation of formulas" "valutazione semplificata delle formule")
("simplified menus" "menu semplificati")
("simplify" "semplifica")
("sine" "seno")
("sixth" "sesto")
("size" "dimensioni")
("size limits" "limiti delle dimensioni")
("size tag" "tag taglia")
("skew" "inclina")
("skin" "pelle")
("skip all" "salta tutto")
("slant" "inclinazione")
("slanted" "inclinata")
("slashed fraction" "frazione ridotta")
("slides" "diapositive")
("sloppy" "sloppy")
("slovene" "sloveno")
("slow" "lento")
("slow decrease" "diminuzione lenta")
("slow increase" "aumento lento")
("small" "piccolo")
("small Capitals" "piccole Maiuscole")
("small capitals" "piccole maiuscole")
("small caps" "maiuscoletto")
("small environment box" "piccola scatola ambiente")
("small figure" "figura piccola")
("small focus" "focus piccola")
("small inline" "in linea piccolo")
("small inline fraction" "frazione in linea piccola")
("small skip" "salto piccolo")
("small table" "tabella piccola")
("smash" "smash")
("smooth" "liscio")
("smooth end" "estremità liscia")
("smooth extremities" "estremità lisce")
("smooth start" "avvio regolare")
("snap" "aggancia")
("snap distance" "distanza di aggancio")
("snap to curves" "aggancio alle curve")
("snap to grid" "aggancia alla griglia")
("snap to grid curve" "aggancia alla curva della griglia")
("snap to intersections of curves" "aggancia alle intersezioni tra curve")
("snap to text borders" "aggancia ai bordi del testo")
("snap to text corners" "aggancia agli angoli del testo")
("solution" "soluzione")
("solution to exercise" "soluzione dell'esercizio")
("solution to problem" "soluzione del problema")
("solutions" "soluzioni")
("sound" "suono")
("source" "sorgente")
("source code" "codice sorgente")
("source macros tool" "strumento macro del sorgente")
("source tags" "tag del sorgente")
("south" "sud")
("south east" "sud-est")
("space" "spazio")
("space bar in math mode" "barra spaziatrice in modalità matematica")
("space bar in text mode" "barra spaziatrice in modalità testo")
("space between lines" "spazio tra le righe")
("space between paragraphs" "spazio tra i paragrafi")
("space stretchability" "estensibilità dello spazio")
("spacing" "spaziatura")
("span" "span")
("span over all columns" "estendi su tutte le colonne")
("spanish" "spagnolo")
("special" "speciale")
("special cell properties" "proprietà speciali della cella")
("special functions" "funzioni speciali")
("special properties" "proprietà speciali")
("special table properties" "proprietà speciali della tabella")
("specific" "specifico")
("specific baseline" "linea di base specifica")
("specified" "specificato")
("specify color alternation" "specifica alternanza di colore")
("specify how to traverse the manual" "specifica come attraversare il manuale")
("specify semantics of a symbol or formula" "specifica la semantica di un simbolo o di una formula")
("specify the size of the table" "specifica la dimensione della tabella")
("specify user identity" "specifica l'identità dell'utente")
("spell" "ortografia")
("spell check" "controllo ortografico")
("spell checking complete" "controllo ortografico completato")
("spelling error" "errore ortografico")
("spelling errors have been corrected" "gli errori ortografici sono stati corretti")
("spline" "spline")
("split" "dividi")
("split program" "dividi programma")
("split session" "dividi sessione")
("square" "quadrato")
("square overbrace" "overbrace quadrato")
("square root" "radice quadrata")
("square underbrace" "underbrace quadrato")
("stack" "pila")
("standard" "standard")
("standard Output" "Uscita standard")
("standard TeXmacs styles" "stili TeXmacs standard")
("standard environment variables" "variabili di ambiente standard")
("standard formats" "formati standard")
("standard fraction" "frazione standard")
("star" "stella")
("start" "inizio")
("start a new chapter" "inizia un nuovo capitolo")
("start a new section" "inizia una nuova sezione")
("start an interactive session" "inizia una sessione interattiva")
("start server" "avvia server")
("statement" "dichiarazione")
("statistics" "statistiche")
("status" "status")
("status bar" "barra di stato")
("stop server" "arresta server")
("storage" "archiviazione")
("store tracking information in LaTeX files" "memorizza le informazioni di tracciamento nei file LaTeX")
("stretch" "allunga")
("stretch factor" "fattore di allungamento")
("stretchable" "estensibile")
("stretchable horizontal" "estensibile orizzontalmente")
("stretchable vertical" "estensibile verticalmente")
("stretched" "allungato")
("strict Ascii" "Ascii rigoroso")
("strike through" "barrato")
("stroke" "tratto")
("strokes" "tratti")
("strong" "enfatizzato")
("structural" "strutturale")
("structured insert above" "inserimento strutturato sopra")
("structured insert at the left" "inserimento strutturato a sinistra")
("structured insert at the right" "inserimento strutturato a destra")
("structured insert below" "inserimento strutturato sotto")
("structured remove downwards" "rimozione strutturata verso il basso")
("structured remove leftwards" "rimozione strutturata verso sinistra")
("structured remove rightwards" "rimozione strutturata verso destra")
("structured remove upwards" "rimozione strutturata verso l'alto")
("structured variant" "variante strutturata")
("style" "stile")
("style options" "opzioni di stile")
("style parameters" "parametri di stile")
("styles" "stili")
("stylesheet language" "lingua del foglio di stile")
("sub" "secondo livello")
("subject" "soggetto")
("submenu" "sottomenu")
("subparagraph" "sotto-paragrafo")
("subscript" "pedice")
("subscript below" "pedice in basso")
("subsection" "sotto-sezione")
("subsub" "terzo livello")
("subsubmenu" "sotto-sottomenu")
("subsubsection" "sotto-sotto-sezione")
("subsubsubmenu" "sotto-sotto-sottomenu")
("subsubsubsubmenu" "sotto-sotto-sotto-sottomenu")
("subtable" "sottotabella")
("subtitle" "sottotitolo")
("subtraction" "sottrazione")
("summarized" "riassunto")
("summary" "sommario")
("summary of the principal TeXmacs tags" "sommario dei principali tag di TeXmacs")
("superpose" "sovrapponi")
("superposed" "sovrapposto")
("superscript" "apice")
("superscript above" "apice sopra")
("supported plug-ins" "plug-in supportati")
("surface" "superficie")
("swedish" "svedese")
("swiss" "svizzero")
("switch" "switch")
("switch to buffer" "passa al buffer")
("switch to first" "passa al primo")
("switch to formula style" "passa allo stile formula")
("switch to last" "passa all'ultimo")
("switch to next" "passa al successivo")
("switch to previous" "passa al precedente")
("switching and folding" "switch e arrotolamento")
("symbol" "simbolo")
("symbol browser" "browser dei simboli")
("symbol properties not found" "proprietà del simbolo non trovate")
("symbols" "simboli")
("synchronization status" "stato della sincronizzazione")
("synchronize" "sincronizza")
("synchronize bibliographic references" "sincronizza i riferimenti bibliografici")
("synchronize file or directory" "sincronizza file o directory")
("synchronize with remote server" "sincronizza con server remoto")
("synopsis" "sinossi")
("system command" "comando di sistema")
("system environment variables" "variabili ambientali di sistema")
("tab" "tab")
("tab-completion" "completamento con tabulazione")
("tabbed" "a schede")
("table" "tabella")
("table breaking" "spezzamento della tabella")
("table command" "comando di tabella")
("table height" "altezza della tabella")
("table of contents" "indice")
("table properties" "proprietà della tabella")
("table width" "larghezza della tabella")
("tables" "tabelle")
("tabular" "tabellare")
("tabular material" "materiale tabellare")
("tags with special rendering" "tag con rendering speciale")
("tangent" "tangente")
("teXmacs DTD" "teXmacs DTD")
("teXmacs as an interface" "TeXmacs come un'interfaccia")
("teXmacs buffer expected" "buffer TeXmacs previsto")
("teXmacs buffer on disk expected" "buffer TeXmacs su disco previsto")
("teXmacs database preferences" "preferenze del database teXmacs")
("teXmacs extensions to scheme and utilities" "estensioni di TeXmacs a Scheme e alle utilità")
("teXmacs fonts" "font di TeXmacs")
("teXmacs macro" "macro TeXmacs")
("teXmacs notice" "avviso di TeXmacs")
("teXmacs package" "pacchetto TeXmacs")
("teXmacs plugins" "plugin TeXmacs")
("teXmacs primitives" "primitive TeXmacs")
("teXmacs style" "stile TeXmacs")
("teXmacs style files" "fogli di stile di TeXmacs")
("ternary" "ternario")
("test" "provare")
("test routine" "routine di test")
("testing tree-view" "vista ad albero in prova")
("tex" "tex")
("text" "testo")
("text borders" "bordi del testo")
("text box style" "stile casella di testo")
("text corners" "angoli del testo")
("text font" "carattere del testo")
("text height correction" "correzione dell'altezza del testo")
("text padding" "spaziatura del testo")
("text width" "larghezza del testo")
("texts" "testi")
("textual" "testuale")
("textual operator" "operatore testuale")
("textual spreadsheet" "foglio di calcolo testuale")
("th century bc" "-esimo secolo A.C.")
("th root" "radice -esima")
("thai" "tailandese")
("the TeXmacs authors" "gli autori di TeXmacs")
("the TeXmacs format" "il formato TeXmacs")
("the TeXmacs plug-in system" "il sistema plugin TeXmacs")
("the application did not send its usual startup banner" "l'applicazione non ha inviato il suo solito banner iniziale")
("the application does not reply" "l'applicazione non risponde")
("the application is already running" "l'applicazione è già in esecuzione")
("the boxes produced by the typesetter" "i box prodotti dal sistema di composizione")
("the document has not been saved" "il documento non è stato salvato")
("the graphical user interface" "l'interfaccia grafica utente")
("the leaves of TeXmacs trees" "le foglie dell'albero di TeXmacs")
("the mycas example" "l'esempio di mycas")
("the primitive TeXmacs constructs" "i costrutti primitivi di TeXmacs")
("the standard TeXmacs styles" "gli stili standard di TeXmacs")
("theme parameters" "parametri del tema")
("theorem" "teorema")
("there are unsaved documents" "ci sono documenti non salvati")
("these collected public keys will be definitely lost" "queste chiavi pubbliche raccolte andranno sicuramente perse")
("these public keys will be definitely lost" "queste chiavi pubbliche andranno sicuramente perse")
("these secret keys will be definitely lost" "queste chiavi segrete andranno sicuramente perse")
("thicken" "ispessire")
("thin" "sottile")
("third" "terzo")
("this" "questo")
("this column" "questa colonna")
("this document has been produced using" "questo documento è stato realizzato usando")
("this document has not been saved" "questo documento non è stato salvato")
("this line" "questa linea")
("this page" "questa pagina")
("this page footer" "questo piè di pagina")
("this page header" "questa intestazione di pagina")
("this page number" "questo numero di pagina")
("this row" "questa riga")
("this style specifies page margins in the TeX way" "questo stile specifica i margini della pagina nel modo TeX")
("three columns" "tre colonne")
("three dots" "tre punti")
("three times" "tre volte")
("through popup windows" "attraverso le finestre popup")
("through the menus" "attraverso i menu")
("thumbnails" "miniature")
("tilda" "tilda")
("tilde" "tilde")
("time evolution" "evoluzione temporale")
("times" "per")
("timings" "tempi")
("tiny" "diminuito")
("title" "titolo")
("title presentation options" "opzioni di presentazione del titolo")
("title style" "stile del titolo")
("title suffix" "suffisso del titolo")
("titled block" "blocco intitolato")
("to the left" "a sinistra")
("to the right" "a destra")
("today" "oggi")
("toggle cell wrapping mode" "attiva/disattiva modalità a capo automatico nella cella")
("toggle here" "attiva/disattiva qui")
("toggle name" "attiva/disattiva nome")
("toggle numbering" "attiva/disattiva numerazione")
("toggle off" "disattiva")
("toggle on" "attiva")
("toggle specification" "attiva/disattiva specifica")
("toggle titled" "attiva/disattiva titolato")
("tolerant" "tollerante")
("tools" "strumenti")
("top" "superiore")
("top baseline" "linea di base superiore")
("top border" "bordo superiore")
("top cell border" "bordo superiore della cella")
("top cell padding" "spaziatura superiore della cella")
("top level" "livello superiore")
("top margin" "margine superiore")
("top padding" "spaziatura superiore")
("top table border" "bordo superiore della tabella")
("top table padding" "spaziatura superiore della tabella")
("transform" "trasforma")
("transform cell into subtable" "trasforma cella in sottotabella")
("translate" "traduci")
("translations" "traduzioni")
("translations loaded" "traduzioni caricate")
("transpose" "trasponi")
("traversal" "traversal")
("traverse" "traversa")
("tree" "albero")
("triangle" "triangolo")
("triangularize" "triangolarizza")
("trigonometric" "trigonometrico")
("trigonometry" "trigonometria")
("tuple" "tupla")
("turkish" "turco")
("turn off" "spegni")
("turn on" "accendi")
("turn on wallet" "attiva portafoglio")
("tutorial" "tutorial")
("twice" "due volte")
("two columns" "due colonne")
("two dots" "due punti")
("type" "tipo")
("type a latex command followed by" "scrivi un comando latex seguito da")
("type a latex command followed by return" "digitare un comando latex seguito da un a capo")
("type body" "scrivi il corpo")
("type denominator" "scrivi il denominatore")
("type numerator" "scrivi il numeratore")
("type script" "scrivi l'indice")
("typesetted boxes" "composizione tipografica dei box")
("typewriter" "macchina da scrivere")
("typewriter small caps" "maiuscoletto macchina da scrivere")
("typing a simple text" "comporre un semplice testo")
("typing simple texts" "comporre semplici testi")
("ugaritic" "ugaritico")
("ukrainian" "ucraino")
("unchanged" "invariato")
("underbrace" "underbrace")
("underline" "sottolinea")
("underlined" "sottolineato")
("undo" "annulla")
("undo last changes" "annulla gli ultimi cambiamenti")
("unevaluated argument" "argomento non valutato")
("unevaluated value" "valore non valutato")
("unextended" "non esteso")
("unit" "unità")
("unit length" "lunghezza unitaria")
("unknown secret key fingerprint" "impronta digitale chiave segreta sconosciuta")
("unregistered file" "file non registrato")
("unroll" "srotola")
("unsecure script refused" "script non sicuro rifiutato")
("unsupported link mode" "modalità di collegamento non supportata")
("until" "fino a")
("untitled block" "blocco senza titolo")
("up" "su")
("up to date" "aggiornato")
("update" "aggiorna")
("update buffer" "aggiorna buffer")
("update from web" "aggiorna dal web")
("update image links" "aggiorna i collegamenti alle immagini")
("update this buffer" "aggiorna questo buffer")
("update web site" "aggiorna sito web")
("upload" "carica")
("upload file or directory" "carica file o directory")
("upper border" "bordo superiore")
("upright" "verticale")
("upwards" "verso l'alto")
("url" "url")
("use CSS for more advanced formatting" "usa CSS per una formattazione più avanzata")
("use MathML" "usa MathML")
("use TeXmacs" "usa TeXmacs")
("use a black color" "usa colore nero")
("use a blue color" "usa colore blu")
("use a bold font" "usa un font grassetto")
("use a brown color" "usa colore marrone")
("use a calligraphic font" "usa un carattere calligrafico")
("use a green color" "usa colore verde")
("use a grey color" "usa colore grigio")
("use a magenta color" "usa colore magenta")
("use a orange color" "usa colore arancione")
("use a pink color" "usa colore rosa")
("use a red color" "usa colore rosso")
("use a sans serif font" "usa un carattere sans serif")
("use a typewriter font" "usa un carattere macchina da scrivere")
("use a white color" "usa colore bianco")
("use a yellow color" "usa colore giallo")
("use as master" "usa come master")
("use blackboard bold font" "usa carattere lavagna grassetto")
("use bold font series" "usa serie di caratteri grassetto")
("use calligraphical font" "usa carattere calligrafico")
("use extensible brackets" "usa parentesi estensibili")
("use footnote font size" "usa dimensione del carattere piè di pagina")
("use fraktur font" "usa carattere fraktur")
("use high resolution fonts" "usa caratteri ad alta risoluzione")
("use high resolution icons" "usa icone ad alta risoluzione")
("use huge font size" "usa un carattere enorme")
("use italic font shape" "usa un carattere di forma corsiva")
("use large font size" "usa un carattere grande")
("use left hand column as border" "usa la colonna di sinistra come bordo")
("use line wrapping for lines which are longer than 80 characters" "usa il ritorno a capo per righe che superano gli 80 caratteri")
("use margin kerning (protrusion)" "usa la crenatura del margine (sporgenza)")
("use medium font series" "usa serie di caratteri medio")
("use normal font size" "usa carattere di dimensioni normali")
("use package" "usa pacchetto")
("use paragraph width" "usa larghezza di paragrafo")
("use print dialogue" "usa dialoghi di stampa")
("use protrusion" "usa sporgenza")
("use really huge font size" "usa un carattere gigante")
("use relative path" "usa percorso relativo")
("use retina fonts" "usa caratteri retina")
("use retina icons" "usa icone retina")
("use right font shape" "usa forma del carattere di destra")
("use right hand column as border" "usa la colonna di destra come bordo")
("use roman font family" "usa famiglia di caratteri roman")
("use row above as border" "usa la riga superiore come bordo")
("use row below as border" "usa la riga inferiore come bordo")
("use sans serif font family" "usa famiglia di caratteri sans serif")
("use script font size" "usa dimensione del carattere script")
("use slanted font shape" "usa forma di carattere inclinata")
("use small capitals" "usa maiuscoletto")
("use small font size" "usa carattere piccolo")
("use small-caps font shape" "usa forma di carattere maiuscoletto")
("use the blackboard bold font" "usa carattere lavagna grassetto")
("use the fraktur font" "usa il carattere fraktur")
("use tiny font font size" "usa dimensione del carattere piccolo")
("use typewriter font family" "usa famiglia di caratteri macchina da scrivere")
("use unified toolbars" "usa barre degli strumenti unificate")
("use very large font size" "usa un carattere molto grande")
("user interface" "interfaccia utente")
("user interface language" "lingua dell'interfaccia utente")
("user manual" "manuale utente")
("user preferences" "preferenze dell'utente")
("user provided icons" "icone definite dall'utente")
("users of Cyrillic languages" "utenti di lingue cirilliche")
("users of oriental languages" "utenti di lingue orientali")
("utf-8 with inputenc" "utf-8 con inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 con pacchetto LaTeX inputenc")
("utilities" "programmi di utilità")
("value" "valore")
("vanish" "fai svanire")
("variable" "variabile")
("variant" "variante")
("vector" "vettore")
("verbatim" "testo semplice")
("verbose" "verboso")
("verse" "verso")
("version" "versione")
("versioning tool" "strumento di versioning")
("vertical" "verticale")
("vertical after" "verticale dopo")
("vertical alignment" "allineamento verticale")
("vertical before" "verticale prima")
("vertical cell alignment" "allineamento verticale della cella")
("vertical margins" "margini verticali")
("vertical part" "parte verticale")
("vertical position" "posizione verticale")
("vertical space" "spazio verticale")
("vertical space after" "spazio verticale dopo")
("vertical space before" "spazio verticale prima")
("vertical space stretchability" "estensibilità dello spazio verticale")
("vertical table alignment" "alineamento verticale della tabella")
("vertically align cell to the base" "allinea verticalmente la cella alla base")
("vertically center the cell" "centra verticalmente la cella")
("very large" "molto grande")
("very small" "molto piccolo")
("vietnamese" "vietnamita")
("view" "visualizza")
("visible" "visibile")
("visible except here" "visibile tranne qui")
("visible from here on" "visibile da qui in poi")
("visible only here" "visibile solo qui")
("visible until here" "visibile fino a qui")
("visited loci" "loci visitati")
("wallet" "portafoglio")
("warning" "avviso")
("wave" "onda")
("web" "web")
("weight" "peso")
("welcome" "benvenuto")
("welcome to GNU TeXmacs" "benvenuto in GNU TeXmacs")
("what is new" "che c'è di nuovo")
("when finished" "una volta terminato")
("when line wrapping" "quando si va a capo automaticamente")
("when wrapping" "quando si va a capo automaticamente")
("while" "mentre")
("white" "bianco")
("whitespace" "spazio bianco")
("wide" "largo")
("wide accent" "accento largo")
("wide bar" "barra larga")
("wide block" "blocco largo")
("wide colored" "colorato largo")
("wide float" "fluttuante largo")
("wide footnote" "nota a piè di pagina larga")
("wide tabular" "tabella larga")
("widescreen" "widescreen")
("width" "larghezza")
("width is exactly the specified width" "la larghezza è esattamente la larghezza specificata")
("width is maximum of specified width and box width" "la larghezza è la massimo tra quella specificata e quella del box")
("width is minimum of specified width and box width" "la larghezza è la minima tra quella specificata e quella del box")
("width magnification" "ingrandimento della larghezza")
("window" "finestra")
("window height" "altezza della finestra")
("window width" "larghezza della finestra")
("windows key" "tasto Windows")
("with" "con")
("with newer version" "con una versione più recente")
("with older version" "con una versione precedente")
("wrap lines" "manda a capo automaticamente")
("write a macro" "scrivi una macro")
("write a name" "scrivi un nome")
("write bold mathematics" "scrivi matematica in grassetto")
("write bold text" "scrivi in grassetto")
("write italic text" "scrivi in corsivo")
("write sample text" "scrivi esempio")
("write strong text" "scrivi testo marcato")
("write typewriter text" "scrivi testo macchina da scrivere")
("write verbatim text" "scrivi testo a larghezza fissa")
("writing TeXmacs bibliography styles" "scrivere stili bibliografici di TeXmacs")
("writing data converters" "scrivere convertitori di formato")
("writing documentation" "scrivendo la documentazione")
("writing your own style files" "scrivere il proprio file di stile")
("written with TeXmacs" "scritto con TeXmacs")
("wrong empty passphrase" "passphrase vuota errata")
("wrong passphrase" "passphrase errata")
("year" "anno")
("year, Name" "anno, Nome")
("yellow" "giallo")
("yes" "sì")
("you can also obtain" "puoi anche ottenere")
("you must add a bibliography file" "devi aggiungere un file bibliografico")
("you should also make sure that GnuPG is installed" "dovresti anche assicurarti che GnuPG sia installato")
("your document is back in its original state" "il documento è stato riportato allo stato originale")
("your first interface" "la tua prima interfaccia")
("your language" "la tua lingua")
("your personal dictionary has been modified" "il tuo dizionario personale è stato modificato")
("zebra" "zebra")
("zoom" "zoom")
("zoom in" "ingrandisci")
("zoom out" "riduci")
("zoom/unzoom objects" "ingrandisci/riduci oggetti")
