("\"encryption\" features from the preference panel" "\"kryptering\"-funktioner från preferenspanelen")
("(Re)Build autocompletion index" "(Re) Build autocompletion index")
("a modifier" "en modifierare")
("a series" "en serie")
("a.C.M. computing class" "a.C.M. computing class")
("a.M.S. subject class" "a.M.S. ämnesklass")
("abbreviated authors" "förkortade författare")
("abbreviation" "förkortning")
("about menu" "om menyn")
("abreviated authors" "författade författare")
("accent above" "accent ovan")
("accent below" "accent nedan")
("accept" "acceptera")
("accept all scripts" "acceptera alla skript")
("accept during this pass" "acceptera under detta pass")
("accept no scripts" "acceptera inga skript")
("accept script" "acceptera skript")
("acknowledgment" "bekräftelse")
("acknowledgments" "bekräftelser")
("acronym" "akronym")
("action" "action")
("activate hidden" "aktivera dold")
("activate once" "aktivera en gång")
("activation" "aktivering")
("active link types" "aktiva länktyper")
("add" "lägg till")
("add abstract information" "lägg till abstrakt information")
("add author information" "lägg till författarinformation")
("add branch after" "lägg till gren efter")
("add branch before" "lägg till gren innan")
("add other package" "lägg till annat paket")
("add package" "lägg till paket")
("add style package" "Lägg till stilpaket")
("add switch after" "lägg till switch efter")
("add switch before" "lägg till switch innan")
("add title information" "lägg till titelinformation")
("addition" "tillägg")
("address block" "adressblock")
("adjust" "justera")
("adjust limits" "justera gränser")
("advanced font customization" "avancerad typsnittsanpassning")
("advanced layout features" "avancerade layoutfunktioner")
("affiliation" "anslutning")
("albanian" "albanska")
("algorithm" "algoritm")
("align cell to the bottom" "anpassa cell till botten")
("align cell to the decimal comma" "anpassa cell till decimal komma")
("align cell to the decimal dot" "anpassa cellen till decimalpunkten")
("align cell to the left" "justera cell till vänster")
("align cell to the right" "justera cell till höger")
("align cell to the top" "anpassa cell till toppen")
("align table at axis" "justera bordet vid axeln")
("align table at base of left column" "justera tabellen i basen av vänster kolumn")
("align table at base of middle column" "justera bordet vid basen av mittkolumnen")
("align table at base of origin column" "justera tabellen vid ursprungskolonnens bas")
("align table at base of right column" "anpassa tabellen i basen till höger kolumn")
("align table at fraction bar height" "justera bordet vid bråkstångshöjd")
("align table at the base of bottom row" "Justera tabellen i botten av nedre raden")
("align table at the base of middle row" "justera bordet vid botten av den mellersta raden")
("align table at the base of origin row" "justera bordet vid basen för ursprungsraden")
("align table at the base of top row" "justera bordet vid basen på den översta raden")
("align table at the bottom" "justera bordet längst ner")
("align table at the center" "justera bordet i mitten")
("align table at the horizontal center" "justera bordet vid det horisontella mitten")
("align table at the left" "justera bordet till vänster")
("align table at the top" "justera bordet överst")
("align table to the right" "justera bordet till höger")
("align text to the left" "justera text till vänster")
("align text to the right" "justera text till höger")
("aligned" "inriktad")
("alignment" "justering")
("alignment of balloon" "justering av ballong")
("all cells" "alla celler")
("all data attached to this identity will be lost" "all information som är kopplad till denna identitet kommer att gå förlorad")
("all saved passphrases will be lost forever" "alla sparade lösenfraser kommer att gå förlorade för alltid")
("allow" "tillåt")
("allow for macro definitions in preamble" "möjliggör makrodefinitioner i ingressen")
("allow multiple spaces" "tillåta flera mellanslag")
("allow spurious spaces" "tillåt falska utrymmen")
("allowed extension" "tillåten förlängning")
("allowed page height extension" "tillåten sidhöjdförlängning")
("allowed page height reduction" "tillåtet sidhöjdreduktion")
("allowed positions" "tillåtna positioner")
("allowed positions of floating object" "tillåtna positioner för flytande objekt")
("allowed reduction" "tillåten reduktion")
("alpha transparency" "alfa-transparens")
("also on paper" "också på papper")
("alt key" "altnyckel")
("alter" "förändra")
("alternate" "alternativ")
("alternate except here" "alternativt utom här")
("alternate from here on" "alternerande härifrån")
("alternate only here" "endast alternativ här")
("alternate until here" "alternerande tills här")
("alternative colors" "alternativa färger")
("alternative specification" "alternativ specifikation")
("always" "alltid")
("american" "amerikan")
("amplified" "förstärkt")
("ancient" "forntida")
("and" "och")
("and perform casual settings from the \"Encryption\" tab" "och utför tillfälliga inställningar från fliken \"Kryptering\"")
("angular" "vinklad")
("animate" "animerad")
("animate folding" "animera vikning")
("animate object" "animerat objekt")
("animate objects" "animerade objekt")
("animate unfolding" "animerad utveckling")
("animated" "animerad")
("animation" "animering")
("animation toolbar" "verktygsfält för animering")
("annotate" "kommentera")
("answer" "svar")
("answer field" "svarsfält")
("answer to question" "svar på fråga")
("answers only" "svarar bara")
("any" "valfri")
("appear" "visas")
("apply macro" "applicera makro")
("apply macro once" "applicera makro en gång")
("approximate" "ungefärligt")
("arc" "båge")
("arc cosine" "bågkosinus")
("arc sine" "bågsinus")
("arc tangent" "bågtangent")
("arch series" "arch series")
("are you sure you want to delete collected public keys" "är du säker på att du vill ta bort insamlade offentliga nycklar")
("are you sure you want to delete selected public keys" "är du säker på att du vill ta bort valda offentliga nycklar")
("are you sure you want to delete selected secret keys" "är du säker på att du vill ta bort valda hemliga nycklar")
("are you sure you want to destroy the wallet" "är du säker på att du vill förstöra plånboken")
("argument" "argument")
("arithmetic" "aritmetik")
("arrows" "pilar")
("art Pen" "konstpenna")
("art frame" "konstram")
("arxiv category" "arxiv kategori")
("as visual grid" "som visuellt rutnät")
("aspect" "aspekt")
("at fraction bar height" "på bråkdelens höjd")
("at the baseline" "vid baslinjen")
("at the bottom" "längst ner")
("at the left" "till vänster")
("at the middle" "i mitten")
("at the right" "till höger")
("at the top" "överst")
("attach master" "bifoga master")
("attached" "bifogad")
("authorize" "godkänn")
("auto" "auto")
("auto-save file" "autospara fil")
("automatic brackets" "automatiska konsoler")
("automatic content generation" "automatisk innehållsgenerering")
("automatic program brackets" "automatiska programkonsoler")
("automatic quotes" "automatiska citat")
("automatically close brackets" "stäng parentes automatiskt")
("automatically generated content" "automatiskt genererat innehåll")
("automatically import bibliographies when opening files" "importerar automatiskt bibliografier när filer öppnas")
("automatically remember all passphrases in the wallet" "kommer automatiskt ihåg alla lösenfraser i plånboken")
("automatically save" "spara automatiskt")
("autosave" "autosave")
("avoid spurious spaces" "undvika falska utrymmen")
("axis" "axel")
("b series" "b-serie")
("back" "tillbaka")
("background" "bakgrund")
("background evaluations" "bakgrundsutvärderingar")
("background picture selector" "bakgrundsbildväljare")
("backtrace errors" "backtrace-fel")
("backward replace" "bakåt ersätta")
("backward search" "bakåtsökning")
("base" "bas")
("baseline" "baslinje")
("basic communication using pipes" "grundläggande kommunikation med rör")
("basic data types" "grundläggande datatyper")
("beamer" "beamer")
("beamer formats" "beamerformat")
("beamer theme" "beamer tema")
("become a TeXmacs developer" "bli en TeXmacs-utvecklare")
("bench" "bänk")
("bend bottom" "böjbotten")
("bend corner" "böjhörn")
("bend diagonal" "böj diagonal")
("bend in" "böja in")
("bend out" "böj ut")
("bezier" "bezier")
("bibTeX command" "bibTeX-kommando")
("bidirectional" "dubbelriktad")
("big" "stor")
("big environment box" "stor miljöbox")
("big figure" "stor figur")
("big focus" "stort fokus")
("big table" "stort bord")
("binary operator" "binär operatör")
("bitmap resolution (dpi)" "bitmappsupplösning (dpi)")
("black floral I" "svart blommig I")
("black floral II" "svart blommig II")
("blackboard embold" "blackboard embold")
("blank column" "tom kolumn")
("blank row" "tom rad")
("block" "block")
("block content" "blockera innehåll")
("block of code" "kodblock")
("blur" "oskärpa")
("border" "gräns")
("both" "båda")
("both versions" "båda versionerna")
("bottom baseline" "bottenlinje")
("bottom border" "nedre gränsen")
("bottom cell border" "nedre cellgränsen")
("bottom cell padding" "bottencellstoppning")
("bottom padding" "botten stoppning")
("bottom table border" "nedre tabellgränsen")
("bottom table padding" "bottenfodral")
("bottom tools" "bottenverktyg")
("box" "box")
("breaking" "bryta")
("british" "brittiska")
("broken white" "trasigt vitt")
("browse" "bläddra")
("browse back" "bläddra tillbaka")
("browse forward" "bläddra framåt")
("browse modules documentation" "dokumentation av moduler")
("browse web" "surfa på webben")
("browser" "webbläsare")
("buffer management" "bufferthantering")
("buffer must be on disk" "buffert måste finnas på disken")
("buffer must have a name" "buffert måste ha ett namn")
("build buffer" "build buffert")
("build buffer in" "build buffert in")
("build directory" "bygga katalog")
("build directory in" "bygga katalog i")
("build link pages" "bygga länksidor")
("build-all" "build-all")
("bulgarian" "bulgariska")
("bullet" "kula")
("bullets" "kulor")
("bump" "bult")
("busy" "upptagen")
("cJK" "cJK")
("cJK spacing" "cJK-avstånd")
("calculus" "kalkyl")
("cancel" "avbryt")
("cancelled" "avbruten")
("cannot download directory to file" "kan inte ladda ner katalog till fil")
("cannot rename across different servers" "kan inte byta namn på olika servrar")
("cannot upload directory to file" "kan inte ladda upp katalog till fil")
("caps-lock key" "lock-lock nyckel")
("cartesian" "kartesisk")
("carved wood" "huggen trä")
("case" "fall")
("case-insensitive search" "case-okänslig sökning")
("categories" "kategorier")
("category" "kategori")
("cc" "cc")
("cell" "cell")
("cell background color" "cellbakgrundsfärg")
("cell border" "cellgräns")
("cell height" "cellhöjd")
("cell operation mode" "celldriftläge")
("cell properties" "cellegenskaper")
("cell width" "cellbredd")
("cells" "celler")
("center baseline" "mittlinje")
("center text" "mitttext")
("centered block" "centrerad block")
("centered tabular" "centrerad tabellform")
("chalk" "krita")
("change border of cell" "ändra cellgränsen")
("change cell operation mode" "ändra celldriftläge")
("change default unit" "ändra standardenhet")
("change log" "ändra logg")
("change passphrase" "ändra lösenfras")
("change permissions" "ändra behörigheter")
("change step-size" "ändra stegstorlek")
("change tags" "ändra taggar")
("change the TeXmacs preferences" "ändra inställningarna för TeXmac")
("change the border of the table" "ändra bordets gräns")
("change the style of mathematical formulas" "ändra stilen för matematiska formler")
("change wallet passphrase" "byta lösenordsfras för plånbok")
("character contraction" "teckenkontraktion")
("character encoding" "teckenkodning")
("character expansion" "teckenutvidgning")
("check exported Pdf files for correctness" "kontrollera exporterade Pdf-filer för korrekthet")
("check for automatic updates" "kolla om automatiska uppdateringar")
("check for updates" "kolla efter uppdateringar")
("check text for spelling errors" "kontrollera text för stavfel")
("checkable field" "kontrollerbart fält")
("chinese" "kinesiska")
("choice" "val")
("choose background" "välj bakgrund")
("choose color" "välj färg")
("cipher algorithm for passphrase encryption" "chifferalgoritm för lösenfrasskryptering")
("circle" "cirkel")
("cite" "citerar")
("classification" "klassificering")
("clean slate" "ren skiffer")
("clear all fields" "rensa alla fält")
("clear local information" "tydlig lokal information")
("clear menu" "rensa menyn")
("clear selection" "rensa urval")
("clear undo history" "rensa ångra historik")
("click Ok button twice to discard this warning" "klicka på Ok-knappen två gånger för att kassera den här varningen")
("clip" "klipp")
("clipboard image format" "bildformat för Urklipp")
("close animation tool" "nära animeringsverktyg")
("close document" "stäng dokument")
("close program" "stäng program")
("close replace tool" "close byteverktyg")
("close search tool" "stäng sökverktyg")
("close session" "stäng session")
("close spell tool" "stänga stavverktyg")
("close translations to rebuild" "nära översättningar för att bygga om")
("closed bezier" "stängd bezier")
("closed curve" "stängd kurva")
("closed smooth" "stängd slät")
("closed spline" "sluten spline")
("closing" "stängning")
("closing style" "stängningsstil")
("cluster by affiliation" "kluster efter anknytning")
("code" "kod")
("collect garbage" "samla skräp")
("collected keys" "insamlade nycklar")
("color of the axes" "axlarnas färg")
("color of the subunits" "färg på underenheterna")
("color of the units" "färg på enheterna")
("colors" "färger")
("column to the left" "kolumn till vänster")
("column to the right" "kolumn till höger")
("columns" "kolumner")
("column separation" "kolonnseparation")
("commit" "begå")
("commit file" "begå fil")
("common" "vanligt")
("common formats" "vanliga format")
("commutative diagram" "kommutativt diagram")
("compact" "kompakt")
("compactification" "komprimering")
("compactify" "komprimera")
("compare" "jämför")
("compare with" "jämför med")
("compatibility with other formats" "kompatibilitet med andra format")
("compile article" "sammanställa artikel")
("compile book" "sammanställa bok")
("complete bibliographic reference" "fullständig bibliografisk referens")
("completion" "slutförande")
("complex" "komplex")
("complex actions" "komplexa åtgärder")
("compose" "komponera")
("compound" "förening")
("compress" "komprimera")
("compress into toolbar" "komprimera till verktygsfältet")
("compressed" "komprimerad")
("conceal" "dölja")
("condition" "skick")
("configuration" "konfiguration")
("configure look and feel" "konfigurera utseende och känsla")
("confirm collected public key deletion" "bekräfta raderad offentlig nyckel")
("confirm database entry" "bekräfta databasinmatning")
("confirm entry" "bekräfta inträde")
("confirm public key deletion" "bekräfta borttagning av offentlig nyckel")
("confirm secret key deletion" "bekräfta borttagning av hemlig nyckel")
("confirm selected database entries" "bekräfta valda databasposter")
("confirm selected entries" "bekräfta valda poster")
("confirm wallet destruction" "bekräfta förstörelse av plånbok")
("conservative conversion options" "konservativa omvandlingsalternativ")
("consoles" "konsoler")
("constellation" "konstellation")
("contact" "kontakt")
("content" "innehåll")
("content tag" "innehållskod")
("context aids" "kontexthjälpmedel")
("context dependent icons" "kontextberoende ikoner")
("contextual hints" "kontextuella tips")
("continuation of" "fortsättning av")
("continue" "fortsätt")
("continued fraction" "fortsatt fraktion")
("contour" "kontur")
("contract logarithms" "kontraktlogaritmer")
("contribute" "bidra")
("control flow" "kontrollflöde")
("control the evaluation of expressions" "kontrollera utvärderingen av uttryck")
("convention" "konvention")
("convert" "konvertera")
("converters" "omvandlare")
("converters to other data formats" "omvandlare till andra dataformat")
("convertible" "konvertibel")
("copy new objects to all frames" "kopiera nya objekt till alla ramar")
("copy new objects to previous frames" "kopiera nya objekt till tidigare ramar")
("copy new objects to subsequent frames" "kopiera nya objekt till efterföljande ramar")
("copy text" "kopiera text")
("copy to" "kopia till")
("copy to all frames after" "kopia till alla ramar efter")
("copy to all frames before" "kopia till alla ramar innan")
("copy to all other frames" "kopia till alla andra ramar")
("copyright" "copyright")
("cork charset with TeX catcode definition in preamble" "korkbitar med TeX-kodkoddefinition i ingressen)")
("cork with catcodes" "kork med koder")
("correct" "korrekt")
("correct all" "korrigera alla")
("correct formula" "korrekt formel")
("correct manually" "korrigera manuellt")
("correct mathematical formulas" "korrekta matematiska formler")
("correct text" "rätt text")
("correction" "korrigering")
("cosine" "kosinus")
("count characters" "räkna tecken")
("count lines" "räknelinjer")
("count words" "räkna ord")
("create a new document" "skapa ett nytt dokument")
("create link" "skapa länk")
("create preamble" "skapa ingress")
("create remote account" "skapa fjärrkonto")
("create remote directory" "skapa fjärrkatalog")
("create remote file" "skapa fjärrfil")
("create subprogram" "skapa underprogram")
("create subsession" "skapa subsession")
("create table macro" "skapa tabellmakro")
("create web site" "skapa webbplats")
("creating new account" "skapa nytt konto")
("creating technical pictures" "skapa tekniska bilder")
("crop" "gröda")
("crop marks" "grödor")
("cross" "kors")
("crossed boxes" "korsade rutor")
("crossed circles" "korsade cirklar")
("current user version" "aktuell användarversion")
("current version" "aktuell version")
("cursor" "markör")
("curve" "kurva")
("curve intersections" "kurvkorsningar")
("curve points" "kurvpunkter")
("custom tab" "anpassad flik")
("customizations" "anpassningar")
("customizing TeXmacs" "anpassa TeXmacs")
("customizing and extending the user interface" "anpassa och utöka användargränssnittet")
("customizing the TeXmacs styles" "anpassa TeXmacs-stilar")
("custum tab" "custum-flik")
("cut text" "klipp text")
("cut to" "snitt till")
("cyan" "cyan")
("cyrillic input method" "cyrillisk inmatningsmetod")
("czech" "tjeckisk")
("danish" "danska")
("dark grey" "mörkgrå")
("dash" "streck")
("dashes" "streck")
("data" "data")
("data conversion" "datakonvertering")
("data format" "dataformat")
("database entry" "databasinmatning")
("database tool" "databasverktyg")
("database toolbar" "databasverktygsfält")
("date" "datum")
("deactivate" "inaktivera")
("deactivate once" "inaktivera en gång")
("deactivate table" "inaktivera tabell")
("dead" "död")
("debug" "felsökning")
("debugging console" "felsökningskonsol")
("debugging tool" "felsökningsverktyg")
("decimal comma" "decimal komma")
("decimal dot" "decimalpunkt")
("decomposed" "sönderdelad")
("decorate atoms" "dekorera atomer")
("decorated" "dekorerad")
("decorated wood" "dekorerat trä")
("decorative" "dekorativ")
("decrease size" "minska storlek")
("decrypt" "dekryptera")
("decrypted" "dekrypterat")
("decryption" "dekryptering")
("default padding" "standard stoppning")
("default size" "standardstorlek")
("degrade" "degradera")
("degraded" "degraderad")
("delete column" "radera kolumn")
("delete documentation cache" "ta bort dokumentationscache")
("delete entries" "radera poster")
("delete link" "radera länk")
("delete row" "radera rad")
("delete selected entries in wallet" "radera valda poster i plånbok")
("delete user identity" "radera användaridentitet")
("deleted" "raderad")
("describe" "beskriv")
("describe tag" "beskriv tag")
("destination" "destination")
("destroy" "förstöra")
("detach master" "lossa master")
("detailed" "detaljerad")
("detailed menus" "detaljerade menyer")
("details in menus" "detaljer i menyer")
("determinant" "determinant")
("determine margins from text width" "bestämma marginaler från textbredd")
("developer" "utvecklare")
("developer tool" "utvecklarverktyg")
("developers guide" "utvecklarguide")
("device" "enhet")
("diamond" "diamant")
("differentiate" "differentiera")
("digital" "digital")
("dilate" "dilat")
("direction of progression" "progressionsriktning")
("direction of translation" "översättningsriktning")
("directory" "katalog")
("disable" "inaktivera")
("disable coloring on paper" "inaktivera färg på papper")
("disable encryption" "inaktivera kryptering")
("disable first indentation" "inaktivera första intryck")
("disable first indentation after" "inaktivera första intryck efter")
("disable first indentation before" "inaktivera första intrycket innan")
("disabled" "inaktiverad")
("disallow" "disallow")
("disappear" "försvinna")
("disk" "disk")
("display style" "visningsstil")
("displayed formula" "visad formel")
("dissociate joined cells" "dissociera förenade celler")
("distill encapsulated Pdf files" "destillera inkapslade Pdf-filer")
("distort" "distort")
("distorted" "förvrängd")
("distribute unused space" "distribuera oanvänt utrymme")
("div" "div")
("division" "division")
("do not remap" "ombilda inte")
("document colors" "dokumentfärger")
("document font selector" "dokumentteckensnittväljare")
("document format" "dokumentformat")
("document language" "dokumentspråk")
("document metadata" "dokumentmetadata")
("document page format" "dokumentsidesformat")
("document paragraph format" "dokumentparagrafformat")
("document source tree preferences" "inställningar för trädkällor för dokumentkälla")
("document updates run" "dokumentuppdateringar körs")
("documentation" "dokumentation")
("documents are trees" "dokument är träd")
("documents in separate windows" "dokument i separata fönster")
("dots" "prickar")
("download" "nedladdning")
("download file or directory" "ladda ner fil eller katalog")
("downwards" "nedåt")
("dragging" "dra")
("draw" "drag")
("draw graphics" "Rita grafik")
("draw image" "Rita bild")
("draw over" "draw over")
("draw over selection" "draw over select")
("drop" "droppe")
("due to" "på grund av")
("duplicate" "duplikat")
("dynamic" "dynamisk")
("dynamic libraries" "dynamiska bibliotek")
("eRROR" "eRROR")
("edit animation" "redigera animering")
("edit groups of objects" "redigera grupper av objekt")
("edit macro" "redigera makro")
("edit macros" "redigera makron")
("edit object properties" "redigera objektegenskaper")
("edit preamble" "redigera ingress")
("edit source" "redigera källa")
("edit source tree" "redigera källträd")
("edit style" "redigeringsstil")
("edit translations file" "redigera översättningsfil")
("editing tools" "redigeringsverktyg")
("education" "utbildning")
("effect pen" "effektpenna")
("eigenvalues" "egenvärden")
("eighth" "åttonde")
("email" "e-post")
("embold" "embold")
("emboss" "prägling")
("emphasize" "betona")
("emphasize text" "betona text")
("enable first indentation" "aktivera första intryck")
("enable first indentation after" "aktivera första intryck efter")
("enable first indentation before" "aktivera första intryck innan")
("enable page breaking" "aktivera sidbrytning")
("enabled" "aktiverad")
("encl" "encl")
("encoding" "kodning")
("encrypt" "kryptera")
("encrypted" "krypterad")
("encrypted buffer" "krypterad buffert")
("encryption" "kryptering")
("encryption error" "krypteringsfel")
("encryption facilities are not currently available" "krypteringsfaciliteter är inte tillgängliga för närvarande")
("encryption facilities have not been enabled for TeXmacs" "krypteringsfaciliteter har inte aktiverats för TeXmacs")
("enforce brackets to match" "tvinga fram parentes för att matcha")
("engrave" "gravera")
("enter a title" "ange en titel")
("enter data" "ange data")
("enter graphics" "ange grafik")
("enter graphics mode" "gå in i grafikläge")
("enter new passphrase for encryption" "ange ny lösenfras för kryptering")
("enter passphrase for decryption" "ange lösenfras för dekryptering")
("enter passphrase for identity" "ange lösenord för identitet")
("enter title information" "ange titelinformation")
("entire table" "hela tabellen")
("entry up to date in database" "aktuell uppdatering i databasen")
("enunciation" "uttalande")
("environment variable" "miljövariabel")
("environments" "miljöer")
("equal" "lika")
("equivalent for" "ekvivalent för")
("erode" "erodera")
("error messages" "felmeddelanden")
("error output" "felutgång")
("error status report" "felstatusrapport")
("error: bracket does not match" "fel: konsolen matchar inte")
("error: cyclic or missing chunks detected" "fel: cykliska eller saknade bitar upptäckta")
("error: file not found" "fel: fil hittades inte")
("error: ghostview does not seem to be installed on your system" "fel: ghostview verkar inte vara installerat på ditt system")
("error: one of the alternatives should be filled out" "fel: ett av alternativen bör fyllas ut")
("error: only one alternatives should be filled out" "fel: endast ett alternativ ska fyllas i")
("error: should fill out name for referencing" "fel: ska fylla i namn för referens")
("error: should fill out required field" "fel: ska fylla i obligatoriskt fält")
("escape" "fly")
("esperanto" "esperanto")
("evaluable field" "utvärderbart fält")
("evaluate" "utvärdera")
("evaluate above" "utvärdera ovan")
("evaluate all" "utvärdera alla")
("evaluate below" "utvärdera nedan")
("evaluate fields" "utvärdera fält")
("evaluate fields in order" "utvärdera fält i ordning")
("evaluate script" "utvärdera skript")
("evaluation" "utvärdering")
("evaluation switch" "utvärderingsomkopplare")
("evaluation tag" "utvärderingstagg")
("even page" "jämn sida")
("even page footer" "jämn sidfot")
("even page header" "jämn sidhuvud")
("even page left margin" "jämn marginal på vänster sida")
("even page shift" "jämn sidförskjutning")
("even page text" "jämn sidtext")
("even pages" "jämna sidor")
("events" "händelser")
("exact" "exakt")
("exact mode" "exakt läge")
("exam" "tentamen")
("exclusive" "exklusivt")
("exclusive or" "exklusivt eller")
("executable" "körbar")
("execution of scripts" "exekvering av skript")
("exit graphics" "utgångsgrafik")
("exit graphics mode" "avsluta grafikläge")
("exit left" "utgång vänster")
("exit right" "utgång höger")
("exit tag on the left" "exit-tagg till vänster")
("exit tag on the right" "exit tag till höger")
("expand" "expandera")
("expand TeXmacs macros with no LaTeX equivalents" "expandera TeXmac-makron utan LaTeX-ekvivalenter")
("expand beamer slides" "expandera beamer slides")
("expand inclusions" "expandera inkluderingar")
("expand logarithms" "expandera logaritmer")
("expand trigonometric functions" "expandera trigonometriska funktioner")
("expand unrecognized macros" "expandera okända makron")
("expand user-defined macros" "expandera användardefinierade makron")
("expanded" "utvidgad")
("experimental features (to be used with care)" "experimentella funktioner (ska användas med försiktighet)")
("explain" "förklara")
("explained" "förklarade")
("explanatory item" "förklarande artikel")
("explicit keystroke" "uttrycklig tangenttryckning")
("explicit margins" "uttryckliga marginaler")
("exponential" "exponentiell")
("export as" "exportera som")
("export bibliographies as links" "exportera bibliografier som länkar")
("export bibliography" "exportbibliografi")
("export entries in buffer" "exportera poster i buffert")
("export file" "exportfil")
("export formulas as images" "exportformler som bilder")
("export mathematical formulas as MathML" "exportera matematiska formler som MathML")
("export mathematical formulas as images" "exportera matematiska formler som bilder")
("export selected entries" "exportera valda poster")
("export selection" "exportval")
("export selection as image" "exportval som bild")
("export selections as" "exportval som")
("export sessions" "exportsessioner")
("exported bibliographic entries" "exporterade bibliografiska poster")
("exported bibliographic references" "exporterade bibliografiska referenser")
("extend" "förlänga")
("extend table to full paragraph width" "utöka tabellen till hela styckets bredd")
("extended" "utökad")
("extensible left arrow" "utdragbar vänsterpil")
("extensible right arrow" "utdragbar högerpil")
("extern" "extern")
("extern " "extern")
("external" "extern")
("extra" "extra")
("extra branch" "extra gren")
("extra interline space" "extra interline space")
("extra name" "extra namn")
("extract" "extrakt")
("extract format" "extraktformat")
("extract style file" "extrahera stilfil")
("extract style package" "paket med extraktstil")
("factor" "faktor")
("fade" "blekna")
("fade in" "blekna in")
("fade out" "blekna ut")
("fast" "snabbt")
("fast decrease" "snabb minskning")
("fast environments" "snabba miljöer")
("fast increase" "snabb ökning")
("field reference" "fältreferens")
("fifth" "femte")
("file saved" "fil sparad")
("fill color" "fyllfärg")
("fill out" "fyll i")
("filter" "filter")
("find file" "hitta fil")
("find next match" "hitta nästa match")
("find text" "hitta text")
("finished collecting symbols documentation" "färdig samla dokumentation av symboler")
("finnish" "finsk")
("first" "först")
("first chunk" "första biten")
("first contact" "första kontakt")
("first difference" "första skillnaden")
("first error" "första felet")
("first field" "första fältet")
("first occurrence" "första förekomst")
("first similar" "första liknande")
("first start" "första start")
("fit" "passform")
("fit to height" "anpassad till höjd")
("fit to screen" "fit to screen")
("fit to screen width" "anpassad till skärmbredd")
("fit to width" "passar till bredd")
("five columns" "fem kolumner")
("fixed" "fast")
("flag is off" "flaggan är av")
("flag is on" "flaggan är på")
("flatten" "platta")
("flexibility" "flexibilitet")
("flexibility factor for vertical spacing" "flexibilitetsfaktor för vertikalt avstånd")
("floating algorithm" "flytande algoritm")
("floating figure" "flytande figur")
("floating object" "flytande objekt")
("floating phantom" "flytande fantom")
("floating table" "flytande bord")
("focus" "fokus")
("focus dependent icons" "fokusberoende ikoner")
("fold" "vik")
("fold all" "vik alla")
("fold all fields" "vik alla fält")
("fold back" "fäll tillbaka")
("fold input field" "vik inmatningsfält")
("folded" "vikta")
("follow external links" "följ externa länkar")
("follow inverse links" "följ omvända länkar")
("font customization" "fontanpassning")
("font effects" "fonteffekter")
("font name" "typsnittnamn")
("font selector" "teckensnittsväljare")
("font type" "typsnitt")
("font variant" "typsnittsvariant")
("fonts" "typsnitt")
("footer" "sidfot")
("footnote" "fotnot")
("for" "för")
("for each" "för varje")
("force reloading of translations" "tvinga om omlastning av översättningar")
("foreground" "förgrund")
("format" "format")
("formatted and structured output" "formaterad och strukturerad utgång")
("formatted date" "formaterat datum")
("formatting" "formatering")
("forward" "framåt")
("forward replace" "framåt ersätt")
("forward search" "framåt sökning")
("four columns" "fyra kolumner")
("four dots" "fyra prickar")
("fourth" "fjärde")
("fraktur" "fraktur")
("framed" "inramad")
("framed theorems" "inramade satser")
("from" "från")
("from center" "från centrum")
("front matter" "främre materia")
("full" "full")
("full author list" "fullständig författarlista")
("full manuals" "fullständiga manualer")
("full screen mode" "helskärmsläge")
("functional" "funktionell")
("further customization" "ytterligare anpassning")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs kommer utan någon form av laglig garanti")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs faller under GNU: s allmänna licens")
("gap" "gap")
("garbage collection" "sopsamling")
("gaussian" "gaussian")
("gcd" "gcd")
("general" "allmänt")
("general architecture of TeXmacs" "allmän arkitektur av TeXmacs")
("general note" "allmän not")
("generate GnuPG key" "generera GnuPG-nyckel")
("generated LaTeX document contains no errors" "genererat LaTeX-dokument innehåller inga fel")
("generated field" "genererat fält")
("generating font file" "genererar teckensnittsfil")
("generic" "generisk")
("geometry" "geometri")
("get arity" "få arity")
("get label" "få etikett")
("get list with remote versions" "få lista med fjärrversioner")
("global log" "global logg")
("global status" "global status")
("glossary entry" "ordlista")
("glue decorations" "limdekorationer")
("glue multiple spaces" "lim flera utrymmen")
("glyphs" "glyfer")
("gnaw" "gnaga")
("gnawed" "gnagd")
("gnuPG command" "gnuPG-kommando")
("gnuPG decryption error" "gnuPG-dekrypteringsfel")
("gnuPG error: buffer encryption failed" "gnuPG-fel: buffertkryptering misslyckades")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG-fel: kan inte hitta lämplig hemlig nyckel för att dekryptera")
("gnuPG requires name and email to have at least 5 characters" "gnuPG kräver namn och e-post för att ha minst 5 tecken")
("go" "gå")
("go to anchor" "gå till ankare")
("go to anchor or float" "gå till ankare eller flottör")
("go to anchor or footnote" "gå till ankare eller fotnot")
("go to first similar tag" "gå till den första liknande taggen")
("go to float" "gå till flyta")
("go to footnote" "gå till fotnot")
("go to last similar tag" "gå till sista liknande tagg")
("go to next similar tag" "gå till nästa liknande tagg")
("go to previous similar tag" "gå till föregående liknande tagg")
("go to section" "gå till sektion")
("grain" "korn")
("granite" "granit")
("graphical effects" "grafiska effekter")
("graphical interface font scale" "skala för grafiskt gränssnitt")
("graphical overlays" "grafiska överlägg")
("graphical slides and overlays" "grafiska bilder och överlägg")
("graphics" "grafik")
("graphics geometry" "grafikgeometri")
("graphics grids" "grafiknät")
("greater" "större")
("greater or equal" "större eller lika")
("greyed" "gråtonad")
("grid" "rutnät")
("grid curves" "rutnätkurvor")
("grid points" "rutnätpunkter")
("grid-curve intersections" "grid-kurvskorsningar")
("group of objects" "grupp av objekt")
("group/ungroup" "grupp / avgrupp")
("group/ungroup objects" "grupp / ta bort gruppobjekt")
("grouped" "grupperad")
("guarantee transparent source tracking" "garantera transparent källspårning")
("h modifier" "h modifierare")
("half wide" "halv bred")
("hand drawn" "handritad")
("handwritten" "handskrivna")
("hangul" "hangul")
("happy typing" "glad att skriva")
("has been aborted" "har avbrutits")
("has completed its task" "har slutfört sin uppgift")
("header" "rubrik")
("header and footer" "sidhuvud och sidfot")
("headers" "rubriker")
("height is exactly the specified height" "höjd är exakt den specificerade höjden")
("height is maximum of specified height and box height" "höjd är högst specificerad höjd och boxhöjd")
("height is minimum of specified height and box height" "höjd är minst specificerad höjd och boxhöjd")
("help us" "hjälp oss")
("here" "här")
("hidden" "dold")
("high resolution settings" "inställningar med hög upplösning")
("history" "historia")
("home" "hem")
("homepage" "hemsida")
("homoglyph substitutions" "homoglyfsubstitutioner")
("horizontal" "horisontell")
("horizontal alignment" "horisontell inriktning")
("horizontal cell alignment" "horisontell cellinriktning")
("horizontal collapse distance" "horisontellt kollapsavstånd")
("horizontal margins" "horisontella marginaler")
("horizontal part" "horisontell del")
("horizontal table alignment" "horisontell tabellinriktning")
("horizontally align cell to the base" "horisontellt anpassa cell till basen")
("horizontally center the cell" "horisontellt centrera cellen")
("how much longer may pages become" "hur mycket längre tid kan bli")
("how much shorter may pages become" "hur mycket kortare sidor kan bli")
("hungarian" "ungerska")
("hybrid command" "hybridkommando")
("hyphenate as" "bindestreck som")
("icon" "ikon")
("if" "om")
("if hyphenated" "om bindestreck")
("ignore" "ignorera")
("image links" "bildlänkar")
("impact" "påverkan")
("import bibliography" "importbibliografi")
("import database entry" "importdatabasinmatning")
("import entries in buffer" "importera poster i buffert")
("import entry" "importpost")
("import file" "importfil")
("import public keys from buffer" "importera offentliga nycklar från buffert")
("import selected database entries" "importera valda databasposter")
("import selected entries" "importera valda poster")
("import selections as" "importval som")
("import sessions" "importsessioner")
("import sophisticated objects as pictures" "importera sofistikerade objekt som bilder")
("imported bibliographic entries" "importerade bibliografiska poster")
("improving the current implementation" "förbättra den nuvarande implementeringen")
("in popup windows" "i popup-fönster")
("inanimated" "inanimerad")
("inch" "tum")
("include" "inkludera")
("include a document" "inkludera ett dokument")
("include file" "inkludera fil")
("inclusion into TeXmacs" "inkludering i TeXmacs")
("inclusions" "inneslutningar")
("incomplete entries found to be filled out" "ofullständiga poster visade sig vara fyllda ut")
("increase size" "öka storleken")
("indent paragraphs" "strecksatser")
("indentation" "intryck")
("index entry" "indexpost")
("indication" "indikation")
("informative flags" "informativa flaggor")
("initialize" "initialisera")
("initialize wallet" "initialisera plånbok")
("initials" "initialer")
("ink here" "bläck här")
("ink in" "bläck in")
("ink out" "bläck ut")
("inline" "inline")
("inline args" "inline args")
("inline arguments" "inline argument")
("inline code" "inline-kod")
("inline content" "inline innehåll")
("inline formula" "inline formel")
("inner bottom" "inre botten")
("inner left" "inre vänster")
("inner right" "inre höger")
("inner top" "inre topp")
("input command" "ingångskommando")
("input field" "inmatningsfält")
("input mode" "ingångsläge")
("input options" "inmatningsalternativ")
("insert a big operator" "infoga en stor operatör")
("insert a binary operation" "infoga en binär operation")
("insert a binary relation" "infoga en binär relation")
("insert a blackboard bold character" "infoga en svart tavla fet karaktär")
("insert a bold calligraphic character" "infoga ett djärvt kalligrafiskt tecken")
("insert a bold character" "infoga ett djärvt tecken")
("insert a calligraphic character" "infoga ett kalligrafiskt tecken")
("insert a computer program" "infoga ett datorprogram")
("insert a condition" "infoga ett villkor")
("insert a control flow instruction" "infoga en styrflödesinstruktion")
("insert a fraction" "infoga en bråkdel")
("insert a fraktur character" "infoga en frakturkaraktär")
("insert a gap" "infoga ett gap")
("insert a greek character" "infoga en grekisk karaktär")
("insert a large left delimiter" "infoga en stor vänsteravgränsare")
("insert a large right delimiter" "infoga en stor högeravgränsare")
("insert a large separator" "infoga en stor separator")
("insert a link" "infoga en länk")
("insert a list" "infoga en lista")
("insert a miscellaneous symbol" "infoga en diverse symbol")
("insert a multiple choice" "infoga ett flerval")
("insert a negation" "infoga en negation")
("insert a new entry" "infoga en ny post")
("insert a new item" "infoga en ny artikel")
("insert a note or a floating object" "infoga en anteckning eller ett flytande objekt")
("insert a numerical operation" "infoga en numerisk operation")
("insert a picture" "infoga en bild")
("insert a prominent piece of text" "infoga en framstående textbit")
("insert a question" "infoga en fråga")
("insert a root" "infoga en rot")
("insert a script" "infoga ett skript")
("insert a section block" "infoga ett sektionsblock")
("insert a square root" "infoga en kvadratrot")
("insert a table" "infoga en tabell")
("insert a table or a matrix" "infoga en tabell eller en matris")
("insert a textual operation" "infoga en textoperation")
("insert a textual operator" "infoga en textoperatör")
("insert a wide symbol above" "sätt in en bred symbol ovan")
("insert a wide symbol below" "sätt in en bred symbol nedan")
("insert above" "infoga ovan")
("insert abstract" "infoga abstrakt")
("insert an" "infoga en")
("insert an accent" "infoga en accent")
("insert an answer" "infoga ett svar")
("insert an arrow" "infoga en pil")
("insert an enunciation" "infoga ett uttal")
("insert an environment" "infoga en miljö")
("insert an n" "infoga ett n")
("insert an operation on tuples" "infoga en operation på tuples")
("insert annotation" "infoga kommentar")
("insert arcs" "infoga bågar")
("insert argument after" "infoga argument efter")
("insert argument before" "infoga argument före")
("insert author" "infoga författare")
("insert automatically generated content" "infoga automatiskt genererat innehåll")
("insert below" "infoga nedan")
("insert bibliography" "infoga bibliografi")
("insert circles" "infoga cirklar")
("insert closed splines" "infoga stängda splines")
("insert column" "infoga kolumn")
("insert column to the left" "infoga kolumn till vänster")
("insert column to the right" "infoga kolumn till höger")
("insert copyright and license information" "infoga upphovsrätt och licensinformation")
("insert executable markup" "infoga körbar markering")
("insert explanatory item" "infoga förklarande artikel")
("insert field above" "infoga fält ovan")
("insert field below" "infoga fält nedan")
("insert fields" "infoga fält")
("insert footnote" "infoga fotnot")
("insert hand drawn curves" "infoga handritade kurvor")
("insert image" "infoga bild")
("insert inactive markup" "infoga inaktiv markering")
("insert input field above" "infoga inmatningsfält ovan")
("insert input field below" "infoga inmatningsfält nedan")
("insert large delimiters" "infoga stora avgränsare")
("insert last name" "infoga efternamn")
("insert left" "infoga vänster")
("insert lines" "infoga rader")
("insert macro" "infoga makro")
("insert mathematics" "infoga matematik")
("insert missing invisible operators" "infoga saknade osynliga operatörer")
("insert more names" "infoga fler namn")
("insert multiple paragraphs" "infoga flera stycken")
("insert new rows or columns" "infoga nya rader eller kolumner")
("insert or delete rows or columns" "infoga eller radera rader eller kolumner")
("insert overlay after" "infoga överlägg efter")
("insert overlay before" "infoga överlägg före")
("insert particle" "infoga partikel")
("insert plain text" "infoga vanlig text")
("insert points" "infoga poäng")
("insert polygons" "infoga polygoner")
("insert right" "infoga höger")
("insert row" "infoga rad")
("insert row above" "infoga rad ovan")
("insert row below" "infoga rad nedan")
("insert similar above" "infoga liknande ovan")
("insert similar below" "infoga liknande nedan")
("insert similar block above" "infoga liknande block ovan")
("insert similar block below" "infoga liknande block nedan")
("insert slide after" "infoga bild efter")
("insert slide before" "infoga bild före")
("insert splines" "infoga splines")
("insert structural markup" "infoga strukturell markering")
("insert subscript" "infoga abonnemang")
("insert subtable" "infoga subtablerande")
("insert superscript" "infoga superscript")
("insert symbol documentation" "infoga symboldokumentation")
("insert template" "infoga mall")
("insert text" "infoga text")
("insert text field" "infoga textfält")
("insert text field above" "infoga textfält ovan")
("insert text field below" "infoga textfält nedan")
("insert title" "infoga titel")
("insert title after name" "infoga titel efter namn")
("insert user interface related markup" "infoga användargränssnittrelaterad markering")
("insert value" "infoga värde")
("inserting control points" "infoga styrpunkter")
("inside mathematics" "inuti matematik")
("integrate" "integrera")
("interactive command" "interaktivt kommando")
("interactive questions" "interaktiva frågor")
("intercharacter compression" "interkaraktärkomprimering")
("intercharacter stretching" "interkaraktärsträckning")
("interfacing" "gränssnitt")
("interfacing TeXmacs with other systems" "gränssnitt TeXmac med andra system")
("interjection" "injektion")
("interline separation" "mellanlinjeseparering")
("internationalization" "internationalisering")
("interrupt execution" "avbrott av körning")
("interrupted" "avbruten")
("invalid multi-paragraph selection" "ogiltigt val av flera stycken")
("invalid renaming" "ogiltig byte av namn")
("invert" "invertera")
("inverted breve" "inverterad breve")
("invisible" "osynlig")
("invisible ending" "osynlig avslutning")
("invisible newline" "osynlig ny linje")
("invisible opening" "osynlig öppning")
("inwards" "inåt")
("is running" "kör")
("is tuple" "är tuple")
("ispell does not respond" "ispell svarar inte")
("ispell is already busy" "ispell är redan upptagen")
("italian" "italiensk")
("japanese" "japansk")
("join selected cells" "gå med i utvalda celler")
("jump in" "hoppa in")
("junior" "junior")
("justify" "motivera")
("justify text" "motivera text")
("keep evaluated expressions" "håll utvärderade uttryck")
("keep local" "håll lokal")
("keep remote" "håll fjärrkontrollen")
("keep track of source code" "hålla reda på källkoden")
("keep unfolded" "fortsätt utvecklas")
("key" "nyckel")
("key manager" "key manager")
("keyboard configuration" "tangentbordskonfiguration")
("keyboard equivalent" "tangentbord motsvarande")
("keyboard modifiers" "tangentbordsmodifierare")
("keyboard shortcut" "kortkommando")
("keyword" "nyckelord")
("keywords" "nyckelord")
("laTeX errors" "laTeX-fel")
("laptop presentations" "bärbara presentationer")
("large brackets" "stora konsoler")
("large cells" "stora celler")
("large displayed" "stor visas")
("large displayed fraction" "stor visad bråk")
("large tables" "stora bord")
("last" "sista")
("last check" "sista kontrollen")
("last difference" "sista skillnaden")
("last error" "sista fel")
("last field" "sista fältet")
("last name" "efternamn")
("last occurrence" "senaste händelse")
("last similar" "senast liknande")
("lcm" "lcm")
("left arrow" "vänsterpil")
("left axis" "vänsteraxel")
("left baseline" "vänster baslinje")
("left bottom" "vänster botten")
("left cell border" "vänstercellgräns")
("left cell padding" "vänstercellstoppning")
("left center" "vänster mitt")
("left click: add point; Right click: undo" "vänsterklick: lägg till punkt; Högerklicka: ångra")
("left click: finish; Right click: undo" "vänsterklick: avsluta; Högerklicka: ångra")
("left click: new object" "vänsterklick: nytt objekt")
("left click: operate" "vänsterklick: operera")
("left down" "vänster ner")
("left on even pages" "kvar på jämna sidor")
("left padding" "vänster stoppning")
("left prime" "left prime")
("left surrounding" "vänster omgivande")
("left table border" "vänster bordskant")
("left table padding" "vänster bordstoppning")
("left top" "vänster topp")
("left up" "vänster upp")
("left-right arrow" "vänster-höger pil")
("leftwards" "vänster")
("length" "längd")
("less" "mindre")
("less or equal" "mindre eller lika")
("let the environment float" "låt miljön flyta")
("light grey" "ljusgrå")
("limits" "gränser")
("line arrows" "radpilar")
("line breaking" "radbrytning")
("line dashes" "radstreck")
("line portion" "raddel")
("line style" "linjestil")
("line width" "radbredd")
("line wrapping" "linjeomslag")
("line wrapping inside cell" "radomslag inuti cellen")
("linear 2D" "linjär 2D")
("linear algebra" "linjär algebra")
("lines around" "linjer runt")
("link image" "länkbild")
("link image and copies as" "länkbild och kopierar som")
("link image as" "länkbild som")
("link mode" "länkläge")
("link to URL" "länk till URL")
("linking tool" "länkverktyg")
("live" "live")
("live input-output" "live input-output")
("load a file" "ladda en fil")
("load buffer" "lastbuffert")
("load file" "ladda fil")
("load help file" "ladda hjälpfil")
("load image" "ladda bild")
("load remote file" "ladda fjärrfil")
("loading" "lastning")
("local entries" "lokala poster")
("loci" "loci")
("locus" "locus")
("locus rendering" "locus rendering")
("logarithm" "logaritm")
("logarithmic" "logaritmisk")
("logarithmic base" "logaritmisk bas")
("logarithms" "logaritmer")
("logging in" "loggar in")
("logical and" "logiskt och")
("logical implication" "logisk implikation")
("logical not" "logiskt inte")
("logical or" "logiskt eller")
("login" "inloggning")
("logout" "utloggning")
("long macro" "lång makro")
("long text" "lång text")
("look and feel" "look and feel")
("look for more fonts" "leta efter fler teckensnitt")
("look up" "slå upp")
("loops" "slingor")
("m modifier" "m modifierare")
("macro" "makro")
("macro argument" "makroargument")
("macro definition" "makrodefinition")
("macro editor" "makroeditor")
("macro name" "makronamn")
("macros" "makron")
("macros editor" "makroseditor")
("magnify horizontally" "förstora horisontellt")
("magnify vertically" "förstora vertikalt")
("main" "huvud")
("main icon bar" "huvudikonfältet")
("main presentation style" "huvudpresentationstil")
("major changes" "större förändringar")
("make a letter environment" "skapa en bokstavsmiljö")
("make a multi-slide presentation" "göra en presentation med flera bilder")
("make a page insertion" "gör en sidainsättning")
("make a subscript" "gör ett abonnemang")
("make a superscript" "gör ett superscript")
("make block wide" "make block wide")
("make float wide" "gör float wide")
("make floating" "gör flytande")
("make footnote wide" "gör fotnot bred")
("make link" "gör länk")
("make non floating" "gör icke flytande")
("make page reference" "göra sidreferens")
("make wide" "gör bred")
("making donations" "gör donationer")
("manila paper" "manilapapper")
("manual" "manual")
("map arguments" "kartargument")
("map to" "karta till")
("marginal note" "marginalnot")
("margins as on paper" "marginaler som på papper")
("margins from width" "marginaler från bredden")
("margins on paper" "marginaler på papper")
("margins on screen" "marginaler på skärmen")
("marked" "markerad")
("marker" "markör")
("master" "mästare")
("master file" "huvudfil")
("material" "material")
("math Extra" "matematik extra")
("math Letters" "matematiska bokstäver")
("math Symbols" "matematiska symboler")
("mathematical and customized input" "matematisk och anpassad inmatning")
("mathematical font" "matematisk typsnitt")
("mathematical formulas" "matematiska formler")
("mathematical input" "matematisk inmatning")
("mathematical output" "matematisk utgång")
("mathematical typesetting" "matematisk inställning")
("matrices" "matriser")
("maximal" "maximalt")
("maximal cell height" "maximal cellhöjd")
("maximal clustering" "maximal klustering")
("maximal number of columns" "maximalt antal kolumner")
("maximal number of rows" "maximalt antal rader")
("maximal table height" "maximal bordhöjd")
("maximal table width" "maximal tabellbredd")
("maximum" "maximalt")
("maximum mode" "maximalt läge")
("meander" "slingrande")
("medieval" "medeltida")
("memory" "minne")
("memory usage" "minnesanvändning")
("menu" "meny")
("merge" "sammanslagning")
("merge lines into paragraphs unless separated by blank lines" "slå samman linjer i stycken om de inte är separerade med tomma rader")
("messages" "meddelanden")
("meta data" "metadata")
("meta key" "metatangent")
("metadata" "metadata")
("metal" "metall")
("middle baseline" "mitt baslinje")
("minimal" "minimal")
("minimal cell height" "minimal cellhöjd")
("minimal cell width" "minimal cellbredd")
("minimal line separation" "minimal linjeseparering")
("minimal number of columns" "minimalt antal kolumner")
("minimal number of rows" "minimalt antal rader")
("minimal table height" "minimal bordhöjd")
("minimal table width" "minimal bordbredd")
("minimum" "minimum")
("minimum mode" "minimiläge")
("mirror" "spegel")
("miscellaneous features" "diverse funktioner")
("miscellanous" "diverse")
("mixed" "blandad")
("mod" "mod")
("mode dependent icons" "läge beroende ikoner")
("modifier" "modifierare")
("modify bibliography" "modifiera bibliografi")
("modify cell alignment" "modifiera cellinriktning")
("modify cell border" "ändra cellgränsen")
("modify cell padding" "modifiera cellplastning")
("modify cell size" "modifiera cellstorlek")
("modify remote live document" "ändra externt live-dokument")
("modify table border" "modifiera tabellgränsen")
("modify table padding" "modifiera bordstoppning")
("module" "modul")
("module browser" "modulwebbläsare")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help" "mer information om GNU TeXmac finns i Hjälpen")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "mer information om GNU TeXmac finns i Hjälp-<gtr> Om-menyn")
("more information about GNU TeXmacs can be found in the help" "mer information om GNU TeXmac finns i hjälpen")
("motion" "rörelse")
("mouse over object" "mus över objekt")
("move" "flytta")
("move objects" "flytta objekt")
("move over object on which to operate" "flytta över objekt som ska fungera")
("multiline" "multiline")
("multiline input" "multiline input")
("multiple choice" "flerval")
("multiple documents share window" "fönstret för flera dokumentdelning")
("multiple root" "multipelrot")
("multiplication" "multiplikation")
("mutator tags" "mutator taggar")
("my documents" "mina dokument")
("named" "heter")
("navigation options" "navigationsalternativ")
("never" "aldrig")
("new account" "nytt konto")
("new bibliography dialogue" "ny bibliografidialog")
("new buffer" "ny buffert")
("new document" "nytt dokument")
("new double page" "ny dubbelsida")
("new double page before" "ny dubbelsida innan")
("new entry" "ny post")
("new identity" "ny identitet")
("new locus" "nytt lokus")
("new macro" "ny makro")
("new page before" "ny sida innan")
("new passphrase" "ny lösenfras")
("new remote directory" "ny fjärrkatalog")
("new remote file" "ny fjärrfil")
("new style fonts" "ny typsnitt")
("new style page breaking" "ny stil sidbrytning")
("new version" "ny version")
("new window" "nytt fönster")
("newer version" "nyare version")
("next" "nästa")
("next chunk" "nästa bit")
("next difference" "nästa skillnad")
("next error" "nästa fel")
("next field" "nästa fält")
("next occurrence" "nästa förekomst")
("next screen" "nästa skärm")
("next similar" "nästa liknande")
("no animation" "ingen animering")
("no clustering" "ingen kluster")
("no completions" "inga kompletteringar")
("no dictionary for" "ingen ordbok för")
("no errors have been corrected" "inga fel har korrigerats")
("no grid" "inget rutnät")
("no indentation" "ingen intryck")
("no matches found" "inga matchningar hittade")
("no matches found for" "inga träffar hittades för")
("no more matches for" "inga fler matcher för")
("no more redo information available" "Inte mer göra om information tillgänglig")
("no more undo information available" "inte längre ångra information tillgänglig")
("no multiple spaces" "inga flera mellanslag")
("no new public key in document" "ingen ny offentlig nyckel i dokumentet")
("no page break" "ingen sidbrytning")
("no page numbers" "inga sidnummer")
("no parent" "ingen förälder")
("no selection" "inget val")
("no spelling errors" "inga stavfel")
("no spelling errors found in text" "inga stavfel hittade i text")
("no spurious spaces" "inga falska utrymmen")
("no style" "ingen stil")
("normal loci" "normal loci")
("norwegian" "norsk")
("not" "inte")
("not allowed to remove home directory" "får inte ta bort hemkatalogen")
("not connected to server" "inte ansluten till servern")
("not equal" "inte lika")
("not yet implemented" "ännu inte implementerat")
("notation" "notation")
("notebook" "anteckningsbok")
("number" "nummer")
("number equation" "talekvation")
("number of columns" "antal kolumner")
("number of polar steps" "antal polära steg")
("number of subunit steps" "antal underenhetssteg")
("numbered" "numrerad")
("numbering" "numrering")
("numeric spreadsheet" "numeriskt kalkylblad")
("oblique" "sned")
("occurrences" "händelser")
("odd page" "udda sida")
("odd page footer" "udda sidfot")
("odd page header" "udda sidhuvud")
("odd page left margin" "udda sidomarginal")
("odd page right margin" "udda sidor höger marginal")
("odd page shift" "udda sidförskjutning")
("odd page text" "udda sidtext")
("odd pages" "udda sidor")
("of fingerprint" "av fingeravtryck")
("ok" "ok")
("old style" "gammal stil")
("old version" "gammal version")
("older version" "äldre version")
("on cells" "på celler")
("on columns" "på kolumner")
("on entire table" "på hela bordet")
("on rows" "på rader")
("on the footer" "på sidfoten")
("on your system and set it up from the \"Security\" tab" "på ditt system och konfigurera det från fliken \"Säkerhet\"")
("once" "en gång")
("one column" "en kolumn")
("one error has been corrected" "ett fel har rättats")
("one lower case letter, one non alpha-numeric symbol" "en liten bokstav, en icke alfanumerisk symbol")
("one numeric character, one upper case letter" "ett numeriskt tecken, en stor bokstav")
("one spelling error has been corrected" "ett stavfel har korrigerats")
("online documentation" "online-dokumentation")
("online help" "onlinehjälp")
("only convert changes when re-importing" "konverterar endast ändringar vid återimport")
("only convert changes with respect to imported version" "konverterar endast ändringar med avseende på importerad version")
("only convert changes with respect to tracked version" "konverterar endast ändringar med avseende på spårad version")
("only implemented for complete subtrees" "implementeras endast för kompletta underträd")
("only inline tags" "endast inline taggar")
("only keep folded" "bara hålla vikta")
("only keep unfolded" "bara fortsätt utvecklas")
("only show paragraphs with hits" "visa endast stycken med träffar")
("only show semantic focus" "endast visa semantiskt fokus")
("opacity" "opacitet")
("open" "öppen")
("open a new buffer" "öppna en ny buffert")
("open bibliography" "öppen bibliografi")
("open identities" "öppna identiteter")
("open in new window" "öppnas i nytt fönster")
("open key manager" "open key manager")
("open licence agreement" "öppet licensavtal")
("open mailbox" "öppen brevlåda")
("open module browser" "webbläsare med öppen modul")
("open symbol browser" "webbläsare med öppen symbol")
("open tool in separate window" "öppet verktyg i separat fönster")
("opening" "öppning")
("operation mode" "driftläge")
("operation on named selection" "operation på namngivna val")
("operation on primary selection" "operation vid primärval")
("operation on secondary selection" "operation vid sekundärval")
("operation on ternary selection" "operation vid ternär val")
("or" "eller")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "eller ge den kompletta sökvägen till kommandot \"gpg\" eller \"gpg2\"")
("order" "beställning")
("ordinary symbol" "vanlig symbol")
("origin" "ursprung")
("original welcome message" "original välkomstmeddelande")
("ornamented" "ornament")
("other login" "annan inloggning")
("other package" "annat paket")
("other pages" "andra sidor")
("other style" "annan stil")
("outer bottom" "yttre botten")
("outer left" "yttre vänster")
("outer right" "yttre höger")
("outer top" "yttre topp")
("outline" "disposition")
("outlined" "beskrivs")
("outlined emboss" "beskrivs prägling")
("outlined engrave" "skisserad gravering")
("output options" "utgångsalternativ")
("outwards" "utåt")
("oval" "oval")
("over" "över")
("overbrace" "överbrace")
("overlap" "överlappning")
("overlay" "överlägg")
("overlay mode" "överläggningsläge")
("overlays" "överlägg")
("overline" "överlinje")
("overlined" "överlinjerad")
("overview of the scheme extension language" "översikt över schemaens förlängningsspråk")
("padded" "vadderad")
("padding" "stoppning")
("page background" "sidobakgrund")
("page break after" "sidbrytning efter")
("page break before" "sidbrytning före")
("page breaking algorithm" "sidbrytande algoritm")
("page format" "sidformat")
("page insertion" "sidinsättning")
("page number" "sidnummer")
("page number rendering" "rendering av sidnummer")
("page number text" "sidnummer text")
("page numbering" "sidnummer")
("page reference" "sidreferens")
("page rendering" "sidåtergivning")
("page setup" "sidinställning")
("pagedown" "pagedown")
("pageup" "pageup")
("palette" "palett")
("panorama" "panorama")
("paragraph format" "styckeformat")
("paragraphs" "stycken")
("parametric curve" "parametrisk kurva")
("parametric surface" "parametrisk yta")
("parenthesis" "parentes")
("parenthesized" "parentes")
("particle" "partikel")
("passphrase decryption" "lösenfrasdekryptering")
("passphrase encryption" "lösenfrasskryptering")
("passphrase wallet facilities are not currently available" "passphrase plånbok är inte tillgängligt för närvarande")
("passphrases are expected to have at least: 8 characters" "lösenfraser förväntas ha minst: 8 tecken")
("passphrases mismatch" "lösenfraser överensstämmer")
("paste from" "klistra in från")
("paste text" "klistra in text")
("pastel" "pastell")
("pattern" "mönster")
("pattern selector" "mönsterväljare")
("pause" "paus")
("pdf version number" "pdf-version nummer")
("pen" "penna")
("pen width" "pennbredd")
("perform operations on cells" "utföra operationer på celler")
("perform operations on columns" "utför operationer på kolumner")
("perform operations on entire table" "utföra operationer på hela bordet")
("perform operations on rows" "utför operationer på rader")
("permanent" "permanent")
("permanent footer" "permanent sidfot")
("permanent header" "permanent rubrik")
("permanently add to dictionary" "permanent lägg till i ordlistan")
("permanently insert into dictionary" "permanent infoga i ordboken")
("permissions" "behörigheter")
("person" "person")
("personal dictionary has been modified" "personlig ordbok har ändrats")
("phantom" "fantom")
("phantoms" "fantom")
("philosophy" "filosofi")
("physics and astronomy class" "fysik och astronomiklass")
("picture" "bild")
("pine" "tall")
("plain" "vanlig")
("plain block" "vanligt block")
("plain boxes" "vanliga lådor")
("plain circles" "vanliga cirklar")
("plain tabular" "vanlig tabell")
("planned changes" "planerade ändringar")
("plans for the future" "planer för framtiden")
("play" "spela")
("play all animations" "spela alla animationer")
("play animation" "spela animation")
("please install GnuPG software from https://www.gnupg.org" "installera GnuPG-programvara från https://www.gnupg.org")
("please wait" "vänta")
("plot" "tomt")
("plug-ins" "plug-ins")
("plugin" "plugin")
("plugins" "plugins")
("plural" "plural")
("plus" "plus")
("point" "punkt")
("point border" "punktgräns")
("point size" "punktstorlek")
("point style" "punktstil")
("polar" "polärt")
("polish" "polska")
("polygon" "polygon")
("pop server settings" "pop-serverinställningar")
("porting TeXmacs to other platforms" "portar TeXmac till andra plattformar")
("portion" "portion")
("portuguese" "portugisiska")
("position float" "position float")
("position floating object" "position flytande objekt")
("position of marginal note" "marginalnotens position")
("position the table" "placera bordet")
("poster formats" "affischformat")
("poster theme" "affischtema")
("postfix" "postfix")
("preamble mode" "ingressläge")
("preferences" "preferenser")
("preferences for editing mathematical formulas" "preferenser för redigering av matematiska formler")
("preferences for tag" "preferenser för tagg")
("prefix" "prefix")
("presentation" "presentation")
("presentation mode" "presentationsläge")
("presentation tag" "presentationstagg")
("presentation tool" "presentationsverktyg")
("preserve" "bevara")
("preserve tags" "bevara taggar")
("pretty" "vacker")
("pretty tree output" "vacker trädutgång")
("preview" "förhandsvisning")
("preview command" "förhandsvisningskommando")
("previous" "föregående")
("previous difference" "föregående skillnad")
("previous error" "föregående fel")
("previous field" "föregående fält")
("previous occurrence" "tidigare förekomst")
("previous screen" "föregående skärm")
("previous similar" "tidigare liknande")
("primary" "primär")
("prime" "prime")
("primitive or macro" "primitiv eller makro")
("print buffer" "utskriftsbuffert")
("print buffer to file" "utskriftsbuffert till fil")
("print document" "tryckt dokument")
("print to file" "skriva ut till fil")
("printer" "skrivare")
("printer setup" "skrivarinställning")
("problem" "problem")
("produce Pdf using native export filter" "producera Pdf med ursprungligt exportfilter")
("produce Postscript using native export filter" "producera Postscript med nativt exportfilter")
("program bracket matching" "programfäste matchning")
("program bracket selections" "val av programfäste")
("program commands" "programkommandon")
("program font" "programteckensnitt")
("program interface for buffer management" "programgränssnitt för bufferthantering")
("programming" "programmering")
("programming routines for editing documents" "programmeringsrutiner för redigering av dokument")
("progressive" "progressiv")
("prominent" "framträdande")
("prompt on scripts" "prompt på skript")
("prompts and default input" "instruktioner och standardinmatning")
("proportional" "proportionell")
("provoke C++ error" "provocera C ++-fel")
("provoke menu error" "provokera menyfel")
("provoke scheme error" "provokera schemafel")
("pseudo code" "pseudokod")
("public key encryption" "kryptering av offentlig nyckel")
("public keys" "offentliga nycklar")
("pulse" "puls")
("qt GUI only, sorry. Use \"Export selection\"" "Endast qt GUI, sorry. Använd \"Exportera val\"")
("qt-widgets" "qt-widgets")
("quantifier" "kvantifierare")
("quasi" "kvasi")
("query replace" "fråga ersätt")
("question" "fråga")
("questions only" "bara frågor")
("questions with answers" "frågor med svar")
("quick evaluation of formulas" "snabb utvärdering av formler")
("range" "intervall")
("rank" "rang")
("raw" "rå")
("really close it" "verkligen stäng det")
("really delete user identity" "verkligen radera användaridentitet")
("really tiny" "riktigt liten")
("rebuild translations file" "bygga om översättningsfilen")
("recent" "nyligen")
("recent documents" "senaste dokument")
("recipients" "mottagare")
("recognize" "känna igen")
("recolor" "återfärgning")
("recover autosave file" "återställa autosavefil")
("rectangular" "rektangulär")
("redo" "göra om")
("redo undone changes" "ångra ångra ändringar")
("reduce" "minska")
("reduce trigonometric functions" "minska trigonometriska funktioner")
("reduced margins" "reducerade marginaler")
("reference guide" "referensguide")
("reference guide for the TeXmacs primitives" "referensguide för TeXmacs primitiva")
("reference guide for the standard TeXmacs styles" "referensguide för TeXmacs standardformat")
("regenerate" "regenerera")
("register" "register")
("register file" "registerfil")
("regular" "vanlig")
("relate" "relatera")
("relation" "relation")
("release left button: finish editing" "släpp vänster knapp: avsluta redigeringen")
("reload" "ladda om")
("remote" "fjärrkontroll")
("remote connections" "fjärranslutningar")
("remote control" "fjärrkontroll")
("remote controllers with keyboard simulation" "fjärrkontroller med tangentbordssimulering")
("remote directory" "fjärrkatalog")
("remote login" "fjärrinloggning")
("remote servers" "fjärrservrar")
("remote tool" "fjärrverktyg")
("remove" "ta bort")
("remove all output fields" "ta bort alla utgångsfält")
("remove animation" "ta bort animering")
("remove argument after" "ta bort argument efter")
("remove argument before" "ta bort argument innan")
("remove banner" "ta bort banner")
("remove database entry" "ta bort databasposten")
("remove downwards" "ta bort nedåt")
("remove entries" "ta bort poster")
("remove entry" "ta bort post")
("remove field above" "ta bort fältet ovan")
("remove field below" "ta bort fältet nedan")
("remove fields" "ta bort fält")
("remove folded" "ta bort vikta")
("remove from previous frames" "ta bort från tidigare ramar")
("remove from subsequent frames" "ta bort från efterföljande ramar")
("remove input field" "ta bort inmatningsfält")
("remove input field above" "ta bort inmatningsfältet ovan")
("remove last field" "ta bort sista fältet")
("remove leftwards" "ta bort vänster")
("remove link" "ta bort länk")
("remove next field" "ta bort nästa fält")
("remove number" "ta bort nummer")
("remove overlay after" "ta bort överlägg efter")
("remove overlay before" "ta bort överlägg innan")
("remove package" "ta bort paketet")
("remove previous field" "ta bort föregående fält")
("remove rightwards" "ta bort höger")
("remove selected database entries" "ta bort valda databasposter")
("remove selected entries" "ta bort valda poster")
("remove slide after" "ta bort bild efter")
("remove slide before" "ta bort bild före")
("remove superfluous invisible operators" "ta bort överflödiga osynliga operatörer")
("remove tag" "ta bort tagg")
("remove this branch" "ta bort denna gren")
("remove this frame" "ta bort den här ramen")
("remove this switch" "ta bort den här omkopplaren")
("remove unfolded" "ta bort brett")
("remove upwards" "ta bort uppåt")
("removed entries from database" "borttagna poster från databasen")
("removed entry from database" "borttagen post från databasen")
("rename" "byta namn")
("rename section" "byta namn på avsnitt")
("rendering" "rendering")
("rendering options for tag" "återgivningsalternativ för tagg")
("renumber this page" "byta om denna sida")
("repeat" "upprepa")
("repeat object" "upprepa objekt")
("replace" "ersätt")
("replace TeXmacs styles with no LaTeX equivalents" "ersätta TeXmacs-stilar utan LaTeX-ekvivalenter")
("replace all further occurrences" "ersätta alla ytterligare händelser")
("replace by" "ersätt med")
("replace one occurrence" "ersätt en händelse")
("replace toolbar" "byt verktygsfält")
("replace unrecognized styles" "ersätta okända stilar")
("replaced" "ersatt")
("replaced one occurrence" "ersatt en händelse")
("reset error counters" "Ã\x85terställ felräknare")
("resize" "ändra storlek")
("resize objects" "ändra storlek på objekt")
("restart TeXmacs in order to let changes take effect" "starta om TeXmacs för att låta ändringar träda i kraft")
("restart in order to let the new look and feel take effect" "starta om för att låta det nya utseendet och känslan träda i kraft")
("retain" "behålla")
("retime" "retime")
("retina settings" "retina-inställningar")
("retrieve email" "hämta e-post")
("retrieve remote live document" "hämta externt live-dokument")
("retrieved contents" "hämtat innehåll")
("retro" "retro")
("reverse" "omvänd")
("reverse ordering" "omvänd beställning")
("revert" "återgå")
("ridged paper" "ridged paper")
("right arrow" "högerpil")
("right baseline" "höger baslinje")
("right cell border" "höger cellgräns")
("right cell padding" "polstring med höger cell")
("right down" "höger ned")
("right on even pages" "rätt på jämna sidor")
("right padding" "höger stoppning")
("right surrounding" "höger om")
("right table border" "höger bordgräns")
("right table padding" "höger bordstoppning")
("right up" "rätt upp")
("rightwards" "höger")
("rigid box" "styv låda")
("rotate" "rotera")
("rotate backward" "rotera bakåt")
("rotate forward" "rotera framåt")
("rotate objects" "rotera objekt")
("rough" "grov")
("rough paper" "grovt papper")
("round" "rund")
("round overbrace" "rund överbrace")
("round underbrace" "rund underbrace")
("row above" "rad ovan")
("row below" "rad under")
("rows" "rader")
("run" "kör")
("run current file" "kör aktuell fil")
("running author" "kör författare")
("running title" "körtitel")
("russian" "ryska")
("same names" "samma namn")
("same screen margins as on paper" "samma skärmmarginaler som på papper")
("sample" "prov")
("sample text" "exempeltext")
("save auxiliary data" "spara hjälpdata")
("save buffer" "spara buffert")
("save buffer as" "spara buffert som")
("save entries" "spara poster")
("save entry" "spara post")
("save file" "spara fil")
("save image" "spara bild")
("save image as" "spara bild som")
("save position" "spara position")
("save remote file" "spara fjärrfil")
("save this buffer" "spara denna buffert")
("saved modifications in database" "sparade ändringar i databasen")
("scheme command" "schemakommando")
("scheme developers guide" "schemautvecklare guide")
("scheme extensions" "schemaläggningar")
("scheme interface for the graphical mode" "schema-gränssnitt för det grafiska läget")
("screen" "skärm")
("screen rendering" "skärmvisning")
("screens" "skärmar")
("screenshot" "skärmdump")
("scripting language" "skriptspråk")
("scripts" "skript")
("scripts not accepted" "manus accepteras inte")
("search" "sökning")
("search and replace" "sök och ersätt")
("search in database" "sök i databasen")
("search results for" "sökresultat för")
("search toolbar" "sökverktygsfält")
("search words in my documents" "sökord i mina dokument")
("search words in the documentation" "sökord i dokumentationen")
("search words in the source code" "sökord i källkoden")
("searching" "sökande")
("second" "sekund")
("secondary" "sekundär")
("secret keys" "hemliga nycklar")
("sections" "sektioner")
("security" "säkerhet")
("see" "se")
("see documentation" "se dokumentation")
("select GnuPG recipients" "välj GnuPG-mottagare")
("select a document style" "välj en dokumentstil")
("select a foreground color" "välj en förgrundsfärg")
("select a language" "välj ett språk")
("select background picture" "välj bakgrundsbild")
("select document style" "välj dokumentstil")
("select pen" "välj penna")
("select the action to be undertaken for each conflict" "välj den åtgärd som ska vidtas för varje konflikt")
("select view mode" "välj visningsläge")
("selections" "val")
("semantic correctness" "semantisk korrekthet")
("semantic editing" "semantisk redigering")
("semantic selections" "semantiska markeringar")
("semantics" "semantik")
("sending commands to TeXmacs" "skicka kommandon till TeXmacs")
("senior" "senior")
("serb" "serb")
("serif" "serif")
("server" "server")
("server licence agreement" "serverlicensavtal")
("session commands" "sessionskommandon")
("session name" "sessionens namn")
("session type" "sessionstyp")
("sessions" "sessioner")
("set background color of cell" "ställa in cellens bakgrundsfärg")
("set cell mode" "ställa in cellläge")
("set default" "ställa in standard")
("set difference" "inställd skillnad")
("set extension center" "inställ förlängningscenter")
("set height" "inställd höjd")
("set height of cell" "inställd cellhöjd")
("set intersection" "inställningskorsning")
("set number of columns" "inställt antal kolumner")
("set number of rows" "inställt antal rader")
("set or get environment variables" "ställa in eller få miljövariabler")
("set paragraph margins" "fastställa styckemarginaler")
("set paragraph mode" "ställa avsnittläge")
("set properties" "inställningsegenskaper")
("set span" "set span")
("set special cell properties" "ställa in speciella cellegenskaper")
("set special table properties" "ställa in specialtabellegenskaper")
("set union" "fast union")
("set user information" "ställa in användarinformation")
("set width" "ställa in bredd")
("set width of cell" "ställa in cellens bredd")
("settings" "inställningar")
("seventh" "sjunde")
("several equations" "flera ekvationer")
("shadow" "skugga")
("shadowed" "skuggad")
("shadowed raise" "skuggad höjning")
("shift" "skift")
("short" "kort")
("show" "show")
("show all parts" "visa alla delar")
("show current focus" "visa aktuellt fokus")
("show full context" "visa fullständigt sammanhang")
("show hidden" "visa dold")
("show key presses" "visa knapptryckningar")
("show main document" "visa huvuddokument")
("show memory usage" "visa minnesanvändning")
("show on screen" "visa på skärmen")
("show one part" "visa en del")
("show panorama" "visa panorama")
("show preamble" "visa ingress")
("show several parts" "visa flera delar")
("show subunits" "visa underenheter")
("show table cells" "visa tabellceller")
("show timings" "visa tidpunkter")
("side tools" "sidoverktyg")
("signature" "signatur")
("simple" "enkel")
("simple form" "enkel form")
("simple widget" "enkel widget")
("simplification" "förenkling")
("simplified evaluation of formulas" "förenklad utvärdering av formler")
("simplified menus" "förenklade menyer")
("simplify" "förenkla")
("sine" "sinus")
("sixth" "sjätte")
("size limits" "storleksbegränsningar")
("size tag" "storlek tagg")
("skew" "skev")
("skin" "hud")
("skip all" "hoppa över alla")
("slant" "sned")
("slashed fraction" "snittad fraktion")
("slides" "slides")
("sloppy" "slarvig")
("slovene" "slovenska")
("slow" "långsam")
("slow decrease" "långsam minskning")
("slow increase" "långsam ökning")
("small Capitals" "små huvudstäder")
("small capitals" "småstäder")
("small environment box" "liten miljöbox")
("small figure" "liten figur")
("small focus" "litet fokus")
("small inline" "liten inline")
("small inline fraction" "liten inlinefraktion")
("small table" "litet bord")
("smash" "smash")
("smooth" "slät")
("smooth end" "slät ände")
("smooth extremities" "släta extremiteter")
("smooth start" "smidig start")
("snap" "snap")
("snap distance" "snäppavstånd")
("snap to curves" "snäpp till kurvor")
("snap to grid" "snap to grid")
("snap to grid curve" "snap to grid curve")
("snap to intersections of curves" "snäpp till korsningar av kurvor")
("snap to text borders" "snäpp till textgränser")
("snap to text corners" "snäpp till texthörn")
("solution" "lösning")
("solution to exercise" "lösning på träning")
("solution to problem" "lösning på problem")
("solutions" "lösningar")
("sound" "ljud")
("source" "källa")
("source code" "källkod")
("source macros tool" "källmakrosverktyg")
("source tags" "källtaggar")
("south" "söder")
("south east" "sydost")
("space bar in math mode" "mellanslag i matematikläge")
("space bar in text mode" "mellanslag i textläge")
("space between lines" "utrymme mellan linjer")
("space between paragraphs" "utrymme mellan stycken")
("space stretchability" "utrymmessträckbarhet")
("span" "span")
("span over all columns" "spänner över alla kolumner")
("spanish" "spanska")
("special cell properties" "speciella cellegenskaper")
("special functions" "specialfunktioner")
("special properties" "specialegenskaper")
("special table properties" "specialtabellegenskaper")
("specific baseline" "specifik baslinje")
("specified" "specificerad")
("specify color alternation" "specificera färgväxling")
("specify how to traverse the manual" "specificera hur man går igenom manualen")
("specify semantics of a symbol or formula" "specificera semantik för en symbol eller formel")
("specify the size of the table" "ange tabellens storlek")
("specify user identity" "specificera användaridentitet")
("spell" "stava")
("spell check" "stavningskontroll")
("spell checking complete" "stavningskontroll fullständig")
("spelling error" "stavfel")
("spelling errors have been corrected" "stavfel har korrigerats")
("spline" "spline")
("split program" "split program")
("split session" "split session")
("square" "kvadrat")
("square overbrace" "fyrkantig överbryggning")
("square underbrace" "kvadratisk underbrace")
("stack" "stack")
("standard" "standard")
("standard Output" "standardutgång")
("standard TeXmacs styles" "standard TeXmacs-stilar")
("standard environment variables" "standardmiljövariabler")
("standard formats" "standardformat")
("standard fraction" "standardfraktion")
("star" "stjärna")
("start a new chapter" "starta ett nytt kapitel")
("start a new section" "starta ett nytt avsnitt")
("start an interactive session" "starta en interaktiv session")
("start server" "startserver")
("statement" "uttalande")
("statistics" "statistik")
("status" "status")
("status bar" "statusfält")
("stop server" "stoppserver")
("storage" "lagring")
("store tracking information in LaTeX files" "lagra spårningsinformation i LaTeX-filer")
("stretch" "stretch")
("stretch factor" "sträckfaktor")
("stretched" "sträckt")
("strict Ascii" "strikt Ascii")
("strike through" "slå igenom")
("stroke" "stroke")
("strokes" "slag")
("strong" "stark")
("structural" "strukturell")
("structured insert above" "strukturerat inlägg ovan")
("structured insert at the left" "strukturerat skär till vänster")
("structured insert at the right" "strukturerat skär till höger")
("structured insert below" "strukturerat inlägg nedan")
("structured remove downwards" "strukturerad ta bort nedåt")
("structured remove leftwards" "strukturerad ta bort vänster")
("structured remove rightwards" "strukturerad ta bort höger")
("structured remove upwards" "strukturerat ta bort uppåt")
("structured variant" "strukturerad variant")
("style options" "stilalternativ")
("style parameters" "stilparametrar")
("stylesheet language" "stilarkspråk")
("sub" "sub")
("subject" "ämne")
("submenu" "undermeny")
("subparagraph" "stycke")
("subscript below" "abonnemang nedan")
("subsub" "subsub")
("subsubmenu" "subsubmenu")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtablerbar")
("subtitle" "undertext")
("subtraction" "subtraktion")
("summarized" "sammanfattad")
("summary" "sammanfattning")
("summary of the principal TeXmacs tags" "sammanfattning av de viktigaste TeXmacs-taggarna")
("superpose" "superpose")
("superposed" "överlagrad")
("superscript above" "superscript ovan")
("supported plug-ins" "stödd plug-ins")
("surface" "yta")
("inflate" "svälla")
("swiss" "schweizisk")
("switch" "switch")
("switch to buffer" "växla till buffert")
("switch to first" "växla till först")
("switch to last" "växla till sista")
("switch to next" "växla till nästa")
("switch to previous" "växla till föregående")
("switching and folding" "växla och vikas")
("symbol browser" "symbolwebbläsare")
("symbol properties not found" "symbolegenskaper hittades inte")
("symbols" "symboler")
("synchronization status" "synkroniseringsstatus")
("synchronize" "synkronisera")
("synchronize bibliographic references" "synkronisera bibliografiska referenser")
("synchronize file or directory" "synkronisera fil eller katalog")
("synchronize with remote server" "synkronisera med fjärrservern")
("synopsis" "synopsis")
("system command" "systemkommando")
("system environment variables" "systemmiljövariabler")
("tab-completion" "tabbfyllning")
("tabbed" "flik")
("table breaking" "tabellbrytning")
("table command" "tabellkommando")
("table height" "bordhöjd")
("table properties" "tabellegenskaper")
("table width" "bordbredd")
("tables" "tabeller")
("tabular material" "tabellmaterial")
("tags with special rendering" "taggar med speciell återgivning")
("tangent" "tangent")
("teXmacs DTD" "teXmacs DTD")
("teXmacs as an interface" "teXmacs som gränssnitt")
("teXmacs buffer expected" "teXmacs buffert förväntas")
("teXmacs buffer on disk expected" "teXmacs buffert på disk förväntad")
("teXmacs database preferences" "teXmacs databasinställningar")
("teXmacs extensions to scheme and utilities" "teXmacs tillägg till schema och verktyg")
("teXmacs fonts" "teXmacs-teckensnitt")
("teXmacs macro" "teXmacs makro")
("teXmacs notice" "teXmacs meddelande")
("teXmacs package" "teXmacs-paket")
("teXmacs plugins" "teXmacs plugins")
("teXmacs primitives" "teXmacs primitiva")
("teXmacs style" "teXmacs-stil")
("teXmacs style files" "teXmacs stilfiler")
("ternary" "ternär")
("test routine" "testrutin")
("testing tree-view" "testa trädvy")
("text borders" "textgränser")
("text box style" "textboxstil")
("text corners" "texthörn")
("text height correction" "korrigering av texthöjd")
("text padding" "textfyllning")
("texts" "texter")
("textual" "textuell")
("textual operator" "textoperatör")
("textual spreadsheet" "textligt kalkylblad")
("the TeXmacs authors" "TeXmacs författare")
("the TeXmacs format" "TeXmacs-formatet")
("the TeXmacs plug-in system" "TeXmacs plug-in-system")
("the application did not send its usual startup banner" "ansökan skickade inte sitt vanliga startbaner")
("the application does not reply" "ansökan svarar inte")
("the application is already running" "applikationen körs redan")
("the boxes produced by the typesetter" "lådorna producerade av typsättaren")
("the document has not been saved" "dokumentet har inte sparats")
("the graphical user interface" "det grafiska användargränssnittet")
("the leaves of TeXmacs trees" "bladen på TeXmacs träd")
("the mycas example" "mycas exemplet")
("the primitive TeXmacs constructs" "de primitiva TeXmacs-konstruktionerna")
("the standard TeXmacs styles" "de vanliga TeXmacs-stilarna")
("theme parameters" "temaparametrar")
("these collected public keys will be definitely lost" "dessa insamlade offentliga nycklar kommer definitivt att gå förlorade")
("these public keys will be definitely lost" "dessa offentliga nycklar kommer definitivt att gå förlorade")
("these secret keys will be definitely lost" "dessa hemliga nycklar kommer definitivt att gå förlorade")
("thicken" "tjockare")
("thin" "tunn")
("third" "tredje")
("this" "detta")
("this column" "denna kolumn")
("this document has been produced using" "detta dokument har producerats med")
("this document has not been saved" "detta dokument har inte sparats")
("this page" "denna sida")
("this page footer" "denna sidfot")
("this page header" "denna sidhuvud")
("this page number" "detta sidnummer")
("this row" "denna rad")
("this style specifies page margins in the TeX way" "den här stilen specificerar sidmarginaler på TeX-sättet")
("three columns" "tre kolumner")
("three dots" "tre prickar")
("three times" "tre gånger")
("through popup windows" "genom popup-fönster")
("through the menus" "genom menyerna")
("thumbnails" "miniatyrbilder")
("time evolution" "tidsutveckling")
("times" "gånger")
("timings" "tidtagningar")
("title presentation options" "Alternativ för titelpresentation")
("title style" "titelstil")
("title suffix" "titelsuffix")
("titled block" "betecknad block")
("to the left" "till vänster")
("to the right" "till höger")
("today" "idag")
("toggle cell wrapping mode" "växla cellomslagsläge")
("toggle here" "växla här")
("toggle name" "växla namn")
("toggle numbering" "växla numrering")
("toggle off" "slå av")
("toggle on" "slå på")
("toggle specification" "växlingsspecifikation")
("toggle titled" "toggle titled")
("tolerant" "tolerant")
("tools" "verktyg")
("top baseline" "topp baslinje")
("top border" "övre gränsen")
("top cell border" "toppcellgräns")
("top cell padding" "toppcellstoppning")
("top padding" "top padding")
("top table border" "övre bordgränsen")
("top table padding" "toppbordstoppning")
("transform" "transformera")
("transform cell into subtable" "omvandla cell till subtablerbar")
("translate" "översätta")
("translations" "översättningar")
("translations loaded" "översättningar laddade")
("transpose" "transponera")
("traversal" "traversal")
("traverse" "travers")
("triangle" "triangel")
("triangularize" "triangularisera")
("trigonometric" "trigonometrisk")
("trigonometry" "trigonometri")
("tuple" "tuple")
("turn off" "stäng av")
("turn on" "slå på")
("turn on wallet" "slå på plånboken")
("tutorial" "tutorial")
("twice" "två gånger")
("two columns" "två kolumner")
("two dots" "två prickar")
("type a latex command followed by return" "skriv ett latexkommando följt av retur")
("typesetted boxes" "typsatta lådor")
("typing a simple text" "att skriva en enkel text")
("typing simple texts" "att skriva enkla texter")
("ukrainian" "ukrainska")
("unchanged" "oförändrad")
("underbrace" "underbrace")
("underline" "understrykning")
("underlined" "understruket")
("undo last changes" "ångra senaste ändringar")
("unevaluated argument" "ovärderat argument")
("unevaluated value" "ovärderat värde")
("unextended" "ej utvidgad")
("unfold" "utvecklas")
("unfold all" "utveckla alla")
("unfold all fields" "utveckla alla fält")
("unfolded" "utbrett")
("unit" "enhet")
("unit length" "enhetslängd")
("unknown secret key fingerprint" "okänt hemligt nyckelfingeravtryck")
("unregistered file" "oregistrerad fil")
("unroll" "rulle")
("unsecure script refused" "osäkert skript vägrade")
("unsupported link mode" "länkläge som inte stöds")
("until" "till")
("untitled block" "untitled block")
("up to date" "aktuell")
("update buffer" "uppdateringsbuffert")
("update from web" "uppdatering från webben")
("update image links" "uppdatera bildlänkar")
("update this buffer" "uppdatera denna buffert")
("update web site" "uppdatera webbplats")
("upight" "upprätt")
("upload" "ladda upp")
("upload file or directory" "ladda upp fil eller katalog")
("upright" "upprätt")
("upwards" "uppåt")
("url" "url")
("use CSS for more advanced formatting" "använd CSS för mer avancerad formatering")
("use MathML" "använd MathML")
("use TeXmacs" "använd TeXmacs")
("use a bold font" "använd ett djärvt teckensnitt")
("use a calligraphic font" "använd ett kalligrafiskt teckensnitt")
("use a sans serif font" "använd ett sans serif-teckensnitt")
("use a typewriter font" "använd ett typmaskinsteckensnitt")
("use as master" "använd som master")
("use calligraphical font" "använd kalligrafiskt teckensnitt")
("use extensible brackets" "använd utdragbara konsoler")
("use high resolution fonts" "använder högupplösta typsnitt")
("use high resolution icons" "använd ikoner med hög upplösning")
("use left hand column as border" "använd vänster kolumn som gräns")
("use line wrapping for lines which are longer than 80 characters" "använd radomslag för rader som är längre än 80 tecken")
("use margin kerning (protrusion)" "använd marginal kerning (utsprång)")
("use paragraph width" "använd styckebredden")
("use print dialogue" "använd tryckt dialog")
("use protrusion" "använda utsprång")
("use relative path" "använd relativ sökväg")
("use retina fonts" "använd retina-teckensnitt")
("use retina icons" "använd retinaikoner")
("use right hand column as border" "använd höger kolumn som gräns")
("use row above as border" "använd raden ovan som gräns")
("use row below as border" "använd raden nedan som gräns")
("use small capitals" "använd små huvudstäder")
("use the blackboard bold font" "använd tavlan med fet stil")
("use the fraktur font" "använd frakturteckensnittet")
("use unified toolbars" "använd enhetliga verktygsfält")
("user interface" "användargränssnitt")
("user interface language" "språk för användargränssnitt")
("user manual" "användarmanual")
("user preferences" "användarinställningar")
("user provided icons" "ikoner för användare som tillhandahålls")
("users of Cyrillic languages" "användare av kyrilliska språk")
("users of oriental languages" "användare av orientaliska språk")
("utf-8 with inputenc" "utf-8 med inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 med inputenc LaTeX-paket")
("utilities" "verktyg")
("value" "värde")
("vanish" "försvinna")
("variable" "variabel")
("variant" "variant")
("verbose" "verbose")
("version" "version")
("versioning tool" "versioneringsverktyg")
("vertical" "vertikal")
("vertical alignment" "vertikal justering")
("vertical cell alignment" "vertikal cellinriktning")
("vertical margins" "vertikala marginaler")
("vertical part" "vertikal del")
("vertical space after" "vertikalt utrymme efter")
("vertical space before" "vertikalt utrymme före")
("vertical space stretchability" "vertikal utdragbarhet")
("vertical table alignment" "vertikal bordinriktning")
("vertically align cell to the base" "justera cell vertikalt mot basen")
("vertically center the cell" "vertikalt centrera cellen")
("view" "vy")
("visible" "synlig")
("visible except here" "synlig utom här")
("visible from here on" "synlig härifrån")
("visible only here" "endast synlig här")
("visible until here" "synlig tills här")
("visited loci" "besökte loci")
("wallet" "plånbok")
("wave" "våg")
("web" "webb")
("weight" "vikt")
("welcome to GNU TeXmacs" "Välkommen till GNU TeXmacs")
("what is new" "vad är nytt")
("when line wrapping" "vid radomslag")
("when wrapping" "vid inslagning")
("while" "medan")
("whitespace" "vitrum")
("wide" "bred")
("wide bar" "bred bar")
("wide block" "brett block")
("wide colored" "bred färgad")
("wide float" "bred float")
("wide footnote" "bred fotnot")
("wide tabular" "brett tabellformat")
("widescreen" "widescreen")
("width is exactly the specified width" "bredd är exakt den specificerade bredden")
("width is maximum of specified width and box width" "bredd är högst angiven bredd och rutbredd")
("width is minimum of specified width and box width" "bredd är minst angiven bredd och rutbredd")
("window" "fönster")
("windows key" "windows key")
("with" "med")
("with newer version" "med nyare version")
("with older version" "med äldre version")
("wrap lines" "lindningslinjer")
("write a macro" "skriv en makro")
("write a name" "skriv ett namn")
("write bold mathematics" "skriva fet matematik")
("write bold text" "skriva fet text")
("write italic text" "skriv kursiv text")
("write sample text" "skriv provtext")
("write strong text" "skriv stark text")
("write typewriter text" "skriva skrivmaskintext")
("write verbatim text" "skriva verbatim text")
("writing TeXmacs bibliography styles" "skriver TeXmacs bibliografi-stilar")
("writing data converters" "skriva datakonverterare")
("writing documentation" "skriva dokumentation")
("writing your own style files" "skriva dina egna stilfiler")
("written with TeXmacs" "skriven med TeXmacs")
("wrong empty passphrase" "fel tom lösenfras")
("wrong passphrase" "fel lösenfras")
("year" "år")
("year, Name" "år, namn")
("you are attempting to open an encrypted file while" "du försöker öppna en krypterad fil medan")
("you might consider enabling the experimental" "du kan överväga att aktivera det experimentella")
("you must add a bibliography file" "du måste lägga till en bibliografifil")
("you should also make sure that GnuPG is installed" "Du bör också se till att GnuPG är installerat")
("your document is back in its original state" "ditt dokument är tillbaka i sitt ursprungliga skick")
("your first interface" "ditt första gränssnitt")
("your language" "ditt språk")
("your personal dictionary has been modified" "din personliga ordbok har ändrats")
("zebra" "zebra")
("zoom" "zoom")
("zoom in" "zooma in")
("zoom out" "zooma ut")
("zoom/unzoom objects" "zoom / avzoom objekt")
