<TeXmacs|1.0.7.20>

<style|source>

<\body>
  <\active*>
    <\src-title>
      <src-style-file|seminar|1.0>

      <\src-purpose>
        The seminar style.
      </src-purpose>

      <\src-copyright|1998--2004>
        Joris van der Hoeven
      </src-copyright>

      <\src-license>
        This software falls under the <hlink|GNU general public license,
        version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
        WARRANTY WHATSOEVER. You should have received a copy of the license
        which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
      </src-license>
    </src-title>
  </active*>

  <use-package|seminar>

  \;

  <assign|part-display-numbers|<macro|false>>

  <assign|chapter-display-numbers|<macro|false>>

  <assign|section-display-numbers|<macro|false>>

  <assign|subsection-display-numbers|<macro|false>>

  <assign|subsubsection-display-numbers|<macro|false>>

  <assign|paragraph-display-numbers|<macro|false>>

  <assign|subparagraph-display-numbers|<macro|false>>

  <assign|appendix-display-numbers|<macro|false>>
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>