("\"encryption\" features from the preference panel" "환경 설정 패널의 암호화 기능")
("(Re)Build autocompletion index" "(재) 빌드 자동 완성 색인")
("a.C.M. computing class" "a.C.M. 컴퓨팅 클래스")
("a.M.S. subject class" "a.M.S. 과목 클래스")
("abbreviated authors" "약칭 된 저자")
("abreviated authors" "약칭 작가")
("accent above" "위의 액센트")
("accent below" "아래 악센트")
("accept during this pass" "이 패스 중에 수락")
("acknowledgments" "승인")
("active link types" "개의 활성 링크 유형")
("add" "추가")
("add abstract information" "추상 정보 추가")
("add author information" "저자 정보 추가")
("add branch after" "다음 지점 추가")
("add branch before" "전에 지점 추가")
("add other package" "다른 패키지 추가")
("add style package" "스타일 패키지 추가")
("add title information" "제목 정보 추가")
("addition" "추가")
("adjust" "조정")
("adjust limits" "제한 조정")
("advanced font customization" "고급 글꼴 사용자 정의")
("affiliation" "계열")
("align cell to the decimal comma" "10 진수 쉼표에 셀 정렬")
("align cell to the decimal dot" "소수점에 셀 정렬")
("align table at axis" "축에 테이블 정렬")
("alignment of balloon" "풍선의 정렬")
("all cells" "모든 세포")
("all data attached to this identity will be lost" "이 ID에 첨부 된 모든 데이터가 손실됩니다")
("all saved passphrases will be lost forever" "저장된 모든 암호는 영구적으로 손실됩니다")
("allow for macro definitions in preamble" "프리앰블의 매크로 정의 허용")
("allowed page height extension" "허용 된 페이지 높이 확장")
("allowed page height reduction" "허용 된 페이지 높이 감소")
("allowed positions" "허용 위치")
("allowed positions of floating object" "부동 물체의 허용 위치")
("alpha transparency" "알파 투명도")
("also on paper" "종이에")
("alter" "변경")
("alternate" "대체")
("alternate except here" "여기를 제외하고 대체")
("alternate from here on" "여기부터 변경")
("alternate only here" "여기에만 변경")
("alternate until here" "여기까지 대체")
("always" "항상")
("amplified" "증폭 된")
("and perform casual settings from the \"Encryption\" tab" "\"암호화\" 탭에서 일반 설정 수행")
("animate" "애니메이션")
("animate folding" "애니메이션 폴딩")
("animate unfolding" "애니메이션 전개")
("animated" "애니메이션")
("animation toolbar" "애니메이션 툴바")
("annotate" "주석")
("answer" "답변")
("answer field" "답변 입력란")
("answer to question" "질문에 대한 답변")
("answers only" "답변 만")
("any" "any")
("appear" "나타납니다")
("approximate" "대략")
("arc" "아크")
("arc cosine" "아크 코사인")
("arc sine" "아크 사인")
("arc tangent" "아크 탄젠트")
("are you sure you want to delete collected public keys" "수집 된 공개 키를 삭제 하시겠습니까?")
("are you sure you want to delete selected public keys" "선택한 공개 키를 삭제 하시겠습니까?")
("are you sure you want to delete selected secret keys" "선택한 비밀 키를 삭제 하시겠습니까?")
("are you sure you want to destroy the wallet" "지갑을 파괴하겠습니까?")
("art frame" "아트 프레임")
("arxiv category" "arxiv 카테고리")
("as visual grid" "비주얼 그리드로")
("aspect" "종횡비")
("attach master" "첨부 마스터")
("auto" "자동")
("auto-save file" "자동 저장 파일")
("automatic brackets" "자동 브래킷")
("automatic content generation" "자동 컨텐츠 생성")
("automatic program brackets" "자동 프로그램 브래킷")
("automatically import bibliographies when opening files" "파일을 열 때 자동으로 참고 문헌 가져 오기")
("automatically remember all passphrases in the wallet" "지갑에있는 모든 암호문을 자동으로 기억합니다")
("automatically save" "자동 저장")
("back" "뒤로")
("backtrace errors" "역 추적 오류")
("base" "베이스")
("baseline" "기준선")
("beamer" "비머")
("beamer formats" "비머 형식")
("beamer theme" "비머 테마")
("bench" "벤치")
("bend bottom" "굽힘 바닥")
("bend corner" "벤드 코너")
("bend diagonal" "구부리는 대각선")
("bend in" "구부리 다")
("bend out" "구부리 다")
("bezier" "베 지어")
("bibTeX command" "bibTeX 명령")
("bidirectional" "양방향")
("big environment box" "큰 환경 상자")
("big focus" "큰 초점")
("binary operator" "이진 연산자")
("bitmap resolution (dpi)" "비트 맵 해상도 (dpi)")
("black floral I" "블랙 플로랄 I")
("black floral II" "블랙 플로랄 II")
("blackboard embold" "칠판 내장")
("blank column" "공백 칼럼")
("blank row" "공행")
("block" "블록")
("block content" "블록 내용")
("block of code" "코드 블록")
("blur" "흐림")
("both versions" "두 버전")
("bottom baseline" "하단 기준선")
("bottom tools" "하단 도구")
("box" "상자")
("browse back" "찾아보기")
("browse forward" "앞으로 탐색")
("browse modules documentation" "브라우즈 모듈 문서")
("buffer management" "버퍼 관리")
("buffer must be on disk" "버퍼가 디스크에 있어야합니다")
("buffer must have a name" "버퍼 이름이 있어야합니다")
("build buffer" "빌드 버퍼")
("build buffer in" "빌드 버퍼 입력")
("build directory" "빌드 디렉토리")
("build directory in" "빌드 디렉토리")
("build link pages" "빌드 링크 페이지")
("build-all" "모두 빌드")
("bump" "범프")
("busy" "바쁜")
("cJK" "cJK")
("cJK spacing" "cJK 간격")
("calculus" "미적분학")
("cancelled" "취소 된")
("cannot download directory to file" "디렉토리를 파일로 다운로드 할 수 없습니다")
("cannot rename across different servers" "다른 서버에서 이름을 바꿀 수 없습니다")
("cannot upload directory to file" "디렉토리를 파일로 업로드 할 수 없습니다")
("cartesian" "카테 시안")
("carved wood" "조각 된 나무")
("case-insensitive search" "대소 문자 구분없는 검색")
("categories" "카테고리")
("category" "카테고리")
("cell properties" "셀 속성")
("cells" "개의 셀")
("change default unit" "기본 단위 변경")
("change passphrase" "비밀번호 변경")
("change step-size" "단계 크기 변경")
("change tags" "태그 변경")
("change the TeXmacs preferences" "TeXmacs 환경 설정 변경")
("change the border of the table" "테이블의 경계 변경")
("change the style of mathematical formulas" "수학 공식 스타일 변경")
("character contraction" "캐릭터 수축")
("character encoding" "문자 인코딩")
("character expansion" "캐릭터 확장")
("check for updates" "업데이트 확인")
("checkable field" "체크 가능 필드")
("cipher algorithm for passphrase encryption" "패스 프레이즈 암호화를위한 암호 알고리즘")
("circle" "원")
("classification" "분류")
("clean slate" "청결한 슬레이트")
("clear all fields" "모든 필드 지우기")
("clear local information" "명확한 지역 정보")
("clear menu" "클리어 메뉴")
("clear undo history" "클리어 취소 기록")
("click Ok button twice to discard this warning" "이 경고를 무시하려면 확인 단추를 두 번 클릭하십시오")
("clip" "클립")
("clipboard image format" "클립 보드 이미지 형식")
("close animation tool" "애니메이션 도구 닫기")
("close program" "프로그램 닫기")
("close replace tool" "닫기 교체 도구")
("close search tool" "닫기 검색 도구")
("close spell tool" "주문 철자 도구")
("close translations to rebuild" "다시 번역 할 번역을 닫으십시오")
("closed bezier" "폐쇄 베 지어")
("closed curve" "폐쇄 곡선")
("closed smooth" "닫힌 부드러운")
("closed spline" "폐쇄 스플라인")
("cluster by affiliation" "가맹에 의한 클러스터")
("collect garbage" "수집 쓰레기")
("collected keys" "수집 된 키")
("color of the axes" "축의 색상")
("color of the subunits" "서브 유닛의 색")
("color of the units" "단위의 색상")
("colors" "색상")
("column to the left" "왼쪽 열")
("column to the right" "오른쪽 열")
("columns" "열")
("column separation" "열 분리")
("commit file" "커밋 파일")
("common" "공통")
("commutative diagram" "정류도")
("complete bibliographic reference" "완전한 참고 문헌")
("complex actions" "복잡한 행동")
("compose" "구문")
("compound" "화합물")
("compress" "압축기")
("compress into toolbar" "툴바로 압축")
("compressed" "압축")
("conceal" "감추기")
("configure look and feel" "모양 및 모양 구성")
("confirm database entry" "데이터베이스 항목 확인")
("confirm entry" "입국 확인")
("confirm selected database entries" "선택된 데이터베이스 항목 확인")
("confirm selected entries" "선택된 항목 확인")
("conservative conversion options" "보수적 변환 옵션")
("consoles" "콘솔")
("constellation" "별자리")
("context aids" "문맥 보조제")
("contextual hints" "문맥 힌트")
("continue" "계속")
("continued fraction" "연속 분수")
("contour" "컨투어")
("contract logarithms" "계약 로그")
("control flow" "제어 흐름")
("convert" "변환")
("converters" "컨버터")
("convertible" "컨버터블")
("copyright" "저작권")
("cork charset with TeX catcode definition in preamble" "프리앰블의 TeX catcode 정의가있는 코르크 문자 세트")
("correct" "올바른")
("correct all" "올바른 수정")
("correct formula" "정확한 공식")
("correct manually" "수동 수정")
("correct mathematical formulas" "올바른 수학 공식")
("correction" "수정")
("cosine" "코사인")
("count characters" "개의 문자 수")
("count lines" "카운트 라인")
("count words" "카운트 단어")
("create a new document" "새 문서 작성")
("create link" "링크 만들기")
("create preamble" "프리앰블 생성")
("create remote directory" "원격 디렉토리 생성")
("create remote file" "원격 파일 작성")
("create subprogram" "서브 프로그램 작성")
("create subsession" "세션 생성")
("create table macro" "테이블 매크로 생성")
("creating new account" "새 계정 만들기")
("creating technical pictures" "기술적 인 그림 만들기")
("crop" "자르기")
("crop marks" "자르기 표시")
("cross" "십자가")
("crossed boxes" "교차 박스")
("crossed circles" "교차 원")
("current user version" "현재 사용자 버전")
("current version" "현재 버전")
("cursor" "커서")
("curve" "곡선")
("curve intersections" "곡선 교차점")
("curve points" "곡선 점")
("customizations" "사용자 정의")
("customizing and extending the user interface" "사용자 인터페이스 사용자 정의 및 확장")
("data" "데이터")
("database entry" "데이터베이스 항목")
("database tool" "데이터베이스 도구")
("database toolbar" "데이터베이스 툴바")
("dead" "죽은")
("debug" "디버그")
("debugging console" "디버깅 콘솔")
("debugging tool" "디버깅 툴")
("decimal comma" "십진 쉼표")
("decimal dot" "소수점")
("decomposed" "분해")
("decorated" "장식 된")
("decorated wood" "장식 된 나무")
("decrease size" "크기 감소")
("decrypt" "암호 해독")
("default size" "기본 크기")
("degrade" "degrade")
("degraded" "분해됨")
("delete documentation cache" "문서 캐시 삭제")
("delete entries" "항목 삭제")
("delete link" "링크 삭제")
("deleted" "삭제됨")
("describe" "설명")
("describe tag" "태그 설명")
("destroy" "파괴")
("detach master" "분리 마스터")
("detailed menus" "상세 메뉴")
("details in menus" "메뉴의 상세")
("determine margins from text width" "텍스트 너비와 여백 결정")
("developer" "개발자")
("developer tool" "개발자 도구")
("device" "장치")
("diamond" "다이아몬드")
("differentiate" "차등화")
("dilate" "확장하다")
("direction of progression" "진행 방향")
("direction of translation" "번역 방향")
("disable coloring on paper" "종이에 채색 비활성화")
("disable encryption" "암호화 비활성화")
("disappear" "사라짐")
("disk" "디스크")
("display style" "디스플레이 스타일")
("displayed formula" "표시된 공식")
("dissociate joined cells" "결합 된 세포를 분리")
("distort" "디 스트릿")
("distorted" "왜곡 된")
("division" "구분")
("document font selector" "문서 글꼴 선택기")
("document language" "문서 언어")
("document page format" "문서 페이지 형식")
("document paragraph format" "문서 단락 형식")
("document updates run" "문서 업데이트 실행")
("downwards" "아래로")
("dragging" "끌기")
("draw image" "그리기 이미지")
("draw over" "인출")
("draw over selection" "인출 선택")
("drop" "드롭")
("due to" "때문에")
("dynamic" "동적")
("eRROR" "eRROR")
("edit animation" "애니메이션 편집")
("edit groups of objects" "객체 그룹 편집")
("edit macro" "매크로 편집")
("edit macros" "매크로 편집")
("edit preamble" "프리앰블 편집")
("edit source" "편집 소스")
("edit style" "스타일 편집")
("edit translations file" "번역 파일 편집")
("education" "교육")
("effect pen" "효과 펜")
("eigenvalues" "고유 값")
("eighth" "제 8")
("embold" "임베디드")
("emboss" "엠 보스")
("enable page breaking" "페이지 나누기 활성화")
("encoding" "인코딩")
("encrypt" "암호화")
("encryption" "암호화")
("encryption facilities are not currently available" "암호화 기능은 현재 사용할 수 없습니다")
("encryption facilities have not been enabled for TeXmacs" "Tekmacs에 암호화 기능이 활성화되지 않았습니다")
("enforce brackets to match" "괄호를 일치 시키십시오")
("engrave" "조각")
("enter data" "데이터 입력")
("enter graphics" "그래픽 입력")
("enter graphics mode" "그래픽 모드 입력")
("enter new passphrase for encryption" "암호화를위한 새로운 암호 입력")
("enter passphrase for decryption" "암호 해독 암호 입력")
("enter passphrase for identity" "신분을위한 암호 구 입력")
("enter title information" "제목 정보 입력")
("entire table" "전체 테이블")
("entry up to date in database" "데이터베이스에 최신 항목")
("enunciation" "성명")
("environment variable" "환경 변수")
("environments" "환경")
("erode" "침식")
("error messages" "오류 메시지")
("error output" "오류 출력")
("error status report" "오류 상태 보고서")
("error: bracket does not match" "오류 : 대괄호가 일치하지 않습니다")
("error: cyclic or missing chunks detected" "오류 : 주기적 또는 누락 된 청크가 발견되었습니다")
("error: file not found" "오류 : 파일을 찾을 수 없습니다")
("error: ghostview does not seem to be installed on your system" "오류 : ghostview가 시스템에 설치되지 않은 것 같습니다")
("error: one of the alternatives should be filled out" "오류 : 대안 중 하나를 작성해야합니다")
("error: only one alternatives should be filled out" "오류 : 하나의 대안 만 작성해야합니다.")
("error: should fill out name for referencing" "오류 : 참조 할 이름을 입력해야합니다")
("error: should fill out required field" "오류 : 필수 입력란을 작성해야합니다")
("evaluable field" "평가 가능한 분야")
("evaluate above" "위의 평가")
("evaluate all" "모두 평가")
("evaluate below" "아래 평가")
("evaluate fields" "필드 평가")
("evaluate fields in order" "필드를 순서대로 평가")
("evaluate script" "스크립트 평가")
("evaluation" "평가")
("evaluation switch" "평가 스위치")
("evaluation tag" "평가 태그")
("even page" "짝수 페이지")
("even pages" "짝수 페이지")
("events" "이벤트")
("exact" "정확한")
("execution of scripts" "스크립트 실행")
("exit graphics" "종료 그래픽")
("exit graphics mode" "종료 그래픽 모드")
("exit left" "나가기")
("exit right" "나가기 권리")
("exit tag on the left" "왼쪽 출구 태그")
("exit tag on the right" "오른쪽 출구 태그")
("expand TeXmacs macros with no LaTeX equivalents" "LaTeX 동등 물이없는 TeXmacs 매크로 확장")
("expand beamer slides" "확장 비머 슬라이드")
("expand inclusions" "확장 포함")
("expand logarithms" "확장 로그")
("expand trigonometric functions" "확장 삼각 함수")
("expand unrecognized macros" "인식되지 않은 매크로 확장")
("expand user-defined macros" "사용자 정의 매크로 확장")
("expanded" "확장")
("experimental features (to be used with care)" "경험과 함께 사용되는 실험 기능")
("explain" "설명")
("explanatory item" "설명 항목")
("explicit keystroke" "명시적인 키 스트로크")
("explicit margins" "명백한 마진")
("exponential" "지수")
("export bibliographies as links" "참고 문헌을 링크로 내보내기")
("export bibliography" "수출 서지")
("export entries in buffer" "버퍼에서 항목 내보내기")
("export file" "내보내기 파일")
("export formulas as images" "수식을 이미지로 내보내기")
("export mathematical formulas as MathML" "수학 공식을 MathML로 내보내기")
("export mathematical formulas as images" "수학 공식을 이미지로 내보내기")
("export selected entries" "선택된 항목 내보내기")
("export selection" "내보내기 선택")
("export selection as image" "선택 이미지를 이미지로 내보내기")
("export selections as" "선택을 다른 이름으로 내보내기")
("export sessions" "수출 세션")
("exported bibliographic entries" "내 보낸 서지 목록")
("exported bibliographic references" "내 보낸 서지 문헌")
("extend" "확장하다")
("extended" "확장 된")
("extensible left arrow" "확장 가능한 왼쪽 화살표")
("extensible right arrow" "확장 가능한 오른쪽 화살표")
("extern" "외국인")
("external" "외부")
("extra branch" "추가 지점")
("extra interline space" "추가 인터 라인 공간")
("extra name" "추가 이름")
("extract" "추출물")
("extract style file" "추출 스타일 파일")
("extract style package" "추출 스타일 패키지")
("factor" "인자")
("fade" "페이드")
("fade in" "페이드 인")
("fade out" "페이드 아웃")
("fast" "빠른")
("fast decrease" "빠른 감소")
("fast environments" "빠른 환경")
("fast increase" "빠른 증가")
("field reference" "필드 참조")
("fifth" "제 5")
("file saved" "파일이 저장되었습니다")
("fill color" "채우기 색")
("fill out" "채우기")
("filter" "필터")
("find file" "파일 찾기")
("finished collecting symbols documentation" "완료된 수집 기호 문서")
("first" "첫번째")
("first chunk" "첫 번째 덩어리")
("first difference" "첫 번째 차이")
("first error" "첫 번째 오류")
("first field" "첫번째 필드")
("first occurrence" "첫회 발생")
("first similar" "첫번째 유사")
("fit to screen" "화면에 맞추기")
("fit to screen width" "화면 너비에 맞게")
("five columns" "5 열")
("fixed" "고정")
("flag is off" "플래그가 꺼져 있습니다")
("flag is on" "플래그가 켜져 있습니다")
("flatten" "평평한")
("floating algorithm" "부동 알고리즘")
("floating phantom" "부동 팬텀")
("focus" "초점")
("focus dependent icons" "초점에 따라 아이콘")
("fold all" "모두 접기")
("fold all fields" "모든 필드 접기")
("fold back" "다시 접어")
("follow external links" "외부 링크 따르기")
("follow inverse links" "역 링크를 따르십시오")
("font effects" "글꼴 효과")
("font selector" "글꼴 선택기")
("for each" "각")
("force reloading of translations" "번역 강제 재로드")
("forward" "앞으로")
("four columns" "4 열")
("four dots" "4 점")
("fourth" "제 4")
("fraktur" "fraktur")
("framed" "프레임")
("from" "보낸 사람")
("from center" "중심에서")
("front matter" "전방 문제")
("full" "전체")
("full author list" "전체 저자 목록")
("gap" "갭")
("garbage collection" "가비지 콜렉션")
("gaussian" "가우시안")
("gcd" "gcd")
("general" "일반")
("generated LaTeX document contains no errors" "생성 된 LaTeX 문서에 오류가 없습니다")
("generated field" "생성 된 필드")
("geometry" "형상")
("get arity" "열심히")
("get label" "라벨 받기")
("get list with remote versions" "원격 버전 목록보기")
("glyphs" "글리프")
("gnaw" "gna 아 먹기")
("gnawed" "갈기")
("gnuPG command" "gnuPG 명령")
("gnuPG error: buffer encryption failed" "gnuPG 오류 : 버퍼 암호화 실패")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG 오류 : 암호 해독에 적합한 비밀 키를 찾을 수 없습니다")
("gnuPG requires name and email to have at least 5 characters" "gnuPG에는 이름과 이메일이 5 자 이상이어야합니다")
("go to anchor" "고정")
("go to anchor or float" "고정하거나 부유하다")
("go to anchor or footnote" "고정 또는 각주로 이동")
("go to first similar tag" "첫번째 유사한 태그로 이동")
("go to float" "부유하다")
("go to footnote" "각주로 이동")
("go to last similar tag" "마지막 유사한 태그로 이동")
("go to next similar tag" "다음 유사한 태그로 이동")
("go to previous similar tag" "이전 유사 태그로 이동")
("go to section" "섹션으로 이동")
("grain" "곡물")
("granite" "화강암")
("graphical effects" "그래픽 효과")
("graphical interface font scale" "그래픽 인터페이스 글꼴 크기")
("graphics" "그래픽")
("graphics geometry" "그래픽 지오메트리")
("graphics grids" "그래픽 그리드")
("greyed" "회색")
("grid" "그리드")
("grid curves" "그리드 커브")
("grid points" "그리드 포인트")
("grid-curve intersections" "그리드-곡선 교차점")
("group of objects" "객체 그룹")
("group/ungroup" "그룹 / 그룹 해제")
("grouped" "그룹화")
("guarantee transparent source tracking" "보증 투명한 소스 추적")
("half wide" "반폭")
("hand drawn" "손으로 그린")
("headers" "헤더")
("history" "역사")
("homoglyph substitutions" "상형 문자 치환")
("horizontal alignment" "가로 정렬")
("horizontal collapse distance" "수평 붕괴 거리")
("horizontal margins" "가로 마진")
("hyphenate as" "하이픈으로")
("icon" "아이콘")
("if hyphenated" "하이픈으로 연결 한 경우")
("ignore" "무시")
("impact" "충격")
("import bibliography" "수입 서지")
("import database entry" "가져 오기 데이터베이스 항목")
("import entries in buffer" "버퍼의 항목 가져 오기")
("import entry" "가져 오기 항목")
("import file" "가져 오기 파일")
("import selected database entries" "선택한 데이터베이스 항목 가져 오기")
("import selected entries" "선택한 항목 가져 오기")
("import selections as" "선택 항목 가져 오기")
("import sessions" "가져 오기 세션")
("import sophisticated objects as pictures" "세련된 대상을 그림으로 가져 오기")
("imported bibliographic entries" "가져온 서지 목록")
("in popup windows" "팝업 창에서")
("inanimated" "애니메이션")
("inch" "인치")
("incomplete entries found to be filled out" "불완전한 항목이 발견되지 않았습니다")
("increase size" "크기 증가")
("indent paragraphs" "문단 들여 쓰기")
("indentation" "들여 쓰기")
("indication" "표시")
("initialize" "초기화")
("ink here" "여기 잉크")
("ink in" "잉크 인")
("ink out" "잉크 아웃")
("inline" "인라인")
("inline code" "인라인 코드")
("inline content" "인라인 컨텐츠")
("inline formula" "인라인 수식")
("inner bottom" "내부 바닥")
("inner left" "내부 왼쪽")
("inner right" "내부 오른쪽")
("inner top" "내부 상단")
("input command" "입력 명령")
("input field" "입력 필드")
("input options" "입력 옵션")
("insert a computer program" "컴퓨터 프로그램 삽입")
("insert a gap" "갭 삽입")
("insert a list" "목록 삽입")
("insert a multiple choice" "다중 선택 삽입")
("insert a negation" "부정 삽입")
("insert a new entry" "새 항목을 삽입하십시오")
("insert a note or a floating object" "노트 또는 부동 개체 삽입")
("insert a prominent piece of text" "눈에 띄는 텍스트 삽입")
("insert a question" "질문 삽입")
("insert a root" "루트 삽입")
("insert a script" "스크립트 삽입")
("insert a section block" "섹션 블록 삽입")
("insert a textual operator" "텍스트 연산자 삽입")
("insert above" "위에 삽입")
("insert abstract" "추상 삽입")
("insert an answer" "답변을 삽입하십시오")
("insert an enunciation" "성명서 삽입")
("insert annotation" "주석 삽입")
("insert below" "아래에 삽입")
("insert copyright and license information" "저작권 및 라이센스 정보 삽입")
("insert explanatory item" "설명 설명문 삽입")
("insert field above" "위의 필드 삽입")
("insert field below" "아래 필드 삽입")
("insert large delimiters" "큰 구분 기호 삽입")
("insert last name" "성 삽입")
("insert left" "왼쪽 삽입")
("insert missing invisible operators" "삽입 된 보이지 않는 연산자 삽입")
("insert more names" "이름을 더 입력하십시오")
("insert particle" "입자 삽입")
("insert plain text" "일반 텍스트 삽입")
("insert right" "오른쪽 삽입")
("insert similar above" "위의 유사한 삽입")
("insert similar below" "아래에 유사한 삽입")
("insert similar block above" "위의 유사한 블록 삽입")
("insert similar block below" "아래에 유사한 블록 삽입")
("insert subtable" "서브 테이블 삽입")
("insert symbol documentation" "삽입 기호 문서")
("insert template" "삽입 템플릿")
("insert text field above" "위의 텍스트 필드 삽입")
("insert text field below" "아래에 텍스트 필드 삽입")
("insert title after name" "이름 뒤에 제목 삽입")
("insert user interface related markup" "사용자 인터페이스 관련 마크 업 삽입")
("inserting control points" "제어점 삽입")
("integrate" "통합")
("interactive questions" "대화 형 질문")
("intercharacter compression" "문자 압축")
("intercharacter stretching" "문자 스트레칭")
("interrupted" "중단됨")
("invalid multi-paragraph selection" "잘못된 다중 단락 선택")
("invalid renaming" "잘못된 이름 변경")
("invert" "반전")
("inverted breve" "역전 된 바람개비")
("invisible ending" "보이지 않는 결말")
("invisible newline" "보이지 않는 줄 바꿈")
("invisible opening" "보이지 않는 오프닝")
("join selected cells" "선택된 셀에 참여")
("jump in" "점프")
("junior" "주니어")
("keep evaluated expressions" "평가 된 표현식 유지")
("keep local" "지역 유지")
("keep remote" "원격 유지")
("keep track of source code" "소스 코드 추적")
("keep unfolded" "펼친 상태로 유지")
("keyboard configuration" "키보드 구성")
("keyboard shortcut" "키보드 단축키")
("laptop presentations" "노트북 프레젠테이션")
("large cells" "큰 세포")
("large displayed" "큰 표시")
("large displayed fraction" "큰 부분 표시")
("large tables" "큰 테이블")
("last" "마지막")
("last difference" "마지막 차이")
("last error" "마지막 오류")
("last field" "마지막 필드")
("last name" "성")
("last occurrence" "마지막 발생")
("last similar" "마지막 유사")
("lcm" "lcm")
("left axis" "왼쪽 축")
("left baseline" "왼쪽 기준선")
("left bottom" "왼쪽 아래")
("left center" "왼쪽 중앙")
("left click: add point; Right click: undo" "왼쪽 클릭 : 포인트 추가; 오른쪽 클릭 : 실행 취소")
("left click: finish; Right click: undo" "왼쪽 클릭 : 완료; 오른쪽 클릭 : 실행 취소")
("left click: new object" "왼쪽 클릭 : 새 개체")
("left click: operate" "왼쪽 클릭 : 작동")
("left down" "왼쪽 아래로")
("left on even pages" "짝수 페이지에 남음")
("left top" "왼쪽 상단")
("left up" "왼쪽")
("left-right arrow" "왼쪽 오른쪽 화살표")
("leftwards" "왼쪽")
("let the environment float" "환경을 부유하게하라")
("line breaking" "줄 바꿈")
("line wrapping" "라인 랩핑")
("linear 2D" "선형 2D")
("linear algebra" "선형 대수")
("lines around" "라인 주변")
("link image and copies as" "이미지를 복사하고 다른 이름으로 복사")
("link image as" "다음으로 이미지 링크")
("link mode" "링크 모드")
("link to URL" "URL 링크")
("linking tool" "연결 도구")
("live" "라이브")
("live input-output" "실시간 입 / 출력")
("load help file" "도움말 파일로드")
("load remote file" "원격 파일로드")
("loading" "로드 중")
("local entries" "로컬 항목")
("loci" "loci")
("locus" "locus")
("locus rendering" "locus rendering")
("logarithm" "로그")
("logarithmic" "대수")
("logarithmic base" "로그베이스")
("logarithms" "로그")
("logging in" "로그인")
("logical and" "논리적")
("logical implication" "논리적 함의")
("logical not" "논리적 아님")
("logical or" "논리 또는")
("login" "로그인")
("logout" "로그 아웃")
("long macro" "긴 매크로")
("long text" "긴 텍스트")
("look for more fonts" "더 많은 글꼴 찾기")
("loops" "루프")
("macro argument" "매크로 논쟁")
("macro definition" "매크로 정의")
("macro name" "매크로 이름")
("macros" "매크로")
("magnify horizontally" "가로로 확대")
("magnify vertically" "세로 확대")
("main presentation style" "주요 프리젠 테이션 스타일")
("make a letter environment" "문자 환경 만들기")
("make a multi-slide presentation" "멀티 슬라이드 프리젠 테이션 만들기")
("make floating" "부유하다")
("make link" "링크 만들기")
("make non floating" "부동하지 않기")
("manila paper" "마닐라 종이")
("map arguments" "지도 인수")
("marginal note" "마지막 메모")
("margins from width" "폭의 여백")
("margins on paper" "종이의 여백")
("margins on screen" "화면상의 여백")
("marked" "표시")
("material" "소재")
("mathematical output" "수학적 출력")
("matrices" "행렬")
("maximal cell height" "최대 셀 높이")
("maximal clustering" "최대 클러스터링")
("maximal table height" "최대 테이블 높이")
("maximal table width" "최대 테이블 너비")
("maximum" "최대")
("meander" "미안 더")
("memory" "메모리")
("memory usage" "메모리 사용")
("menu" "메뉴")
("merge lines into paragraphs unless separated by blank lines" "공백 줄로 구분하지 않으면 줄을 단락으로 병합")
("messages" "메시지")
("meta data" "메타 데이터")
("metadata" "메타 데이터")
("metal" "금속")
("middle baseline" "중간 기준선")
("minimal cell height" "최소 셀 높이")
("minimal cell width" "최소 셀 너비")
("minimal line separation" "최소 라인 분리")
("minimal table height" "최소 테이블 높이")
("minimal table width" "최소 테이블 너비")
("minimum" "최소")
("mirror" "미러")
("miscellanous" "기타")
("mode dependent icons" "모드 의존 아이콘")
("modify remote live document" "원격 라이브 문서 수정")
("module" "모듈")
("monospaced" "단일 간격")
("more information about GNU TeXmacs can be found in the Help->About menu" "GNU TeXmacs에 대한 자세한 정보는 도움말-> 정보 메뉴에서 찾을 수 있습니다")
("more information about GNU TeXmacs can be found in the help" "GNU TeXmacs에 대한 자세한 정보는 도움말에서 찾을 수 있습니다")
("motion" "모션")
("mouse over object" "마우스 오버 대상")
("move" "이동")
("move objects" "물체 이동")
("move over object on which to operate" "조작 할 물체 위로 이동")
("multiline" "멀티 라인")
("multiple choice" "복수 선택")
("multiple root" "다중 루트")
("multiplication" "곱셈")
("navigation options" "탐색 옵션")
("never" "never")
("new account" "새 계정")
("new bibliography dialogue" "새로운 참고 문헌 대화")
("new document" "새 문서")
("new entry" "새 항목")
("new identity" "새로운 정체성")
("new locus" "새 궤적")
("new macro" "새 매크로")
("new passphrase" "새 비밀번호 문구")
("new remote directory" "새로운 원격 디렉토리")
("new remote file" "새 원격 파일")
("new style fonts" "새 스타일 글꼴")
("new style page breaking" "새 스타일 페이지 나누기")
("new version" "새 버전")
("new window" "새 창")
("newer version" "최신 버전")
("next chunk" "다음 청크")
("next difference" "다음 차이")
("next error" "다음 오류")
("next field" "다음 필드")
("next occurrence" "다음 발생")
("next screen" "다음 화면")
("next similar" "다음 유사")
("no clustering" "클러스터링 없음")
("no completions" "완료 안 됨")
("no errors have been corrected" "오류가 수정되지 않았습니다")
("no grid" "그리드 없음")
("no new public key in document" "문서에 새로운 공개 키가 없습니다")
("no page break" "페이지 나누기 없음")
("no page numbers" "페이지 번호 없음")
("no parent" "부모 없음")
("no selection" "선택하지 않음")
("no spelling errors" "맞춤법 오류 없음")
("normal loci" "정상 좌")
("not allowed to remove home directory" "홈 디렉토리를 제거 할 수 없습니다")
("not connected to server" "서버에 연결되지 않았습니다")
("not yet implemented" "아직 구현되지 않았습니다")
("notebook" "노트북")
("number of polar steps" "극성 단계 수")
("number of subunit steps" "서브 유닛 단계 수")
("numbering" "번호 매기기")
("numeric spreadsheet" "숫자 스프레드 시트")
("odd page" "홀수 페이지")
("odd pages" "홀수 페이지")
("of fingerprint" "지문의")
("old version" "이전 버전")
("older version" "이전 버젼")
("on the footer" "바닥 글에")
("on your system and set it up from the \"Security\" tab" "시스템에서 \"보안\" 탭에서 설정")
("one column" "1 열")
("one error has been corrected" "하나의 오류가 수정되었습니다")
("one lower case letter, one non alpha-numeric symbol" "하나의 소문자, 하나의 영숫자가 아닌 기호")
("one numeric character, one upper case letter" "숫자 하나, 대문자 하나")
("only convert changes when re-importing" "다시 가져올 때 변경 사항 만 변환")
("only convert changes with respect to imported version" "가져온 버전에 대한 변경 사항 만 변환")
("only convert changes with respect to tracked version" "추적 된 버전에 대한 변경 사항 만 변환")
("only implemented for complete subtrees" "완전한 서브 트리에만 구현 됨")
("only keep folded" "접힌 상태로 유지")
("only keep unfolded" "펼친 상태로 유지")
("only show semantic focus" "시맨틱 포커스 만 표시")
("opacity" "불투명도")
("open bibliography" "공개 서지")
("open identities" "공개 신원")
("open in new window" "새 창에서 열기")
("open key manager" "열린 키 관리자")
("open licence agreement" "개방 라이센스 계약")
("open mailbox" "열린 편지함")
("open module browser" "오픈 모듈 브라우저")
("open symbol browser" "오픈 심볼 브라우저")
("open tool in separate window" "별도의 창에서 도구 열기")
("operation mode" "작동 모드")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "또는 \"gpg\" 또는 \"gpg2\" 명령의 전체 경로를 제공하십시오")
("order" "주문")
("ordinary symbol" "일반 기호")
("ornamented" "장식")
("other login" "기타 로그인")
("other package" "기타 패키지")
("outer bottom" "하단")
("outer left" "왼쪽 바깥 쪽")
("outer right" "외부 오른쪽")
("outer top" "외부 상단")
("outline" "개요")
("outlined" "개요")
("outlined emboss" "개요 엠 보스")
("outlined engrave" "개정 된 조각")
("output options" "출력 옵션")
("oval" "타원형")
("overlap" "오버랩")
("overlay" "오버레이")
("overlays" "오버레이")
("overlined" "개요")
("overview of the scheme extension language" "체계 확장 언어 개요")
("padded" "패딩 됨")
("page background" "페이지 배경")
("page break after" "다음 페이지 나누기")
("page breaking algorithm" "페이지 나누기 알고리즘")
("page number" "페이지 번호")
("page number rendering" "페이지 번호 렌더링")
("page rendering" "페이지 렌더링")
("palette" "팔레트")
("panorama" "파노라마")
("paragraphs" "문단")
("parametric curve" "파라 메트릭 커브")
("parametric surface" "매개 변수 표면")
("parenthesis" "괄호")
("parenthesized" "괄호")
("particle" "입자")
("passphrase encryption" "패스 프레이즈 암호화")
("passphrase wallet facilities are not currently available" "암호 지갑 기능은 현재 사용할 수 없습니다")
("passphrases are expected to have at least: 8 characters" "암호는 8 자 이상이어야합니다")
("passphrases mismatch" "암호 불일치")
("pastel" "파스텔")
("pattern" "패턴")
("pause" "일시 정지")
("pen width" "펜 너비")
("permanent footer" "영구 바닥 글")
("permanent header" "영구 헤더")
("permanently add to dictionary" "영구적으로 사전에 추가")
("permanently insert into dictionary" "영구적으로 사전에 삽입")
("permissions" "권한")
("phantom" "팬텀")
("phantoms" "팬텀")
("physics and astronomy class" "물리 및 천문학 수업")
("picture" "그림")
("pine" "소나무")
("plain" "일반")
("plain boxes" "일반 상자")
("plain circles" "일반 서클")
("play" "놀이")
("play animation" "애니메이션 재생")
("please install GnuPG software from https://www.gnupg.org" "https://www.gnupg.org에서 GnuPG 소프트웨어를 설치하십시오")
("plot" "플롯")
("plug-ins" "플러그인")
("plural" "복수")
("point" "포인트")
("polar" "폴라")
("polygon" "다각형")
("pop server settings" "팝 서버 설정")
("position of marginal note" "마지막 메모 위치")
("poster formats" "포스터 형식")
("poster theme" "포스터 테마")
("postfix" "접미사")
("preferences for editing mathematical formulas" "수학 공식 편집 환경 설정")
("preferences for tag" "태그 환경 설정")
("prefix" "접두사")
("presentation tool" "프레젠테이션 툴")
("preserve" "보존")
("preserve tags" "태그 유지")
("pretty tree output" "예쁜 나무 출력")
("preview" "미리보기")
("previous difference" "이전 차이")
("previous error" "이전 오류")
("previous field" "이전 분야")
("previous occurrence" "이전 발생")
("previous screen" "이전 화면")
("previous similar" "이전 유사")
("primitive or macro" "기본 또는 매크로")
("print buffer" "인쇄 버퍼")
("print buffer to file" "파일로 인쇄 버퍼")
("print to file" "파일로 인쇄")
("printer setup" "프린터 설정")
("program bracket matching" "프로그램 브래킷 일치")
("program bracket selections" "프로그램 브래킷 선택")
("program commands" "프로그램 명령")
("program interface for buffer management" "버퍼 관리를위한 프로그램 인터페이스")
("programming routines for editing documents" "문서 편집을위한 프로그래밍 루틴")
("prominent" "명명 한")
("provoke C++ error" "C ++ 오류 유발")
("provoke menu error" "도발 메뉴 오류")
("provoke scheme error" "도발 오류")
("pseudo code" "의사 코드")
("public key encryption" "공개 키 암호화")
("public keys" "공개 키")
("pulse" "펄스")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUI 전용, 죄송합니다. \"내보내기 선택\" 사용")
("qt-widgets" "qt- 위젯")
("quantifier" "정량 기")
("quasi" "의사")
("question" "질문")
("questions only" "질문 만")
("questions with answers" "답변이있는 질문")
("quick evaluation of formulas" "공식의 빠른 평가")
("rank" "순위")
("raw" "원시")
("really delete user identity" "실제로 사용자 ID 삭제")
("really tiny" "정말 작은")
("rebuild translations file" "번역 파일 재구성")
("recent" "최근")
("recent documents" "최근 문서")
("recipients" "수신자")
("recognize" "인식")
("rectangular" "직사각형")
("reduce" "감소")
("reduce trigonometric functions" "삼각 함수 감소")
("reduced margins" "감소 된 마진")
("regenerate" "재생성")
("register file" "등록 파일")
("relate" "관련")
("relation" "관계")
("release left button: finish editing" "왼쪽 버튼 해제 : 편집 완료")
("remote" "원격")
("remote connections" "원격 연결")
("remote control" "원격 제어")
("remote controllers with keyboard simulation" "키보드 시뮬레이션 기능이있는 원격 컨트롤러")
("remote directory" "원격 디렉토리")
("remote servers" "원격 서버")
("remote tool" "원격 도구")
("remove" "제거")
("remove banner" "배너 제거")
("remove database entry" "데이터베이스 항목 제거")
("remove downwards" "아래로 제거")
("remove entries" "항목 제거")
("remove entry" "항목 제거")
("remove field above" "위의 필드 제거")
("remove field below" "아래 필드 제거")
("remove folded" "접힌 제거")
("remove last field" "마지막 필드 제거")
("remove leftwards" "왼쪽으로 제거")
("remove link" "링크 제거")
("remove next field" "다음 필드 제거")
("remove previous field" "이전 필드 제거")
("remove rightwards" "오른쪽으로 제거")
("remove selected database entries" "선택한 데이터베이스 항목 제거")
("remove selected entries" "선택된 항목 제거")
("remove superfluous invisible operators" "불필요한 보이지 않는 연산자 제거")
("remove tag" "태그 제거")
("remove this branch" "이 지점 제거")
("remove unfolded" "펼친 상태로 제거")
("remove upwards" "위로 제거")
("removed entries from database" "데이터베이스에서 제거 된 항목")
("removed entry from database" "데이터베이스에서 제거 된 항목")
("rename" "이름 바꾸기")
("rename section" "이름 변경 섹션")
("replace TeXmacs styles with no LaTeX equivalents" "Tekmacs 스타일을 LaTeX와 동등한 것으로 대체")
("replace all further occurrences" "모든 다른 발생을 교체하십시오")
("replace one occurrence" "한 번의 교체")
("replace toolbar" "바꾸기 도구 모음")
("replace unrecognized styles" "인식 할 수없는 스타일 바꾸기")
("reset error counters" "오류 카운터 재설정")
("resize" "크기 변경")
("resize objects" "객체 크기 조정")
("restart TeXmacs in order to let changes take effect" "변경 사항을 적용하려면 TeXmacs를 다시 시작하십시오")
("restart in order to let the new look and feel take effect" "새 모양과 느낌을 적용하기 위해 다시 시작하십시오")
("retain" "보유")
("retime" "리 타임")
("retina settings" "망막 설정")
("retrieve email" "이메일 검색")
("retrieve remote live document" "원격 라이브 문서 검색")
("retrieved contents" "검색된 내용")
("reverse" "리버스")
("reverse ordering" "역순")
("ridged paper" "리지 용지")
("right baseline" "오른쪽 기준선")
("right down" "오른쪽 아래")
("right on even pages" "짝수 페이지에 오른쪽")
("right up" "오른쪽")
("rightwards" "오른쪽")
("rigid box" "견고한 상자")
("rotate" "회전")
("rotate objects" "객체 회전")
("rough" "거친")
("rough paper" "거친 종이")
("round" "라운드")
("round overbrace" "둥근 괄호")
("round underbrace" "둥근 밑받침")
("row above" "위의 행")
("row below" "아래 행")
("rows" "행")
("run" "실행")
("run current file" "현재 ​​파일 실행")
("same names" "같은 이름")
("same screen margins as on paper" "용지와 같은 화면 여백")
("sample text" "샘플 텍스트")
("save auxiliary data" "보조 데이터 저장")
("save entries" "항목 저장")
("save entry" "항목 저장")
("save image as" "이미지를 다른 이름으로 저장")
("save position" "저장 위치")
("save remote file" "원격 파일 저장")
("saved modifications in database" "데이터베이스에 저장된 수정 사항")
("scheme developers guide" "구성표 개발자 안내서")
("scheme extensions" "체계 확장")
("scheme interface for the graphical mode" "그래픽 모드 용 스키마 인터페이스")
("screen" "화면")
("screen rendering" "화면 렌더링")
("screens" "스크린")
("screenshot" "스크린 샷")
("scripting language" "스크립트 언어")
("scripts" "스크립트")
("search and replace" "검색 및 교체")
("search toolbar" "검색 툴바")
("second" "초")
("secret keys" "비밀 키")
("sections" "섹션")
("see documentation" "문서 참조")
("select pen" "펜 선택")
("select the action to be undertaken for each conflict" "각 충돌에 대해 수행 할 조치를 선택하십시오")
("select view mode" "뷰 모드 선택")
("semantic correctness" "의미 적 정확성")
("semantic editing" "의미론적인 편집")
("semantic selections" "의미있는 선택")
("semantics" "의미론")
("senior" "노인")
("serif" "세리프")
("server" "서버")
("session commands" "세션 명령")
("set default" "기본 설정")
("set difference" "차이점")
("set intersection" "세트 교차점")
("set number of columns" "열 수 설정")
("set number of rows" "행 수 설정")
("set properties" "속성 설정")
("set union" "집합")
("set user information" "사용자 정보 설정")
("seventh" "일곱 번째")
("several equations" "여러 방정식")
("shadow" "그림자")
("shadowed" "그림자")
("shadowed raise" "그림자 제기")
("shift" "시프트")
("show all parts" "모든 부품 표시")
("show current focus" "현재 초점 표시")
("show full context" "전체 컨텍스트 표시")
("show key presses" "키 누름 표시")
("show main document" "주요 문서보기")
("show memory usage" "메모리 사용량 표시")
("show one part" "한 부분 보여주기")
("show panorama" "쇼 파노라마")
("show preamble" "쇼 프리앰블")
("show several parts" "여러 부분 보여주기")
("show subunits" "쇼 서브 유닛")
("show table cells" "표 셀 표시")
("show timings" "타이밍 표시")
("side tools" "사이드 툴")
("simple" "간단한")
("simplification" "단순화")
("simplified evaluation of formulas" "간단한 수식 평가")
("simplified menus" "간단한 메뉴")
("simplify" "단순화")
("sine" "사인")
("sixth" "여섯 번째")
("size tag" "크기 태그")
("skew" "비뚤어 짐")
("skip all" "모두 건너 뛰기")
("slant" "경사")
("slashed fraction" "슬래시 분수")
("slides" "슬라이드")
("slow" "느린")
("slow decrease" "느린 감소")
("slow increase" "느린 증가")
("small capitals" "작은 수도")
("small environment box" "작은 환경 상자")
("small focus" "작은 초점")
("small inline" "작은 인라인")
("small inline fraction" "작은 인라인 분수")
("smash" "스매쉬")
("smooth" "부드러운")
("smooth end" "부드러운 끝")
("smooth extremities" "매끄러운 사지")
("smooth start" "부드러운 시작")
("snap" "스냅")
("snap distance" "스냅 거리")
("snap to curves" "곡선에 스냅")
("snap to grid" "그리드에 스냅")
("snap to grid curve" "그리드에 스냅 커브")
("snap to intersections of curves" "곡선의 교차점에 스냅")
("snap to text borders" "텍스트 테두리에 맞추기")
("snap to text corners" "텍스트 모서리에 맞추기")
("solution" "솔루션")
("solution to exercise" "운동 솔루션")
("solution to problem" "문제 해결")
("solutions" "솔루션")
("sound" "소리")
("source macros tool" "소스 매크로 도구")
("south" "남쪽")
("south east" "남동쪽")
("space bar in math mode" "수학 모드의 스페이스 바")
("space bar in text mode" "텍스트 모드의 스페이스 바")
("space stretchability" "공간 확장 성")
("span" "스팬")
("span over all columns" "모든 열에 걸쳐")
("special functions" "특수 기능")
("special properties" "특수 속성")
("specific baseline" "특정 기준선")
("specify color alternation" "색 교체 지정")
("specify how to traverse the manual" "설명서를 탐색하는 방법을 지정하십시오")
("specify semantics of a symbol or formula" "기호 또는 공식의 의미를 지정하십시오")
("specify the size of the table" "테이블의 크기를 지정하십시오")
("spell check" "맞춤법 검사")
("spline" "스플라인")
("split program" "분할 프로그램")
("square" "스퀘어")
("square overbrace" "정사각형 괄호")
("square underbrace" "사각 밑받침")
("stack" "스택")
("standard" "표준")
("standard Output" "표준 출력")
("standard fraction" "표준 분수")
("star" "별")
("start server" "서버 시작")
("statement" "문장")
("statistics" "통계")
("status" "상태")
("stop server" "서버 중지")
("storage" "스토리지")
("store tracking information in LaTeX files" "LaTeX 파일에 추적 정보 저장")
("stretch factor" "스트레치 팩터")
("strict Ascii" "엄격한 아스키")
("strike through" "파업")
("structured insert above" "위의 구조화 된 인서트")
("structured insert at the left" "왼쪽의 구조화 된 인서트")
("structured insert at the right" "오른쪽의 구조화 된 인서트")
("structured insert below" "아래 구조화 된 인서트")
("structured remove downwards" "하부 구조 제거")
("structured remove leftwards" "구조적으로 왼쪽으로 제거")
("structured remove rightwards" "오른쪽으로 구조화 된 제거")
("structured remove upwards" "위쪽으로 구조화 제거")
("structured variant" "구조화 된 변형")
("style options" "스타일 옵션")
("style parameters" "스타일 매개 변수")
("subject" "대상")
("submenu" "하위 메뉴")
("subscript below" "아래 첨자")
("subsubmenu" "하위 메뉴")
("subsubsubmenu" "하위 서브 메뉴")
("subsubsubsubmenu" "하위 서브 서브 서브 메뉴")
("subtable" "서브 테이블")
("subtraction" "빼기")
("summarized" "요약")
("superscript above" "위의 첨자")
("supported plug-ins" "지원되는 플러그인")
("surface" "표면")
("inflate" "팽창")
("switch to buffer" "버퍼로 전환")
("symbol properties not found" "기호 속성을 찾을 수 없음")
("symbols" "기호")
("synchronize" "동기화")
("synchronize bibliographic references" "서지 참조 동기화")
("synchronize with remote server" "원격 서버와 동기화")
("synopsis" "시놉시스")
("tab-completion" "탭 완성")
("tabbed" "탭")
("table breaking" "테이블 파괴")
("table height" "테이블 높이")
("table properties" "테이블 속성")
("table width" "테이블 폭")
("tags with special rendering" "특수 렌더링 태그")
("tangent" "탄젠트")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacs 버퍼 예상")
("teXmacs buffer on disk expected" "디스크상의 TeXmacs 버퍼 예상")
("teXmacs extensions to scheme and utilities" "구성표 및 유틸리티에 대한 TeXmacs 확장")
("teXmacs macro" "teXmacs 매크로")
("teXmacs package" "teXmacs 패키지")
("teXmacs primitives" "teXmacs 프리미티브")
("teXmacs style" "teXmacs 스타일")
("test routine" "테스트 루틴")
("testing tree-view" "테스트 트리 뷰")
("text borders" "텍스트 테두리")
("text box style" "텍스트 상자 스타일")
("text corners" "텍스트 코너")
("textual" "텍스트")
("textual operator" "텍스트 연산자")
("textual spreadsheet" "텍스트 스프레드 시트")
("the TeXmacs plug-in system" "TeXmacs 플러그인 시스템")
("theme parameters" "테마 매개 변수")
("these collected public keys will be definitely lost" "이 수집 된 공개 키는 확실히 손실됩니다")
("these public keys will be definitely lost" "이 공개 키는 확실히 없어 질 것입니다")
("these secret keys will be definitely lost" "이 비밀 키는 확실히 없어 질 것입니다")
("thicken" "두꺼워")
("third" "제 3의")
("this" "이쪽")
("this column" "이 칼럼")
("this page number" "이 페이지 번호")
("this row" "이 줄")
("this style specifies page margins in the TeX way" "이 스타일은 TeX 방식으로 페이지 여백을 지정합니다")
("three columns" "3 열")
("three dots" "세 점")
("through popup windows" "팝업 창을 통해")
("through the menus" "메뉴를 통해")
("thumbnails" "썸네일")
("time evolution" "시간 진화")
("timings" "타이밍")
("title presentation options" "제목 프레젠테이션 옵션")
("title style" "제목 스타일")
("title suffix" "제목 접미사")
("titled block" "제목 블록")
("toggle cell wrapping mode" "셀 랩핑 모드 전환")
("toggle here" "여기 토글")
("toggle off" "토글 오프")
("toggle on" "켜기")
("tolerant" "허용")
("top baseline" "최고 기준선")
("transform" "변환")
("transform cell into subtable" "셀을 서브 테이블로 변환")
("translations" "번역")
("translations loaded" "번역이로드되었습니다")
("transpose" "전치")
("traversal" "순회")
("traverse" "트래버스")
("triangle" "삼각형")
("triangularize" "삼각 화")
("trigonometric" "삼각법")
("trigonometry" "삼각법")
("turn off" "끄기")
("turn on" "켜기")
("two columns" "2 열")
("two dots" "두 점")
("type a latex command followed by return" "라텍스 명령을 입력 한 후 리턴")
("underlined" "밑줄")
("unevaluated argument" "평가되지 않은 논쟁")
("unevaluated value" "평가되지 않은 가치")
("unfold" "펼치기")
("unfold all" "모두 펼치십시오")
("unfold all fields" "모든 펼치기")
("unit" "단위")
("unit length" "단위 길이")
("unknown secret key fingerprint" "알 수없는 비밀 키 지문")
("unregistered file" "등록되지 않은 파일")
("unroll" "언롤")
("unsecure script refused" "안전하지 않은 스크립트 거부")
("unsupported link mode" "지원되지 않는 링크 모드")
("until" "까지")
("untitled block" "제목없는 블록")
("up to date" "최신")
("update buffer" "업데이트 버퍼")
("update this buffer" "이 버퍼 업데이트")
("update web site" "웹 사이트 업데이트")
("upight" "upight")
("upload" "업로드")
("upwards" "위로")
("use CSS for more advanced formatting" "고급 포맷을 위해 CSS 사용")
("use MathML" "MathML 사용")
("use as master" "마스터로 사용")
("use extensible brackets" "확장 브래킷 사용")
("use line wrapping for lines which are longer than 80 characters" "80 자보다 긴 줄에 줄 바꿈 사용")
("use margin kerning (protrusion)" "사용 마진 커닝 (돌출)")
("use protrusion" "용도 돌출부")
("use relative path" "상대 경로 사용")
("user interface" "사용자 인터페이스")
("user interface language" "사용자 인터페이스 언어")
("user preferences" "사용자 환경 설정")
("users of oriental languages" "동양어 사용자")
("utf-8 with inputenc LaTeX package" "putenc LaTeX 패키지를 갖춘 UTF-8")
("utilities" "유틸리티")
("vanish" "소멸")
("verbose" "자세한 내용")
("version" "버전")
("versioning tool" "버전 관리 도구")
("vertical alignment" "수직 정렬")
("vertical margins" "수직 마진")
("vertical space after" "수직 공간 뒤")
("vertical space before" "세로 전 공간")
("vertical space stretchability" "세로 공간 신축성")
("visible except here" "여기를 제외하고 볼 수 있음")
("visible from here on" "여기부터 볼 수 있습니다")
("visible only here" "여기에만 표시")
("visible until here" "여기까지 볼 수 있습니다")
("visited loci" "방문 장소")
("wallet" "지갑")
("wave" "파")
("weight" "무게")
("when line wrapping" "라인 랩핑시")
("whitespace" "공백")
("wide" "와이드")
("wide block" "와이드 블록")
("wide colored" "와이드 컬러")
("wide float" "와이드 플로트")
("wide footnote" "넓은 각주")
("wide tabular" "와이드 테이블 형식")
("widescreen" "와이드 스크린")
("wrap lines" "랩 줄")
("writing TeXmacs bibliography styles" "TeXmacs 참고 문헌 스타일 작성")
("writing documentation" "문서 작성")
("wrong empty passphrase" "잘못된 빈 암호 문구")
("wrong passphrase" "잘못된 암호")
("year" "년")
("you are attempting to open an encrypted file while" "귀하가 암호화 된 파일을 열려고합니다")
("you might consider enabling the experimental" "실험 사용을 고려할 수도 있습니다")
("you must add a bibliography file" "서지 파일을 추가해야합니다")
("you should also make sure that GnuPG is installed" "GnuPG가 설치되어 있는지 확인하십시오")
("your personal dictionary has been modified" "개인 사전이 수정되었습니다")
("zoom" "줌")
("zoom in" "확대")
("zoom out" "확대")
