; Copyright David Moriano García (2001), Álvaro Tejero Cantero
; (alvaro@antalia.com, 2001,2002,2003).
("a modifier" "modificador A")
("GNU" "GNU")
("h modifier" "modificador H")
("LaTeX" "LaTeX")
("m modifier" "modificador M")
("TeX" "TeX")
("abbreviation" "abreviatura")
("about" "acerca de")
("about menu" "menú acerca de")
("above" "encima")
("abstract" "resumen")
("accent" "acento")
("accept" "aceptar")
;?
("accept all scripts" "aceptar todos los guiones")
("accept no scripts" "no aceptar guiones")
("accept script" "aceptar guión")
("accessed" "acceso")  ; ojo, acceder es intransitivo
("acknowledgment" "reconocimiento")
("acronym" "acrónimo")
("action" "acción")
("activate" "activar")
("acute" "agudo")
("add switch after" "añadir fotograma antes")
("add switch before" "añadir fotograma después")
("address" "dirección")
("address block" "dirección")
("advanced" "avanzado")
("advanced layout features" "funciones de composición avanzadas")
("after" "después de")
("albanian" "albanés")
("algorithm" "algoritmo")
("align cell to the bottom" "alinear celda por abajo")
("align cell to the left" "alinear celda a la izquierda")
("align cell to the right" "alinear celda a la derecha")
("align cell to the top" "alinear celda arriba")
("align table at base of left column" "alinear tabla con la base de la columna izquierda")
("align table at base of middle column" "alinear tabla con la base de la columna central")
("align table at base of origin column" "alinear tabla a la base de la columna original")
("align table at base of right column" "alinear tabla con la base de la columna derecha")
("align table at fraction bar height" "alinear tabla a la altura de la barra defracción")
("align table at the base of bottom row" "alinear tabla a la base de la fila inferior")
("align table at the base of middle row" "alinear tabla a la base de la fila central")
("align table at the base of origin row" "alinear tabla a la base de la fila original")
("align table at the base of top row" "alinear tabla a la base de la fila superior")
("align table at the bottom" "alinear tabla por abajo")
("align table at the center" "alinear tabla por el centro")
("align table at the horizontal center" "alinear tabla por el centro horizontal")
("align table at the left" "alinear tabla a la izquierda")
("align table at the top" "alinear tabla arriba")
("align table to the right" "alinear tabla a la derecha")
("align text to the left" "alinear el texto a la izquierda")
("align text to the right" "alinear el texto a la derecha")
("aligned" "alineada")
("alignment" "alineación")
("all" "todo")
("allow" "permitir")
("allowed extension" "extensión permitida")
("allowed reduction" "reducción permitida")
("alpha release" "versión alfa")
("alt key" "tecla alt")
("and" "y")
("answer" "respuesta")
("appendix" "apéndice")
("apply" "aplicar")
("april" "abril")
("arab" "árabe")
("archaic" "arcaica")
("architecture" "arquitectura")
("argument" "argumento")
("arithmetic" "aritmética")
("armenian" "armenio")
("arrow" "flecha")
("arrows" "flechas")
("article" "artículo")
("as on paper" "como en papel")
("assign" "asignar")
("at fraction bar height" "a la altura de la raya de fracción")
("at the baseline" "a la línea base")
("at the bottom" "abajo")
("at the left" "a la izquierda")
("at the middle" "al medio")
("at the right" "a la derecha")
("at the top" "arriba")
("attach" "vincular")
("attach buffer to which project" "a qué proyecto vincular el búfer")
("august" "agosto")
("author" "autor")
("authorize" "autorizar")
("automatic" "automático")
("automatically close brackets" "cerrar paréntesis automáticamente")
("automatically generated content" "contenido generado automáticamente")
("axiom" "axioma")
("background" "fondo")
("background color" "color de fondo")
("backward replace" "sustituir hacia atrás")
("backward search" "buscar hacia atrás")
("bad data format" "formato de datos erróneo")
("bar" "barra")
("bard" "bardo")
("base level" "nivel base")
("bashkirian" "bashkirian")
("basic" "básico")
("basic data types" "tipos de datos básicos")
("basic types" "tipos básicos")
("be useful" "ser útil")
("become a TeXmacs developer" "hazte desarrollador de TeXmacs")
("before" "antes de")
("begin" "principio")
("below" "debajo")
("beta release" "versión beta")
("bibliography" "bibliografía")
("bibliography file" "fichero de bibliografía")
("bibliography style" "estilo de bibliografía")
("big" "grande")
("big figure" "figura grande")
("big operator" "operador grande")
("big skip" "salto grande")
("big table" "tabla grande")
("binary operation" "operación binaria")
("binary relation" "relación binaria")
("black" "negro")
("blackboard bold" "negrita de pizarra")
("blackboard math" "matemática de pizarra")
;?
("blackletter" "blackletter")
("blue" "azul")
("body" "cuerpo")
("bold" "negrita")
("book" "libro")
("border" "borde")
("both" "ambas")
("bottom" "al final")
("bottom border" "borde inferior")
("bottom margin" "margen inferior")
("bottom padding" "acolchado inferior")
("branch" "rama")
("break" "salto")
("breaking" "saltos")
;?
("breve" "breve")
("british" "británico")
("broken white" "blanco roto")
("brown" "marrón")
("browse" "examinar")
("browse web" "examinar en la red")
("browser" "navegador")
("buffer" "búfer")
("bulgarian" "búlgaro")
("bullet" "bolo")
("bullets" "bolos")
("by" "por")
("by typing" "escribiendo")
("bytes free" "bytes libres")
("bytes used" "bytes usados")
("calligraphic" "caligráfica")
("cancel" "cancelar")
("case" "caso")
("cc" "cc")
("cell" "celda")
("cell background color" "color de fondo de la celda")
("cell border" "borde de la celda")
("cell height" "altura de la celda")
("cell operation mode" "modo de operación de la celda")
("cell width" "anchura de la celda")
("center" "centro")
("center text" "centrar texto")
("centered" "centrado")
("centered block" "bloque centrado")
("centered tabular" "tabla centrada")
("change border of cell" "cambiar borde de la celda")
("change cell operation mode" "cambiar modo de operación de la celda")
("change log" "bitácora de cambios")
("changes" "cambios")
("chapter" "capítulo")
;?
("check" "check")
("check text for spelling errors" "comprobar ortografía")
("chinese" "chino")
("choice" "elección")
("citation" "cita")
("cite" "cita")
("class" "clase")
("clear" "limpiar")
("clear selection" "borrar selección")
("clipped" "recortado")
("clipped and magnified" "recortado y ampliado")
("clipped and resized" "recortad y redimensionado")
("clone" "duplicar")
("clone window" "duplicar ventana")
("close" "cerrar")
("close TeXmacs" "cerrar TeXmacs")
("close buffer" "cerrar búfer")
("close session" "cerrar sesión")
("close window" "cerrar ventana")
("closing" "cierre")
("code" "código")
("color" "color")
("column" "columna")
("column contains glued items" "la columna contiene elementos pegados")
("compact" "compacta")
("compatibility with other formats" "compatibilidad con otros formatos")
("compile article" "compilar artículo")
("compile book" "compilar libro")
("compile buffer" "compilar búfer")
("compile project" "compilar proyecto")
("complex" "compleja")
;?
("concrete" "concrete")
("condensed" "condensada")
("condition" "condición")
("configuration" "configuración")
("content tag" "marcar contenido")
("context dependent icons" "iconos dependientes del contexto")
("continuation of" "continuación de")
("convention" "convenio")
("converters to other data formats" "convertidores a otros formatos de datos")
("copy" "copiar")
("copy text" "copiar texto")
("copy to" "copiar a")
("copying" "copiando")
("corollary" "corolario")
("correct text" "corregir texto")
("cursors" "cursores")
("custom tab" "tabulador personalizado")
;?

("customizing TeXmacs" "personalización de TeXmacs")
("customizing the TeXmacs styles" "personalización de los estilos de TeXmacs")
("cut" "cortar")
("cut text" "cortar texto")
("cut to" "cortar a")
("cypriot" "chipriota")
("cyrillic" "cirílico")
("cyrillic input method" "entrada de cirílico")
("cyrillic italic right" "cirílico cursiva recta")
("czech" "checo")
("dancers" "bailarines")
("danish" "danés")
("dark grey" "gris oscuro")
("dash" "guión")
("dashes" "guiones")
("data conversion" "conversión de datos")
("data format" "formato de datos")
("date" "fecha")
("deactivate" "desactivar")
("deactivate table" "desactivar tabla")
("december" "diciembre")
("decorate atoms" "decoraciones atómicas")
("default" "por defecto")
("default padding" "acolchado por defecto")
("definition" "definición")
("delete" "borrar")
("delete column" "borrar columna")
("delete row" "borrar fila")
("denominator" "denominador")
("description" "descripción")
("destination" "destino")
("detach" "desvincular")
("determinant" "determinante")
("devangari" "devangari")
("developers guide" "guía de programadores")
("directory" "directorio")
("disable first indentation" "deshabilitar primer sangrado")
("disable first indentation after" "deshabilitar primer sangrado posterior")
("disable first indentation before" "deshabilitar primer sangrado anterior")
("disable indentation" "deshabilitar sangrado")
("disable indentation after" "deshabilitar sangrado después")
("disable indentation before" "deshabilitar sangrado antes")
("disable last indentation" "deshabilitar último sangrado")
("disable last indentation after" "deshabilitar último sangrado después")
("disable last indentation before" "deshabilitar último sangrado antes")
("disallow" "no permitir")
("distribute unused space" "distribuir el espacio no utilizado")
;?
("div" "div")
("document" "documento")
("document format" "formato del documento")
("document style" "estilo del documento")
("document styles" "estilos de documento")
("documentation" "documentación")
("documents are trees" "los documentos son árboles")
;nuevo
("do not remap" "no reasignar")
("dot" "punto")
("dots" "puntos")
("double stroke" "trazo doble")
("down" "abajo")
("dpi" "ppp")
("duplicate" "duplicada")
("dutch" "holandés")
("dynamic libraries" "bibliotecas dinámicas")
("edit" "editar")
("editing tools" "herramientas de edición")
("emacs prefix command" "comando con prefijo de emacs")
("email" "correo-e")
("emphasize" "con énfasis")
("emphasize text" "enfatizar texto")
("empty box" "caja vacía")
("enable first indentation" "habilitar primer sangrado")
("enable first indentation after" "habilitar primer sangrado después")
("enable first indentation before" "habilitar primer sangrado antes")
("enable indentation" "habilitar sangrado")
("enable indentation after" "habilitar sangrado después")
("enable indentation before" "habilitar sangrado antes")
("enable last indentation" "habilitar último sangrado")
("enable last indentation after" "habilitar último sangrado después")
("enable last indentation before" "habilitar último sangrado antes")
("encl" "adj.")
("end" "fin")
("english" "inglés")
("enter a title" "introduce un título")
("enumerate" "lista numerada")
("enumerate|Alpha" "numerar|Alfa")
("enumerate|Roman" "numerar|Romano")
("enumerate|alpha" "numerar|alfa")
("enumerate|roman" "numerar|romano")
("env" "env")
("environment" "entorno")
("epilogue" "epílogo")
("equal" "igual")
("equation" "ecuación")
("equations" "ecuaciones")
("equivalent for" "equivalente a")
("error" "error")
("esperanto" "esperanto")
("etruscan" "etrusco")
("evaluate" "evaluar")
("evaluate scheme expression" "evaluar expresión en scheme")
("even page footer" "pie de página par")
("even page header" "cabecera de página par")
("even page margin" "margen de página par")
("even page text" "texto de página par")
;?
("exact horizontal" "horizontal exacta")
("exact mode" "modo exacto")
("exam" "examen")
("example" "ejemplo")
("exclusive" "exclusivo")
("exclusive or" "o exclusivo")
("executable" "ejecutable")
("execute" "ejecutar")
("execute a TeXmacs command" "ejecuta un comando de TeXmacs")
("execute system command" "ejecutar comando del sistema")
("executive" "ejecutivo")
("exercise" "ejercicio")
("expand" "desarrollar")
;?
("explained" "explicada")
("export" "exportar")
("export as" "exportar como")
("extend or normal" "extendido o normal")
("extern " "externo")
("extra" "extra")
("extract format" "extraer formato")
("family" "familia")
("february" "febrero")
("figure" "figura")
("file" "fichero")
("file name" "nombre del fichero")
("file not found" "fichero no encontrado")
("find next match" "buscar el siguiente")
("find text" "buscar texto")
("finnish" "finlandés")
("first contact" "primer contacto")
("first indentation" "primer sangrado")
("first item" "primer elemento")
("first page" "primera página")
("first start" "comienzo rápido")
("flat" "plana")
("flexibility" "elasticidad")
("flexibility factor for vertical spacing" "factor de flexibilidad para el espaciado vertical")
("float" "flotante")
("floating figure" "figura flotante")
("floating object" "objeto flotante")
("floating table" "tabla flotante")
("fold" "plegar")
("folded" "plegado")
("font" "tipo de letra")
("font base size" "tamaño base del tipo")
("font dpi" "resolución del tipo (ppp)")
("font family" "familia del tipo")
("font name" "nombre del tipo")
("font series" "estilo del tipo")
("font shape" "forma del tipo")
("font size" "tamaño del tipo")
("font variant" "variante del tipo")
("fonts" "tipos de letra")
("footer" "pie")
("footnote" "nota al pie")
("for" "para")
("foreground" "primer plano")
("foreign" "extranjera")
("format" "formato")
("formatted date" "fecha formateada")
("formula" "fórmula")
("formula style" "estilo de fórmula")
("forward replace" "sustituir el siguiente")
("forward search" "buscar el siguiente")
("fraction" "fracción")
("french" "francés")
("full manuals" "manuales completos")
("function" "función")
("further customization" "personalización adicional")
("future changes" "cambios futuros")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs viene sin ninguna forma de garantía legal")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs se desarrolla bajo la licencia pública general GNU (GNU GPL)")
("general architecture of TeXmacs" "arquitectura general de TeXmacs")
("general negation" "negación general")
("generating font file" "generando fichero del tipo")
("generic" "genérico")
("georgian" "georgiano")
("german" "alemán")
("getting started" "primeros pasos")
("glossary" "glosario")
("glossary entry" "entrada de glosario")
("glue" "pegar")
;?
("glue decorations" "pegar decorados")
("go" "ir")
("gothic" "gótica")
("graphical interface" "interfaz gráfica")
;?
("grave" "grave")
("greater" "mayor que")
("greater or equal" "mayor o igual que")
("greek" "griego")
("greek letter" "letra griega")
("green" "verde")
("grey" "gris")
("group" "grupo")
("happy typing" "feliz escritura")
("has been aborted" "ha sido interrumpida")
("has completed its task" "ha acabado su tarea")
("hat" "sombrero")
("header" "cabecera")
("header and footer" "cabecera y pie")
("hebrew" "hebreo")
("height" "altura")
("height is exactly the specified height" "la altura es exactamente la especificada")
("height is maximum of specified height and box height" "la altura es la mayor de entre la especificada y la altura de caja")
("height is minimum of specified height and box height" "la altura es la menor de entre la especificada y la altura de caja")
("height magnification" "ampliación de altura")
("help" "ayuda")
("help me" "ayúdame")
("help us" "ayúdanos")
("here" "aquí")
("home" "inicio")
("horizontal" "horizontal")
("horizontal cell alignment" "alineación horizontal de celdas")
("horizontal ink separation" "separación de entintado horizontal")
("horizontal part" "parte horizontal")
("horizontal position" "posición horizontal")
("horizontal space" "espacio horizontal")
("horizontal table alignment" "alineación horizontal de tabla")
("horizontally align cell to the base" "alinear la celda horizontalmente con la base")
("horizontally center the cell" "centrar horizontalmente la celda")
("how much longer may pages become" "cuánto más largas pueden hacerse las páginas")
("how much shorter may pages become" "cuánto más cortas pueden hacerse las páginas")
("huge" "enorme")
("hungarian" "húngaro")
("hyperlink" "hiperenlace")
("hyphenation" "guionado")
("icelandic" "islandés")
("if" "si")
("image" "imagen")
("image links" "vínculos a imágenes")
("implementation" "implementación")
("import" "importar")
("improving the current implementation" "mejorar la implementación actual")
("inactive" "inactivo")
("include" "incluir fichero")
("include a document" "incluir un documento")
("include file" "incluir fichero")
("inclusion into TeXmacs" "inclusión en TeXmacs")
("inclusions" "inclusiones")
;?
("indent" "sangrar")
("indentation flag" "marcador de sangrado")
("index" "índice de materias")
("index entry" "entrada de índice")
("index level" "nivel de índice")
("insert" "insertar")
("insert Pr" "insertar Pr")
("insert a TeXmacs symbol" "insertar un símbolo de TeXmacs")
("insert a big operator" "insertar un operador grande")
("insert a binary operation" "insertar una operación binaria")
("insert a binary relation" "insertar una relación binaria")
("insert a blackboard bold character" "insertar un carácter de negrita de pizarra")
("insert a bold calligraphic character" "insertar un carácter en negrita caligráfica")
("insert a bold character" "insertar un carácter en negrita")
("insert a calligraphic character" "insertar un carácter en caligráfica")
("insert a fraction" "insertar una fracción")
("insert a fraktur character" "insertar un carácter en fráctur")
("insert a greek character" "insertar un carácter griego")
("insert a large left delimiter" "insertar un delimitador grande a la izquierda")
("insert a large right delimiter" "insertar un delimitador grande a la derecha")
("insert a large separator" "insertar un gran separador")
("insert a left subscript" "insertar un subíndice a la izquierda")
("insert a link" "insertar un enlace")
("insert a miscellaneous symbol" "insertar un símbolo misceláneo")
("insert a new branch" "insertar una nueva rama")
("insert a new item" "insertar un nuevo elemento")
("insert a picture" "insertar una imagen")
("insert a square root" "insertar una raíz cuadrada")
("insert a table" "insertar tabla")
("insert a table or a matrix" "insertar una tabla o una matriz")
("insert an" "insertar un/a")
("insert an accent" "insertar un acento")
("insert an arrow" "insertar una flecha")
("insert an environment" "insertar un nuevo entorno")
("insert an n" "insertar una n")
("insert appendix" "insertar apéndice")
("insert arccos" "insertar arccos")
("insert arcsin" "insertar arcsin")
("insert arctan" "insertar arctan")
("insert arg" "insertar arg")
("insert argument" "insertar argumento")
("insert automatically generated content" "insertar contenido generado automáticamente")
("insert big contour integral" "insertar integral de contorno grande")
("insert big coproduct" "insertar coproductorio grande")
("insert big direct sum" "insertar suma directa grande")
("insert big dotted point" "insertar producto puntual grande")
("insert big integral" "insertar integral grande")
("insert big intersection" "insertar intersección grande")
("insert big logical and" "insertar Y lógico grande")
("insert big logical or" "insertar O lógico grande")
("insert big product" "insertar productorio grande")
("insert big square union" "insertar unión cuadrada grande")
("insert big summation" "insertar sumatorio grande")
("insert big tensor product" "insertar producto tensorial grande")
("insert big union" "insertar unión grande")
("insert big union sum" "insertar suma unión grande")
("insert big vertical space" "insertar espacio vertical grande")
("insert chapter" "insertar capítulo")
("insert column" "insertar columna")
("insert column to the left" "insertar columna a la izquierda")
("insert column to the right" "insertar columna a la derecha")
("insert cos" "insertar cos")
("insert cosh" "insertar cosh")
("insert cot" "insertar cot")
("insert coth" "insertar coth")
("insert csc" "insertar csc")
("insert deg" "insertar deg")
("insert det" "insertar det")
("insert dim" "insertar dim")
("insert dollar" "insertar dólar")
("insert equation" "insertar ecuación")
("insert executable markup" "insertar código ejecutable")
("insert exp" "insertar exp")
("insert footnote" "insertar nota")
("insert formula" "insertar fórmula")
("insert gcd" "insertar gcd")
("insert hom" "insertar hom")
("insert horizontal interword space" "insertar espacio horizontal entre palabras")
("insert image" "insertar imagen")
("insert inactive markup" "insertar marcado inactivo")
("insert inf" "insertar inf")
("insert ker" "insertar ker")
("insert lg" "insertar lg")
("insert lim" "insertar lim")
("insert liminf" "insertar liminf")
("insert limsup" "insertar limsup")
("insert ln" "insertar ln")
("insert log" "insertar log")
("insert mathematics" "insertar matemáticas")
("insert max" "insertar max")
("insert medium horizontal space" "insertar espacio horizontal medio")
("insert medium vertical space" "insertar espacio vertical medio")
("insert min" "insertar min")
("insert negative horizontal space" "insertar espacio horizontal negativo")
("insert new item or number" "insertar nuevo elemento o número")
("insert new rows or columns" "insertar nuevas filas o columnas")
("insert or delete rows or columns" "insertar o borrar filas o columnas")
("insert row" "insertar fila")
("insert row above" "insertar fila encima")
("insert row below" "insertar fila debajo")
("insert sec" "insertar sec")
("insert section" "insertar sección")
;?
("insert sharp" "insertar almohadilla")
("insert sin" "insertar sin")
("insert sinh" "insertar sinh")
("insert small horizontal space" "insertar espacio horizontal pequeño")
("insert small vertical space" "insertar espacio vertical pequeño")
("insert structural markup" "insertar marcado estructural")
("insert subsection" "insertar subsección")
("insert subsubsection" "insertar subsubsección")
("insert sup" "insertar sup")
("insert tan" "insertar tan")
("insert tanh" "insertar tanh")
("insert thick horizontal space" "insertar espacio horizontal grueso")
("interface" "interfaz")
("interfacing" "comunicación")
("interfacing TeXmacs with other systems" "comunicar TeXmacs con otros sistemas")
("interjection" "interjección")
("interline separation" "separación entre líneas")
("interline space" "interlineado")
("internationalization" "internacionalización")
("interparagraph space" "espacio entre párrafos")
("interrupt execution" "interrumpir ejecución")
("introduction" "introducción")
("invisible" "invisible")
("invisible citation" "cita invisible")
("irish" "irlandés")
("is running" "está ejecutándose")
("is tuple" "es una tupla")
("ispell does not respond" "ispell no responde")
("ispell is already busy" "ispell ya está ocupado")
("italian" "italiano")
("italic" "cursiva")
("italic right" "cursiva recta")
("item" "elemento")
("itemize" "bolos")
("january" "enero")
("japanese" "japonés")
("july" "julio")
("june" "junio")
("justified" "justificado")
("justify text" "justificar el texto")
("key" "tecla")
("keyboard" "teclado")
("keyboard equivalent" "equivalencia de teclado")
("keyboard modifiers" "modificadores de teclado")
("keyboard shortcut" "atajo de teclado")
("keymaps" "disposición del teclado")
("keyword" "palabra clave")
("keywords" "palabras clave")
("kill" "matar")
("known bugs" "gazapos conocidos")
("label" "etiqueta")
("landscape" "apaisado")
("language" "idioma")
("large" "grande")
("large closing bracket" "gran paréntesis de cierre")
("large delimiter" "delimitador grande")
("large opening bracket" "gran paréntesis de apertura")
("large separator" "separador grande")
("last indentation" "última sangría")
("last page" "última página")
("latex command" "comando de latex")
("latin" "latín")
("layout" "presentación")
("lecture note" "notas de clase")
("left" "izquierda")
("left border" "borde izquierdo")
("left margin" "margen izquierdo")
("left padding" "acolchado izquierdo")
("left prime" "prima izquierda")
("left aligned" "alineado a la izquierda")
("left slanted" "inclinada izquierda")
("left subscript" "subíndice a la izquierda")
("left superscript" "superíndice a la izquierda")
("left surrounding" "entorno a la izquierda")
("legal" "legal")
("lemma" "lema")
("length" "longitud")
("less" "menos")
("less or equal" "menos o igual")
("letter" "carta")
("license" "licencia")
("light" "ligero")
("light grey" "gris claro")
("limitations" "limitaciones")
("limits" "límites")
("line" "línea")
("line break" "salto de línea")
("line stretch" "elasticidad de la línea")
("link" "enlace")
("link image" "vincular imagen")
("list" "lista")
("list of figures" "lista de figuras")
("list of tables" "lista de tablas")
("load" "cargar")
("load LaTeX file" "cargar fichero LaTeX")
("load TeX file" "cargar fichero TeX")
("load TeXmacs file" "cargar fichero TeXmacs")
("load TeXmacs style file" "cargar fichero de estilos de TeXmacs")
("load a file" "cargar un fichero")
("load buffer" "cargar búfer")
("load file" "cargar fichero")
("load html file" "cargar fichero html")
("load image" "cargar imagen")
("load in new window" "cargar en nueva ventana")
("load latex file" "cargar fichero latex")
("load more recent autosave file" "cargar el fichero autoguardado más reciente")
("load tex file" "cargar fichero tex")
("load verbatim file" "cargar fichero de texto plano")
("loaded" "cargado")
("long" "larga")
("look and feel" "aspecto y comportamiento")
("look up" "buscar")
("lower border" "borde inferior")
("macro" "macro")
("magenta" "magenta")
("magic" "mágico")
("magnification" "ampliación")
("magnified" "ampliado")
("main" "principal")
("main icon bar" "barra de iconos principal")
("major changes" "cambios principales")
("make a page insertion" "hacer una inserción de página")
("make a subscript" "poner un subíndice")
("make a superscript" "poner un superíndice")
("make acute" "hacer agudo")
("make bar" "hacer barra")
;?
("make check" "hacer check")
("make fraction" "hacer fracción")
("make grave" "hacer grave")
("make hat" "hacer sombrero")
("make label" "hacer etiqueta")
("make negation" "hacer negación")
;?
("make page reference" "hacer referencia a página")
("make reference" "hacer referencia")
("make square root" "hacer raíz cuadrada")
("make tilde" "hacer tilde")
("make title" "componer título")
("make vector" "hacer vector")
("making donations" "donar")
("manual" "manual")
("map to" "se convierte en")
("march" "marzo")
("margins" "márgenes")
("margins as on paper" "márgenes como en el papel")
("master" "maestro")
("master file" "fichero maestro")
;?
("math" "matemática")
("math font" "tipo matemático")
("math font family" "familia de tipo matemático")
("math font series" "estilo de tipo matemático")
("math font shape" "forma de tipo matemático")
("mathematical" "matemático")
("mathematical formulas" "fórmulas matemáticas")
("mathematical typesetting" "composición tipográfica de las matemáticas")
("mathematics" "matemáticas")
("matrix" "matriz")
("maximal number of columns" "número máximo de columnas")
("maximal number of rows" "número máximo de filas")
("maximum mode" "modo máximo")
("may" "mayo")
("medium" "medio")
("medium skip" "salto mediano")
;?
("meminfo" "meminfo")
("merge" "fusionar")
;?
("messy" "liosa")
("meta key" "tecla meta")
("middle" "medio")
("minimal number of columns" "numero mínimo de columnas")
("minimal number of rows" "número mínimo de filas")
("minimum mode" "modo mínimo")
("minus" "menos")
("miscellaneous" "miscelánea")
("mod" "mod")
("mode" "modo")
("modifier" "modificador")
("modify cell alignment" "modificar alineación de la celda")
("modify cell border" "modificar borde de celda")
("modify cell padding" "modificar acolchado de celda")
("modify cell size" "modificar tamaño de celda")
("modify table border" "modificar borde de celda")
("modify table padding" "modificar acolchado de tabla")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "más información sobre GNU TeXmacs en la ayuda")
("mosaic" "mosaico")
("move" "mover")
("move down" "ir abajo")
("move object" "mover objeto")
("move to the right when finished" "mueve a la derecha cuando termines")
("move up" "ir arriba")
("n-th" "enésima")
("n-th root" "raiz enésima")
("name" "nombre")
("negation" "negación")
("new" "nuevo")
("new buffer" "nuevo búfer")
("new column" "nueva columna")
("new item" "nuevo elemento")
("new line" "nueva línea")
("new number" "nuevo número")
("new page" "nueva página")
("new page before" "nueva página antes")
("new paragraph" "nuevo párrafo")
;?
("new roman" "nueva roman")
("new row" "nueva fila")
("new table" "nueva tabla")
("next line" "siguiente línea")
("no" "no")
("no changes need to be saved" "no hay cambios que guardar")
("no dictionary for" "no hay diccionario para")
;?
("no first indentation" "sin primer sangrado")
("no indentation" "sin sangrado")
("no last indentation" "sin último sangrado")
("no line break" "no saltar de línea")
("no matches found" "no se encontraron coincidencias")
("no more matches for" "no se encontraron más coincidencias")
("no more redo information available" "no hay disponible más información 'rehacer'")
("no more undo information available" "no hay disponible más información 'deshacer'")
("no name" "sin nombre")
("no page break after" "sin salto de página posterior")
("no page break before" "sin salto de página anterior")
("no spelling errors found in text" "no se encontraron errores de ortografía")
("no style" "sin estilo")
("none" "nada")
("normal" "normal")
("norwegian" "noruego")
("not" "no")
;?
("not equal" "no igual")
("not found" "no encontrado")
("notation" "notación")
("note" "nota")
("november" "noviembre")
("number" "número")
("number equation" "numerar ecuación")
("number of columns" "número de columnas")
("numbered equation" "ecuación numerada")
("numbered equations" "ecuaciones numeradas")
("numerator" "numerador")
("numeric" "numérico")
("objectives" "objetivos")
("occurrences" "apariciones")
("october" "octubre")
("odd page footer" "pie de página impar")
("odd page header" "cabecera de página impar")
("odd page margin" "margen de página impar")
("odd page text" "texto de página impar")
("of" "de")
("off" "desactivado")
("ok" "vale")
("old english" "inglés antiguo")
("old slavonic" "eslavo antiguo")
("old style" "estilo antiguo")
("on" "activado")
("on cells" "sobre celdas")
("on columns" "sobre columnas")
("on entire table" "sobre la tabla entera")
("on rows" "sobre filas")
("one spelling error has been corrected" "un error ortográfico corregido")
("online documentation" "documentación en línea")
("online help" "ayuda en línea")
("open" "abrir")
("open a new buffer" "abrir un nuevo búfer")
("open new window" "abrir nueva ventana")
("opening" "apertura")
;?
("operation on named selection" "operación sobre la selección indicada")
("operation on primary selection" "operación sobre la selección primaria")
("operation on secondary selection" "operación sobre la selección secundaria")
("operation on ternary selection" "operación sobre la selección ternaria")
("optical" "óptico")
("option" "opción")
("options" "opciones")
("or" "o")
("orange" "naranja")
("orientation" "orientación")
("origin" "origen")
("original welcome message" "mensaje original de bienvenida")
("other" "otro")
("other pages" "otras páginas")
("other projects" "otros proyectos")
("other style" "otro estilo")
("outlined roman" "perfil romano")
("over" "sobre")
("padding" "acolchado")
("page" "página")
("page bottom margin" "margen inferior de página")
("page break" "salto de página")
("page break before" "salto de página antes")
("page height" "alto de página")
("page insertion" "inserción de página")
("page layout" "presentación de página")
("page number text" "texto para número de página")
("page numbering" "numeración de páginas")
("page reference" "referencia de página")
("page right margin" "margen derecho de página")
;nuevo
("page setup" "configuración de página")
("page top margin" "margen superior de página")
("page type" "tipo de página")
("page width" "ancho de página")
("paper" "papel")
("paper type" "tipo de papel")
("papyrus" "papiro")
("paragraph" "párrafo")
("paragraph mode" "modo del párrafo")
("paragraph width" "ancho del párrafo")
("part" "parte")
("past changes" "cambios pasados")
("paste" "pegar")
("paste from" "pegar desde")
("paste text" "pegar texto")
("path" "camino")
("perform operations on cells" "operar sobre celdas")
("perform operations on columns" "operar sobre columnas")
("perform operations on entire table" "operar sobre la tabla entera")
("perform operations on rows" "operar sobre filas")
("permanent" "permanente")
("person" "persona")
("personal dictionary has been modified" "el diccionario personal ha sido modificado")
("phantasy" "fantasía")
("philosophy" "filosofía")
("phoenician" "fenicio")
("phonetic" "fonético")
("pink" "rosa")
("plain" "natural")
("plain block" "bloque normal")
("plain tabular" "tabla normal")
("planned changes" "cambios planeados")
("plans for the future" "planes para el futuro")
("please" "por favor")
("please wait" "por favor, espera")
("plus" "más")
("polish" "polaco")
("porting TeXmacs to other platforms" "portar TeXmacs a otras plataformas")
("portrait" "vertical")
("portuguese" "portugués")
("position" "posición")
;?
("position float" "ubicar flotante")
("position floating object" "ubicar objeto flotante")
("position the table" "ubicar la tabla")
("postscript" "postscript")
("postscript image" "imagen postscript")
("pre-alpha release" "versión prealfa")
("preamble" "preámbulo")
("preamble mode" "modo preámbulo")
("preferences" "preferencias")
("presentation mode" "modo presentación")
("preview before printing" "previsualizar antes de imprimir")
;?
("preview with ghostview" "previsualizar con ghostview")
("preview command" "comando de previsualización")
("primary" "primario")
("prime" "prima")
("print" "imprimir")
("print all" "imprimir todo")
("print all to file" "imprimir todo en un fichero")
("print page selection" "imprimir la selección")
("print page selection to file" "imprimir la selección en un fichero")
("print to postscript file" "imprimir en fichero postscript")
("printer" "impresora")
("printer dpi" "ppp de la impresora")
("printing command" "comando de impresión")
("problem" "problema")
("professional" "profesional")
("prog" "prog")
("prog font" "tipo prog")
("prog font family" "familia de tipo prog")
("prog font series" "estilo del tipo prog")
("prog font shape" "forma del tipo prog")
("program" "programa")
("program mode" "modo programa")
;?
("programming" "programación")
("progressive" "progresivo")
("project" "proyecto")
("projects" "proyectos")
("prologue" "prólogo")
("prompt on scripts" "preguntar sobre los guiones")
("proof" "demostración")
("proportional" "proporcional")
("proportional typewriter" "de ancho fijo proporcional")
("proposition" "proposición")
("query replace" "buscar y reemplazar")
("question" "pregunta")
("quit" "salir")
("quotation" "cita (varios párrafos)")
("quote" "cita")
("range" "rango")
("really close it" "cerrarlo de verdad")
("really huge" "gigante")
("really quit" "salir de verdad")
("red" "rojo")
("redo" "rehacer")
("redo undone changes" "rehacer los cambios deshechos")
("reduce bottom margin by" "reducir margen inferior en")
("reduce left margin by" "reducir margen izquierdo en")
("reduce margins" "reducir márgenes")
("reduce right margin by" "reducir margen derecho en")
("reduce top margin by" "reducir margen superior en")
("reduction even page margin" "reducción del margen de página par")
("reduction odd page margin" "reducción del margen de página impar")
("reduction page bottom margin" "reducción del margen inferior de página")
("reduction page right margin" "reducción del margen derecho de página")
("reduction page top margin" "reducción del margen superior de página")
("reference" "referencia")
("references" "referencias")
("regular" "normal")
("release" "versión")
("reload" "recargar")
("remark" "observación")
("remove number" "eliminar número")
("remove this switch" "eliminar este fotograma")
("renumber this page" "renumerar esta página")
("repeat object" "repetir objeto")
("replace" "sustituir")
("replace by" "sustituir por")
("replaced" "sustituido")
("replaced one occurrence" "sustituída una aparición")
("reset" "reiniciar")
("resize object" "cambiar tamaño del objeto")
("resized" "tamaño cambiado")
("return" "return")
("revert" "volver al original")
("revert buffer" "recuperar el búfer")
("right" "derecha")
("right border" "borde derecho")
("right margin" "margen derecho")
("right padding" "acolchado derecho")
("right aligned" "alineado a la derecha")
("right subscript" "subíndice a la derecha")
("right superscript" "superíndice a la derecha")
("right surrounding" "entorno derecho")
("rigid" "rígido")
("rigid horizontal" "horizontal rígida")
("rigid space" "espacio rígido")
("romanian" "rumano")
("root" "raíz")
("rotate backward" "rotar hacia atrás")
("rotate forward" "rotar hacia delante")
("row" "fila")
("row contains glued items" "la fila contiene elementos pegados")
("runic" "rúnico")
("running author" "autor en cabecera o pie")
("running title" "título en cabecera o pie")
("russian" "ruso")
("russian and Ukrainian users" "usuarios rusos y ucranianos")
("sample" "muestra")
("sans serif" "sin serifado")
("save" "guardar")
("save TeXmacs file" "guardar fichero TeXmacs")
("save TeXmacs style file" "guardar fichero de estilos TeXmacs")
("save as" "guardar como")
("save as LaTeX" "guardar como LaTeX")
("save as TeX" "guardar como TeX")
("save buffer" "guardar búfer")
("save buffer as" "guardar búfer como")
("save file" "guardar fichero")
("save html file" "guardar fichero html")
("save image" "guardar imagen")
("save latex file" "guardar fichero latex")
("save tex file" "guardar fichero tex")
("save this buffer" "guardar este búfer")
("save verbatim file" "guardar fichero de texto plano")
("saved" "guardado")
("screen layout" "presentación en pantalla")
("screen margins" "márgenes en pantalla")
("script" "índice")
("script above" "índice arriba")
("script below" "índice debajo")
("script script size" "tamaño de índice de índice")
("script size" "tamaño de índice")
("scripts not accepted" "no se aceptan guiones")
("search" "buscar")
("searching" "buscando")
("secondary" "secundario")
("section" "sección")
("security" "seguridad")
("see" "ver")
("select a document style" "seleccionar un estilo de documento")
("select a foreground color" "seleccionar un color de primer plano")
("select a language" "seleccionar un idioma")
("selected region" "región seleccionada")
("selection" "selección")
("selections" "selecciones")
("seminar" "seminario")
("separation between lines" "separación entre líneas")
("separation between paragraphs" "separación entre párrafos")
("separator" "separador")
("september" "septiembre")
("serb" "serbio")
("series" "estilo")
("series|right" "estilo|recta")
("session" "sesión")
("session name" "nombre de la sesión")
("session type" "tipo de sesión")
("sessions" "sessiones")
("set" "fijar")
("set background color of cell" "fijar color de fondo de celda")
("set cell mode" "fijar modo de celda")
("set extension center" "fijar centro de extensión")
("set height" "fijar altura")
("set height of cell" "fijar altura de celda")
("set margins" "fijar márgenes")
("set n" "fijar n")
("set paragraph margins" "fijar márgenes de párrafo")
("set paragraph mode" "fijar modo de párrafo")
("set printer dpi" "establecer resolución de la impresora (ppp)")
("set printing command" "indicar comando de impresión")
;?
("set span" "fijar alcance")
("set special cell properties" "fijar propiedades especiales de celda")
("set special table properties" "fijar propiedades especiales de tabla")
("set text width" "fijar ancho del texto")
("set width" "fijar anchura")
("set width of cell" "fijar anchura de celda")
("settings" "ajustes")
("setup printer" "configurar la impresora")
("shape" "forma")
("shift-down" "shift-abajo")
("shift-right" "shift-derecha")
("show" "mostrar")
("show header and footer" "mostrar cabecera y pie")
("show on screen" "mostrar en pantalla")
("shrinking factor" "factor de reducción")
("signature" "firma")
("single" "sencillo")
("size" "tamaño")
("size limits" "límites de tamaño")
("slanted" "inclinada")
("sloppy" "laxo")
("small" "pequeño")
("small caps" "versalitas")
("small figure" "figura pequeña")
("small skip" "salto pequeño")
("small table" "tabla pequeña")
("solution" "solución")
("source code" "código fuente")
("space" "espacio")
("space between lines" "espacio entre líneas")
("space between paragraphs" "espacio entre párrafos")
("spacing" "espaciado")
("spanish" "español")
("special" "especial")
("special cell properties" "propiedades especiales de celda")
("special table properties" "propiedades especiales de tabla")
("specific" "específico")
("spell" "ortografía")
("spell checking complete" "comprobación de ortografía finalizada")
("spelling error" "error ortográfico")
("spelling errors have been corrected" "se han corregido las faltas de ortografía")
("split" "partir")
("square root" "raíz cuadrada")
("standard" "estándar")
("start" "empieza")
("start a new chapter" "empezar un nuevo capítulo")
("start a new section" "empezar una nueva sección")
("start an interactive session" "empezar una sesión interactiva")
("status bar" "barra de estado")
("stretchable" "estirable")
("stretchable horizontal" "estirable horizontal")
("stretchable vertical" "estirable vertical")
("stroke" "trazo")
("strokes" "trazos")
("strong" "resaltado")
("structural" "estructural")
("style" "estilo")
("styles" "estilos")
("sub" "sub")
("subparagraph" "subpárrafo")
("subscript" "subíndice")
("subsection" "subsección")
("subsub" "subsub")
("subsubsection" "subsubsección")
("summary" "resumen")
("summary of the principal TeXmacs tags" "resumen de los principales elementos de marcado de TeXmacs")
("superpose" "superponer")
("superposed" "superpuesto")
("superscript" "superíndice")
("swedish" "sueco")
("switch" "fotogramas")
("switch to first" "cambiar al primero")
("switch to formula style" "cambiar a estilo de fórmula")
("switch to last" "cambiar al último")
("switch to next" "cambiar al siguiente")
("switch to previous" "cambiar al anterior")
("switching and folding" "fotogramas y entornos plegados")
("symbol" "símbolo")
("system environment variables" "variables de entorno del sistema")
("tab" "tabulador")
("table" "tabla")
("table command" "comando de tabla")
("table of contents" "índice")
("tables" "tablas")
;?
("tabular" "tabular")
("tabular material" "material tabular")
("teXmacs as an interface" "teXmacs como interfaz")
("teXmacs fonts" "tipos de letra de TeXmacs")
("teXmacs notice" "aviso de TeXmacs")
("teXmacs style files" "ficheros de estilo de TeXmacs")
("ternary" "ternario")
("test" "probar")
("tex" "tex")
("text" "texto")
("text font" "tipo texto")
("text height correction" "correción de altura de texto")
("text width" "ancho de texto")
("texts" "textos")
("th century bc" "-ava centuria ac")
("th root" "ésima raiz")
("thai" "tailandés")
("the TeXmacs authors" "los autores de TeXmacs")
("the application did not send its usual startup banner" "la aplicación no envió su aviso de inicio habitual")
("the application does not reply" "la aplicación no responde")
("the application is already running" "la aplicación ya se está ejecutando")
("the boxes produced by the typesetter" "las cajas producidas por el sistema de composición")
("the graphical user interface" "el interfaz gráfico de usuario")
("the leaves of TeXmacs trees" "las hojas de los árboles de TeXmacs")
("the mycas example" "el ejemplo de mycas")
("the primitive TeXmacs constructs" "las construcciones primitivas de TeXmacs")
("the standard TeXmacs styles" "los estilos estándar de TeXmacs")
("theorem" "teorema")
("there are unsaved documents" "hay ficheros sin guardar")
("this document has not been saved" "no se ha grabado este búfer")
("this document has been produced using" "este documento ha sido producido utilizando")
("this line" "esta línea")
("this page" "esta página")
("tilda" "tilda")
("tilde" "tilde")
("times" "times")
("tiny" "diminuto")
("title" "título")
("to the left" "a la izquierda")
("to the right" "a la derecha")
("today" "hoy")
("tools" "herramientas")
;?
("top" "arriba del todo")
("top border" "borde superior")
("top level" "nivel superior")
("top margin" "margen superior")
("top padding" "acolchado superior")
("translate" "traducir")
("tree" "árbol")
("tuple" "tupla")
("turkish" "turco")
("tutorial" "tutorial")
("type" "tipo")
("type a latex command followed by" "escribe un comando de latex seguido por")
("type body" "escribe el cuerpo")
("type denominator" "escribe el denominador")
("type numerator" "escribe el numerador")
("type script" "escribe el índice")
("typesetted boxes" "composición tipográfica de cajas")
("typewriter" "ancho fijo")
("typewriter small caps" "versalitas de ancho fijo")
("typing a simple text" "teclear un texto sencillo")
("typing simple texts" "teclear textos sencillos")
("ugaritic" "ugarítico")
("ukrainian" "ucraniano")
("undo" "deshacer")
("undo last changes" "deshacer los últimos cambios")
("up" "arriba")
("update" "actualizar")
("update from web" "actualizar desde la red")
("update image links" "actualizar vínculos a imágenes")
("upper border" "borde superior")
("use TeXmacs" "usar TeXmacs")
("use a black color" "usar color negro")
("use a blue color" "usar color azul")
("use a bold font" "usar un tipo en negrita")
("use a brown color" "usar color marrón")
("use a calligraphic font" "usar un tipo caligráfico")
("use a green color" "usar color verde")
("use a grey color" "usar color gris")
("use a magenta color" "usar color magenta")
("use a orange color" "usar color naranja")
("use a pink color" "usar color rosa")
("use a red color" "usar color rojo")
("use a sans serif font" "usar un tipo sin serifado")
("use a typewriter font" "usar un tipo de ancho fijo")
("use a white color" "usar color blanco")
("use a yellow color" "usar color amarillo")
("use blackboard bold font" "usar tipo negrita de pizarra")
("use bold font series" "usar serie negrita")
("use calligraphical font" "usar tipo caligráfico")
("use footnote font size" "usar tamaño de tipo nota al pie")
("use fraktur font" "usar tipo fraktur")
("use huge font size" "usar tamaño de tipo enorme")
("use italic font shape" "usar forma de tipo cursiva")
("use large font size" "usar tamaño de tipo grande")
("use left hand column as border" "usar columna de la izquierda como borde")
("use medium font series" "usar serie de tipo medio")
("use normal font size" "usar tamaño de tipo normal")
("use package" "usar paquete")
("use paragraph width" "usar anchura de párrafo")
("use really huge font size" "usar tamaño de tipo gigante")
("use right font shape" "usar forma de tipo recta")
("use right hand column as border" "usar columna de la derecha como borde")
("use roman font family" "usar familia de tipos romana")
("use row above as border" "usar fila superior como borde")
("use row below as border" "usar fila inferior como borde")
("use sans serif font family" "usar familia de tipos sans serif")
("use script font size" "usar tamaño de tipo índice")
("use slanted font shape" "usar forma de tipo inclinada")
("use small capitals" "usar versalitas")
("use small font size" "usar tamaño de tipo pequeño")
("use small-caps font shape" "usar forma de tipo versalitas")
("use the blackboard bold font" "usar el tipo negrita de pizarra")
("use the fraktur font" "usar el tipo fraktur")
("use tiny font font size" "usar tamaño de tipo diminuto")
("use typewriter font family" "usar familia de tipos de ancho fijo")
("use very large font size" "usar tamaño de tipo muy grande")
("user manual" "manual de usuario")
("user provided icons" "iconos proporcionados por el usuario")
("value" "valor")
("variable" "variable")
("variant" "variante")
("vector" "vector")
("verbatim" "sin formato")
("verse" "verso")
("vertical" "vertical")
("vertical after" "vertical posterior")
("vertical before" "vertical anterior")
("vertical cell alignment" "alineación vertical de celda")
("vertical part" "parte vertical")
("vertical position" "posición vertical")
("vertical space" "espacio vertical")
("vertical table alignment" "alineación vertical de tabla")
("vertically align cell to the base" "linear verticalmente la celda a la base")
("vertically center the cell" "centrar verticalmente la celda")
("very large" "muy grande")
("very small" "muy pequeño")
("vietnamese" "vietnamita")
("view" "ver")
("visible" "visible")
("volume" "volumen")
("warning" "aviso")
("welcome" "bienvenido")
("welcome to GNU TeXmacs" "bienvenido a GNU TeXmacs")
("what is new" "qué es nuevo")
("when finished" "cuando termines")
("while" "mientras")
("white" "blanco")
("wide accent" "acento ancho")
("width" "ancho")
("width is exactly the specified width" "la anchura es exactamente la especificada")
("width is maximum of specified width and box width" "la anchura es la mayor de entre la especificada y de la de la caja")
("width is minimum of specified width and box width" "la anchura es la menor de entre la especificada y la de la caja")
("width magnification" "ampliación de anchura")
("window" "ventana")
("window height" "altura de la ventana")
("window width" "anchura de la ventana")
("windows key" "tecla de Windows")
("with" "con")
("write a name" "escribir un nombre")
("write bold mathematics" "escribir matemáticas en negrita")
("write bold text" "escribir en negrita")
("write italic text" "escribir en cursiva")
("write sample text" "escribir un texto de ejemplo")
("write strong text" "escribir texto resaltado")
("write typewriter text" "escribir texto de ancho fijo")
("write verbatim text" "escribir texto sin formato")
("writing data converters" "escribir traductores de datos")
("writing your own style files" "escribir tus propios ficheros de estilo")
("yellow" "amarillo")
("yes" "sí")
("you can also obtain" "también puedes obtener")
("your document is back in its original state" "el documento ha vuelto a su estado original")
("your first interface" "tu primer interfaz")
; new entries for 1.0.1.21
("background evaluations" "evaluaciones en segundo plano")
("basic communication using pipes" "comunicación básica por tuberías")
("completion" "compleción")
("content" "contenido")
("custum tab" "tab personalizado")
("fold input field" "campo de entrada plegado")
("formatted and structured output" "salida formateada y estructurada")
("input mode" "modo de entrada")
("insert a wide symbol above" "insertar símbolo ancho sobre")
("insert a wide symbol below" "insertar símbolo ancho bajo")
("insert fields" "insertar campos")
("insert input field above" "insertar campo de entrada sobre")
("insert input field below" "insertar campo de entrada bajo")
("insert text field" "insertar campo de texto")
("left arrow" "flecha izquierda")
("mathematical and customized input" "entrada matemática y personalizada")
("mathematical input" "entrada matemática")
("miscellaneous features" "características misceláneas")
("multiline input" "entrada multilínea")
("my documents" "mis documentos")
("no matches found for" "no se encontraron coincidencias para")
("overbrace" "llave por encima")
("overline" "línea por encima")
("plugin" "plugin")
("plugins" "plugins")
("presentation" "presentación")
("prompts and default input" "Prompts y entrada por defecto")
("remove all output fields" "quitar todos los campos de salida")
("remove fields" "quitar campos")
("remove input field" "quitar campo de entrada")
("remove input field above" "quitar campo de entrada arriba")
("search results for" "resultados de la búsqueda de")
("right arrow" "flecha derecha")
("search words in my documents" "buscar palabras en mis documentos")
("search words in the documentation" "buscar palabras en la documentación")
("search words in the source code" "buscar palabras en el código fuente")
("sending commands to TeXmacs" "cómo enviar comandos a TeXmacs")
("split session" "dividir sesiones")
("teXmacs plugins" "plugins de TeXmacs")
("underbrace" "llave por debajo")
("underline" "línea por debajo")
("users of Cyrillic languages" "usuarios de cirílico")
("wide bar" "barra ancha")
("your language" "su idioma")
("browse forward" "siguiente")
("browse back" "anterior")
("pageup" "RePag")
("find file" "buscar fichero")
("A.M.S. subject classification" "clasificación por temas de la AMS")
("caps-lock key" "tecla bloqueo de mayúsculas")
("extras" "extra")
("insert large" "insertar un gran")
("reduction bottom margin" "reducción del margen inferior")
("reduction right margin" "reducción del margen derecho")
("reduction top margin" "reducción del margen superior")
("right page margin" "margen de la página a la derecha")
("roman" "roman")
("use calligraphic font" "utilizar tipo caligráfico")
("more information about GNU TeXmacs can be found in the Help" "Puedes encontrar más información sobre GNU TeXmacs en la ayuda")
