("\"encryption\" features from the preference panel" "設定パネルの 暗号化 機能")
("(Re)Build autocompletion index" "(再)ビルド自動補完インデックス")
("a.C.M. computing class" "a.C.M.コンピューティングクラス")
("a.M.S. subject class" "a.M.S.サブジェクトクラス")
("abbreviated authors" "短縮著者")
("abreviated authors" "著者の短縮")
("accent above" "上記のアクセント")
("accent below" "下のアクセント")
("accept during this pass" "このパス中に受け入れる")
("acknowledgments" "謝辞")
("active link types" "アクティブなリンクタイプ")
("add" "追加")
("add abstract information" "抽象情報を追加する")
("add author information" "著者情報を追加する")
("add branch after" "後にブランチを追加")
("add branch before" "前にブランチを追加")
("add other package" "他のパッケージを追加")
("add style package" "スタイルパッケージの追加")
("add title information" "タイトル情報を追加する")
("addition" "追加")
("adjust" "調整")
("adjust limits" "制限の調整")
("advanced font customization" "高度なフォントのカスタマイズ")
("affiliation" "所属")
("align cell to the decimal comma" "セルを10進数のコンマに揃える")
("align cell to the decimal dot" "セルを小数点に揃える")
("align table at axis" "軸にテーブルを揃える")
("alignment of balloon" "バルーンの整列")
("all cells" "すべてのセル")
("all data attached to this identity will be lost" "このIDに添付されたすべてのデータは失われます")
("all saved passphrases will be lost forever" "保存されたすべてのパスフレーズは永久に失われます")
("allow for macro definitions in preamble" "プリアンブルのマクロ定義を許可")
("allowed page height extension" "許可され​​たページの高さの拡張")
("allowed page height reduction" "許可され​​たページの高さの減少")
("allowed positions" "許可ポジション")
("allowed positions of floating object" "浮動オブジェクトの許容位置")
("alpha transparency" "アルファ透明度")
("also on paper" "紙にも")
("alter" "変更")
("alternate" "代替")
("alternate except here" "ここ以外の代替")
("alternate from here on" "これからの代替")
("alternate only here" "ここでのみ代替")
("alternate until here" "ここまで代替")
("always" "常に")
("amplified" "増幅")
("and perform casual settings from the \"Encryption\" tab" "および \"暗号化\" タブからカジュアル設定を実行")
("animate" "動物")
("animate folding" "動物の折りたたみ")
("animate unfolding" "動物の展開")
("animated" "アニメーション")
("animation" "アニメーション")
("animation toolbar" "アニメーションツールバー")
("annotate" "注釈")
("answer" "答え")
("answer field" "回答フィールド")
("answer to question" "質問への回答")
("answers only" "回答のみ")
("any" "any")
("appear" "表示")
("approximate" "概算")
("arc" "アーク")
("arc cosine" "アークコサイン")
("arc sine" "アークサイン")
("arc tangent" "アークタンジェント")
("are you sure you want to delete collected public keys" "収集した公開鍵を削除してもよろしいですか？")
("are you sure you want to delete selected public keys" "選択した公開鍵を削除してもよろしいですか？")
("are you sure you want to delete selected secret keys" "選択した秘密鍵を削除してもよろしいですか？")
("are you sure you want to destroy the wallet" "ウォレットを破壊してもよろしいですか")
("art frame" "アートフレーム")
("arxiv category" "arxivカテゴリ")
("as visual grid" "視覚グリッドとして")
("aspect" "アスペクト")
("attach master" "アタッチマスター")
("auto" "自動")
("auto-save file" "自動保存ファイル")
("automatic brackets" "自動ブラケット")
("automatic content generation" "コンテンツの自動生成")
("automatic program brackets" "自動プログラムブラケット")
("automatically import bibliographies when opening files" "ファイルを開くときに参考文献を自動的にインポートする")
("automatically remember all passphrases in the wallet" "ウォレット内のすべてのパスフレーズを自動的に記憶する")
("automatically save" "自動保存")
("back" "戻る")
("backtrace errors" "バックトレースエラー")
("base" "ベース")
("baseline" "ベースライン")
("beamer" "ビーマー")
("beamer formats" "ビーマーフォーマット")
("beamer theme" "ビーマーテーマ")
("bench" "ベンチ")
("bend bottom" "ベンドボトム")
("bend corner" "曲げコーナー")
("bend diagonal" "ベンドダイアゴナル")
("bend in" "ベンドイン")
("bend out" "ベンドアウト")
("bezier" "ベジエ")
("bibTeX command" "bibTeXコマンド")
("bidirectional" "双方向")
("big environment box" "大きな環境ボックス")
("big focus" "大きな焦点")
("binary operator" "二項演算子")
("bitmap resolution (dpi)" "ビットマップ解像度(dpi)")
("black floral I" "ブラックフローラルI")
("black floral II" "ブラックフローラルII")
("blackboard embold" "黒板のエンボルド")
("blank column" "空欄")
("blank row" "空白行")
("block" "ブロック")
("block content" "ブロックコンテンツ")
("block of code" "コードブロック")
("blur" "ぼかし")
("both versions" "両方のバージョン")
("bottom baseline" "ボトムベースライン")
("bottom tools" "ボトムツール")
("box" "ボックス")
("browse back" "参照")
("browse forward" "前方に参照")
("browse modules documentation" "参照モジュールのドキュメント")
("buffer management" "バッファ管理")
("buffer must be on disk" "バッファはディスク上になければなりません")
("buffer must have a name" "バッファには名前が必要です")
("build buffer" "ビルドバッファ")
("build buffer in" "build buffer in")
("build directory" "ビルドディレクトリ")
("build directory in" "ビルドディレクトリ")
("build link pages" "リンクページの構築")
("build-all" "build-all")
("bump" "バンプ")
("busy" "ビジー")
("cJK" "cJK")
("cJK spacing" "cJK間隔")
("calculus" "計算")
("cancelled" "キャンセル")
("cannot download directory to file" "ディレクトリをファイルにダウンロードできません")
("cannot rename across different servers" "異なるサーバー間で名前を変更することはできません")
("cannot upload directory to file" "ディレクトリをファイルにアップロードできません")
("cartesian" "デカルト")
("carved wood" "刻まれた木")
("case-insensitive search" "大文字と小文字を区別しない検索")
("categories" "カテゴリ")
("category" "カテゴリ")
("cell properties" "セルプロパティ")
("cells" "セル")
("change default unit" "デフォルト単位の変更")
("change passphrase" "パスフレーズの変更")
("change step-size" "ステップサイズの変更")
("change tags" "タグの変更")
("change the TeXmacs preferences" "TeXmacsの設定を変更する")
("change the border of the table" "テーブルの境界線を変更する")
("change the style of mathematical formulas" "数式のスタイルを変更する")
("character contraction" "キャラクター収縮")
("character encoding" "文字エンコーディング")
("character expansion" "文字拡張")
("check for updates" "アップデートの確認")
("checkable field" "チェック可能なフィールド")
("cipher algorithm for passphrase encryption" "パスフレーズ暗号化のための暗号アルゴリズム")
("circle" "円")
("classification" "分類")
("clean slate" "白紙の状態")
("clear all fields" "すべてのフィールドをクリア")
("clear local information" "ローカル情報のクリア")
("clear menu" "メニューをクリア")
("clear undo history" "取り消し履歴をクリア")
("click Ok button twice to discard this warning" "OKボタンを2回クリックしてこの警告を破棄します")
("clip" "クリップ")
("clipboard image format" "クリップボードイメージ形式")
("close animation tool" "アニメーションツールを閉じる")
("close document" "ドキュメントを閉じる")
("close program" "プログラムを閉じる")
("close replace tool" "クローズ交換ツール")
("close search tool" "検索ツールを閉じる")
("close spell tool" "クローズスペルツール")
("close translations to rebuild" "再構築する翻訳を閉じる")
("closed bezier" "閉じたベジェ")
("closed curve" "閉曲線")
("closed smooth" "閉じた滑らか")
("closed spline" "閉じたスプライン")
("cluster by affiliation" "所属によるクラスター")
("collect garbage" "ごみ収集")
("collected keys" "収集されたキー")
("color of the axes" "軸の色")
("color of the subunits" "サブユニットの色")
("color of the units" "単位の色")
("colors" "色")
("column to the left" "左側の列")
("column to the right" "右側の列")
("columns" "列")
("column separation" "カラム分離")
("commit file" "コミットファイル")
("common" "共通")
("commutative diagram" "可換図")
("complete bibliographic reference" "完全な書誌参照")
("complex actions" "複雑なアクション")
("compose" "作曲")
("compound" "化合物")
("compress" "圧縮")
("compress into toolbar" "ツールバーに圧縮")
("compressed" "圧縮")
("conceal" "隠蔽")
("configure look and feel" "ルックアンドフィールの構成")
("confirm database entry" "データベースエントリの確認")
("confirm entry" "エントリの確認")
("confirm selected database entries" "選択したデータベースエントリを確認")
("confirm selected entries" "選択したエントリを確認")
("conservative conversion options" "保守的な変換オプション")
("consoles" "コンソール")
("constellation" "星座")
("context aids" "コンテキストエイド")
("contextual hints" "コンテキストヒント")
("continue" "継続")
("continued fraction" "継続分数")
("contour" "輪郭")
("contract logarithms" "契約対数")
("control flow" "制御フロー")
("convert" "変換")
("converters" "コンバーター")
("convertible" "コンバーチブル")
("copyright" "著作権")
("cork charset with TeX catcode definition in preamble" "プリアンブルにTeX catcode定義があるコルク文字セット")
("correct" "正しい")
("correct all" "すべて修正")
("correct formula" "正しい式")
("correct manually" "手動で修正")
("correct mathematical formulas" "正しい数式")
("correction" "修正")
("cosine" "コサイン")
("count characters" "カウント文字")
("count lines" "カウント行")
("count words" "カウントワード")
("create a new document" "新しいドキュメントを作成")
("create link" "リンクの作成")
("create preamble" "プリアンブルの作成")
("create remote directory" "リモートディレクトリの作成")
("create remote file" "リモートファイルの作成")
("create subprogram" "サブプログラムの作成")
("create subsession" "サブセッションの作成")
("create table macro" "テーブルマクロの作成")
("creating new account" "新しいアカウントの作成")
("creating technical pictures" "技術的な写真の作成")
("crop" "作物")
("crop marks" "クロップマーク")
("cross" "クロス")
("crossed boxes" "クロスボックス")
("crossed circles" "交差円")
("current user version" "現在のユーザーバージョン")
("current version" "現在のバージョン")
("cursor" "カーソル")
("curve" "曲線")
("curve intersections" "曲線交差点")
("curve points" "曲線ポイント")
("customizations" "カスタマイズ")
("customizing and extending the user interface" "ユーザーインターフェイスのカスタマイズと拡張")
("data" "データ")
("database entry" "データベースエントリ")
("database tool" "データベースツール")
("database toolbar" "データベースツールバー")
("dead" "死んだ")
("debug" "デバッグ")
("debugging console" "デバッグコンソール")
("debugging tool" "デバッグツール")
("decimal comma" "10進数のコンマ")
("decimal dot" "小数点")
("decomposed" "分解")
("decorated" "装飾")
("decorated wood" "装飾木材")
("decrease size" "サイズを縮小")
("decrypt" "復号化")
("default size" "デフォルトサイズ")
("degrade" "劣化")
("degraded" "劣化")
("delete documentation cache" "ドキュメントキャッシュの削除")
("delete entries" "エントリの削除")
("delete link" "リンクの削除")
("deleted" "削除済み")
("describe" "説明")
("describe tag" "タグの説明")
("destroy" "破壊")
("detach master" "マスターを切り離す")
("detailed menus" "詳細メニュー")
("details in menus" "メニューの詳細")
("determine margins from text width" "テキスト幅からマージンを決定する")
("developer" "開発者")
("developer tool" "開発者ツール")
("device" "デバイス")
("diamond" "ダイヤモンド")
("differentiate" "差別化")
("dilate" "拡張")
("direction of progression" "進行方向")
("direction of translation" "翻訳の方向")
("disable coloring on paper" "紙の着色を無効にする")
("disable encryption" "暗号化を無効にする")
("disappear" "消える")
("disk" "ディスク")
("display style" "表示スタイル")
("displayed formula" "表示された数式")
("dissociate joined cells" "結合されたセルの分離")
("distort" "ゆがむ")
("distorted" "ゆがんだ")
("division" "分割")
("document font selector" "ドキュメントフォントセレクター")
("document language" "ドキュメント言語")
("document page format" "ドキュメントページ形式")
("document paragraph format" "ドキュメントの段落形式")
("document updates run" "ドキュメントの更新の実行")
("downwards" "下向き")
("dragging" "ドラッグ")
("draw image" "画像を描く")
("draw over" "ドローオーバー")
("draw over selection" "選択範囲を描く")
("drop" "ドロップ")
("due to" "による")
("dynamic" "動的")
("eRROR" "エラー")
("edit animation" "アニメーションの編集")
("edit groups of objects" "オブジェクトのグループの編集")
("edit macro" "マクロの編集")
("edit macros" "マクロの編集")
("edit preamble" "プリアンブルの編集")
("edit source" "ソースを編集")
("edit style" "スタイルを編集")
("edit translations file" "翻訳ファイルの編集")
("education" "教育")
("effect pen" "効果ペン")
("eigenvalues" "固有値")
("eighth" "8番目")
("embold" "embold")
("emboss" "エンボス")
("enable page breaking" "改ページを有効にする")
("encoding" "エンコード")
("encrypt" "暗号化")
("encryption" "暗号化")
("encryption facilities are not currently available" "暗号化機能は現在利用できません")
("encryption facilities have not been enabled for TeXmacs" "TeXmacsの暗号化機能は有効になっていません")
("enforce brackets to match" "ブラケットを一致させる")
("engrave" "刻む")
("enter data" "データを入力")
("enter graphics" "グラフィックを入力")
("enter graphics mode" "グラフィックモードに入る")
("enter new passphrase for encryption" "暗号化用の新しいパスフレーズを入力してください")
("enter passphrase for decryption" "復号化のためにパスフレーズを入力してください")
("enter passphrase for identity" "IDのパスフレーズを入力")
("enter title information" "タイトル情報を入力")
("entire table" "テーブル全体")
("entry up to date in database" "データベースに最新のエントリ")
("enunciation" "発音")
("environment variable" "環境変数")
("environments" "環境")
("erode" "侵食")
("error messages" "エラーメッセージ")
("error output" "エラー出力")
("error status report" "エラーステータスレポート")
("error: bracket does not match" "エラー：ブラケットが一致しません")
("error: cyclic or missing chunks detected" "エラー：循環チャンクまたは欠落したチャンクが検出されました")
("error: file not found" "エラー：ファイルが見つかりません")
("error: ghostview does not seem to be installed on your system" "エラー：ghostviewがシステムにインストールされていないようです")
("error: one of the alternatives should be filled out" "エラー：選択肢の1つを記入する必要があります")
("error: only one alternatives should be filled out" "エラー：1つの選択肢のみを記入する必要があります")
("error: should fill out name for referencing" "エラー：参照する名前を入力する必要があります")
("error: should fill out required field" "エラー：必須フィールドに入力する必要があります")
("evaluable field" "評価可能なフィールド")
("evaluate above" "上記で評価")
("evaluate all" "すべてを評価")
("evaluate below" "以下を評価")
("evaluate fields" "フィールドの評価")
("evaluate fields in order" "順番にフィールドを評価する")
("evaluate script" "スクリプトを評価")
("evaluation" "評価")
("evaluation switch" "評価スイッチ")
("evaluation tag" "評価タグ")
("even page" "偶数ページ")
("even pages" "偶数ページ")
("events" "イベント")
("exact" "正確")
("execution of scripts" "スクリプトの実行")
("exit graphics" "出口グラフィックス")
("exit graphics mode" "グラフィックモードを終了")
("exit left" "左に出る")
("exit right" "右に出る")
("exit tag on the left" "左側の出口タグ")
("exit tag on the right" "右側の出口タグ")
("expand TeXmacs macros with no LaTeX equivalents" "LaTeXに相当するものがないTeXmacsマクロを展開する")
("expand beamer slides" "ビーマースライドを拡張する")
("expand inclusions" "包含物を展開する")
("expand logarithms" "対数を展開")
("expand trigonometric functions" "三角関数の拡張")
("expand unrecognized macros" "認識されないマクロを展開する")
("expand user-defined macros" "ユーザー定義マクロを展開する")
("expanded" "拡張")
("experimental features (to be used with care)" "実験的機能(注意して使用するため)")
("explain" "説明")
("explanatory item" "説明項目")
("explicit keystroke" "明示的なキーストローク")
("explicit margins" "明示的なマージン")
("exponential" "指数")
("export bibliographies as links" "参考文献をリンクとしてエクスポート")
("export bibliography" "書誌のエクスポート")
("export entries in buffer" "バッファ内のエントリをエクスポート")
("export file" "エクスポートファイル")
("export formulas as images" "数式を画像としてエクスポート")
("export mathematical formulas as MathML" "数式をMathMLとしてエクスポート")
("export mathematical formulas as images" "数式を画像としてエクスポート")
("export selected entries" "選択したエントリをエクスポート")
("export selection" "エクスポート選択")
("export selection as image" "選択範囲を画像としてエクスポート")
("export selections as" "選択範囲をエクスポート")
("export sessions" "エクスポートセッション")
("exported bibliographic entries" "エクスポートされた書誌エントリ")
("exported bibliographic references" "エクスポートされた書誌参照")
("extend" "拡張")
("extended" "拡張")
("extensible left arrow" "拡張可能な左矢印")
("extensible right arrow" "拡張可能な右矢印")
("extern" "外部")
("external" "外部")
("extra branch" "追加ブランチ")
("extra interline space" "余分な行間スペース")
("extra name" "余分な名前")
("extract" "抽出")
("extract style file" "スタイルファイルの抽出")
("extract style package" "スタイルパッケージの抽出")
("factor" "ファクター")
("fade" "フェード")
("fade in" "フェードイン")
("fade out" "フェードアウト")
("fast" "高速")
("fast decrease" "速い減少")
("fast environments" "高速環境")
("fast increase" "高速増加")
("field reference" "フィールド参照")
("fifth" "5番目")
("file saved" "保存されたファイル")
("fill color" "塗りつぶし色")
("fill out" "記入")
("filter" "フィルター")
("find file" "ファイルを検索")
("finished collecting symbols documentation" "収集シンボルのドキュメントの完成")
("first" "最初")
("first chunk" "最初のチャンク")
("first difference" "最初の違い")
("first error" "最初のエラー")
("first field" "最初のフィールド")
("first occurrence" "最初の発生")
("first similar" "最初の類似")
("fit to screen" "画面に合わせる")
("fit to screen width" "画面幅に合わせる")
("five columns" "5列")
("fixed" "修正済み")
("flag is off" "フラグはオフです")
("flag is on" "フラグはオンです")
("flatten" "フラット化")
("floating algorithm" "浮動アルゴリズム")
("floating phantom" "フローティングファントム")
("focus" "フォーカス")
("focus dependent icons" "フォーカス依存アイコン")
("fold all" "すべて折り")
("fold all fields" "すべてのフィールドを折りたたむ")
("fold back" "折り返し")
("follow external links" "外部リンクをたどる")
("follow inverse links" "逆リンクに従う")
("font effects" "フォント効果")
("font selector" "フォントセレクター")
("for each" "for each")
("force reloading of translations" "翻訳の強制再読み込み")
("forward" "フォワード")
("four columns" "4列")
("four dots" "4つのドット")
("fourth" "4番目")
("fraktur" "fraktur")
("framed" "framed")
("from" "から")
("from center" "中心から")
("front matter" "フロントマター")
("full" "フル")
("full author list" "全著者リスト")
("full screen mode" "全画面モード")
("gap" "ギャップ")
("garbage collection" "ガベージコレクション")
("gaussian" "ガウス")
("gcd" "gcd")
("general" "一般")
("generated LaTeX document contains no errors" "生成されたLaTeXドキュメントにはエラーが含まれていません")
("generated field" "生成フィールド")
("geometry" "ジオメトリ")
("get arity" "アリティを得る")
("get label" "ラベルを取得")
("get list with remote versions" "リモートバージョンのリストを取得")
("glyphs" "グリフ")
("gnaw" "かじる")
("gnawed" "かじった")
("gnuPG command" "gnuPGコマンド")
("gnuPG error: buffer encryption failed" "gnuPGエラー：バッファの暗号化に失敗しました")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPGエラー：復号化する適切な秘密鍵が見つかりません")
("gnuPG requires name and email to have at least 5 characters" "gnuPGには名前とメールに少なくとも5文字が必要です")
("go to anchor" "アンカーに移動")
("go to anchor or float" "アンカーまたはフロートに移動")
("go to anchor or footnote" "アンカーまたは脚注に移動")
("go to first similar tag" "最初の同様のタグに移動")
("go to float" "フロートする")
("go to footnote" "脚注に移動")
("go to last similar tag" "最後の同様のタグに移動")
("go to next similar tag" "次の類似タグに移動")
("go to previous similar tag" "前の同様のタグに移動")
("go to section" "セクションに移動")
("grain" "粒")
("granite" "花崗岩")
("graphical effects" "グラフィック効果")
("graphical interface font scale" "グラフィカルインターフェイスフォントスケール")
("graphics" "グラフィック")
("graphics geometry" "グラフィックスジオメトリ")
("graphics grids" "グラフィックグリッド")
("greyed" "グレー")
("grid" "グリッド")
("grid curves" "グリッド曲線")
("grid points" "グリッドポイント")
("grid-curve intersections" "グリッド曲線交差点")
("group of objects" "オブジェクトのグループ")
("group/ungroup" "グループ/グループ解除")
("grouped" "グループ化")
("guarantee transparent source tracking" "透過的なソース追跡の保証")
("half wide" "ハーフワイド")
("hand drawn" "手描き")
("headers" "ヘッダー")
("history" "履歴")
("homoglyph substitutions" "ホモグリフ置換")
("horizontal alignment" "水平方向の配置")
("horizontal collapse distance" "水平崩壊距離")
("horizontal margins" "水平マージン")
("hyphenate as" "ハイフネーション")
("icon" "アイコン")
("if hyphenated" "ハイフネーションされている場合")
("ignore" "無視")
("impact" "影響")
("import bibliography" "参考文献のインポート")
("import database entry" "データベースエントリのインポート")
("import entries in buffer" "バッファ内のエントリをインポート")
("import entry" "インポートエントリ")
("import file" "インポートファイル")
("import selected database entries" "選択したデータベースエントリをインポートする")
("import selected entries" "選択したエントリをインポート")
("import selections as" "選択範囲をインポート")
("import sessions" "セッションのインポート")
("import sophisticated objects as pictures" "洗練されたオブジェクトを写真としてインポート")
("imported bibliographic entries" "インポートされた書誌事項")
("in popup windows" "ポップアップウィンドウ")
("inanimated" "アニメーション化")
("inch" "インチ")
("incomplete entries found to be filled out" "入力が不完全なエントリが見つかりました")
("increase size" "サイズを大きくする")
("indent paragraphs" "段落のインデント")
("indentation" "インデント")
("indication" "表示")
("initialize" "初期化")
("ink here" "ここにインク")
("ink in" "ink in")
("ink out" "インクアウト")
("inline" "インライン")
("inline code" "インラインコード")
("inline content" "インラインコンテンツ")
("inline formula" "インライン式")
("inner bottom" "インナーボトム")
("inner left" "内側左")
("inner right" "内側の権利")
("inner top" "インナートップ")
("input command" "入力コマンド")
("input field" "入力フィールド")
("input options" "入力オプション")
("insert a computer program" "コンピュータープログラムの挿入")
("insert a gap" "ギャップを挿入")
("insert a list" "リストを挿入")
("insert a multiple choice" "複数の選択肢を挿入")
("insert a negation" "否定を挿入")
("insert a new entry" "新しいエントリを挿入")
("insert a note or a floating object" "メモまたはフローティングオブジェクトを挿入する")
("insert a prominent piece of text" "顕著なテキストを挿入")
("insert a question" "質問を挿入")
("insert a root" "ルートを挿入")
("insert a script" "スクリプトを挿入")
("insert a section block" "セクションブロックの挿入")
("insert a textual operator" "テキスト演算子を挿入")
("insert above" "上に挿入")
("insert abstract" "要約を挿入")
("insert an answer" "回答を挿入")
("insert an enunciation" "発音を挿入")
("insert annotation" "注釈を挿入")
("insert below" "下に挿入")
("insert copyright and license information" "著作権とライセンス情報を挿入")
("insert explanatory item" "説明項目を挿入")
("insert field above" "上にフィールドを挿入")
("insert field below" "下にフィールドを挿入")
("insert large delimiters" "大きな区切り文字を挿入")
("insert last name" "姓を挿入")
("insert left" "左に挿入")
("insert missing invisible operators" "欠落している不可視の演算子を挿入")
("insert more names" "さらに名前を挿入")
("insert particle" "粒子を挿入")
("insert plain text" "プレーンテキストを挿入")
("insert right" "右挿入")
("insert similar above" "上記と同様の挿入")
("insert similar below" "下に同様のものを挿入")
("insert similar block above" "上に同様のブロックを挿入")
("insert similar block below" "下に同様のブロックを挿入")
("insert subtable" "サブテーブルを挿入")
("insert symbol documentation" "シンボルドキュメントを挿入")
("insert template" "テンプレートを挿入")
("insert text field above" "上にテキストフィールドを挿入")
("insert text field below" "下にテキストフィールドを挿入")
("insert title after name" "名前の後にタイトルを挿入")
("insert user interface related markup" "ユーザーインターフェイス関連のマークアップを挿入")
("inserting control points" "コントロールポイントの挿入")
("integrate" "統合")
("interactive questions" "インタラクティブな質問")
("intercharacter compression" "文字間圧縮")
("intercharacter stretching" "文字間ストレッチ")
("interrupted" "中断されました")
("invalid multi-paragraph selection" "無効な複数段落選択")
("invalid renaming" "無効な名前変更")
("invert" "反転")
("inverted breve" "逆さブレーブ")
("invisible ending" "見えないエンディング")
("invisible newline" "見えない改行")
("invisible opening" "見えない開口部")
("join selected cells" "選択したセルを結合")
("jump in" "ジャンプイン")
("junior" "ジュニア")
("keep evaluated expressions" "評価された式を保持")
("keep local" "ローカルに保つ")
("keep remote" "リモートに保つ")
("keep track of source code" "ソースコードの追跡")
("keep unfolded" "展開したままにする")
("keyboard configuration" "キーボード構成")
("keyboard shortcut" "キーボードショートカット")
("laptop presentations" "ラップトッププレゼンテーション")
("large cells" "大きなセル")
("large displayed" "大きい表示")
("large displayed fraction" "表示される大きな部分")
("large tables" "大きなテーブル")
("last" "最後")
("last difference" "最後の違い")
("last error" "最後のエラー")
("last field" "最後のフィールド")
("last name" "姓")
("last occurrence" "最後の出現")
("last similar" "最後の類似")
("lcm" "lcm")
("left axis" "左軸")
("left baseline" "左のベースライン")
("left bottom" "左下")
("left center" "左中央")
("left click: add point; Right click: undo" "左クリック：ポイントを追加、右クリック：元に戻す")
("left click: finish; Right click: undo" "左クリック：終了;右クリック：元に戻す")
("left click: new object" "左クリック：新しいオブジェクト")
("left click: operate" "左クリック：操作")
("left down" "左下")
("left on even pages" "偶数ページに残っています")
("left top" "左上")
("left up" "左アップ")
("left-right arrow" "左右矢印")
("leftwards" "左方向")
("let the environment float" "環境をフロートさせる")
("line breaking" "改行")
("line wrapping" "行の折り返し")
("linear 2D" "リニア2D")
("linear algebra" "線形代数")
("lines around" "周りの行")
("link image and copies as" "画像とコピーをリンク")
("link image as" "リンク画像")
("link mode" "リンクモード")
("link to URL" "URLへのリンク")
("linking tool" "リンクツール")
("live" "ライブ")
("live input-output" "ライブ入出力")
("load help file" "ヘルプファイルの読み込み")
("load remote file" "リモートファイルの読み込み")
("loading" "読み込み中")
("local entries" "ローカルエントリ")
("loci" "loci")
("locus" "locus")
("locus rendering" "軌跡レンダリング")
("logarithm" "対数")
("logarithmic" "対数")
("logarithmic base" "対数ベース")
("logarithms" "対数")
("logging in" "ログイン")
("logical and" "論理and")
("logical implication" "論理的含意")
("logical not" "論理否定")
("logical or" "論理OR")
("login" "ログイン")
("logout" "ログアウト")
("long macro" "長いマクロ")
("long text" "長いテキスト")
("look for more fonts" "他のフォントを探す")
("loops" "ループ")
("macro argument" "マクロ引数")
("macro definition" "マクロ定義")
("macro name" "マクロ名")
("macros" "マクロ")
("magnify horizontally" "水平方向に拡大")
("magnify vertically" "垂直方向に拡大")
("main presentation style" "メインプレゼンテーションスタイル")
("make a letter environment" "レター環境を作成する")
("make a multi-slide presentation" "マルチスライドプレゼンテーションを作成する")
("make floating" "フローティングにする")
("make link" "リンクを作成")
("make non floating" "非フローティングにする")
("manila paper" "マニラ紙")
("map arguments" "マップ引数")
("marginal note" "マージンノート")
("margins from width" "幅からのマージン")
("margins on paper" "紙の余白")
("margins on screen" "画面上の余白")
("marked" "マーク")
("material" "素材")
("mathematical output" "数学的な出力")
("matrices" "行列")
("maximal cell height" "最大セル高さ")
("maximal clustering" "最大クラスタリング")
("maximal table height" "テーブルの最大高さ")
("maximal table width" "テーブルの最大幅")
("maximum" "最大")
("meander" "蛇行")
("memory" "メモリー")
("memory usage" "メモリ使用量")
("menu" "メニュー")
("merge lines into paragraphs unless separated by blank lines" "空白行で区切られていない限り、行を段落にマージします")
("messages" "メッセージ")
("meta data" "メタデータ")
("metadata" "メタデータ")
("metal" "金属")
("middle baseline" "中間ベースライン")
("minimal cell height" "最小セル高")
("minimal cell width" "最小セル幅")
("minimal line separation" "最小ライン分離")
("minimal table height" "テーブルの最小高さ")
("minimal table width" "最小テーブル幅")
("minimum" "最小")
("mirror" "ミラー")
("miscellanous" "その他")
("mode dependent icons" "モード依存アイコン")
("modify remote live document" "リモートライブドキュメントの変更")
("module" "モジュール")
("monospaced" "モノスペース")
("more information about GNU TeXmacs can be found in the Help->About menu" "GNU TeXmacsの詳細は、[ヘルプ]-> [バージョン情報]メニューにあります]")
("more information about GNU TeXmacs can be found in the help" "GNU TeXmacsの詳細については、ヘルプをご覧ください")
("motion" "モーション")
("mouse over object" "オブジェクト上のマウス")
("move" "移動")
("move objects" "オブジェクトの移動")
("move over object on which to operate" "操作するオブジェクトの上に移動")
("multiline" "マルチライン")
("multiple choice" "複数選択")
("multiple root" "複数ルート")
("multiplication" "乗算")
("navigation options" "ナビゲーションオプション")
("never" "決して")
("new account" "新しいアカウント")
("new bibliography dialogue" "新しい書誌対話")
("new document" "新しいドキュメント")
("new entry" "新しいエントリ")
("new identity" "新しいアイデンティティ")
("new locus" "新しい軌跡")
("new macro" "新しいマクロ")
("new passphrase" "新しいパスフレーズ")
("new remote directory" "新しいリモートディレクトリ")
("new remote file" "新しいリモートファイル")
("new style fonts" "新しいスタイルのフォント")
("new style page breaking" "新しいスタイルの改ページ")
("new version" "新しいバージョン")
("new window" "新しいウィンドウ")
("newer version" "新しいバージョン")
("next chunk" "次のチャンク")
("next difference" "次の違い")
("next error" "次のエラー")
("next field" "次のフィールド")
("next occurrence" "次の出現")
("next screen" "次の画面")
("next similar" "次の類似")
("no clustering" "クラスタリングなし")
("no completions" "完了なし")
("no errors have been corrected" "エラーは修正されていません")
("no grid" "グリッドなし")
("no new public key in document" "ドキュメントに新しい公開キーがありません")
("no page break" "改ページなし")
("no page numbers" "ページ番号なし")
("no parent" "親なし")
("no selection" "選択なし")
("no spelling errors" "スペルミスなし")
("normal loci" "正常遺伝子座")
("not allowed to remove home directory" "ホームディレクトリの削除は許可されていません")
("not connected to server" "サーバーに接続されていません")
("not yet implemented" "まだ実装されていません")
("notebook" "ノートブック")
("number of polar steps" "極ステップ数")
("number of subunit steps" "サブユニットのステップ数")
("numbering" "番号付け")
("numeric spreadsheet" "数値スプレッドシート")
("odd page" "奇数ページ")
("odd pages" "奇数ページ")
("of fingerprint" "指紋の")
("old version" "古いバージョン")
("older version" "古いバージョン")
("on the footer" "フッター上")
("on your system and set it up from the \"Security\" tab" "システム上で、\"セキュリティ\" タブから設定")
("one column" "1列")
("one error has been corrected" "1つのエラーが修正されました")
("one lower case letter, one non alpha-numeric symbol" "1つの小文字、1つの非英数字記号")
("one numeric character, one upper case letter" "1つの数字、1つの大文字")
("only convert changes when re-importing" "再インポート時にのみ変更を変換する")
("only convert changes with respect to imported version" "インポートされたバージョンに関してのみ変更を変換する")
("only convert changes with respect to tracked version" "追跡バージョンに関してのみ変更を変換する")
("only implemented for complete subtrees" "完全なサブツリーにのみ実装")
("only keep folded" "折りたたむだけ")
("only keep unfolded" "展開したままにする")
("only show semantic focus" "セマンティックフォーカスのみを表示")
("opacity" "不透明度")
("open bibliography" "公開書誌")
("open identities" "オープンID")
("open in new window" "新しいウィンドウで開く")
("open key manager" "オープンキーマネージャー")
("open licence agreement" "オープンライセンス契約")
("open mailbox" "メールボックスを開く")
("open module browser" "モジュールブラウザを開く")
("open symbol browser" "シンボルブラウザを開く")
("open tool in separate window" "別のウィンドウでツールを開く")
("operation mode" "操作モード")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "または \"gpg\" または \"gpg2\" コマンドへの完全なパスを指定してください")
("order" "注文")
("ordinary symbol" "普通のシンボル")
("ornamented" "装飾")
("other login" "その他のログイン")
("other package" "その他のパッケージ")
("outer bottom" "外底")
("outer left" "外側左")
("outer right" "外側右")
("outer top" "アウタートップ")
("outline" "アウトライン")
("outlined" "アウトライン")
("outlined emboss" "アウトラインエンボス")
("outlined engrave" "輪郭を刻んだ")
("output options" "出力オプション")
("oval" "楕円")
("overlap" "重複")
("overlay" "オーバーレイ")
("overlays" "オーバーレイ")
("overlined" "上線付き")
("overview of the scheme extension language" "スキーム拡張言語の概要")
("padded" "パッド入り")
("page background" "ページの背景")
("page break after" "改ページ後")
("page breaking algorithm" "改ページアルゴリズム")
("page number" "ページ番号")
("page number rendering" "ページ番号のレンダリング")
("page rendering" "ページレンダリング")
("palette" "パレット")
("panorama" "パノラマ")
("paragraphs" "段落")
("parametric curve" "パラメトリックカーブ")
("parametric surface" "パラメトリックサーフェス")
("parenthesis" "括弧")
("parenthesized" "かっこ付き")
("particle" "粒子")
("passphrase encryption" "パスフレーズ暗号化")
("passphrase wallet facilities are not currently available" "パスフレーズウォレット施設は現在利用できません")
("passphrases are expected to have at least: 8 characters" "パスフレーズには少なくとも8文字が必要です")
("passphrases mismatch" "パスフレーズの不一致")
("pastel" "パステル")
("pattern" "パターン")
("pause" "一時停止")
("pen width" "ペン幅")
("permanent footer" "パーマネントフッター")
("permanent header" "パーマネントヘッダー")
("permanently add to dictionary" "永続的に辞書に追加")
("permanently insert into dictionary" "永続的に辞書に挿入")
("permissions" "許可")
("phantom" "ファントム")
("phantoms" "ファントム")
("physics and astronomy class" "物理学と天文学のクラス")
("picture" "写真")
("pine" "松")
("plain" "プレーン")
("plain boxes" "プレーンボックス")
("plain circles" "プレーンサークル")
("play" "遊び")
("play animation" "アニメーションを再生")
("please install GnuPG software from https://www.gnupg.org" "https://www.gnupg.orgからGnuPGソフトウェアをインストールしてください")
("plot" "プロット")
("plug-ins" "プラグイン")
("plural" "複数")
("point" "ポイント")
("polar" "極")
("polygon" "ポリゴン")
("pop server settings" "ポップサーバー設定")
("position of marginal note" "マージナルノートの位置")
("poster formats" "ポスター形式")
("poster theme" "ポスターテーマ")
("postfix" "後置記号")
("preferences for editing mathematical formulas" "数式を編集するための設定")
("preferences for tag" "タグの設定")
("prefix" "プレフィックス")
("presentation tool" "プレゼンテーションツール")
("preserve" "保存")
("preserve tags" "タグを保持する")
("pretty tree output" "きれいなツリー出力")
("preview" "プレビュー")
("previous difference" "以前の違い")
("previous error" "前のエラー")
("previous field" "前のフィールド")
("previous occurrence" "以前の発生")
("previous screen" "前の画面")
("previous similar" "以前の類似")
("primitive or macro" "プリミティブまたはマクロ")
("print buffer" "印刷バッファ")
("print buffer to file" "ファイルへのバッファーの印刷")
("print to file" "ファイルに印刷")
("printer setup" "プリンターのセットアップ")
("program bracket matching" "プログラムブラケットマッチング")
("program bracket selections" "プログラムブラケットの選択")
("program commands" "プログラムコマンド")
("program interface for buffer management" "バッファ管理用のプログラムインターフェイス")
("programming routines for editing documents" "ドキュメントを編集するためのプログラミングルーチン")
("prominent" "著名")
("provoke C++ error" "C ++エラーを引き起こす")
("provoke menu error" "メニューエラーを引き起こす")
("provoke scheme error" "挑発スキームエラー")
("pseudo code" "擬似コード")
("public key encryption" "公開鍵暗号化")
("public keys" "公開鍵")
("pulse" "パルス")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUIのみ、申し訳ありません。\"選択範囲のエクスポート\" を使用してください")
("qt-widgets" "qt-widgets")
("quantifier" "数量詞")
("quasi" "準")
("question" "質問")
("questions only" "質問のみ")
("questions with answers" "質問と回答")
("quick evaluation of formulas" "式の迅速な評価")
("rank" "ランク")
("raw" "生")
("really delete user identity" "ユーザーIDを本当に削除")
("really tiny" "本当に小さい")
("rebuild translations file" "翻訳ファイルの再構築")
("recent" "最近")
("recent documents" "最近の文書")
("recipients" "受信者")
("recognize" "認識")
("rectangular" "長方形")
("reduce" "削減")
("reduce trigonometric functions" "三角関数の削減")
("reduced margins" "マージンの削減")
("regenerate" "再生")
("register file" "登録ファイル")
("relate" "関連する")
("relation" "関係")
("release left button: finish editing" "左ボタンをリリース：編集を終了")
("remote" "リモート")
("remote connections" "リモート接続")
("remote control" "リモートコントロール")
("remote controllers with keyboard simulation" "キーボードシミュレーションを備えたリモートコントローラー")
("remote directory" "リモートディレクトリ")
("remote servers" "リモートサーバー")
("remote tool" "リモートツール")
("remove" "削除")
("remove banner" "バナーを削除")
("remove database entry" "データベースエントリの削除")
("remove downwards" "下向きに削除")
("remove entries" "エントリを削除")
("remove entry" "エントリを削除")
("remove field above" "上にフィールドを削除")
("remove field below" "下のフィールドを削除")
("remove folded" "折りたたむ")
("remove last field" "最後のフィールドを削除")
("remove leftwards" "左に削除")
("remove link" "リンクを削除")
("remove next field" "次のフィールドを削除")
("remove previous field" "前のフィールドを削除")
("remove rightwards" "右方向に削除")
("remove selected database entries" "選択したデータベースエントリを削除")
("remove selected entries" "選択したエントリを削除")
("remove superfluous invisible operators" "余分な不可視の演算子を削除する")
("remove tag" "タグを削除")
("remove this branch" "このブランチを削除")
("remove unfolded" "展開されたものを削除")
("remove upwards" "上方向に削除")
("removed entries from database" "データベースからエントリを削除")
("removed entry from database" "データベースからエントリを削除しました")
("rename" "名前変更")
("rename section" "セクション名の変更")
("replace TeXmacs styles with no LaTeX equivalents" "TeXmacsスタイルをLaTeXに相当するものと置き換えます")
("replace all further occurrences" "以降のすべての出現を置換")
("replace one occurrence" "1回の置換")
("replace toolbar" "ツールバーを置換")
("replace unrecognized styles" "認識されないスタイルを置き換える")
("reset error counters" "エラーカウンターのリセット")
("resize" "サイズ変更")
("resize objects" "オブジェクトのサイズ変更")
("restart TeXmacs in order to let changes take effect" "変更を有効にするためにTeXmacsを再起動します")
("restart in order to let the new look and feel take effect" "新しいルックアンドフィールを有効にするために再起動します")
("retain" "保持")
("retime" "リタイム")
("retina settings" "網膜設定")
("retrieve email" "メールの取得")
("retrieve remote live document" "リモートライブドキュメントの取得")
("retrieved contents" "取得したコンテンツ")
("reverse" "逆")
("reverse ordering" "逆順")
("ridged paper" "ridge紙")
("right baseline" "正しいベースライン")
("right down" "右下")
("right on even pages" "偶数ページで正しい")
("right up" "右")
("rightwards" "右")
("rigid box" "リジッドボックス")
("rotate" "回転")
("rotate objects" "オブジェクトの回転")
("rough" "ラフ")
("rough paper" "ラフ紙")
("round" "ラウンド")
("round overbrace" "丸い大括弧")
("round underbrace" "丸いアンダーブレース")
("row above" "上の行")
("row below" "下に行")
("rows" "行")
("run" "実行")
("run current file" "現在のファイルを実行")
("same names" "同じ名前")
("same screen margins as on paper" "紙上と同じ画面マージン")
("sample text" "サンプルテキスト")
("save auxiliary data" "補助データを保存")
("save entries" "エントリを保存")
("save entry" "エントリを保存")
("save image as" "名前を付けて画像を保存")
("save position" "位置を保存")
("save remote file" "リモートファイルの保存")
("saved modifications in database" "データベースに保存された変更")
("scheme developers guide" "スキーム開発者ガイド")
("scheme extensions" "スキーム拡張")
("scheme interface for the graphical mode" "グラフィカルモードのスキームインターフェイス")
("screen" "画面")
("screen rendering" "スクリーンレンダリング")
("screens" "スクリーン")
("screenshot" "スクリーンショット")
("scripting language" "スクリプト言語")
("scripts" "スクリプト")
("search and replace" "検索と置換")
("search toolbar" "検索ツールバー")
("second" "秒")
("secret keys" "秘密鍵")
("sections" "セクション")
("see documentation" "ドキュメントを見る")
("select pen" "選択ペン")
("select the action to be undertaken for each conflict" "競合ごとに実行するアクションを選択")
("select view mode" "ビューモードの選択")
("semantic correctness" "意味の正確さ")
("semantic editing" "セマンティック編集")
("semantic selections" "セマンティック選択")
("semantics" "セマンティクス")
("senior" "シニア")
("serif" "セリフ")
("server" "サーバー")
("session commands" "セッションコマンド")
("set default" "デフォルト設定")
("set difference" "差を設定")
("set intersection" "交差点を設定")
("set number of columns" "列数の設定")
("set number of rows" "行数を設定")
("set properties" "プロパティの設定")
("set union" "ユニオンを設定")
("set user information" "ユーザー情報の設定")
("seventh" "7番目")
("several equations" "いくつかの方程式")
("shadow" "シャドウ")
("shadowed" "シャドウ")
("shadowed raise" "シャドウレイズ")
("shift" "シフト")
("show all parts" "すべてのパーツを表示")
("show current focus" "現在のフォーカスを表示")
("show full context" "コンテキスト全体を表示")
("show key presses" "キー押下を表示")
("show main document" "メイン文書を表示")
("show memory usage" "show memory usage")
("show one part" "一部を表示")
("show panorama" "パノラマを表示")
("show preamble" "プリアンブルを表示")
("show several parts" "いくつかのパーツを表示")
("show subunits" "サブユニットを表示")
("show table cells" "表のセルを表示")
("show timings" "タイミングを表示")
("side tools" "サイドツール")
("simple" "シンプル")
("simplification" "単純化")
("simplified evaluation of formulas" "式の簡易評価")
("simplified menus" "簡易メニュー")
("simplify" "簡素化")
("sine" "サイン")
("sixth" "6番目")
("size tag" "サイズタグ")
("skew" "スキュー")
("skip all" "すべてスキップ")
("slant" "スラント")
("slashed fraction" "スラッシュ分数")
("slides" "スライド")
("slow" "遅い")
("slow decrease" "遅い減少")
("slow increase" "緩やかな増加")
("small capitals" "小資本")
("small environment box" "小さな環境ボックス")
("small focus" "小さな焦点")
("small inline" "小さなインライン")
("small inline fraction" "小さなインライン部分")
("smash" "スマッシュ")
("smooth" "スムーズ")
("smooth end" "スムーズエンド")
("smooth extremities" "滑らかな四肢")
("smooth start" "スムーズスタート")
("snap" "スナップ")
("snap distance" "スナップ距離")
("snap to curves" "曲線にスナップ")
("snap to grid" "グリッドにスナップ")
("snap to grid curve" "グリッド曲線にスナップ")
("snap to intersections of curves" "曲線の交点にスナップ")
("snap to text borders" "テキスト枠にスナップ")
("snap to text corners" "テキストコーナーにスナップ")
("solution" "ソリューション")
("solution to exercise" "運動に対する解決策")
("solution to problem" "問題の解決策")
("solutions" "ソリューション")
("sound" "音")
("source" "ソース")
("source macros tool" "ソースマクロツール")
("south" "南")
("south east" "東南")
("space bar in math mode" "数学モードのスペースバー")
("space bar in text mode" "テキストモードのスペースバー")
("space stretchability" "スペース伸縮性")
("span" "スパン")
("span over all columns" "すべての列にわたるスパン")
("special functions" "特別な機能")
("special properties" "特別なプロパティ")
("specific baseline" "特定のベースライン")
("specify color alternation" "色の交互指定")
("specify how to traverse the manual" "マニュアルの横断方法を指定してください")
("specify semantics of a symbol or formula" "記号または式のセマンティクスを指定する")
("specify the size of the table" "テーブルのサイズを指定")
("spell check" "スペルチェック")
("spline" "スプライン")
("split program" "分割プログラム")
("square" "正方形")
("square overbrace" "スクエアオーバーブレース")
("square underbrace" "四角いアンダーブレース")
("stack" "スタック")
("standard" "標準")
("standard Output" "標準出力")
("standard fraction" "標準分数")
("star" "星")
("start server" "サーバーを起動")
("statement" "ステートメント")
("statistics" "統計")
("status" "ステータス")
("stop server" "サーバーの停止")
("storage" "ストレージ")
("store tracking information in LaTeX files" "LaTeXファイルに追跡情報を保存する")
("stretch factor" "ストレッチ係数")
("strict Ascii" "厳格なアスキー")
("strike through" "取り消し線")
("structured insert above" "上記の構造化挿入物")
("structured insert at the left" "左側の構造化挿入物")
("structured insert at the right" "右側の構造化挿入物")
("structured insert below" "構造化された下の挿入")
("structured remove downwards" "下方に構造化された削除")
("structured remove leftwards" "左に構造化された削除")
("structured remove rightwards" "構造化された右側の削除")
("structured remove upwards" "構造化された上向きの削除")
("structured variant" "構造化バリアント")
("style options" "スタイルオプション")
("style parameters" "スタイルパラメータ")
("subject" "対象")
("submenu" "サブメニュー")
("subscript below" "下付き添字")
("subsubmenu" "サブサブメニュー")
("subsubsubmenu" "サブサブメニュー")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "サブテーブル")
("subtraction" "減算")
("summarized" "要約")
("superscript above" "上付き")
("supported plug-ins" "サポートされているプラ​​グイン")
("surface" "表面")
("inflate" "うねり")
("switch to buffer" "バッファに切り替え")
("symbol properties not found" "シンボルプロパティが見つかりません")
("symbols" "記号")
("synchronize" "同期")
("synchronize bibliographic references" "参考文献の同期")
("synchronize with remote server" "リモートサーバーと同期")
("synopsis" "シノプシス")
("tab-completion" "タブ補完")
("tabbed" "タブ付き")
("table breaking" "テーブルブレイク")
("table height" "テーブルの高さ")
("table properties" "テーブルプロパティ")
("table width" "テーブル幅")
("tags with special rendering" "特別なレンダリングを伴うタグ")
("tangent" "接線")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacsバッファが必要です")
("teXmacs buffer on disk expected" "ディスク上のTeXmacsバッファが必要です")
("teXmacs extensions to scheme and utilities" "スキームおよびユーティリティのTeXmacs拡張")
("teXmacs macro" "teXmacsマクロ")
("teXmacs package" "teXmacsパッケージ")
("teXmacs primitives" "teXmacsプリミティブ")
("teXmacs style" "teXmacsスタイル")
("test routine" "テストルーチン")
("testing tree-view" "ツリービューのテスト")
("text borders" "テキストの境界線")
("text box style" "テキストボックススタイル")
("text corners" "テキストコーナー")
("textual" "テキスト")
("textual operator" "テキスト演算子")
("textual spreadsheet" "テキストスプレッドシート")
("the TeXmacs plug-in system" "TeXmacsプラグインシステム")
("theme parameters" "テーマパラメータ")
("these collected public keys will be definitely lost" "これらの収集された公開鍵は間違いなく失われます")
("these public keys will be definitely lost" "これらの公開鍵は間違いなく失われます")
("these secret keys will be definitely lost" "これらの秘密鍵は間違いなく失われます")
("thicken" "厚くする")
("third" "サード")
("this" "これ")
("this column" "この列")
("this page number" "このページ番号")
("this row" "この列")
("this style specifies page margins in the TeX way" "このスタイルはTeXの方法でページの余白を指定します")
("three columns" "3列")
("three dots" "3つのドット")
("through popup windows" "ポップアップウィンドウ経由")
("through the menus" "メニューを使用して")
("thumbnails" "サムネイル")
("time evolution" "時間の進化")
("timings" "タイミング")
("title presentation options" "タイトル表示オプション")
("title style" "タイトルスタイル")
("title suffix" "タイトルサフィックス")
("titled block" "タイトル付きブロック")
("toggle cell wrapping mode" "セルの折り返しモードを切り替え")
("toggle here" "ここで切り替え")
("toggle off" "切り替え")
("toggle on" "オンに切り替え")
("tolerant" "寛容")
("top baseline" "トップベースライン")
("transform" "変換")
("transform cell into subtable" "セルをサブテーブルに変換")
("translations" "翻訳")
("translations loaded" "翻訳が読み込まれました")
("transpose" "転置")
("traversal" "トラバーサル")
("traverse" "トラバース")
("triangle" "三角形")
("triangularize" "三角形化")
("trigonometric" "三角関数")
("trigonometry" "三角法")
("turn off" "オフ")
("turn on" "オン")
("two columns" "2列")
("two dots" "2つのドット")
("type a latex command followed by return" "latexコマンドを入力してからreturn")
("underlined" "下線付き")
("unevaluated argument" "未評価の引数")
("unevaluated value" "未評価の値")
("unfold" "展開")
("unfold all" "すべてを展開")
("unfold all fields" "すべてのフィールドを展開")
("unit" "ユニット")
("unit length" "ユニット長")
("unknown secret key fingerprint" "不明な秘密鍵の指紋")
("unregistered file" "未登録ファイル")
("unroll" "展開")
("unsecure script refused" "安全でないスクリプトは拒否されました")
("unsupported link mode" "サポートされていないリンクモード")
("until" "まで")
("untitled block" "無題のブロック")
("up to date" "最新")
("update buffer" "更新バッファ")
("update this buffer" "このバッファを更新")
("update web site" "Webサイトの更新")
("upight" "upight")
("upload" "アップロード")
("upwards" "上向き")
("use CSS for more advanced formatting" "より高度な書式設定にCSSを使用")
("use MathML" "MathMLを使用")
("use as master" "マスターとして使用")
("use extensible brackets" "拡張可能なブラケットを使用")
("use line wrapping for lines which are longer than 80 characters" "80文字を超える行の折り返しを使用する")
("use margin kerning (protrusion)" "マージンカーニング(突起)を使用")
("use protrusion" "突起を使用")
("use relative path" "相対パスを使用")
("user interface" "ユーザーインターフェイス")
("user interface language" "ユーザーインターフェイス言語")
("user preferences" "ユーザー設定")
("users of oriental languages" "東洋言語のユーザー")
("utf-8 with inputenc LaTeX package" "inputenc LaTeXパッケージを備えたutf-8")
("utilities" "ユーティリティ")
("vanish" "消失")
("verbose" "詳細")
("version" "バージョン")
("versioning tool" "バージョン管理ツール")
("vertical alignment" "垂直方向の配置")
("vertical margins" "垂直マージン")
("vertical space after" "後の垂直スペース")
("vertical space before" "前の垂直スペース")
("vertical space stretchability" "垂直空間の伸縮性")
("visible except here" "ここを除いて表示")
("visible from here on" "ここから見える")
("visible only here" "ここでのみ表示")
("visible until here" "ここまで見える")
("visited loci" "訪問された遺伝子座")
("wallet" "ウォレット")
("wave" "波")
("weight" "重量")
("when line wrapping" "行の折り返し")
("whitespace" "空白")
("wide" "ワイド")
("wide block" "ワイドブロック")
("wide colored" "ワイドカラー")
("wide float" "ワイドフロート")
("wide footnote" "広い脚注")
("wide tabular" "幅広の表")
("widescreen" "ワイドスクリーン")
("wrap lines" "折り返し行")
("writing TeXmacs bibliography styles" "TeXmacs書誌スタイルの作成")
("writing documentation" "ドキュメントの作成")
("wrong empty passphrase" "間違った空のパスフレーズ")
("wrong passphrase" "間違ったパスフレーズ")
("year" "年")
("you are attempting to open an encrypted file while" "暗号化されたファイルを開こうとしています")
("you might consider enabling the experimental" "実験的な機能を有効にすることを検討するかもしれません")
("you must add a bibliography file" "参考文献ファイルを追加する必要があります")
("you should also make sure that GnuPG is installed" "GnuPGがインストールされていることも確認する必要があります")
("your personal dictionary has been modified" "個人用辞書が変更されました")
("zoom" "ズーム")
("zoom in" "ズームイン")
("zoom out" "ズームアウト")
