<TeXmacs|1.99.8>

<style|<tuple|source|std-pattern>>

<\body>
  <active*|<\src-title>
    <src-package-dtd|reduced-margins|1.0|reduced-margins|1.0>

    <\src-purpose>
      Revert to usual margins for styles that use reduced default margins
    </src-purpose>

    <src-copyright|1998--2018|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <use-package|page-numbers>

  \;

  <assign|page-screen-margin|true>

  <assign|page-width-margin|false>

  <assign|page-odd|auto>

  <assign|page-even|auto>

  <assign|page-right|auto>

  <assign|page-top|auto>

  <assign|page-bot|auto>
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>