("\"encryption\" features from the preference panel" "")
("(Re)Build autocompletion index" "")
("a modifier" "")
("a series" "")
("a.C.M. computing class" "")
("a.M.S. subject class" "")
("abbreviated authors" "")
("abbreviation" "")
("about" "")
("about menu" "")
("above" "")
("abbreviated authors" "")
("abstract" "")
("accent" "")
("accent above" "")
("accent below" "")
("accept" "")
("accept all scripts" "")
("accept during this pass" "")
("accept no scripts" "")
("accept script" "")
("acknowledge" "")
("acknowledgment" "")
("acknowledgments" "")
("acronym" "")
("action" "")
("activate" "")
("activate hidden" "")
("activate once" "")
("activation" "")
("active link types" "")
("acute" "")
("add" "")
("add abstract information" "")
("add author information" "")
("add branch after" "")
("add branch before" "")
("add other package" "")
("add package" "")
("add remote ssh connection" "")
("add style package" "")
("add switch after" "")
("add switch before" "")
("add title information" "")
("add to custom colors" "")
("addition" "")
("address" "")
("address block" "")
("adjust" "")
("adjust limits" "")
("advanced" "")
("advanced font customization" "")
("advanced layout features" "")
("affiliation" "")
("after" "")
("albanian" "")
("algorithm" "")
("algorithms" "")
("align cell to the bottom" "")
("align cell to the decimal comma" "")
("align cell to the decimal dot" "")
("align cell to the left" "")
("align cell to the right" "")
("align cell to the top" "")
("align table at axis" "")
("align table at base of left column" "")
("align table at base of middle column" "")
("align table at base of origin column" "")
("align table at base of right column" "")
("align table at fraction bar height" "")
("align table at the base of bottom row" "")
("align table at the base of middle row" "")
("align table at the base of origin row" "")
("align table at the base of top row" "")
("align table at the bottom" "")
("align table at the center" "")
("align table at the horizontal center" "")
("align table at the left" "")
("align table at the top" "")
("align table to the right" "")
("align text to the left" "")
("align text to the right" "")
("aligned" "")
("alignment" "")
("alignment of balloon" "")
("all" "")
("all cells" "")
("all data attached to this identity will be lost" "")
("all saved passphrases will be lost forever" "")
("allow" "")
("allow for macro definitions in preamble" "")
("allow multiple spaces" "")
("allow spurious spaces" "")
("allowed extension" "")
("allowed page height extension" "")
("allowed page height reduction" "")
("allowed positions" "")
("allowed positions of floating object" "")
("allowed reduction" "")
("alpha release" "")
("alpha transparency" "")
("also on paper" "")
("alt key" "")
("alter" "")
("alternate" "")
("alternate except here" "")
("alternate from here on" "")
("alternate only here" "")
("alternate until here" "")
("alternative colors" "")
("alternative specification" "")
("always" "")
("american" "")
("amplified" "")
("anchor" "")
("ancient" "")
("and" "")
("and perform casual settings from the \"Encryption\" tab" "")
("angle" "")
("angular" "")
("animate" "")
("animate folding" "")
("animate object" "")
("animate objects" "")
("animate unfolding" "")
("animated" "")
("animation" "")
("animation toolbar" "")
("annotate" "")
("annote" "")
("answer" "")
("answer field" "")
("answer to question" "")
("answers" "")
("answers only" "")
("any" "")
("appear" "")
("appendix" "")
("apply" "")
("apply macro" "")
("apply macro once" "")
("approximate" "")
("april" "")
("arab" "")
("arc" "")
("arc cosine" "")
("arc sine" "")
("arc tangent" "")
("arch series" "")
("archaic" "")
("architecture" "")
("are you sure you want to delete collected public keys" "")
("are you sure you want to delete selected public keys" "")
("are you sure you want to delete selected secret keys" "")
("are you sure you want to destroy the wallet" "")
("argument" "")
("arithmetic" "")
("armenian" "")
("arrow" "")
("arrows" "")
("art Pen" "")
("art frame" "")
("article" "")
("arxiv category" "")
("as on paper" "")
("as visual grid" "")
("aspect" "")
("assign" "")
("at fraction bar height" "")
("at the baseline" "")
("at the bottom" "")
("at the left" "")
("at the middle" "")
("at the right" "")
("at the top" "")
("attach" "")
("attach buffer to which project" "")
("attach master" "")
("attach master file for project" "")
("attached" "")
("august" "")
("author" "")
("authorize" "")
("auto" "")
("auto-save file" "")
("automate" "")
("automatic" "")
("automatic brackets" "")
("automatic content generation" "")
("automatic program brackets" "")
("automatic quotes" "")
("automatically close brackets" "")
("automatically generated content" "")
("automatically import bibliographies when opening files" "")
("automatically open this console on errors" "")
("automatically open this console on warnings" "")
("automatically remember all passphrases in the wallet" "")
("automatically save" "")
("autosave" "")
("avoid spurious spaces" "")
("axiom" "")
("axioms" "")
("axis" "")
("b series" "")
("back" "")
("background" "")
("background color" "")
("background evaluations" "")
("background pattern" "")
("background picture" "")
("background picture selector" "")
("backtrace errors" "")
("backward replace" "")
("backward search" "")
("bad data format" "")
("balloon" "")
("bar" "")
("bard" "")
("base" "")
("base level" "")
("baseline" "")
("bashkirian" "")
("basic" "")
("basic colors" "")
("basic communication using pipes" "")
("basic data types" "")
("basic types" "")
("be useful" "")
("beamer" "")
("beamer formats" "")
("beamer theme" "")
("become a TeXmacs developer" "")
("before" "")
("begin" "")
("below" "")
("bench" "")
("bend bottom" "")
("bend corner" "")
("bend diagonal" "")
("bend in" "")
("bend out" "")
("beta release" "")
("bezier" "")
("bibTeX command" "")
("bibliography" "")
("bibliography file" "")
("bibliography style" "")
("bidirectional" "")
("big" "")
("big environment box" "")
("big figure" "")
("big focus" "")
("big operator" "")
("big skip" "")
("big table" "")
("binary operation" "")
("binary operator" "")
("binary relation" "")
("bitmap resolution (dpi)" "")
("black" "")
("black floral I" "")
("black floral II" "")
("blackboard" "")
("blackboard bold" "")
("blackboard embold" "")
("blackboard math" "")
("blackletter" "")
("blank column" "")
("blank row" "")
("block" "")
("block content" "")
("block of code" "")
("blue" "")
("bluish" "")
("blur" "")
("blur radius" "")
("body" "")
("body color" "")
("bold" "")
("book" "")
("booklet" "")
("border" "")
("boring-white" "")
("both" "")
("both versions" "")
("bothlined" "")
("bottom" "")
("bottom baseline" "")
("bottom border" "")
("bottom cell border" "")
("bottom cell padding" "")
("bottom center" "")
("bottom left" "")
("bottom margin" "")
("bottom padding" "")
("bottom right" "")
("bottom table border" "")
("bottom table padding" "")
("bottom tools" "")
("box" "")
("branch" "")
("break" "")
("breaking" "")
("breve" "")
("bright" "")
("british" "")
("broken citations" "")
("broken references" "")
("broken white" "")
("brown" "")
("browse" "")
("browse back" "")
("browse forward" "")
("browse modules documentation" "")
("browse symbols documentation" "")
("browse web" "")
("browser" "")
("buffer" "")
("buffer in this window" "")
("buffer management" "")
("buffer must be on disk" "")
("buffer must have a name" "")
("build buffer" "")
("build buffer in" "")
("build directory" "")
("build directory in" "")
("build link pages" "")
("build-all" "")
("bulgarian" "")
("bullet" "")
("bullets" "")
("bump" "")
("busy" "")
("by" "")
("by typing" "")
("bytes free" "")
("bytes used" "")
("cJK" "")
("cJK spacing" "")
("cSS stylesheet" "")
("calculus" "")
("calligraphic" "")
("cancel" "")
("cancelled" "")
("cannot download directory to file" "")
("cannot rename across different servers" "")
("cannot upload directory to file" "")
("caps-lock key" "")
("caption" "")
("cartesian" "")
("cartoon" "")
("carved wood" "")
("case" "")
("case-insensitive search" "")
("categories" "")
("category" "")
("cc" "")
("cell" "")
("cell background color" "")
("cell border" "")
("cell color" "")
("cell height" "")
("cell operation mode" "")
("cell properties" "")
("cell span" "")
("cell width" "")
("cells" "")
("center" "")
("center baseline" "")
("center text" "")
("centered" "")
("centered block" "")
("centered programs" "")
("centered tabular" "")
("chalk" "")
("change border of cell" "")
("change cell operation mode" "")
("change default unit" "")
("change log" "")
("change passphrase" "")
("change permissions" "")
("change step-size" "")
("change tags" "")
("change the TeXmacs preferences" "")
("change the border of the table" "")
("change the style of mathematical formulas" "")
("change wallet passphrase" "")
("changes" "")
("chapter" "")
("character compression" "")
("character contraction" "")
("character count" "")
("character encoding" "")
("character expansion" "")
("check" "")
("check exported Pdf files for correctness" "")
("check for automatic updates" "")
("check for updates" "")
("check text for spelling errors" "")
("checkable field" "")
("chinese" "")
("choice" "")
("choose background" "")
("choose color" "")
("cipher algorithm for passphrase encryption" "")
("circle" "")
("citation" "")
("cite" "")
("cite TeXmacs" "")
("cite TeXmacs-related work" "")
("cite related work" "")
("class" "")
("classic" "")
("classification" "")
("clean slate" "")
("clear" "")
("clear all fields" "")
("clear local information" "")
("clear menu" "")
("clear selection" "")
("clear undo history" "")
("click Ok button twice to discard this warning" "")
("client" "")
("clip" "")
("clipboard image format" "")
("clipped" "")
("clipped and magnified" "")
("clipped and resized" "")
("clone" "")
("clone window" "")
("close" "")
("close TeXmacs" "")
("close animation tool" "")
("close buffer" "")
("close document" "")
("close program" "")
("close replace tool" "")
("close search tool" "")
("close session" "")
("close spell tool" "")
("close translations to rebuild" "")
("close window" "")
("closed bezier" "")
("closed curve" "")
("closed smooth" "")
("closed spline" "")
("closing" "")
("closing style" "")
("cluster by affiliation" "")
("code" "")
("collect garbage" "")
("collected keys" "")
("color" "")
("color according to nesting level" "")
("color of the axes" "")
("color of the subunits" "")
("color of the units" "")
("colors" "")
("column" "")
("column contains glued items" "")
("column separation" "")
("column to the left" "")
("column to the right" "")
("columns" "")
("columns separation" "")
("command" "")
("commit" "")
("commit file" "")
("common" "")
("common formats" "")
("commutative diagram" "")
("compact" "")
("compact lists" "")
("compactification" "")
("compactify" "")
("compare" "")
("compare with" "")
("compatibility with other formats" "")
("compile article" "")
("compile book" "")
("compile buffer" "")
("compile project" "")
("complete bibliographic reference" "")
("completion" "")
("complex" "")
("complex actions" "")
("compose" "")
("compound" "")
("compress" "")
("compress into toolbar" "")
("compressed" "")
("conceal" "")
("concrete" "")
("condensed" "")
("condition" "")
("conference" "")
("configuration" "")
("configure look and feel" "")
("confirm collected public key deletion" "")
("confirm database entry" "")
("confirm entry" "")
("confirm public key deletion" "")
("confirm secret key deletion" "")
("confirm selected database entries" "")
("confirm selected entries" "")
("confirm wallet destruction" "")
("conjecture" "")
("conjectures" "")
("conservative conversion between LaTeX and TeXmacs" "")
("conservative conversion options" "")
("consoles" "")
("constants" "")
("constellation" "")
("contact" "")
("content" "")
("content tag" "")
("context aids" "")
("context dependent icons" "")
("contextual hints" "")
("continuation of" "")
("continue" "")
("continued fraction" "")
("contour" "")
("contract logarithms" "")
("contribute" "")
("control flow" "")
("control the evaluation of expressions" "")
("convention" "")
("conventions" "")
("convert" "")
("converters" "")
("converters to other data formats" "")
("convertible" "")
("copy" "")
("copy new objects to all frames" "")
("copy new objects to previous frames" "")
("copy new objects to subsequent frames" "")
("copy text" "")
("copy to" "")
("copy to all frames after" "")
("copy to all frames before" "")
("copy to all other frames" "")
("copying" "")
("copyright" "")
("cork charset with TeX catcode definition in preamble" "")
("cork with catcodes" "")
("corollaries" "")
("corollary" "")
("correct" "")
("correct all" "")
("correct formula" "")
("correct manually" "")
("correct mathematical formulas" "")
("correct text" "")
("correction" "")
("cosine" "")
("could not load" "")
("count characters" "")
("count lines" "")
("count words" "")
("course" "")
("create a new document" "")
("create context macro" "")
("create link" "")
("create preamble" "")
("create remote account" "")
("create remote directory" "")
("create remote file" "")
("create subprogram" "")
("create subsession" "")
("create table macro" "")
("create web site" "")
("created new document" "")
("creating new account" "")
("creating technical pictures" "")
("croatian" "")
("crop" "")
("crop marks" "")
("cross" "")
("crossed boxes" "")
("crossed circles" "")
("current graphical mode" "")
("current user version" "")
("current version" "")
("cursor" "")
("cursors" "")
("curve" "")
("curve intersections" "")
("curve points" "")
("custom colors" "")
("custom tab" "")
("customizations" "")
("customize macro" "")
("customizing TeXmacs" "")
("customizing and extending the user interface" "")
("customizing the TeXmacs styles" "")
("custum tab" "")
("cut" "")
("cut text" "")
("cut to" "")
("cyan" "")
("cypriot" "")
("cyrillic" "")
("cyrillic input method" "")
("cyrillic italic right" "")
("czech" "")
("dancers" "")
("danish" "")
("dark" "")
("dark grey" "")
("dark-vador" "")
("dash" "")
("dashes" "")
("data" "")
("data conversion" "")
("data format" "")
("database entry" "")
("database tool" "")
("database toolbar" "")
("date" "")
("deactivate" "")
("deactivate once" "")
("deactivate table" "")
("dead" "")
("debug" "")
("debugging console" "")
("debugging tool" "")
("december" "")
("decimal comma" "")
("decimal dot" "")
("decomposed" "")
("decorate atoms" "")
("decorated" "")
("decorated wood" "")
("decorative" "")
("decrease size" "")
("decrypt" "")
("decrypted" "")
("decryption" "")
("default" "")
("default padding" "")
("default size" "")
("definition" "")
("definitions" "")
("degrade" "")
("degraded" "")
("delete" "")
("delete column" "")
("delete documentation cache" "")
("delete entries" "")
("delete link" "")
("delete row" "")
("delete selected entries in wallet" "")
("delete user identity" "")
("deleted" "")
("denominator" "")
("describe" "")
("describe tag" "")
("description" "")
("destination" "")
("destroy" "")
("detach" "")
("detach master" "")
("detailed" "")
("detailed menus" "")
("details in menus" "")
("determinant" "")
("determine margins from text width" "")
("devangari" "")
("developer" "")
("developer tool" "")
("developers guide" "")
("device" "")
("diamond" "")
("differentiate" "")
("digital" "")
("dilate" "")
("direction of progression" "")
("direction of translation" "")
("directory" "")
("disable" "")
("disable coloring on paper" "")
("disable encryption" "")
("disable first indentation" "")
("disable first indentation after" "")
("disable first indentation before" "")
("disable indentation" "")
("disable indentation after" "")
("disable indentation before" "")
("disabled" "")
("disallow" "")
("disappear" "")
("disk" "")
("display style" "")
("displayed formula" "")
("dissociate joined cells" "")
("distill encapsulated Pdf files" "")
("distort" "")
("distorted" "")
("distribute unused space" "")
("div" "")
("division" "")
("do not break up large formulas" "")
("do not remap" "")
("document" "")
("document colors" "")
("document font selector" "")
("document format" "")
("document language" "")
("document metadata" "")
("document page format" "")
("document paragraph format" "")
("document source tree preferences" "")
("document style" "")
("document styles" "")
("document updates run" "")
("documentation" "")
("documents are trees" "")
("documents in separate windows" "")
("dot" "")
("dots" "")
("double stroke" "")
("double the zoom factor for TeXmacs documents" "")
("down" "")
("download" "")
("download file or directory" "")
("downwards" "")
("dpi" "")
("dragging" "")
("draw" "")
("draw graphics" "")
("draw image" "")
("draw over" "")
("draw over selection" "")
("draw under" "")
("drop" "")
("due to" "")
("duplicate" "")
("duplicate labels" "")
("duration" "")
("dutch" "")
("dynamic" "")
("dynamic libraries" "")
("eRROR" "")
("echelon" "")
("edit" "")
("edit animation" "")
("edit groups of objects" "")
("edit macro" "")
("edit macros" "")
("edit object properties" "")
("edit package" "")
("edit preamble" "")
("edit source" "")
("edit source tree" "")
("edit style" "")
("edit translations file" "")
("editing tools" "")
("education" "")
("effect pen" "")
("eigenvalues" "")
("eigenvalues and vectors" "")
("eighth" "")
("elevation" "")
("email" "")
("embed all linked images" "")
("embed image" "")
("embed this image" "")
("embold" "")
("emboss" "")
("emphasize" "")
("emphasize text" "")
("empty box" "")
("enable first indentation" "")
("enable first indentation after" "")
("enable first indentation before" "")
("enable indentation" "")
("enable indentation after" "")
("enable indentation before" "")
("enable page breaking" "")
("enabled" "")
("encl" "")
("encoding" "")
("encrypt" "")
("encrypted" "")
("encrypted buffer" "")
("encryption" "")
("encryption error" "")
("encryption facilities are not currently available" "")
("encryption facilities have not been enabled for TeXmacs" "")
("end" "")
("enforce brackets to match" "")
("english" "")
("engrave" "")
("enter a title" "")
("enter data" "")
("enter graphic mode" "")
("enter graphics" "")
("enter graphics mode" "")
("enter new passphrase for encryption" "")
("enter passphrase for decryption" "")
("enter passphrase for identity" "")
("enter title information" "")
("entire table" "")
("entry" "")
("entry type" "")
("entry up to date in database" "")
("enumerate" "")
("enumerate|Alpha" "")
("enumerate|Roman" "")
("enumerate|alpha" "")
("enumerate|roman" "")
("enunciation" "")
("env" "")
("environment" "")
("environment variable" "")
("environments" "")
("epilogue" "")
("equal" "")
("equation" "")
("equations" "")
("equivalent for" "")
("erode" "")
("error" "")
("error messages" "")
("error output" "")
("error status report" "")
("error: bracket does not match" "")
("error: cyclic or missing chunks detected" "")
("error: file not found" "")
("error: ghostview does not seem to be installed on your system" "")
("error: one of the alternatives should be filled out" "")
("error: only one alternatives should be filled out" "")
("error: should fill out name for referencing" "")
("error: should fill out required field" "")
("escape" "")
("esperanto" "")
("etruscan" "")
("european numbering style" "")
("evaluable field" "")
("evaluate" "")
("evaluate above" "")
("evaluate all" "")
("evaluate below" "")
("evaluate fields" "")
("evaluate fields in order" "")
("evaluate scheme expression" "")
("evaluate script" "")
("evaluation" "")
("evaluation switch" "")
("evaluation tag" "")
("even page" "")
("even page footer" "")
("even page header" "")
("even page left margin" "")
("even page margin" "")
("even page shift" "")
("even page text" "")
("even pages" "")
("events" "")
("exact" "")
("exact horizontal" "")
("exact mode" "")
("exam" "")
("example" "")
("examples" "")
("exclusive" "")
("exclusive or" "")
("executable" "")
("execute" "")
("execute a TeXmacs command" "")
("execute system command" "")
("execution of scripts" "")
("executive" "")
("exercise" "")
("exercises" "")
("exit graphics" "")
("exit graphics mode" "")
("exit left" "")
("exit right" "")
("exit tag on the left" "")
("exit tag on the right" "")
("expand" "")
("expand TeXmacs macros with no LaTeX equivalents" "")
("expand beamer slides" "")
("expand inclusions" "")
("expand logarithms" "")
("expand trigonometric functions" "")
("expand unrecognized macros" "")
("expand user-defined macros" "")
("expanded" "")
("experimental" "")
("experimental features (to be used with care)" "")
("explain" "")
("explained" "")
("explanatory item" "")
("explicit keystroke" "")
("explicit margins" "")
("exponential" "")
("exponential functions" "")
("export" "")
("export as" "")
("export bibliographies as links" "")
("export bibliography" "")
("export entries in buffer" "")
("export file" "")
("export formulas as images" "")
("export mathematical formulas as MathJax" "")
("export mathematical formulas as MathML" "")
("export mathematical formulas as images" "")
("export selected entries" "")
("export selection" "")
("export selection as image" "")
("export selections as" "")
("export sessions" "")
("exported bibliographic entries" "")
("exported bibliographic references" "")
("extend" "")
("extend or normal" "")
("extend table to full paragraph width" "")
("extended" "")
("extensible left arrow" "")
("extensible right arrow" "")
("extern" "")
("extern " "")
("external" "")
("extra" "")
("extra branch" "")
("extra interline space" "")
("extra name" "")
("extract" "")
("extract format" "")
("extract style file" "")
("extract style package" "")
("factor" "")
("fade" "")
("fade in" "")
("fade out" "")
("family" "")
("fast" "")
("fast decrease" "")
("fast environments" "")
("fast increase" "")
("february" "")
("field reference" "")
("fifth" "")
("figure" "")
("figures" "")
("file" "")
("file name" "")
("file not found" "")
("file saved" "")
("fill color" "")
("fill out" "")
("filter" "")
("find file" "")
("find next match" "")
("find text" "")
("finished collecting symbols documentation" "")
("finnish" "")
("first" "")
("first chunk" "")
("first contact" "")
("first difference" "")
("first error" "")
("first field" "")
("first indentation" "")
("first item" "")
("first occurrence" "")
("first page" "")
("first similar" "")
("first start" "")
("fit" "")
("fit to height" "")
("fit to screen" "")
("fit to screen width" "")
("fit to width" "")
("five columns" "")
("fix broken citations" "")
("fix broken references" "")
("fix duplicate labels" "")
("fixed" "")
("flag is off" "")
("flag is on" "")
("flat" "")
("flatten" "")
("flexibility" "")
("flexibility factor for vertical spacing" "")
("floating algorithm" "")
("floating figure" "")
("floating object" "")
("floating phantom" "")
("floating table" "")
("focus" "")
("focus dependent icons" "")
("fold" "")
("fold all" "")
("fold all fields" "")
("fold back" "")
("fold input field" "")
("folded" "")
("follow external links" "")
("follow inverse links" "")
("font" "")
("font base size" "")
("font customization" "")
("font dpi" "")
("font effects" "")
("font family" "")
("font name" "")
("font selector" "")
("font series" "")
("font shape" "")
("font size" "")
("font type" "")
("font variant" "")
("fonts" "")
("footer" "")
("footnote" "")
("for" "")
("for all" "")
("for each" "")
("force reloading of translations" "")
("foreground" "")
("foreign" "")
("format" "")
("formatted and structured output" "")
("formatted date" "")
("formatting" "")
("formula" "")
("formula style" "")
("forward" "")
("forward replace" "")
("forward search" "")
("four columns" "")
("four dots" "")
("fourth" "")
("fraction" "")
("fraktur" "")
("framed" "")
("framed input fields" "")
("framed programs" "")
("framed theorems" "")
("framed title" "")
("french" "")
("frequency" "")
("from" "")
("from center" "")
("front matter" "")
("full" "")
("full author list" "")
("full manuals" "")
("full name" "")
("full screen mode" "")
("function" "")
("functional" "")
("further customization" "")
("future changes" "")
("gNU TeXmacs comes without any form of legal warranty" "")
("gNU TeXmacs falls under the GNU general public license" "")
("gap" "")
("garbage collection" "")
("gaussian" "")
("gaussian blur" "")
("gcd" "")
("general" "")
("general architecture of TeXmacs" "")
("general negation" "")
("general note" "")
("generate GnuPG key" "")
("generated LaTeX document contains no errors" "")
("generated field" "")
("generating font file" "")
("generic" "")
("generic input color" "")
("generic prompt color" "")
("geometry" "")
("georgian" "")
("german" "")
("get arity" "")
("get label" "")
("get list with remote versions" "")
("getting started" "")
("global log" "")
("global status" "")
("glossary" "")
("glossary entry" "")
("glue" "")
("glue decorations" "")
("glue multiple spaces" "")
("glyphs" "")
("gnaw" "")
("gnawed" "")
("gnuPG command" "")
("gnuPG decryption error" "")
("gnuPG error: buffer encryption failed" "")
("gnuPG error: cannot find suitable secret key to decrypt" "")
("gnuPG requires name and email to have at least 5 characters" "")
("go" "")
("go to anchor" "")
("go to anchor or float" "")
("go to anchor or footnote" "")
("go to first similar tag" "")
("go to float" "")
("go to footnote" "")
("go to last similar tag" "")
("go to next similar tag" "")
("go to previous similar tag" "")
("go to section" "")
("gothic" "")
("gradient" "")
("gradient selector" "")
("grain" "")
("granite" "")
("graphical effects" "")
("graphical interface" "")
("graphical interface font scale" "")
("graphical overlays" "")
("graphical slides and overlays" "")
("graphics" "")
("graphics geometry" "")
("graphics grids" "")
("grave" "")
("greater" "")
("greater or equal" "")
("greek" "")
("greek letter" "")
("green" "")
("grey" "")
("greyed" "")
("grid" "")
("grid curves" "")
("grid lines" "")
("grid points" "")
("grid-curve intersections" "")
("group" "")
("group of objects" "")
("group/ungroup" "")
("group/ungroup objects" "")
("grouped" "")
("guarantee transparent source tracking" "")
("h modifier" "")
("half wide" "")
("hand drawn" "")
("handwritten" "")
("hanging theorems" "")
("hangul" "")
("happy typing" "")
("has been aborted" "")
("has completed its task" "")
("hat" "")
("header" "")
("header and footer" "")
("header bars" "")
("headers" "")
("hebrew" "")
("height" "")
("height is exactly the specified height" "")
("height is maximum of specified height and box height" "")
("height is minimum of specified height and box height" "")
("height magnification" "")
("help" "")
("help balloon" "")
("help me" "")
("help us" "")
("here" "")
("hidden" "")
("high resolution screen settings" "")
("high resolution settings" "")
("highlight errors" "")
("history" "")
("home" "")
("homepage" "")
("homoglyph substitutions" "")
("horizontal" "")
("horizontal alignment" "")
("horizontal cell alignment" "")
("horizontal collapse distance" "")
("horizontal ink separation" "")
("horizontal margins" "")
("horizontal padding" "")
("horizontal part" "")
("horizontal position" "")
("horizontal space" "")
("horizontal table alignment" "")
("horizontally align cell to the base" "")
("horizontally center the cell" "")
("how much longer may pages become" "")
("how much shorter may pages become" "")
("huge" "")
("hungarian" "")
("hybrid command" "")
("hyperbolic functions" "")
("hyperlink" "")
("hyphenate as" "")
("hyphenation" "")
("ice" "")
("icelandic" "")
("icon" "")
("identifier" "")
("idle" "")
("if" "")
("if hyphenated" "")
("iff" "")
("ignore" "")
("image" "")
("image links" "")
("impact" "")
("implementation" "")
("import" "")
("import bibliography" "")
("import database entry" "")
("import entries in buffer" "")
("import entry" "")
("import file" "")
("import font" "")
("import public keys from buffer" "")
("import selected database entries" "")
("import selected entries" "")
("import selections as" "")
("import sessions" "")
("import sophisticated objects as pictures" "")
("imported bibliographic entries" "")
("improving the current implementation" "")
("in popup windows" "")
("inactive" "")
("inanimated" "")
("inch" "")
("inches" "")
("include" "")
("include a document" "")
("include file" "")
("inclusion into TeXmacs" "")
("inclusions" "")
("incomplete entries found to be filled out" "")
("increase size" "")
("indent" "")
("indent paragraphs" "")
("indentation" "")
("indentation flag" "")
("index" "")
("index entry" "")
("index level" "")
("indication" "")
("inflate" "")
("informative flags" "")
("initialize" "")
("initialize wallet" "")
("initials" "")
("ink here" "")
("ink in" "")
("ink out" "")
("inline" "")
("inline args" "")
("inline arguments" "")
("inline code" "")
("inline content" "")
("inline formula" "")
("inline note" "")
("inner" "")
("inner bottom" "")
("inner left" "")
("inner right" "")
("inner top" "")
("input" "")
("input command" "")
("input field" "")
("input mode" "")
("input options" "")
("insert" "")
("insert Pr" "")
("insert a TeXmacs symbol" "")
("insert a big operator" "")
("insert a binary operation" "")
("insert a binary relation" "")
("insert a blackboard bold character" "")
("insert a bold calligraphic character" "")
("insert a bold character" "")
("insert a calligraphic character" "")
("insert a computer program" "")
("insert a condition" "")
("insert a control flow instruction" "")
("insert a fraction" "")
("insert a fraktur character" "")
("insert a gap" "")
("insert a greek character" "")
("insert a large left delimiter" "")
("insert a large right delimiter" "")
("insert a large separator" "")
("insert a left subscript" "")
("insert a link" "")
("insert a list" "")
("insert a miscellaneous symbol" "")
("insert a multiple choice" "")
("insert a negation" "")
("insert a new branch" "")
("insert a new entry" "")
("insert a new item" "")
("insert a note or a floating object" "")
("insert a numerical operation" "")
("insert a personal macro" "")
("insert a picture" "")
("insert a prominent piece of text" "")
("insert a question" "")
("insert a root" "")
("insert a script" "")
("insert a section block" "")
("insert a square root" "")
("insert a table" "")
("insert a table or a matrix" "")
("insert a textual operation" "")
("insert a textual operator" "")
("insert a wide symbol above" "")
("insert a wide symbol below" "")
("insert above" "")
("insert abstract" "")
("insert an" "")
("insert an accent" "")
("insert an answer" "")
("insert an arrow" "")
("insert an enunciation" "")
("insert an environment" "")
("insert an n" "")
("insert an operation on tuples" "")
("insert annotation" "")
("insert appendix" "")
("insert arccos" "")
("insert arcs" "")
("insert arcsin" "")
("insert arctan" "")
("insert arg" "")
("insert argument" "")
("insert argument after" "")
("insert argument before" "")
("insert author" "")
("insert automatically generated content" "")
("insert below" "")
("insert bibliography" "")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "")
("insert big intersection" "")
("insert big logical and" "")
("insert big logical or" "")
("insert big product" "")
("insert big square union" "")
("insert big summation" "")
("insert big tensor product" "")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "")
("insert chapter" "")
("insert circles" "")
("insert closed splines" "")
("insert column" "")
("insert column to the left" "")
("insert column to the right" "")
("insert copyright and license information" "")
("insert cos" "")
("insert cosh" "")
("insert cot" "")
("insert coth" "")
("insert csc" "")
("insert deg" "")
("insert det" "")
("insert dim" "")
("insert dollar" "")
("insert equation" "")
("insert executable markup" "")
("insert exp" "")
("insert explanatory item" "")
("insert field above" "")
("insert field below" "")
("insert fields" "")
("insert footnote" "")
("insert formula" "")
("insert gcd" "")
("insert hand drawn curves" "")
("insert hom" "")
("insert horizontal interword space" "")
("insert image" "")
("insert inactive markup" "")
("insert inf" "")
("insert input field above" "")
("insert input field below" "")
("insert ker" "")
("insert large delimiters" "")
("insert last name" "")
("insert left" "")
("insert lg" "")
("insert lim" "")
("insert liminf" "")
("insert limsup" "")
("insert lines" "")
("insert ln" "")
("insert log" "")
("insert macro" "")
("insert mathematics" "")
("insert max" "")
("insert medium horizontal space" "")
("insert medium vertical space" "")
("insert min" "")
("insert missing invisible operators" "")
("insert more names" "")
("insert multiple paragraphs" "")
("insert negative horizontal space" "")
("insert new item or number" "")
("insert new rows or columns" "")
("insert or delete rows or columns" "")
("insert overlay after" "")
("insert overlay before" "")
("insert particle" "")
("insert plain text" "")
("insert points" "")
("insert polygons" "")
("insert right" "")
("insert row" "")
("insert row above" "")
("insert row below" "")
("insert sec" "")
("insert section" "")
("insert sharp" "")
("insert similar above" "")
("insert similar below" "")
("insert similar block above" "")
("insert similar block below" "")
("insert sin" "")
("insert sinh" "")
("insert slide after" "")
("insert slide before" "")
("insert small horizontal space" "")
("insert small vertical space" "")
("insert splines" "")
("insert structural markup" "")
("insert subscript" "")
("insert subsection" "")
("insert subsubsection" "")
("insert subtable" "")
("insert sup" "")
("insert superscript" "")
("insert symbol documentation" "")
("insert tan" "")
("insert tanh" "")
("insert template" "")
("insert text" "")
("insert text field" "")
("insert text field above" "")
("insert text field below" "")
("insert thick horizontal space" "")
("insert title" "")
("insert title after name" "")
("insert user interface related markup" "")
("insert value" "")
("inserting control points" "")
("inside mathematics" "")
("integer arithmetic" "")
("integrate" "")
("interactive command" "")
("interactive questions" "")
("intercharacter compression" "")
("intercharacter stretching" "")
("interfacing" "")
("interfacing TeXmacs with other systems" "")
("interjection" "")
("interline separation" "")
("interline space" "")
("internationalization" "")
("interparagraph space" "")
("interrupt execution" "")
("interrupted" "")
("intersperse" "")
("introduction" "")
("invalid multi-paragraph selection" "")
("invalid paste of text into a formula" "")
("invalid renaming" "")
("invert" "")
("inverted breve" "")
("invisible" "")
("invisible citation" "")
("invisible ending" "")
("invisible newline" "")
("invisible opening" "")
("inwards" "")
("irish" "")
("is running" "")
("is tuple" "")
("ispell does not respond" "")
("ispell is already busy" "")
("italian" "")
("italic" "")
("italic right" "")
("itemize" "")
("january" "")
("japanese" "")
("join selected cells" "")
("journal" "")
("july" "")
("jump in" "")
("june" "")
("junior" "")
("justified" "")
("justify" "")
("justify text" "")
("keep evaluated expressions" "")
("keep local" "")
("keep remote" "")
("keep track of source code" "")
("keep unfolded" "")
("key" "")
("key manager" "")
("keyboard" "")
("keyboard configuration" "")
("keyboard equivalent" "")
("keyboard modifiers" "")
("keyboard shortcut" "")
("keymaps" "")
("keys" "")
("keyword" "")
("keywords" "")
("kill" "")
("known bugs" "")
("korean" "")
("laTeX errors" "")
("label" "")
("landscape" "")
("language" "")
("laptop presentations" "")
("large" "")
("large brackets" "")
("large cells" "")
("large closing bracket" "")
("large delimiter" "")
("large displayed" "")
("large displayed fraction" "")
("large opening bracket" "")
("large separator" "")
("large tables" "")
("last" "")
("last check" "")
("last difference" "")
("last error" "")
("last field" "")
("last name" "")
("last occurrence" "")
("last page" "")
("last similar" "")
("latex command" "")
("latin" "")
("layout" "")
("lcm" "")
("left" "")
("left aligned" "")
("left arrow" "")
("left axis" "")
("left baseline" "")
("left border" "")
("left bottom" "")
("left cell border" "")
("left cell padding" "")
("left center" "")
("left click: add point; Right click: undo" "")
("left click: finish; Right click: undo" "")
("left click: new object" "")
("left click: operate" "")
("left down" "")
("left margin" "")
("left on even pages" "")
("left padding" "")
("left prime" "")
("left slanted" "")
("left subscript" "")
("left superscript" "")
("left surrounding" "")
("left table border" "")
("left table padding" "")
("left top" "")
("left up" "")
("left-right arrow" "")
("leftwards" "")
("legal" "")
("lemma" "")
("lemmas" "")
("length" "")
("less" "")
("less or equal" "")
("let the environment float" "")
("letter" "")
("license" "")
("light" "")
("light grey" "")
("limit" "")
("limitations" "")
("limits" "")
("line" "")
("line arrows" "")
("line break" "")
("line breaking" "")
("line count" "")
("line dashes" "")
("line portion" "")
("line stretch" "")
("line style" "")
("line width" "")
("line wrapping" "")
("line wrapping inside cell" "")
("linear 2D" "")
("linear algebra" "")
("lines around" "")
("link" "")
("link all embedded images" "")
("link image" "")
("link image and copies as" "")
("link image as" "")
("link mode" "")
("link to URL" "")
("linking tool" "")
("lissajous" "")
("list" "")
("list of figures" "")
("list of tables" "")
("live" "")
("live input-output" "")
("load" "")
("load LaTeX file" "")
("load TeX file" "")
("load TeXmacs file" "")
("load TeXmacs style file" "")
("load a file" "")
("load buffer" "")
("load file" "")
("load help file" "")
("load html file" "")
("load image" "")
("load in new window" "")
("load latex file" "")
("load more recent autosave file" "")
("load remote file" "")
("load tex file" "")
("load verbatim file" "")
("loaded" "")
("loading" "")
("local entries" "")
("loci" "")
("locus" "")
("locus color" "")
("locus rendering" "")
("logarithm" "")
("logarithmic" "")
("logarithmic base" "")
("logarithms" "")
("logging in" "")
("logical and" "")
("logical implication" "")
("logical not" "")
("logical or" "")
("login" "")
("logout" "")
("long" "")
("long macro" "")
("long text" "")
("look and feel" "")
("look for more fonts" "")
("look up" "")
("loops" "")
("lower border" "")
("m modifier" "")
("macro" "")
("macro argument" "")
("macro definition" "")
("macro editor" "")
("macro name" "")
("macros" "")
("macros editor" "")
("magenta" "")
("magic" "")
("magnification" "")
("magnified" "")
("magnify horizontally" "")
("magnify vertically" "")
("main" "")
("main document font" "")
("main document style" "")
("main icon bar" "")
("main presentation style" "")
("major changes" "")
("make a letter environment" "")
("make a multi-slide presentation" "")
("make a page insertion" "")
("make a subscript" "")
("make a superscript" "")
("make acute" "")
("make bar" "")
("make block wide" "")
("make check" "")
("make float wide" "")
("make floating" "")
("make footnote wide" "")
("make fraction" "")
("make grave" "")
("make hat" "")
("make label" "")
("make link" "")
("make negation" "")
("make non floating" "")
("make opaque" "")
("make page reference" "")
("make reference" "")
("make slides" "")
("make square root" "")
("make tilde" "")
("make title" "")
("make transparent" "")
("make vector" "")
("make wide" "")
("making donations" "")
("manila paper" "")
("manila-paper" "")
("manual" "")
("manual path" "")
("map arguments" "")
("map to" "")
("march" "")
("marginal note" "")
("margins" "")
("margins as on paper" "")
("margins from width" "")
("margins on paper" "")
("margins on screen" "")
("marked" "")
("marker" "")
("master" "")
("master file" "")
("material" "")
("math" "")
("math Extra" "")
("math Letters" "")
("math Symbols" "")
("math font" "")
("math font family" "")
("math font series" "")
("math font shape" "")
("mathematical" "")
("mathematical and customized input" "")
("mathematical font" "")
("mathematical formulas" "")
("mathematical input" "")
("mathematical output" "")
("mathematical typesetting" "")
("mathematics" "")
("matrices" "")
("matrix" "")
("matrix factorization" "")
("maximal" "")
("maximal cell height" "")
("maximal clustering" "")
("maximal number of columns" "")
("maximal number of rows" "")
("maximal table height" "")
("maximal table width" "")
("maximum" "")
("maximum mode" "")
("may" "")
("meander" "")
("medieval" "")
("medium" "")
("medium skip" "")
("meminfo" "")
("memory" "")
("memory usage" "")
("menu" "")
("merge" "")
("merge lines into paragraphs unless separated by blank lines" "")
("messages" "")
("messy" "")
("meta data" "")
("meta key" "")
("metadata" "")
("metal" "")
("middle" "")
("middle baseline" "")
("minimal" "")
("minimal cell height" "")
("minimal cell width" "")
("minimal line separation" "")
("minimal number of columns" "")
("minimal number of rows" "")
("minimal table height" "")
("minimal table width" "")
("minimum" "")
("minimum mode" "")
("minus" "")
("mirror" "")
("miscellaneous" "")
("miscellaneous features" "")
("miscellanous" "")
("mixed" "")
("mod" "")
("mode" "")
("mode dependent icons" "")
("modifier" "")
("modify bibliography" "")
("modify cell alignment" "")
("modify cell border" "")
("modify cell padding" "")
("modify cell size" "")
("modify remote live document" "")
("modify table border" "")
("modify table padding" "")
("module" "")
("module browser" "")
("mongolian" "")
("monospaced" "")
("month" "")
("more information about GNU TeXmacs can be found in the Help" "")
("more information about GNU TeXmacs can be found in the Help->About menu" "")
("more information about GNU TeXmacs can be found in the help" "")
("mosaic" "")
("motion" "")
("motion blur" "")
("mouse over balloon" "")
("mouse over object" "")
("move" "")
("move down" "")
("move object" "")
("move objects" "")
("move over object on which to operate" "")
("move to the right when finished" "")
("move up" "")
("move::difference" "")
("move::similar" "")
("multiline" "")
("multiline input" "")
("multiple choice" "")
("multiple documents share window" "")
("multiple root" "")
("multiplication" "")
("mutator tags" "")
("my bibliographic database" "")
("my documents" "")
("n-th" "")
("n-th root" "")
("name" "")
("name of bibliography" "")
("name of glossary" "")
("name of index" "")
("name of list of figures" "")
("name of list of tables" "")
("name of table of contents" "")
("named" "")
("navigation options" "")
("negation" "")
("never" "")
("new" "")
("new account" "")
("new bibliography dialogue" "")
("new buffer" "")
("new column" "")
("new context macro" "")
("new document" "")
("new double page" "")
("new double page before" "")
("new entry" "")
("new identity" "")
("new item" "")
("new line" "")
("new locus" "")
("new macro" "")
("new number" "")
("new page" "")
("new page before" "")
("new paragraph" "")
("new passphrase" "")
("new remote directory" "")
("new remote file" "")
("new roman" "")
("new row" "")
("new style fonts" "")
("new style page breaking" "")
("new table" "")
("new table macro" "")
("new version" "")
("new window" "")
("newer version" "")
("next" "")
("next chunk" "")
("next difference" "")
("next error" "")
("next field" "")
("next line" "")
("next occurrence" "")
("next screen" "")
("next similar" "")
("no" "")
("no animation" "")
("no changes need to be saved" "")
("no clustering" "")
("no completions" "")
("no dictionary for" "")
("no errors have been corrected" "")
("no first indentation" "")
("no grid" "")
("no indentation" "")
("no line break" "")
("no matches found" "")
("no matches found for" "")
("no more matches for" "")
("no more redo information available" "")
("no more undo information available" "")
("no multiple spaces" "")
("no name" "")
("no new public key in document" "")
("no page break" "")
("no page break after" "")
("no page break before" "")
("no page numbers" "")
("no parent" "")
("no selection" "")
("no spelling errors" "")
("no spelling errors found in text" "")
("no spurious spaces" "")
("no style" "")
("none" "")
("normal" "")
("normal loci" "")
("normal size" "")
("norwegian" "")
("not" "")
("not allowed to remove home directory" "")
("not connected to server" "")
("not equal" "")
("not found" "")
("not yet implemented" "")
("notation" "")
("notations" "")
("note" "")
("notebook" "")
("notes" "")
("november" "")
("number" "")
("number equation" "")
("number of columns" "")
("number of polar steps" "")
("number of subunit steps" "")
("numbered" "")
("numbered equation" "")
("numbered equations" "")
("numbering" "")
("numerator" "")
("numeric" "")
("numeric analysis" "")
("numeric comma table" "")
("numeric dot table" "")
("numeric spreadsheet" "")
("objectives" "")
("oblique" "")
("occurrences" "")
("october" "")
("odd page" "")
("odd page footer" "")
("odd page header" "")
("odd page left margin" "")
("odd page margin" "")
("odd page right margin" "")
("odd page shift" "")
("odd page text" "")
("odd pages" "")
("of fingerprint" "")
("off" "")
("ok" "")
("old english" "")
("old slavonic" "")
("old style" "")
("old version" "")
("older version" "")
("on" "")
("on cells" "")
("on columns" "")
("on entire table" "")
("on rows" "")
("on the footer" "")
("on your system and set it up from the \"Security\" tab" "")
("once" "")
("one column" "")
("one error has been corrected" "")
("one lower case letter, one non alpha-numeric symbol" "")
("one numeric character, one upper case letter" "")
("one spelling error has been corrected" "")
("online documentation" "")
("online help" "")
("only convert changes when re-importing" "")
("only convert changes with respect to imported version" "")
("only convert changes with respect to tracked version" "")
("only implemented for complete subtrees" "")
("only inline tags" "")
("only keep folded" "")
("only keep unfolded" "")
("only show paragraphs with hits" "")
("only show semantic focus" "")
("opacity" "")
("open" "")
("open a new buffer" "")
("open bibliography" "")
("open identities" "")
("open in new window" "")
("open key manager" "")
("open licence agreement" "")
("open mailbox" "")
("open module browser" "")
("open new window" "")
("open on errors" "")
("open on warnings" "")
("open symbol browser" "")
("open tool in separate window" "")
("opening" "")
("operation mode" "")
("operation on named selection" "")
("operation on primary selection" "")
("operation on secondary selection" "")
("operation on ternary selection" "")
("optical" "")
("option" "")
("options" "")
("or" "")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "")
("orange" "")
("order" "")
("ordinary symbol" "")
("orientation" "")
("origin" "")
("original welcome message" "")
("ornamented" "")
("other" "")
("other login" "")
("other package" "")
("other pages" "")
("other projects" "")
("other style" "")
("outer" "")
("outer bottom" "")
("outer left" "")
("outer right" "")
("outer top" "")
("outline" "")
("outlined" "")
("outlined emboss" "")
("outlined engrave" "")
("outlined roman" "")
("output" "")
("output options" "")
("outwards" "")
("oval" "")
("oval blur" "")
("over" "")
("overbrace" "")
("overlap" "")
("overlay" "")
("overlay mode" "")
("overlays" "")
("overline" "")
("overlined" "")
("overview of the scheme extension language" "")
("padded" "")
("padding" "")
("padding above" "")
("padding below" "")
("page" "")
("page background" "")
("page bottom margin" "")
("page break" "")
("page break after" "")
("page break before" "")
("page breaking algorithm" "")
("page format" "")
("page height" "")
("page insertion" "")
("page layout" "")
("page number" "")
("page number rendering" "")
("page number text" "")
("page numbering" "")
("page reference" "")
("page rendering" "")
("page right margin" "")
("page setup" "")
("page top margin" "")
("page type" "")
("page width" "")
("pagedown" "")
("pages" "")
("pageup" "")
("pale-blue" "")
("palette" "")
("panorama" "")
("paper" "")
("paper size" "")
("paper type" "")
("papyrus" "")
("paragraph" "")
("paragraph format" "")
("paragraph mode" "")
("paragraph width" "")
("paragraph::section" "")
("paragraphs" "")
("parametric curve" "")
("parametric surface" "")
("parchment" "")
("parenthesis" "")
("parenthesized" "")
("parser" "")
("part" "")
("particle" "")
("passphrase decryption" "")
("passphrase encryption" "")
("passphrase wallet facilities are not currently available" "")
("passphrases are expected to have at least: 8 characters" "")
("passphrases mismatch" "")
("password" "")
("past changes" "")
("paste" "")
("paste from" "")
("paste text" "")
("pastel" "")
("path" "")
("pattern" "")
("pattern selector" "")
("pause" "")
("pdf version number" "")
("pen" "")
("pen width" "")
("perform operations on cells" "")
("perform operations on columns" "")
("perform operations on entire table" "")
("perform operations on rows" "")
("permanent" "")
("permanent footer" "")
("permanent header" "")
("permanently add to dictionary" "")
("permanently insert into dictionary" "")
("permissions" "")
("person" "")
("personal dictionary has been modified" "")
("phantasy" "")
("phantom" "")
("phantoms" "")
("philosophy" "")
("phoenician" "")
("phonetic" "")
("physics and astronomy class" "")
("picture" "")
("pine" "")
("pink" "")
("plain" "")
("plain block" "")
("plain boxes" "")
("plain circles" "")
("plain tabular" "")
("planned changes" "")
("plans for the future" "")
("play" "")
("play all animations" "")
("play animation" "")
("please" "")
("please install GnuPG software from https://www.gnupg.org" "")
("please wait" "")
("plot" "")
("plots editor" "")
("plug-ins" "")
("plugin" "")
("plugins" "")
("plural" "")
("plus" "")
("point" "")
("point border" "")
("point size" "")
("point style" "")
("polar" "")
("polish" "")
("polygon" "")
("polynomial arithmetic" "")
("pop server settings" "")
("porting TeXmacs to other platforms" "")
("portion" "")
("portrait" "")
("portuguese" "")
("position" "")
("position float" "")
("position floating object" "")
("position of marginal note" "")
("position the table" "")
("poster" "")
("poster formats" "")
("poster theme" "")
("postfix" "")
("postscript" "")
("postscript image" "")
("pre-alpha release" "")
("preamble" "")
("preamble mode" "")
("preferences" "")
("preferences for editing mathematical formulas" "")
("preferences for tag" "")
("prefix" "")
("prefix by section number" "")
("presentation" "")
("presentation mode" "")
("presentation tag" "")
("presentation tool" "")
("preserve" "")
("preserve tags" "")
("preserving syntactic correctness while editing mathematical formulas" "")
("pretty" "")
("pretty scheme tree output" "")
("pretty tree output" "")
("preview" "")
("preview before printing" "")
("preview command" "")
("preview with ghostview" "")
("previous" "")
("previous difference" "")
("previous error" "")
("previous field" "")
("previous occurrence" "")
("previous screen" "")
("previous similar" "")
("primary" "")
("prime" "")
("primitive or macro" "")
("print" "")
("print all" "")
("print all to file" "")
("print buffer" "")
("print buffer to file" "")
("print document" "")
("print page selection" "")
("print page selection to file" "")
("print to file" "")
("print to postscript file" "")
("printer" "")
("printer dpi" "")
("printer setup" "")
("printing command" "")
("problem" "")
("problems" "")
("proceed" "")
("produce Pdf using native export filter" "")
("produce Postscript using native export filter" "")
("professional" "")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "")
("program bracket matching" "")
("program bracket selections" "")
("program commands" "")
("program font" "")
("program interface for buffer management" "")
("program mode" "")
("programming" "")
("programming routines for editing documents" "")
("progressive" "")
("project" "")
("projector" "")
("projects" "")
("prologue" "")
("prominent" "")
("prompt on scripts" "")
("prompts and default input" "")
("proof" "")
("proofs" "")
("properties" "")
("proportional" "")
("proportional typewriter" "")
("property" "")
("proposition" "")
("propositions" "")
("provoke C++ error" "")
("provoke menu error" "")
("provoke scheme error" "")
("pseudo code" "")
("public key encryption" "")
("public keys" "")
("pulse" "")
("qt GUI only, sorry. Use \"Export selection\"" "")
("qt-widgets" "")
("quadratic forms" "")
("quantifier" "")
("quasi" "")
("query replace" "")
("question" "")
("questions" "")
("questions only" "")
("questions with answers" "")
("quick evaluation of formulas" "")
("quit" "")
("quotation" "")
("quote" "")
("radius" "")
("radius x" "")
("radius y" "")
("range" "")
("rank" "")
("raw" "")
("real" "")
("really close it" "")
("really delete user identity" "")
("really huge" "")
("really quit" "")
("really tiny" "")
("rebuild translations file" "")
("recent" "")
("recent documents" "")
("recipients" "")
("recognize" "")
("recolor" "")
("recover autosave file" "")
("rectangle" "")
("rectangular" "")
("red" "")
("reddish" "")
("redo" "")
("redo undone changes" "")
("reduce" "")
("reduce bottom margin by" "")
("reduce by" "")
("reduce left margin by" "")
("reduce margins" "")
("reduce right margin by" "")
("reduce top margin by" "")
("reduce trigonometric functions" "")
("reduced margins" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "")
("reference guide" "")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("reference to note" "")
("references" "")
("regenerate" "")
("register" "")
("register file" "")
("regular" "")
("relate" "")
("relation" "")
("release" "")
("release left button: finish editing" "")
("reload" "")
("remark" "")
("remarks" "")
("remote" "")
("remote connections" "")
("remote control" "")
("remote controllers with keyboard simulation" "")
("remote directory" "")
("remote login" "")
("remote plug-ins" "")
("remote servers" "")
("remote tool" "")
("remove" "")
("remove all output fields" "")
("remove animation" "")
("remove argument after" "")
("remove argument before" "")
("remove banner" "")
("remove database entry" "")
("remove downwards" "")
("remove entries" "")
("remove entry" "")
("remove field above" "")
("remove field below" "")
("remove fields" "")
("remove folded" "")
("remove from previous frames" "")
("remove from subsequent frames" "")
("remove input field" "")
("remove input field above" "")
("remove last field" "")
("remove leftwards" "")
("remove link" "")
("remove next field" "")
("remove number" "")
("remove overlay after" "")
("remove overlay before" "")
("remove package" "")
("remove previous field" "")
("remove remote ssh connection" "")
("remove rightwards" "")
("remove selected database entries" "")
("remove selected entries" "")
("remove slide after" "")
("remove slide before" "")
("remove superfluous invisible operators" "")
("remove tag" "")
("remove this branch" "")
("remove this frame" "")
("remove this switch" "")
("remove unfolded" "")
("remove upwards" "")
("removed entries from database" "")
("removed entry from database" "")
("rename" "")
("rename section" "")
("rendering" "")
("rendering options for tag" "")
("renumber this page" "")
("repeat" "")
("repeat object" "")
("replace" "")
("replace TeXmacs styles with no LaTeX equivalents" "")
("replace all further occurrences" "")
("replace by" "")
("replace one occurrence" "")
("replace toolbar" "")
("replace unrecognized styles" "")
("replaced" "")
("replaced one occurrence" "")
("research papers" "")
("reset" "")
("reset error counters" "")
("resize" "")
("resize object" "")
("resize objects" "")
("resized" "")
("restart TeXmacs in order to let changes take effect" "")
("restart in order to let the new look and feel take effect" "")
("retain" "")
("retime" "")
("retina settings" "")
("retrieve email" "")
("retrieve remote live document" "")
("retrieved contents" "")
("retro" "")
("return" "")
("reverse" "")
("reverse ordering" "")
("revert" "")
("revert buffer" "")
("rewriting" "")
("ridged paper" "")
("ridged-paper" "")
("right" "")
("right aligned" "")
("right arrow" "")
("right baseline" "")
("right border" "")
("right cell border" "")
("right cell padding" "")
("right down" "")
("right margin" "")
("right on even pages" "")
("right padding" "")
("right subscript" "")
("right superscript" "")
("right surrounding" "")
("right table border" "")
("right table padding" "")
("right up" "")
("rightwards" "")
("rigid" "")
("rigid box" "")
("rigid horizontal" "")
("rigid space" "")
("ring binder notebook style" "")
("romanian" "")
("root" "")
("rotate" "")
("rotate backward" "")
("rotate forward" "")
("rotate objects" "")
("rough" "")
("rough paper" "")
("rough-paper" "")
("round" "")
("round overbrace" "")
("round underbrace" "")
("rounded" "")
("row" "")
("row above" "")
("row below" "")
("row contains glued items" "")
("rows" "")
("run" "")
("run current file" "")
("runic" "")
("running author" "")
("running title" "")
("russian" "")
("same names" "")
("same screen margins as on paper" "")
("sample" "")
("sample text" "")
("sans serif" "")
("save" "")
("save TeXmacs file" "")
("save TeXmacs style file" "")
("save all embedded images" "")
("save as" "")
("save as LaTeX" "")
("save as TeX" "")
("save auxiliary data" "")
("save buffer" "")
("save buffer as" "")
("save entries" "")
("save entry" "")
("save file" "")
("save html file" "")
("save image" "")
("save image as" "")
("save latex file" "")
("save position" "")
("save remote file" "")
("save tex file" "")
("save this buffer" "")
("save verbatim file" "")
("saved" "")
("saved modifications in database" "")
("scale of the graphical user interface" "")
("scale graphical interface" "")
("scheme command" "")
("scheme developers guide" "")
("scheme extensions" "")
("scheme interface for the graphical mode" "")
("screen" "")
("screen layout" "")
("screen margins" "")
("screen rendering" "")
("screens" "")
("screenshot" "")
("script" "")
("script above" "")
("script below" "")
("script script size" "")
("script size" "")
("scripting language" "")
("scripts" "")
("scripts not accepted" "")
("search" "")
("search and replace" "")
("search in database" "")
("search results for" "")
("search toolbar" "")
("search words in my documents" "")
("search words in the documentation" "")
("search words in the source code" "")
("searching" "")
("second" "")
("secondary" "")
("secret keys" "")
("section" "")
("sections" "")
("security" "")
("see" "")
("see documentation" "")
("select GnuPG recipients" "")
("select a document style" "")
("select a foreground color" "")
("select a language" "")
("select background picture" "")
("select color" "")
("select document style" "")
("select pen" "")
("select the action to be undertaken for each conflict" "")
("select view mode" "")
("selected region" "")
("selection" "")
("selections" "")
("semantic correctness" "")
("semantic editing" "")
("semantic selections" "")
("semantics" "")
("seminar" "")
("sending commands to TeXmacs" "")
("senior" "")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "")
("september" "")
("serb" "")
("series" "")
("series|right" "")
("serif" "")
("server" "")
("server licence agreement" "")
("session" "")
("session commands" "")
("session name" "")
("session type" "")
("sessions" "")
("set" "")
("set background color of cell" "")
("set cell mode" "")
("set default" "")
("set difference" "")
("set extension center" "")
("set height" "")
("set height of cell" "")
("set intersection" "")
("set margins" "")
("set n" "")
("set number of columns" "")
("set number of rows" "")
("set or get environment variables" "")
("set paragraph margins" "")
("set paragraph mode" "")
("set printer dpi" "")
("set printing command" "")
("set properties" "")
("set span" "")
("set special cell properties" "")
("set special table properties" "")
("set text width" "")
("set union" "")
("set user information" "")
("set width" "")
("set width of cell" "")
("settings" "")
("setup printer" "")
("seventh" "")
("several equations" "")
("shadow" "")
("shadowed" "")
("shadowed raise" "")
("shape" "")
("sharpness" "")
("shift" "")
("shift-down" "")
("shift-right" "")
("shift::keyboard" "")
("short" "")
("shortcut" "")
("show" "")
("show all parts" "")
("show current focus" "")
("show full context" "")
("show grid" "")
("show header and footer" "")
("show hidden" "")
("show key presses" "")
("show main document" "")
("show memory usage" "")
("show on screen" "")
("show one part" "")
("show panorama" "")
("show preamble" "")
("show several parts" "")
("show subunits" "")
("show table cells" "")
("show timings" "")
("shrinking factor" "")
("side tools" "")
("signature" "")
("simple" "")
("simple form" "")
("simple widget" "")
("simplification" "")
("simplified evaluation of formulas" "")
("simplified menus" "")
("simplify" "")
("sine" "")
("sine and cosine" "")
("sixth" "")
("size" "")
("size limits" "")
("size tag" "")
("skew" "")
("skin" "")
("skip all" "")
("slant" "")
("slanted" "")
("slashed fraction" "")
("slide" "")
("slides" "")
("sloppy" "")
("slovak" "")
("slovene" "")
("slow" "")
("slow decrease" "")
("slow increase" "")
("small" "")
("small Capitals" "")
("small capitals" "")
("small caps" "")
("small environment box" "")
("small figure" "")
("small focus" "")
("small inline" "")
("small inline fraction" "")
("small skip" "")
("small table" "")
("smash" "")
("smooth" "")
("smooth end" "")
("smooth extremities" "")
("smooth start" "")
("snap" "")
("snap distance" "")
("snap to curves" "")
("snap to grid" "")
("snap to grid curve" "")
("snap to intersections of curves" "")
("snap to pages" "")
("snap to text borders" "")
("snap to text corners" "")
("solution" "")
("solution to exercise" "")
("solution to problem" "")
("solutions" "")
("solve" "")
("solve in" "")
("solving equations" "")
("sound" "")
("source" "")
("source code" "")
("source directory" "")
("source macros tool" "")
("source tags" "")
("south" "")
("south east" "")
("space" "")
("space bar in math mode" "")
("space bar in text mode" "")
("space between lines" "")
("space between paragraphs" "")
("space stretchability" "")
("spacing" "")
("span" "")
("span over all columns" "")
("spanish" "")
("special" "")
("special cell properties" "")
("special cell properties and actions" "")
("special functions" "")
("special properties" "")
("special table properties" "")
("specific" "")
("specific baseline" "")
("specified" "")
("specify color alternation" "")
("specify how to traverse the manual" "")
("specify semantics of a symbol or formula" "")
("specify the size of the table" "")
("specify user identity" "")
("spell" "")
("spell check" "")
("spell checking complete" "")
("spelling error" "")
("spelling errors have been corrected" "")
("spline" "")
("split" "")
("split program" "")
("split session" "")
("square" "")
("square overbrace" "")
("square root" "")
("square underbrace" "")
("stack" "")
("standard" "")
("standard Output" "")
("standard TeXmacs styles" "")
("standard environment variables" "")
("standard formats" "")
("standard fraction" "")
("star" "")
("start" "")
("start a new chapter" "")
("start a new section" "")
("start an interactive session" "")
("start remote session" "")
("start server" "")
("statement" "")
("statistics" "")
("status" "")
("status bar" "")
("stop server" "")
("storage" "")
("store tracking information in LaTeX files" "")
("strength" "")
("stretch" "")
("stretch factor" "")
("stretchable" "")
("stretchable horizontal" "")
("stretchable vertical" "")
("stretched" "")
("strict Ascii" "")
("strike through" "")
("string" "")
("stroke" "")
("strokes" "")
("strong" "")
("structural" "")
("structured insert above" "")
("structured insert at the left" "")
("structured insert at the right" "")
("structured insert below" "")
("structured remove downwards" "")
("structured remove leftwards" "")
("structured remove rightwards" "")
("structured remove upwards" "")
("structured variant" "")
("style" "")
("style options" "")
("style parameters" "")
("styles" "")
("stylesheet language" "")
("sub" "")
("subject" "")
("submenu" "")
("subparagraph" "")
("subparagraphs" "")
("subscript" "")
("subscript below" "")
("subsection" "")
("subsections" "")
("subsub" "")
("subsubmenu" "")
("subsubsection" "")
("subsubsections" "")
("subsubsubmenu" "")
("subsubsubsubmenu" "")
("subtable" "")
("subtitle" "")
("subtraction" "")
("summarized" "")
("summary" "")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "")
("superscript above" "")
("supported plug-ins" "")
("surface" "")
("surveys" "")
("swedish" "")
("swiss" "")
("switch" "")
("switch to buffer" "")
("switch to first" "")
("switch to formula style" "")
("switch to last" "")
("switch to next" "")
("switch to previous" "")
("switching and folding" "")
("symbol" "")
("symbol browser" "")
("symbol properties not found" "")
("symbols" "")
("synchronization status" "")
("synchronize" "")
("synchronize bibliographic references" "")
("synchronize file or directory" "")
("synchronize with remote server" "")
("synopsis" "")
("system command" "")
("system environment variables" "")
("tab-completion" "")
("tabbed" "")
("table" "")
("table breaking" "")
("table command" "")
("table height" "")
("table of contents" "")
("table properties" "")
("table width" "")
("tables" "")
("tabular" "")
("tabular material" "")
("tag" "")
("tags with special rendering" "")
("taiwanese" "")
("tangent" "")
("target" "")
("teXmacs DTD" "")
("teXmacs as an interface" "")
("teXmacs buffer expected" "")
("teXmacs buffer on disk expected" "")
("teXmacs database preferences" "")
("teXmacs extensions to scheme and utilities" "")
("teXmacs fonts" "")
("teXmacs macro" "")
("teXmacs manual" "")
("teXmacs notice" "")
("teXmacs package" "")
("teXmacs plugins" "")
("teXmacs primitives" "")
("teXmacs style" "")
("teXmacs style files" "")
("teXmacs website" "")
("teXmacs-related work" "")
("ternary" "")
("test" "")
("test routine" "")
("testing tree-view" "")
("tex" "")
("text" "")
("text borders" "")
("text box style" "")
("text corners" "")
("text font" "")
("text for note" "")
("text height correction" "")
("text padding" "")
("text width" "")
("texts" "")
("textual" "")
("textual operator" "")
("textual spreadsheet" "")
("textual table" "")
("th century bc" "")
("th root" "")
("thai" "")
("the TeXmacs authors" "")
("the TeXmacs format" "")
("the TeXmacs plug-in system" "")
("the application did not send its usual startup banner" "")
("the application does not reply" "")
("the application is already running" "")
("the boxes produced by the typesetter" "")
("the buffer has not been saved" "")
("the document has not been saved" "")
("the graphical user interface" "")
("the leaves of TeXmacs trees" "")
("the mycas example" "")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "")
("theme" "")
("theme parameters" "")
("theorem" "")
("theorems" "")
("there are unsaved documents" "")
("there are unsaved files" "")
("these collected public keys will be definitely lost" "")
("these public keys will be definitely lost" "")
("these secret keys will be definitely lost" "")
("thicken" "")
("thickness" "")
("thin" "")
("third" "")
("this" "")
("this article has been written using" "")
("this buffer has not been saved" "")
("this column" "")
("this document has been produced using" "")
("this document has been written using" "")
("this document has not been saved" "")
("this line" "")
("this page" "")
("this page footer" "")
("this page header" "")
("this page number" "")
("this row" "")
("this style specifies page margins in the TeX way" "")
("three columns" "")
("three dots" "")
("three times" "")
("threshold" "")
("through popup windows" "")
("through the menus" "")
("thumbnails" "")
("tilda" "")
("tilde" "")
("time evolution" "")
("times" "")
("timings" "")
("tiny" "")
("title" "")
("title presentation options" "")
("title style" "")
("title suffix" "")
("titled block" "")
("to the left" "")
("to the right" "")
("today" "")
("toggle cell wrapping mode" "")
("toggle here" "")
("toggle name" "")
("toggle numbering" "")
("toggle off" "")
("toggle on" "")
("toggle specification" "")
("toggle titled" "")
("tolerant" "")
("tools" "")
("top" "")
("top baseline" "")
("top border" "")
("top cell border" "")
("top cell padding" "")
("top level" "")
("top margin" "")
("top padding" "")
("top table border" "")
("top table padding" "")
("topless title" "")
("transform" "")
("transform cell into subtable" "")
("transformations" "")
("translate" "")
("translate::language" "")
("translations" "")
("translations loaded" "")
("transpose" "")
("traversal" "")
("traverse" "")
("tree" "")
("triangle" "")
("triangular list items" "")
("triangularize" "")
("trigonometric" "")
("trigonometric functions" "")
("trigonometry" "")
("try to import formulas using LaTeX annotations" "")
("tuple" "")
("turkish" "")
("turn off" "")
("turn on" "")
("turn on wallet" "")
("tutorial" "")
("tutorials" "")
("twice" "")
("two columns" "")
("two dots" "")
("type" "")
("type a LaTeX command followed by" "")
("type a latex command followed by" "")
("type a latex command followed by return" "")
("type body" "")
("type denominator" "")
("type numerator" "")
("type script" "")
("typesetted boxes" "")
("typewriter" "")
("typewriter small caps" "")
("typing a simple text" "")
("typing simple texts" "")
("uTF-8 with inputenc LaTeX package" "")
("ugaritic" "")
("ukrainian" "")
("ultra compact" "")
("unchanged" "")
("underbrace" "")
("underline" "")
("underlined" "")
("undo" "")
("undo last changes" "")
("unevaluated argument" "")
("unevaluated value" "")
("unextended" "")
("unfold" "")
("unfold all" "")
("unfold all fields" "")
("unfolded" "")
("ungroup" "")
("unit" "")
("unit length" "")
("unknown secret key fingerprint" "")
("unpublished" "")
("unregistered file" "")
("unroll" "")
("unsecure script refused" "")
("unsupported link mode" "")
("until" "")
("untitled block" "")
("up" "")
("up to date" "")
("update" "")
("update buffer" "")
("update from web" "")
("update image links" "")
("update remote ssh connection" "")
("update this buffer" "")
("update web site" "")
("upgrade" "")
("upight" "")
("upload" "")
("upload file or directory" "")
("upper border" "")
("upright" "")
("upwards" "")
("url" "")
("use CSS for more advanced formatting" "")
("use Inkscape for conversion from SVG" "")
("use MathML" "")
("use TeXmacs" "")
("use a black color" "")
("use a blue color" "")
("use a bold font" "")
("use a brown color" "")
("use a calligraphic font" "")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use as master" "")
("use blackboard bold font" "")
("use bold font series" "")
("use calligraphical font" "")
("use custom note symbol" "")
("use extensible brackets" "")
("use footnote font size" "")
("use fraktur font" "")
("use high resolution fonts" "")
("use high resolution icons" "")
("use huge font size" "")
("use italic font shape" "")
("use large font size" "")
("use left hand column as border" "")
("use line wrapping for lines which are longer than 80 characters" "")
("use margin kerning (protrusion)" "")
("use medium font series" "")
("use normal font size" "")
("use package" "")
("use paragraph width" "")
("use print dialogue" "")
("use protrusion" "")
("use really huge font size" "")
("use relative path" "")
("use retina fonts" "")
("use retina icons" "")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "")
("use row above as border" "")
("use row below as border" "")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "")
("use small font size" "")
("use small-caps font shape" "")
("use the blackboard bold font" "")
("use the fraktur font" "")
("use tiny font font size" "")
("use typewriter font family" "")
("use unified toolbars" "")
("use very large font size" "")
("user interface" "")
("user interface language" "")
("user interface theme" "")
("user manual" "")
("user preferences" "")
("user provided icons" "")
("users of Cyrillic languages" "")
("users of oriental languages" "")
("utf-8 with inputenc" "")
("utf-8 with inputenc LaTeX package" "")
("utilities" "")
("value" "")
("vanish" "")
("variable" "")
("variant" "")
("vector" "")
("verbatim" "")
("verbose" "")
("verse" "")
("version" "")
("versioning tool" "")
("vertical" "")
("vertical after" "")
("vertical alignment" "")
("vertical before" "")
("vertical cell alignment" "")
("vertical margins" "")
("vertical padding" "")
("vertical part" "")
("vertical position" "")
("vertical space" "")
("vertical space after" "")
("vertical space before" "")
("vertical space stretchability" "")
("vertical table alignment" "")
("vertically align cell to the base" "")
("vertically center the cell" "")
("very large" "")
("very small" "")
("vietnamese" "")
("view" "")
("visible" "")
("visible except here" "")
("visible from here on" "")
("visible only here" "")
("visible until here" "")
("visited color" "")
("visited loci" "")
("volume" "")
("wallet" "")
("warning" "")
("warnings" "")
("wave" "")
("wave length x" "")
("wave length y" "")
("web" "")
("weight" "")
("welcome" "")
("welcome to GNU TeXmacs" "")
("what is new" "")
("when finished" "")
("when line wrapping" "")
("when wrapping" "")
("while" "")
("white" "")
("whitespace" "")
("wide" "")
("wide accent" "")
("wide bar" "")
("wide block" "")
("wide colored" "")
("wide float" "")
("wide footnote" "")
("wide note" "")
("wide tabular" "")
("widescreen" "")
("width" "")
("width is exactly the specified width" "")
("width is maximum of specified width and box width" "")
("width is minimum of specified width and box width" "")
("width magnification" "")
("window" "")
("window height" "")
("window width" "")
("windows" "")
("windows key" "")
("with" "")
("with newer version" "")
("with older version" "")
("wood" "")
("word count" "")
("wrap lines" "")
("write a macro" "")
("write a name" "")
("write bold mathematics" "")
("write bold text" "")
("write italic text" "")
("write sample text" "")
("write strong text" "")
("write typewriter text" "")
("write verbatim text" "")
("writing TeXmacs bibliography styles" "")
("writing data converters" "")
("writing documentation" "")
("writing your own style files" "")
("written with TeXmacs" "")
("wrong empty passphrase" "")
("wrong passphrase" "")
("year" "")
("year, Name" "")
("yellow" "")
("yes" "")
("you are attempting to open an encrypted file while" "")
("you can also obtain" "")
("you might consider enabling the experimental" "")
("you must add a bibliography file" "")
("you should also make sure that GnuPG is installed" "")
("your document is back in its original state" "")
("your first interface" "")
("your language" "")
("your personal dictionary has been modified" "")
("zebra" "")
("zigzag" "")
("zoom" "")
("zoom factor" "")
("zoom in" "")
("zoom out" "")
("zoom/unzoom objects" "")
