("\"encryption\" features from the preference panel" "\"²ifriranje\" zna£ajke na preferencijskoj plo£i")
("a.C.M. computing class" "a.C.M. ra£unalna klasa")
("a.M.S. subject class" "ameri£ki razred predmeta")
("abbreviated authors" "skra¢enih autora")
("abreviated authors" "skra¢eni autori")
("accept during this pass" "prihvatiti za vrijeme ove propusnice")
("add abstract information" "dodavanje apstraktnih podataka")
("add branch after" "dodaj podruºnicu nakon")
("add branch before" "dodaj gran£icu prije")
("add other package" "dodaj drugi paket")
("addition" "dodatak")
("align cell to the decimal comma" "poravnati ¢eliju decimalnom zarezu")
("align cell to the decimal dot" "poravnati ¢eliju prema decimalnoj to£ki")
("align table at axis" "poravnavanje tablice prema osi")
("all data attached to this identity will be lost" "svi podaci vezani uz ovaj identitet bit ¢e izgubljeni")
("all saved passphrases will be lost forever" "sve spremljene lozinke zauvijek ¢e biti izgubljene")
("alternate except here" "alternativno, osim ovdje")
("alternate from here on" "naizmjence odavde")
("alternate only here" "naizmjence samo ovdje")
("alternate until here" "naizmjence do ovdje")
("and perform casual settings from the \"Encryption\" tab" "i izvr²ite povremene postavke s kartice \"²ifriranje\"")
("animate folding" "animirano savijanje")
("animate unfolding" "animirano odvijanje")
("animated" "animiranih")
("answer field" "polje odgovora")
("answer to question" "odgovor na pitanje")
("any" "bilo koji")
("are you sure you want to delete collected public keys" "ste sigurni da ºelite izbrisati prikupljene javne klju£eve")
("are you sure you want to delete selected public keys" "ste sigurni da ºelite izbrisati odabrane javne klju£eve")
("are you sure you want to delete selected secret keys" "ste sigurni da ºelite izbrisati odabrane tajne klju£eve")
("are you sure you want to destroy the wallet" "ste sigurni da ºelite uni²titi nov£anik")
("arxiv category" "arxiv kategorija")
("as visual grid" "kao vizualna mreºa")
("auto-save file" "datoteka za automatsko spremanje")
("automatically remember all passphrases in the wallet" "automatski pamti sve lozinke u nov£aniku")
("beamer formats" "formata snopa")
("bench" "klupa")
("bezier" "bezier")
("binary operator" "binarni operator")
("bitmap resolution (dpi)" "rezolucija bitmape (dpi)")
("bottom tools" "najniºih alata")
("buffer must have a name" "meuspremnik mora imati naziv")
("build buffer" "meuspremnik")
("build buffer in" "ugradi meuspremnik")
("build directory" "graditi imenik")
("build directory in" "graditi imenik u")
("build-all" "sve izrade")
("cJK" "cJK")
("cancelled" "otkazano")
("cannot download directory to file" "ne mogu preuzeti direktorij u datoteku")
("cannot rename across different servers" "ne mogu preimenovati na razli£itim posluºiteljima")
("cannot upload directory to file" "ne mogu prenijeti direktorij u datoteku")
("change default unit" "promijeni zadanu jedinicu")
("change passphrase" "promijeni zaporku")
("change step-size" "promijenite veli£inu koraka")
("checkable field" "polje koje se moºe provjeriti")
("cipher algorithm for passphrase encryption" "²ifrirani algoritam za ²ifriranje zaporke")
("clean slate" "£istih ²kriljevca")
("clear local information" "jasne lokalne informacije")
("click Ok button twice to discard this warning" "dva puta kliknite gumb U redu da biste odbacili ovo upozorenje")
("close animation tool" "alat za zatvaranje animacije")
("close program" "zatvoriti program")
("close search tool" "zatvori alat za pretraºivanje")
("close spell tool" "zatvori pravopisni alat")
("close translations to rebuild" "zatvori prijevode za obnovu")
("collected keys" "sakupljeni klju£evi")
("column separation" "odvajanje stupaca")
("commit file" "datoteke za unos")
("common" "uobi£ajenih")
("commutative diagram" "komutacijski dijagram")
("complete bibliographic reference" "cjelovita bibliografska referenca")
("conceal" "prikrivanje")
("configure look and feel" "konfiguriranje izgleda i izgleda")
("confirm database entry" "potvrdi unos u bazu podataka")
("confirm selected database entries" "potvrdi odabrane unose u bazu podataka")
("confirm selected entries" "potvrdi odabrane unose")
("contextual hints" "kontekstualni savjeti")
("cork charset with TeX catcode definition in preamble" "plutasti ormar s TeX definicijom koda u preambuli")
("correct formula" "ispravna formula")
("correct manually" "ispravno ru£no")
("correction" "ispravak")
("create remote directory" "stvori udaljeni direktorij")
("create remote file" "stvori udaljenu datoteku")
("create subprogram" "stvori podprogram")
("creating new account" "stvaranje novog ra£una")
("crossed boxes" "prekriºenih kutija")
("crossed circles" "prekriºenih krugova")
("current user version" "trenutna korisni£ka verzija")
("custum tab" "kartica kartice")
("decomposed" "raspadnuto")
("decrypt" "de²ifriranje")
("delete entries" "brisanje unosa")
("destroy" "uni²titi")
("direction of progression" "smjer napredovanja")
("direction of translation" "smjer prijevoda")
("disable encryption" "onemogu¢i ²ifriranje")
("disappear" "nestati")
("dissociate joined cells" "disocirati pridruºene stanice")
("division" "divizija")
("dragging" "vu£enje")
("eRROR" "eRROR")
("edit animation" "ureivanje animacije")
("edit groups of objects" "ureivanje grupa objekata")
("effect pen" "olovka za efekt")
("eighth" "osma")
("encrypt" "²ifriranje")
("encryption facilities are not currently available" "ureaji za ²ifriranje trenutno nisu dostupni")
("encryption facilities have not been enabled for TeXmacs" "mogu¢nosti enkripcije nisu omogu¢ene za TeXmacs")
("enter graphics" "unesite grafiku")
("enter graphics mode" "uite u grafi£ki na£in")
("enter new passphrase for encryption" "unesite novu lozinku za ²ifriranje")
("enter passphrase for decryption" "unesite lozinku za de²ifriranje")
("enter passphrase for identity" "unesite lozinku za identitet")
("entry up to date in database" "dosada²nji unos u bazu podataka")
("error output" "izlaz pogre²ke")
("error: bracket does not match" "pogre²ka: nosa£ se ne podudara")
("error: cyclic or missing chunks detected" "pogre²ka: detektirani su cikli£ki ili nedostaju¢i dijelovi")
("error: file not found" "pogre²ka: datoteka nije pronaena")
("error: ghostview does not seem to be installed on your system" "pogre²ka: £ini se da ghostview nije instaliran na va² sustav")
("error: one of the alternatives should be filled out" "pogre²ka: treba ispuniti jednu od alternativa")
("error: only one alternatives should be filled out" "pogre²ka: treba ispuniti samo jednu opciju")
("error: should fill out name for referencing" "pogre²ka: treba ispuniti naziv za referencu")
("error: should fill out required field" "pogre²ka: treba popuniti obavezno polje")
("evaluate script" "procijeni skriptu")
("events" "dogaaja")
("execution of scripts" "izvr²avanje skripti")
("exit graphics" "izlazna grafika")
("explicit margins" "eksplicitne marºe")
("export bibliography" "izvozna bibliografija")
("export file" "izvozna datoteka")
("export selected entries" "izvoz odabranih unosa")
("export selection" "izbor izvoza")
("exported bibliographic entries" "izvezenih bibliografskih zapisa")
("exported bibliographic references" "izvezenih bibliografskih referenci")
("extra name" "dodatni naziv")
("fade in" "izblijediti")
("fade out" "izblijediti")
("fifth" "peta")
("file saved" "datoteka je spremljena")
("finished collecting symbols documentation" "gotova dokumentacija za prikupljanje simbola")
("first chunk" "prvi komad")
("first error" "prva pogre²ka")
("five columns" "pet stupaca")
("flag is off" "zastava je isklju£ena")
("flag is on" "zastava je uklju£ena")
("fold all" "presavi sve")
("font selector" "odabir slova")
("four columns" "£etiri stupca")
("fourth" "£etvrti")
("fraktur" "fraktur")
("from" "od")
("full" "puno")
("full author list" "puni popis autora")
("generated LaTeX document contains no errors" "generirani LaTeX dokument ne sadrºi pogre²ke")
("generated field" "generirano polje")
("get arity" "dobiti arity")
("get list with remote versions" "dobiti popis s udaljenim verzijama")
("gnuPG command" "naredba gnuPG")
("gnuPG error: buffer encryption failed" "gnuPG pogre²ka: ²ifriranje meuspremnika nije uspjelo")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG pogre²ka: ne mogu prona¢i odgovaraju¢i tajni klju£ za de²ifriranje")
("gnuPG requires name and email to have at least 5 characters" "gnuPG zahtijeva da ime i e-po²ta sadrºe najmanje 5 znakova")
("go to anchor or float" "idi sidri se ili plutaj")
("go to footnote" "prijeite na fusnotu")
("grid-curve intersections" "raskriºja krivulje re²etke")
("group of objects" "grupa objekata")
("group/ungroup" "grupa / grupiranje")
("homoglyph substitutions" "homoglifne supstitucije")
("horizontal margins" "horizontalne margine")
("ignore" "zanemari")
("impact" "utjecaj")
("import bibliography" "uvezena bibliografija")
("import database entry" "unos baze podataka")
("import file" "datoteka za uvoz")
("import selected database entries" "uvoz odabranih unosa u bazu podataka")
("import selected entries" "uvoz odabranih unosa")
("imported bibliographic entries" "uvezenih bibliografskih zapisa")
("inanimated" "neºivi")
("incomplete entries found to be filled out" "utvreno je da nepotpuni unosi nisu ispunjeni")
("initialize" "inicijalizacija")
("ink in" "tinta u")
("ink out" "tinta van")
("inline content" "umetnuti sadrºaj")
("input command" "naredba za unos")
("insert a new entry" "ubaci novi unos")
("insert a section block" "umetnite odjeljak blok")
("insert abstract" "umetni saºetak")
("insert annotation" "umetnite napomenu")
("insert copyright and license information" "ubaci podatke o autorskim pravima i licenci")
("insert explanatory item" "umetnite obja²njenje")
("insert last name" "ubaci prezime")
("insert missing invisible operators" "umetnite nedostaju¢e nevidljive operatere")
("insert more names" "ubaci vi²e imena")
("insert particle" "umetni £esticu")
("insert similar above" "umetnite sli£no gore")
("insert similar below" "umetnite sli£no ispod")
("insert similar block above" "umetnite sli£an blok iznad")
("insert similar block below" "umetnite sli£an blok dolje")
("insert template" "umetni predloºak")
("insert title after name" "umetni naslov iza imena")
("insert user interface related markup" "umetnite oznaku vezanu za korisni£ko su£elje")
("inserting control points" "Umetanje kontrolnih to£aka")
("invalid multi-paragraph selection" "nevaºe¢i odabir vi²e odlomaka")
("invalid renaming" "nevaºe¢e preimenovanje")
("invisible ending" "nevidljivi zavr²etak")
("invisible newline" "nevidljivi novi redak")
("invisible opening" "nevidljivi otvor")
("junior" "mlai")
("keep local" "zadrºi lokalno")
("keep remote" "drºi na daljinu")
("last error" "zadnja pogre²ka")
("last name" "prezime")
("left click: add point; Right click: undo" "lijevi klik: dodaj to£ku; desni klik: poni²ti")
("left click: finish; Right click: undo" "lijevi klik: zavr²i; desni klik: poni²ti")
("left click: new object" "lijevi klik: novi objekt")
("left click: operate" "lijevi klik: djeluj")
("left down" "lijevo dolje")
("left up" "lijevo gore")
("left-right arrow" "strelica lijevo-desno")
("link image and copies as" "slika veze i kopira kao")
("link image as" "slika veze kao")
("live" "uºivo")
("live input-output" "live input-output")
("load help file" "u£itavanje datoteke pomo¢i")
("load remote file" "u£itavanje udaljene datoteke")
("loading" "utovarivanje")
("local entries" "lokalnih unosa")
("logging in" "prijava")
("logical and" "logi£no i")
("logical implication" "logi£ka implikacija")
("logical not" "logi£no nije")
("logical or" "logi£ki ili")
("logout" "odjava")
("macro definition" "makro definicija")
("macro name" "ime makronaredbe")
("make a letter environment" "stvaranje slova u okruºenju")
("make a multi-slide presentation" "izrada vi²esatne prezentacije")
("make link" "uspostavi vezu")
("margins from width" "margine od ²irine")
("mathematical output" "matemati£ki izlaz")
("mirror" "ogledalo")
("miscellanous" "razni")
("modify remote live document" "izmijeniti udaljeni dokument uºivo")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "")
("more information about GNU TeXmacs can be found in the Help-<less>gtr<gtr>About menu" "vi²e informacija o GNU TeXmacs moºete prona¢i u izborniku Pomo¢- <less>gtr<gtr> O meni")
("more information about GNU TeXmacs can be found in the help" "vi²e informacija o GNU TeXmacs moºete prona¢i u pomo¢i")
("mouse over object" "mi² preko objekta")
("move over object on which to operate" "prelazak preko objekta na kojem ¢e se raditi")
("multiplication" "mnoºenje")
("new identity" "novi identitet")
("new passphrase" "nova lozinka")
("new remote directory" "novi udaljeni direktorij")
("new remote file" "nova udaljena datoteka")
("newer version" "novija verzija")
("next chunk" "sljede¢i komad")
("next error" "sljede¢a pogre²ka")
("no completions" "bez dovr²etaka")
("no errors have been corrected" "pogre²ke nisu ispravljene")
("no new public key in document" "nema novog javnog klju£a u dokumentu")
("no parent" "nema roditelja")
("no selection" "nema izbora")
("not allowed to remove home directory" "nije dopu²teno uklanjanje ku¢nog imenika")
("not connected to server" "nije spojen na posluºitelj")
("numbering" "numeriranje")
("of fingerprint" "otiska prsta")
("older version" "starija verzija")
("on your system and set it up from the \"Security\" tab" "na va²em sustavu i podesite ga s kartice \"Sigurnost\"")
("one lower case letter, one non alpha-numeric symbol" "jedno malo slovo, jedan ne alfa-numeri£ki simbol")
("one numeric character, one upper case letter" "jedan numeri£ki znak, jedno veliko slovo")
("only implemented for complete subtrees" "implementirano samo za kompletne potpotrebe")
("open key manager" "upravitelj otvorenih klju£eva")
("open licence agreement" "otvoreni licen£ni ugovor")
("open mailbox" "otvoreni po²tanski sandu£i¢")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ili dajte cijeli put naredbi \"gpg\" ili \"gpg2\"")
("ordinary symbol" "obi£ni simbol")
("other login" "druga prijava")
("outlined" "ocrtano")
("overlap" "preklapanje")
("overlay" "prekrivanje")
("panorama" "panorama")
("parenthesis" "zagrade")
("parenthesized" "u zagradi")
("particle" "£estica")
("passphrase encryption" "²ifriranje zaporke")
("passphrase wallet facilities are not currently available" "ureaji za nov£anike s lozinkom nisu trenuta£no dostupni")
("passphrases are expected to have at least: 8 characters" "zaporke moraju imati najmanje: 8 znakova")
("passphrases mismatch" "neusklaenost lozinki")
("permanent footer" "trajno podnoºje")
("permanent header" "trajno zaglavlje")
("permanently add to dictionary" "trajno dodaj u rje£nik")
("permanently insert into dictionary" "trajno umetnuti u rje£nik")
("permissions" "dozvole")
("physics and astronomy class" "razred fizike i astronomije")
("plain boxes" "obi£nih kutija")
("plain circles" "obi£nih krugova")
("play animation" "reprodukcija animacije")
("please install GnuPG software from https://www.gnupg.org" "instalirajte GnuPG softver s https://www.gnupg.org")
("plural" "mnoºina")
("pop server settings" "postavke sko£nog posluºitelja")
("position of marginal note" "poloºaj rubne note")
("poster formats" "formata postera")
("postfix" "postfiks")
("pretty tree output" "lijep izlaz stabla")
("previous error" "prethodna pogre²ka")
("print to file" "ispis u datoteku")
("printer setup" "postavljanje pisa£a")
("program commands" "programske naredbe")
("provoke C++ error" "izaziva pogre²ku C ++")
("provoke menu error" "izaziva pogre²ku u izborniku")
("public key encryption" "²ifriranje javnog klju£a")
("public keys" "javnih klju£eva")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUI samo, oprostite. Upotrijebite \"Izvoz izbora\"")
("qt-widgets" "qt-widgeta")
("quantifier" "kvantifikator")
("quasi" "kvazi")
("really delete user identity" "stvarno izbrisati identitet korisnika")
("recipients" "primatelja")
("recognize" "prepoznati")
("regenerate" "regenerirati")
("register file" "registarska datoteka")
("relate" "srodnik")
("relation" "odnos")
("release left button: finish editing" "pu²tanje lijeve tipke: dovr²ite ureivanje")
("remote connections" "daljinske veze")
("remote directory" "udaljeni direktorij")
("remove database entry" "ukloni unos u bazu podataka")
("remove entries" "uklanjanje unosa")
("remove link" "ukloni vezu")
("remove selected database entries" "ukloni odabrane unose u bazu podataka")
("remove selected entries" "ukloni odabrane unose")
("remove superfluous invisible operators" "uklanjanje suvi²nih nevidljivih operatera")
("remove this branch" "ukloni ovu granu")
("removed entries from database" "uklonjeni unosi iz baze podataka")
("removed entry from database" "uklonjen unos iz baze podataka")
("rename section" "preimenovanje odjeljka")
("reset error counters" "resetiranje broja£a pogre²aka")
("restart in order to let the new look and feel take effect" "ponovno pokrenite kako bi novi izgled i osje¢aj dobio u£inak")
("retime" "retime")
("retina settings" "postavke mreºnice")
("retrieve email" "dohva¢anje e-po²te")
("retrieve remote live document" "dohva¢anje udaljenog dokumenta uºivo")
("retrieved contents" "dohva¢enih sadrºaja")
("reverse ordering" "obrnuto naru£ivanje")
("right down" "desno dolje")
("right up" "desno gore")
("round overbrace" "okrugla prekomorka")
("round underbrace" "okrugli podbradak")
("run current file" "pokretanje trenutne datoteke")
("same names" "istoimenih imena")
("save entries" "spremanje unosa")
("save entry" "spremite unos")
("save image as" "spremanje slike kao")
("save remote file" "spremanje udaljene datoteke")
("saved modifications in database" "spremljenih modifikacija u bazi podataka")
("second" "sekundi")
("secret keys" "tajni klju£evi")
("select the action to be undertaken for each conflict" "odaberite radnju koju treba poduzeti za svaki sukob")
("senior" "stariji")
("serif" "serif")
("set default" "postavi zadano")
("set difference" "postavljena razlika")
("set intersection" "postavljeno raskriºje")
("set union" "postavljena unija")
("seventh" "sedma")
("show main document" "prikaºi glavni dokument")
("sixth" "²esti")
("skip all" "presko£i sve")
("small capitals" "malih prijestolnica")
("solution to problem" "rje²enje problema")
("solutions" "rje²enja")
("span over all columns" "raspon preko svih stupaca")
("specify color alternation" "specificiranje izmjene boja")
("specify how to traverse the manual" "odredite kako prije¢i priru£nik")
("specify semantics of a symbol or formula" "navesti semantiku simbola ili formule")
("split program" "split program")
("square overbrace" "kvadratni prekriva£")
("square underbrace" "kvadratni podvod")
("stack" "stog")
("standard Output" "standardni izlaz")
("status" "statusa")
("stop server" "stop server")
("subtraction" "oduzimanje")
("switch to buffer" "prebaci se na meuspremnik")
("symbol properties not found" "svojstva simbola nisu pronaena")
("synchronize" "sinkroniziraj")
("synchronize bibliographic references" "sinkroniziranje bibliografskih referenci")
("synchronize with remote server" "sinkronizacija s udaljenim posluºiteljem")
("tab-completion" "dovr²avanje kartice")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "O£ekuje se meuspremnik TeXmacs")
("teXmacs buffer on disk expected" "O£ekuje se meuspremnik TeXmacs na disku")
("testing tree-view" "testiranje stabla")
("text box style" "stil polja teksta")
("textual" "tekstualna")
("th century bc" "stolje¢e prije Krista")
("these collected public keys will be definitely lost" "ovi prikupljeni javni klju£evi bit ¢e definitivno izgubljeni")
("these public keys will be definitely lost" "ovi javni klju£evi bit ¢e definitivno izgubljeni")
("these secret keys will be definitely lost" "ovi ¢e tajni klju£evi biti definitivno izgubljeni")
("third" "tre¢a")
("this" "ovo")
("this style specifies page margins in the TeX way" "ovaj stil odreuje margine stranice na na£in TeX")
("title suffix" "sufiks naslova")
("toggle here" "prebaci ovdje")
("toggle off" "isklju£ivanje")
("toggle on" "uklju£ivanje")
("translations loaded" "prijevoda je u£itanih")
("turn off" "isklju£i se")
("turn on" "uklju£i")
("type a latex command followed by return" "upi²ite lateks naredbu nakon £ega slijedi povratak")
("unfold all" "razvijte sve")
("unknown secret key fingerprint" "otisak nepoznatog tajnog klju£a")
("unregistered file" "neregistrirana datoteka")
("unsecure script refused" "odbijena nesigurna skripta")
("unsupported link mode" "nepodrºani na£in veze")
("until" "do")
("up to date" "aºurirano")
("update buffer" "meuspremnik aºuriranja")
("upight" "uspravno")
("upload" "prijenos")
("use protrusion" "koristi izbo£enje")
("use relative path" "koristi relativni put")
("utf-8 with inputenc LaTeX package" "utf-8 s paketom inputenc LaTeX")
("verbose" "verbose")
("vertical margins" "vertikalne margine")
("visible except here" "vidljivo osim ovdje")
("visible from here on" "vidljivo odavde")
("visible only here" "vidljivo samo ovdje")
("visible until here" "vidljivo do ovdje")
("wallet" "nov£anik")
("wide colored" "²iroko obojenih")
("wide float" "²iroki plovak")
("wide footnote" "²iroka fusnota")
("wrong empty passphrase" "kriva prazna lozinka")
("wrong passphrase" "pogre²na lozinka")
("you are attempting to open an encrypted file while" "poku²avate otvoriti ²ifriranu datoteku dok")
("you might consider enabling the experimental" "mogli biste razmotriti omogu¢avanje eksperimentalnog")
("you must add a bibliography file" "morate dodati bibliografsku datoteku")
("you should also make sure that GnuPG is installed" "takoer biste trebali biti sigurni da je GnuPG instaliran")
("your personal dictionary has been modified" "va² je osobni rje£nik promijenjen")
