("GNU" "GNU")
("LaTeX" "LaTeX")
("Remove fields" "entferne Felder")
("Save as LaTeX" "als LaTeX sichern")
("Save as TeX" "als TeX sichern")
("Split session" "die Sitzung aufteilen")
("Stop" "Ausführung abbrechen")
("Tab" "Tabulatorabstand")
("TeX" "TeX")
("a modifier" "A Modifikator")
("abbreviation" "Abkürzung")
("about" "über TeXmacs")
("about menu" "über Menü finden")
("above" "oben")
("abstract" "Zusammenfassung")
("accent" "Akzent")
("accept" "akzeptieren")
("accept all scripts" "alle Scripts akzeptieren")
("accept no scripts" "keine Scripts akzeptieren")
("accept script" "Script akzeptieren")
("acknowledgment" "Danksagung")
("acronym" "Akronym")
("action" "Aktion")
("activate" "aktivieren")
("activate once" "aktiviere die Wurzel")
("activation" "Aktivierung")
("acute" "nach rechts")
("add package" "Paket zufügen")
("add switch after" "Ebene danach einfügen")
("add switch before" "Ebene davor einfügen")
("address" "Adresse")
("address block" "Adressblock")
("advanced" "fortgeschritten")
("advanced layout features" "fortgeschrittene Layout-Eigenschaften")
("after" "nach")
("algorithm" "Algorithmus")
("align cell to the bottom" "Zelle nach unten ausrichten")
("align cell to the left" "Zelle nach links ausrichten")
("align cell to the right" "Zelle nach rechts ausrichten")
("align cell to the top" "Zelle nach oben ausrichten")
("align table at base of left column" "Tabelle an der Basislinie der linken Spalte ausrichten")
("align table at base of middle column" "Tabelle an der Basislinie der mittleren Spalte ausrichten")
("align table at base of origin column" "Tabelle an der Basislinie der Ursprungsspalte ausrichten")
("align table at base of right column" "Tabelle an Basislinie der rechten Spalte ausrichten")
("align table at fraction bar height" "Tabelle an der Höhe des Bruchstriches ausrichten")
("align table at the base of bottom row" "Tabelle an der Basislinie der untersten Reihe ausrichten")
("align table at the base of middle row" "Tabelle an der Basislinie der mittleren Reihe ausrichten")
("align table at the base of origin row" "Tabelle an der Basislinie der Ursprungsreihe ausrichten")
("align table at the base of top row" "Tabelle an der Basislinie der obersten Reihe ausrichten")
("align table at the bottom" "Tabelle nach unten ausrichten")
("align table at the center" "Tabelle an der Mitte ausrichten")
("align table at the horizontal center" "Tabelle an der horizontalen Mitte ausrichten")
("align table at the left" "Tabelle nach links ausrichten")
("align table at the top" "Tabelle nach oben ausrichten")
("align table to the right" "Tabelle nach rechts ausrichten")
("align text to the left" "Text linksbündig ausrichten")
("align text to the right" "Text rechtsbündig ausrichten")
("aligned" "rechtsbündig")
("alignment" "Ausrichtung")
("all" "alles")
("allow" "erlauben")
("allowed extension" "erlaubte Verlängerung")
("allowed reduction" "erlaubte Verkürzung")
("alpha release" "Alpha Version")
("alt key" "Alt-Taste")
("american" "amerikanisch")
("and" "und")
("angular" "spitze Klammern")
("answer" "Antwort")
("appendix" "Anhang")
("apply" "anwenden")
("april" "April")
("arab" "arabisch")
("archaic" "archaisch")
("architecture" "Architektur")
("argument" "Argument")
("arithmetic" "arithmetisch")
("armenian" "armenisch")
("arrow" "Pfeil")
("arrows" "Pfeile")
("article" "Artikel")
("as on paper" "wie auf dem Papier")
("assign" "ändern")
("at fraction bar height" "in der Höhe des Bruchstriches")
("at the baseline" "an der Basislinie")
("at the bottom" "an der Unterseite")
("at the left" "auf der linken Seite")
("at the middle" "in der Mitte")
("at the right" "auf der rechten Seite")
("at the top" "an der Oberseite")
("attach" "beifügen")
("attach buffer to which project" "Puffer an welches Project anbinden")
("august" "August")
("author" "Autor")
("authorize" "erlauben")
("automatic" "automatisch")
("automatic quotes" "Anführungszeichen")
("automatically close brackets" "Klammern automatisch schliessen")
("automatically generated content" "automatisch erzeugte Verzeichnisse")
("autosave" "automatisches Sichern")
("axiom" "Axiom")
("background" "Hintergrund")
("background color" "Hintergrundfarbe")
("background evaluations" "Berechnungen im Hintergrund")
("backward replace" "rückwärts ersetzen")
("backward search" "rückwärts suchen")
("bad data format" "falsches Dateiformat")
("bar" "Strich")
("bard" "bard")
("base level" "Grundniveau")
("baseline" "Basislinie")
("bashkirian" "bashkirisch")
("basic" "Basis")
("basic communication using pipes" "Ein- und Ausgabe über Pipelines, Grundlagen")
("basic data types" "grundlegende Datentypen")
("basic types" "Basistypen")
("be useful" "seien Sie nützlich")
("become a TeXmacs developer" "werde ein TeXmacs-Entwickler")
("before" "vor")
("begin" "Anfang")
("below" "unten")
("beta release" "Beta Version")
("bibliography" "Literaturverzeichnis")
("bibliography file" "Literaturverzeichnis-Datei")
("bibliography style" "Literaturverzeichnis-Stil")
("big" "groß")
("big figure" "große Abbildung")
("big operator" "großer Operator")
("big skip" "großer Abstand")
("big table" "große Tabelle")
("binary operation" "binäre Operation")
("binary relation" "binäre Beziehung")
("black" "schwarz")
("blackboard bold" "Blackboard fett")
("blackboard math" "Blackboard Math")
("blackletter" "schwarze Buchstaben")
("blue" "blau")
("body" "Körper")
("bold" "fett")
("book" "Buch")
("border" "sichtbarer Rand")
("both" "beide")
("bottom" "ganz unten")
("bottom border" "sichbarer unterer Rand")
("bottom margin" "unterer Abstand")
("bottom padding" "Padding unten")
("branch" "Ast")
("break" "Zeilenumbruch")
("breaking" "Umbruch")
("breve" "Breve")
("british" "britisch")
("brown" "braun")
("browsable version" "Browserversion")
("browse" "durchsuchen")
("browse web" "Internet durchsuchen")
("browser" "Browser")
("buffer" "Puffer")
("bullet" "Punkt")
("bullets" "Punkte")
("by" "von")
("by typing" "über Tastatur")
("bytes free" "Bytes frei")
("bytes used" "Bytes benutzt")
("calligraphic" "kalligraphisch")
("cancel" "abbrechen")
("caps lock key" "Hochstelltaste")
("case" "falls")
("cc" "Durchschlag")
("cell" "Zelle")
("cell background color" "Hintergrundfarbe")
("cell border" "Zellenumrandung")
("cell height" "Zellenhöhe")
("cell operation mode" "Zellenbearbeitungsmodus")
("cell width" "Zellenbreite")
("cells" "Zellen")
("center" "zentriert")
("center text" "Text zentrieren")
("centered" "zentriert")
("centered at fraction bar height" "auf Bruchlinienhöhe")
("centered block" "zentrierter Block")
("centered tabular" "zentrierter Tabulatormodus")
("change border of cell" "Zellenumrandung ändern")
("change cell operation mode" "Zellenbearbeitungsmodus ändern")
("change log" "Protokoll der Veränderungen")
("changes" "Änderungen")
("chapter" "Kapitel")
("check" "Haken")
("check text for spelling errors" "Text auf Schreibfehler überprüfen")
("chinese" "Chinesisch")
("choice" "Auswahl")
("citation" "Zitat")
("cite" "Zitat")
("class" "Klasse")
("clear" "Zwischenablage leeren")
("clear selection" "Auswahl löschen")
("clipped" "abgeschnitten")
("clipped and magnified" "abgeschnitten und vergrößert")
("clipped and resized" "abgeschnitten und gestreckt")
("clone" "klonen")
("clone window" "Fenster klonen")
("close" "schließen")
("close TeXmacs" "TeXmacs schließen")
("close buffer" "Puffer schließen")
("close session" "Sitzung schließen")
("close window" "Fenster schließen")
("closing" "Schlussformel")
("closing style" "Befehlsabschluss")
("code" "Quellcode")
("color" "Farbe")
("column" "Spalte")
("column contains glued items" "Spalte enthält verbundene Teile")
("column span" "horizontale Zellanzahl")
("columns" "Spalten")
("compact" "Dicht")
("compactification" "Verdichtungsgrad")
("compatibility with other formats" "Kompatibilität mit anderen Formaten")
("compile article" "Artikel kompilieren")
("compile book" "Buch kompilieren")
("compile buffer" "Puffer kompilieren")
("compile project" "Projekt kompilieren")
("completion" "Ergänzung")
("complex" "komplex")
("compound" "unbenanntes Makro")
("concrete" "concrete")
("condensed" "dicht")
("condition" "Bedingung")
("configuration" "Konfiguration")
("content" "Inhalt")
("content tag" "Inhaltliche Auszeichnung")
("context dependent icons" "Kontextabhängige Symbole")
("continuation of" "Fortsetzung von")
("control flow" "Ablaufsteuerung")
("convention" "Konvention")
("converters" "Konvertierer")
("converters to other data formats" "Konvertierung in andere Formate")
("copy" "kopieren")
("copy text" "Text kopieren")
("copy to" "kopieren nach")
("copying" "kopieren")
("corollary" "Folgerung")
("correct text" "Text korrigieren")
("cursors" "Cursors")
("custom tab" "gewöhnlicher Tabulator")
("customize" "Nummerierung")
("customizing TeXmacs" "TeXmacs anpassen")
("customizing the TeXmacs styles" "TeXmacs-Stil anpassen")
("custum tab" "gewöhnlicher Tabulator")
("cut" "ausschneiden")
("cut text" "Text ausschneiden")
("cut to" "ausschneiden nach")
("cypriot" "zypriotisch")
("cyrillic" "Kyrillisch")
("cyrillic input method" "kyrillische Eingabemethode")
("cyrillic italic right" "Kyrillisch kursiv aber senkrecht")
("czech" "tschechisch")
("dancers" "Tänzer")
("danish" "dänisch")
("dash" "Gedankenstrich")
("dashes" "Striche")
("data conversion" "Datenkonvertierung")
("data format" "Datenformat")
("date" "Datum")
("deactivate" "deaktivieren")
("deactivate table" "Tabelle deaktivieren")
("december" "Dezember")
("decimal comma" "Dezimalkomma")
("decimal dot" "Dezimalpunkt")
("decorate atoms" "decorate atoms")
("default" "voreingestellt")
("default padding" "Standard-Padding")
("definition" "Definition")
("delete" "löschen")
("delete column" "Spalte löschen")
("delete row" "Zeile löschen")
("denominator" "Nenner")
("description" "beschreibende Auflistungen")
("destination" "Bestimmung")
("detach" "ablösen")
("detailed" "mit Info")
("determinant" "Determinante")
("devangari" "Devangari")
("developers guide" "Einführung für Entwickler")
("dfn" "Definition")
("directory" "Verzeichnis")
("disable" "aus")
("disable first indentation" "Erstzeileneinzug aus")
("disable first indentation after" "Erstzeileneinzug danach aus")
("disable first indentation before" "Erstzeileneinzug davor ein")
("disable indentation" "Einrückung aus")
("disable indentation after" "Erstzeileneinzug danach aus")
("disable indentation before" "Erstzeileneinzug davor ein")
("disable line breaking" "kein Zeilenumbruch")
("disallow" "verbieten")
("display style" "eigenständige Formel")
("distribute unused space" "den nicht benutzten Freiraum verteilen")
("div" "div")
("do not remap" "nicht umlegen")
("document" "Dokument")
("document format" "Dokumentenformat")
("document style" "Dokumentenstil")
("document styles" "Dokumentenstil")
("documentation" "Dokumentation")
("documents are trees" "Dokumente sind strukturiert")
("dot" "Punkt")
("dots" "Punkte")
("double stroke" "Doppelstrich")
("down" "runter")
("dpi" "Punkte pro Zoll (dpi)")
("duplicate" "doppelt")
("dutch" "niederländisch")
("dynamic libraries" "Dynamische Bibliotheken")
("edit" "bearbeiten")
("edit source tree" "Quellmodus")
("editing tools" "Werkzeuge zum Editieren")
("email" "E-Mail")
("emphasize" "hervorheben")
("emphasize text" "Text hervorheben")
("empty box" "leere Box")
("enable first indentation" "Erstzeileneinzug ein")
("enable first indentation after" "Erstzeileneinzug danach ein")
("enable first indentation before" "Erstzeileneinzug davor ein")
("enable indentation" "Erstzeileneinzug ein")
("enable indentation after" "Erstzeileneinzug danach ein")
("enable indentation before" "Erstzeileneinzug davor ein")
("enable line breaking and align at the bottom line" "Zeilenumbruch und Ausrichtung an der untersten Zeile")
("enable line breaking and align at the center line" "Zeilenumbruch und Ausrichtung an der Mittelzeile")
("enable line breaking and align at the top line" "Zeilenumbruch und Ausrichtung an der obersten Zeile")
("encl" "Anlage")
("end" "Ende")
("english" "englisch")
("enter a title" "einen Titel eingeben")
("entire table" "die ganze Tabelle")
("enumerate" "Aufzählung")
("enumerate|Alpha" "Großbuchstaben")
("enumerate|Roman" "Römisch")
("enumerate|alpha" "Kleinbuchstaben")
("enumerate|roman" "römisch")
("environment" "Umgebung")
("epilogue" "Nachwort")
("equal" "gleich")
("equation" "Gleichung")
("equations" "Gleichungen")
("equivalent for" "äquivalent für")
("equivalent for Mod" "entspricht Mod")
("error" "Fehler")
("etc" "usw")
("etruscan" "etruskisch")
("europe" "europäisch")
("evaluate" "auswerten")
("evaluate scheme expression" "Scheme Ausdruck ausführen")
("evaluation" "Auswertung")
("even page footer" "Fuß für gerade Seiten")
("even page header" "Kopf für gerade Seiten")
("even page margin" "Randabstand für gerade Seiten")
("even page text" "Text für gerade Seiten")
("exact horizontal" "horizontal exakt")
("exact mode" "Fix-Modus")
("exam" "Examensarbeit")
("example" "Beispiel")
("exclusive" "exklusiv")
("exclusive or" "exklusives Oder")
("executable" "ausführbar")
("execute" "ausführen")
("execute a TeXmacs command" "TeXmacs Kommando ausführen")
("execute system command" "Systemkommando ausführen")
("executive" "Executive")
("exercise" "Aufgabe")
("expand" "ausdehnen")
("explained" "mit Erklärung")
("exponent" "Index oben rechts")
("export" "exportieren")
("export as" "exportieren als")
("export bibliographies as links" "Bibliographien als Link exportieren")
("extend or normal" "'extend' oder 'normal'")
("extern " "extern")
("extra" "extra")
("extract format" "Format herausziehen")
("family" "Familie")
("february" "Februar")
("figure" "Abbildung")
("file" "Datei")
("file name" "Dateiname")
("file not found" "Datei nicht gefunden")
("find next match" "nächsten Treffer suchen")
("find text" "Text suchen")
("finnish" "finnländisch")
("first contact" "erster Kontakt")
("first indentation" "Erstzeileneinzug")
("first item" "erster Spiegelstrich")
("first margin" "erster Rand")
("first page" "erste Seite")
("first start" "erster Start")
("flat" "flach")
("flexibility" "Flexibilität")
("flexibility factor for vertical spacing" "vertikaler Flexibilitätsfaktor")
("floating figure" "bewegliche Abbildung")
("floating object" "bewegliches Objekt")
("floating table" "bewegliche Tabelle")
("fold" "zusammenfalten")
("fold input field" "Eingabe-Feld zusammenfalten")
("folded" "zusammengefaltet")
("font" "Schriftart")
("font base size" "Buchstabenbasisgröße")
("font dpi" "Punkte pro Zoll (dpi)")
("font family" "Schriftfamilie")
("font name" "Schriftart")
("font series" "Schriftserie")
("font shape" "Schriftform")
("font size" "Schriftgröße")
("font type" "Schrift-Typ")
("font variant" "Schriftvariante")
("fonts" "Schriftarten")
("footer" "Fußzeile")
("footnote" "Fußnote")
("for" "für")
("for all" "für alle")
("for each" "für jedes")
("foreground" "Vordergrund")
("foreign" "andere Alphabete")
("format" "Formate")
("formatted and structured output" "formatierte und strukturierte Ausgabe")
("formatted date" "formatiertes Datum")
("formatting" "Formatierung")
("formula" "Formel")
("formula style" "Formelstil")
("forward replace" "nach vorne ersetzen")
("forward search" "nach vorne suchen")
("fraction" "Bruch")
("fraction bar height" "Bruchstrichhöhe")
("french" "französisch")
("full manuals" "komplette Handbücher")
("full screen mode" "Vollbildmodus")
("function" "Funktion")
("further customization" "weitere Anpassungen")
("future changes" "zukünftige Änderungen")
("future projects" "Zukunftspläne")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs kommt ohne rechtlich verbindliche Garantie")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs fällt unter die ``GNU general public license''")
("general architecture of TeXmacs" "allgemeiner Aufbau von TeXmacs")
("general negation" "allgemeine Verneinung")
("general note" "allgemeine Anmerkung")
("generated" "erzeugte")
("generating font file" "erzeuge Font-Datei")
("generic" "allgemein")
("georgian" "georgisch")
("german" "deutsch")
("getting started" "erste Schritte")
("glossary" "Glossar")
("glossary entry" "Glossareintrag")
("glue" "verbinden")
("glue decorations" "Zellen verbinden")
("go" "nach")
("gothic" "gotisch")
("graphical interface" "Grafikschnittstelle")
("grave" "nach links")
("greater" "größer")
("greater or equal" "größer oder gleich")
("greek" "griechisch")
("greek letter" "griechischer Buchstabe")
("green" "grün")
("grey" "grau")
("group" "Gruppe")
("h modifier" "H Modifikator")
("happy typing" "viel Spaß beim Tippen")
("has been aborted" "ist abgebrochen worden")
("has completed its task" "hat seine Arbeit beendet")
("hat" "Hut")
("header" "Kopfzeile")
("header and footer" "Seitenkopf und -fuß")
("hebrew" "hebräisch")
("height" "Höhe")
("height is exactly the specified height" "Höhe ist genau die spezifizierte Höhe")
("height is maximum of specified height and box height" "Höhe ist das Maximum von spezifizierter Höhe und Boxenhöhe")
("height is minimum of specified height and box height" "Höhe ist das Minimum von spezifizierter Höhe und Boxenhöhe")
("height magnification" "Höhenvergrößerung")
("help" "Hilfe")
("help me" "Helfen Sie mir")
("help us" "Helfen Sie uns")
("here" "hier")
("hidden" "verborgen")
("hint" "Hinweis")
("home" "Heimverzeichnis")
("horizontal" "horizontal")
("horizontal cell alignment" "horizontale Zellenausrichtung")
("horizontal ink separation" "horizontale Tintentrennung")
("horizontal part" "horizontaler Teil")
("horizontal position" "horizontale Position")
("horizontal space" "horizontaler Abstand")
("horizontal table alignment" "horizontale Tabellenausrichtung")
("horizontally align cell to the base" "Zelle horizontal an der Basislinie ausrichten")
("horizontally center the cell" "Zelle horizontal zentrieren")
("how much longer may pages become" "Wieviel länger dürfen die Seiten werden")
("how much shorter may pages become" "Wieviel kürzer dürfen die Seiten werden")
("huge" "riesig")
("hungarian" "ungarisch")
("hyperlink" "Hyperlink")
("hyphenation" "Trennung")
("icelandic" "isländisch")
("if" "wenn")
("iff" "gdw")
("image" "Bild")
("image links" "Bildverknüpfungen")
("implementation" "Implementation")
("import" "importieren")
("improving the current implementation" "aktuelle Implementation verbessern")
("inactive" "nicht aktiv")
("include" "einfügen")
("include a document" "ein Dokument einfügen")
("include file" "Datei einfügen")
("inclusion into TeXmacs" "Aufnahme in TeXmacs")
("inclusions" "eingefügte Dokumente")
("indent" "einrücken")
("indentation flag" "Einzugmarken")
("index" "Index")
("index entry" "Indexeintrag")
("index level" "Indexhöhe")
("informative flags" "informative Flags")
("inline arguments" "Zeilenargumente")
("inline tags" "Zeilenbefehle")
("input mode" "Eingabe Modus")
("insert" "einfügen")
("insert a TeXmacs symbol" "TeXmacs Symbol einfügen")
("insert a big operator" "einen großen Operator einfügen")
("insert a binary operation" "einen binären Operator einfügen")
("insert a binary relation" "ein binäres Relationszeichen einfügen")
("insert a blackboard bold character" "fetten Tafelschrift-Buchstaben einfügen")
("insert a bold calligraphic character" "fettes kalligrafisches Zeichen einfügen")
("insert a bold character" "fettes Zeichen einfügen")
("insert a calligraphic character" "kalligrafisches Zeichen einfügen")
("insert a fraction" "einen Bruch einfügen")
("insert a fraktur character" "Frakturzeichen einfügen")
("insert a greek character" "einen griechischen Buchstaben einfügen")
("insert a large left delimiter" "eine große linke Klammer einfügen")
("insert a large right delimiter" "eine große rechte Klammer einfügen")
("insert a large separator" "einen großen Separator einfügen")
("insert a left subscript" "Index links unten einfügen")
("insert a link" "Beziehung einfügen")
("insert a miscellaneous symbol" "ein Symbol einfügen")
("insert a new branch" "neuen Zweig einfügen")
("insert a new item" "ein neues Element einfügen")
("insert a picture" "ein Bild einfügen")
("insert a square root" "eine Quadratwurzel einfügen")
("insert a table" "Tabelle einfügen")
("insert a table or a matrix" "eine Tabelle oder eine Matrix einfügen")
("insert an" "einfügen:")
("insert an accent" "einen Akzent einfügen")
("insert an arrow" "einen Pfeil einfügen")
("insert an environment" "eine Umgebung einfügen")
("insert an n" "einfügen: n")
("insert appendix" "Anhang einfügen")
("insert arccos" "arccos einfügen")
("insert arcsin" "arcsin einfügen")
("insert arctan" "arctan einfügen")
("insert arg" "arg einfügen")
("insert argument" "neues Argument einfügen")
("insert author" "Autor einfügen")
("insert automatically generated content" "automatisch erzeugte Verzeichnisse einfügen")
("insert big contour integral" "großes Kreisintegral einfügen")
("insert big coproduct" "großes Koprodukt einfügen")
("insert big direct sum" "große direkte Summe einfügen")
("insert big dotted point" "großen Kreispunkt einfügen")
("insert big integral" "großes Integral einfügen")
("insert big intersection" "großen Durchschnitt einfügen")
("insert big logical and" "großes logisches Und einfügen")
("insert big logical or" "großes logisches Oder einfügen")
("insert big product" "großes Produkt einfügen")
("insert big square union" "große rechte Vereinigung einfügen")
("insert big summation" "große Summe einfügen")
("insert big tensor product" "großes Tensorprodukt einfügen")
("insert big union" "große Vereinigung einfügen")
("insert big union sum" "große Vereinigungssumme einfügen")
("insert big vertical space" "großen vertikalen Abstand einfügen")
("insert chapter" "Kapitel einfügen")
("insert column" "Spalte einfügen")
("insert column to the left" "Spalte links einfügen")
("insert column to the right" "Spalte rechts einfügen")
("insert cos" "cos einfügen")
("insert cosh" "cosh einfügen")
("insert cot" "cot einfügen")
("insert coth" "coth einfügen")
("insert csc" "csc einfügen")
("insert deg" "deg einfügen")
("insert det" "det einfügen")
("insert dim" "dim einfügen")
("insert dollar" "Dollar einfügen")
("insert equation" "Gleichung einfügen")
("insert executable markup" "ausführbaren Inhalt einfügen")
("insert exp" "exp einfügen")
("insert fields" "Feld einfügen")
("insert footnote" "Fußnote einfügen")
("insert formula" "Formel einfügen")
("insert gcd" "gcd einfügen")
("insert hom" "hom einfügen")
("insert horizontal interword space" "horizontalen Abstand einfügen")
("insert image" "Bild einfügen")
("insert inactive markup" "inaktiven Inhalt einfügen")
("insert inf" "inf einfügen")
("insert input field above" "Eingabe-Feld oberhalb einfügen")
("insert input field below" "Eingabe-Feld unterhalb einfügen")
("insert ker" "ker einfügen")
("insert lg" "lg einfügen")
("insert lim" "lim einfügen")
("insert liminf" "liminf einfügen")
("insert limsup" "limsup einfügen")
("insert ln" "ln einfügen")
("insert log" "log einfügen")
("insert mathematics" "Mathematik einfügen")
("insert max" "max einfügen")
("insert medium horizontal space" "mittleren horizontalen Abstand einfügen")
("insert medium vertical space" "mittleren vertikalen Abstand einfügen")
("insert min" "min einfügen")
("insert negative horizontal space" "kleinen negativen horizontalen Abstand einfügen")
("insert new item or number" "neues Element oder Nummer einfügen")
("insert new rows or columns" "neue Zeilen oder Spalten einfügen")
("insert or delete rows or columns" "Zeilen oder Spalten einfügen oder löschen")
("insert row" "Zeile einfügen")
("insert row above" "Reihe oberhalb einfügen")
("insert row below" "Reihe unterhalb einfügen")
("insert sec" "sec einfügen")
("insert section" "Abschnitt einfügen")
("insert sharp" "Kreuz einfügen")
("insert sin" "sin einfügen")
("insert sinh" "sinh einfügen")
("insert small horizontal space" "kleinen horizontalen Abstand einfügen")
("insert small vertical space" "kleinen vertikalen Abstand einfügen")
("insert structural markup" "strukturellen Inhalt einfügen")
("insert subsection" "Unterabschnitt einfügen")
("insert subsubsection" "Unterunterabschnitt einfügen")
("insert sup" "sup einfügen")
("insert tan" "tan einfügen")
("insert tanh" "tanh einfügen")
("insert text field" "Text Feld")
("insert thick horizontal space" "breiten horizontalen Abstand einfügen")
("insert title" "Titel einfügen")
("interface" "Schnittstelle")
("interfacing" "Schnittstellen")
("interfacing TeXmacs with other systems" "Schnittstellen von TeXmacs mit anderen Systemen")
("interjection" "ohne Seitenzahl")
("interline separation" "kleinster vertikaler Zeichenabstand")
("interline space" "Zeilenabstand")
("internationalization" "Internationalisierung")
("interparagraph space" "Absatzabstand")
("interrupt execution" "Ausführung abbrechen")
("introduction" "Einführung")
("invisible" "unsichtbar")
("invisible citation" "unsichtbares Zitat")
("irish" "irisch")
("is running" "läuft")
("is tuple" "ist Tupel")
("ispell does not respond" "ispell antwortet nicht")
("ispell is already busy" "ispell ist schon beschäftigt")
("italian" "italienisch")
("italic" "kursiv")
("italic right" "kursiv aber senkrecht")
("itemize" "Auflistung")
("january" "Januar")
("japanese" "japanisch")
("july" "Juli")
("june" "Juni")
("justified" "ausgerichtet")
("justify text" "Text ausrichten")
("keep unrecognized styles and packages" "unbekannte Stile und Pakete erhalten")
("key" "Taste")
("keyboard" "Tastatur")
("keyboard equivalent" "Tastenkombination")
("keyboard modifiers" "Tastatur-Modifikator")
("keyboard shortcut" "Tastenkombination")
("keymaps" "Tastatur Mappings")
("keyword" "Stichwort")
("keywords" "Stichworte")
("kill" "vernichten")
("known bugs" "bekannte Fehler")
("label" "Textmarke")
("landscape" "quer")
("language" "Sprache")
("large" "groß")
("large closing bracket" "große schließende Klammer")
("large delimiter" "großer Begrenzer")
("large opening bracket" "große öffnende Klammer")
("large separator" "großes Trennzeichen")
("last page" "lezte Seite")
("latex command" "LaTeX Befehl")
("latin" "lateinisch")
("layout" "Layout")
("layout issues" "Anmerkungen zum Layout")
("left" "links")
("left border" "sichtbarer linker Rand")
("left margin" "linker Abstand")
("left padding" "Padding links")
("left prime" "linker Strich")
("left aligned" "linksbündig")
("left slanted" "nach links geneigt")
("left subscript" "Index links unten")
("left superscript" "Index rechts oben")
("left surrounding" "linkes Umfeld")
("legal" "Legal")
("lemma" "Lemma")
("length" "Länge")
("less" "kleiner")
("less or equal" "kleiner oder gleich")
("letter" "Brief")
("license" "Lizenz")
("light" "mager")
("limitations" "Einschränkungen")
("limits" "Grenzen")
("line" "Linie")
("line break" "Zeilenumbruch")
("line stretch" "Dehnbarkeit der Zeilen")
("link" "Verknüpfung")
("link image" "mit Bild verknüpfen")
("list" "Liste")
("list of figures" "Abbildungsverzeichnis")
("list of tables" "Tabellenverzeichnis")
("lists" "Listen")
("load" "laden")
("load LaTeX file" "LaTeX Datei laden")
("load TeX file" "TeX Datei laden")
("load TeXmacs file" "TeXmacs Datei laden")
("load TeXmacs style file" "TeXmacs Stildatei laden")
("load a file" "Datei laden")
("load buffer" "Puffer laden")
("load file" "Datei laden")
("load html file" "HTML-Datei laden")
("load image" "Bild laden")
("load in new window" "in neuem Fenster laden")
("load latex file" "LaTeX-Datei laden")
("load more recent autosave file" "neuere Sicherheitskopie laden")
("load tex file" "TeX-Datei laden")
("load verbatim file" "Text-Datei laden")
("loaded" "geladen")
("long" "lang")
("look and feel" "Aussehen und Verhalten")
("look up" "suche")
("lower border" "sichtbarer unterer Rand")
("m modifier" "M Modifikator")
("macro" "Makro")
("magenta" "violett")
("magic" "magisch")
("magnification" "Vergrößerungsfaktor")
("magnified" "vergrößert")
("main" "Haupt-")
("main icon bar" "Hauptsymbolleiste")
("major changes" "Wichtige Veränderungen")
("make a page insertion" "Fußnoten und bewegliche Objekte einfügen")
("make a subscript" "einen Index erzeugen")
("make a superscript" "eine Potenz machen")
("make acute" "Akzent nach rechts machen")
("make bar" "Balken machen")
("make check" "Haken machen")
("make fraction" "einen Bruch einfügen")
("make grave" "Akzent nach links machen")
("make hat" "Hut machen")
("make label" "Textmarke einfügen")
("make negation" "Verneinung machen")
("make page reference" "Seitenverweis machen")
("make reference" "Verweis machen")
("make square root" "Quadratwurzel machen")
("make tilde" "Tilde machen")
("make title" "Titel erzeugen")
("make vector" "Vektor machen")
("making donations" "Spenden")
("manual" "Handbuch")
("map to" "legen auf")
("map to A modifier" "dem Modifikator A zuordnen")
("map to H modifier" "dem Modifikator H zuordnen")
("map to M modifier" "dem Modifikator M zuordnen")
("march" "März")
("margins" "Ränder")
("margins as on paper" "Ränder wie auf dem Papier")
("master" "Steuerdatei")
("master file" "Steuerdatei")
("math" "Math")
("math font" "Math Schriftart")
("math font family" "Math Schriftfamilie")
("math font series" "Math Schriftserie")
("math font shape" "Math Schriftform")
("mathematical" "mathematisch")
("mathematical and customized input" "Mathematische und angepasste Eingabe")
("mathematical formulas" "mathematische Formeln")
("mathematical input" "Mathematik")
("mathematical typesetting" "mathematischer Schriftsatz")
("mathematics" "Mathematik")
("matrix" "Matrix")
("maximal" "maximal")
("maximal number of columns" "maximale Anzahl von Spalten")
("maximal number of rows" "maximale Anzahl von Zeilen")
("maximum mode" "maximum Modus")
("may" "Mai")
("medium" "mittel")
("medium skip" "mittlerer Abstand")
("meminfo" "Speicher-Info")
("merge" "zusammenfügen")
("messy" "komisch")
("meta key" "Meta-Taste")
("middle" "zentriert")
("minimal" "minimal")
("minimal number of columns" "minimale Anzahl von Spalten")
("minimal number of rows" "minimale Anzahl von Zeilen")
("minimum mode" "minimum Modus")
("minus" "Minus")
("miscellaneous" "verschiedenes")
("miscellaneous features" "weitere Fähigkeiten")
("mod" "mod")
("mode" "Modus")
("modifier" "Modifikator")
("modify cell alignment" "Zellenausrichtung ändern")
("modify cell border" "Zellenumrandung ändern")
("modify cell padding" "Zellenpadding ändern")
("modify cell size" "Zellenbreite ändern")
("modify table border" "Tabellenumrandung ändern")
("modify table padding" "Tabellenpadding ändern")
("mongolian" "mongolisch")
("more information about GNU TeXmacs can be found in the Help" "weitere Informationen über GNU TeXmacs finden Sie unter Hilfe")
("mosaic" "Mosaik")
("move down" "nach unten bewegen")
("move object" "Objekt verschieben")
("move to the right when finished" "zum Schluss nach rechts bewegen")
("move up" "nach oben bewegen")
("multiline input" "Mehrzeilen-Modus")
("mutator tags" "Mutatoren")
("n-th" "n-te")
("n-th root" "n-te Wurzel")
("name" "Name")
("negation" "Verneinung")
("new" "neu")
("new buffer" "neuer Puffer")
("new column" "neue Spalte")
("new double page" "neue Doppelseite")
("new double page before" "neue Doppelseite davor")
("new item" "neuer Eintrag")
("new line" "neue Zeile")
("new number" "neue Nummer")
("new page" "neue Seite")
("new page before" "neue Seite davor")
("new paragraph" "neuer Absatz")
("new roman" "New Roman")
("new row" "neue Zeile")
("new table" "neue Tabelle")
("next line" "nächste Zeile")
("no" "nein")
("no changes need to be saved" "keine Änderungen zu sichern")
("no dictionary for" "kein Wörterbuch für")
("no dictionnary for" "kein Wörterbuch für")
("no first indentation" "keine erste Einrückung")
("no indentation" "keine Einrückung")
("no line break" "kein Zeilenumbruch")
("no matches found" "nichts gefunden")
("no more matches for" "es gibt keine anderen Fundstellen von")
("no more redo information available" "es gibt keine weitere Information für ``wiederholen''")
("no more undo information available" "es gibt keine weitere Information um zurückzugehen")
("no name" "ohne Namen")
("no page break after" "kein Seitenumbruch danach")
("no page break before" "kein Seitenumbruch davor")
("no spelling errors found in text" "keine Schreibfehler im Text entdeckt")
("no style" "kein Stil")
("no vertical correction" "keine Höhenkorrektur")
("none" "keine")
("normal" "normal")
("not" "nicht")
("not equal" "ungleich")
("not found" "nicht gefunden")
("notation" "Notierung")
("note" "Anmerkung")
("november" "November")
("number" "Zahl")
("number of columns" "Spaltenanzahl")
("numbered equation" "nummerierte Gleichung")
("numbered equations" "nummerierte Gleichungen")
("numberlongarticle" "Nummerierung langer Dokumente")
("numerator" "Zähler")
("numeric" "numerisch")
("objectives" "Ziele")
("occurrences" "Vorkommen ersetzt")
("october" "Oktober")
("odd page footer" "Fuß für ungerade Seiten")
("odd page header" "Kopf für ungerade Seiten")
("odd page margin" "Randabstand für ungerade Seiten")
("odd page text" "Text für ungerade Seiten")
("off" "aus")
("ok" "ok")
("old english" "altenglish")
("old slavonic" "altslawisch")
("old style" "alter Stil")
("on" "an")
("on cells" "auf Zellen")
("on columns" "auf Spalten")
("on entire table" "auf die gesamte Tabelle")
("on rows" "auf Zeilen")
("one spelling error has been corrected" "ein Schreibfehler wurde korrigiert")
("online documentation" "Online-Dokumentation")
("online help" "Online-Hilfe")
("only inline tags" "nur Zeilenbefehle")
("open" "öffnen")
("open a new buffer" "neuen Puffer öffnen")
("open new window" "neues Fenster öffnen")
("opening" "Eröffnung")
("operation on named selection" "Operation auf Auswahl mit Namen")
("operation on primary selection" "Operation auf erstee Auswahl")
("operation on secondary selection" "Operation auf zweitee Auswahl")
("operation on ternary selection" "Operation auf drittee Auswahl")
("optical" "optisch")
("option" "Option")
("options" "Optionen")
("or" "oder")
("orange" "orange")
("orientation" "Orientierung")
("origin" "Ursprung")
("original welcome message" "originale Begrüßungsbotschaft")
("other" "anders")
("other pages" "anderen Seiten")
("other projects" "andere Projekte")
("other style" "anderer Stil")
("outlined roman" "Roman Outlined")
("over" "über")
("overline" "überstrichen")
("packages" "Stilpakete")
("padding" "Padding")
("page" "Seite")
("page bottom margin" "unterer Seitenabstand")
("page break" "Seitenumbruchmarke")
("page break before" "Seitenumbruch davor")
("page height" "Seitenhöhe")
("page insertion" "Seiteneinfügung")
("page layout" "Seitenlayout")
("page number text" "Seitennummerntext")
("page numbering" "Seitennummerierung")
("page reference" "Seitenverweis")
("page right margin" "rechter Seitenabstand")
("page setup" "Seite einrichten")
("page top margin" "oberer Seitenabstand")
("page type" "Seitentyp")
("page width" "Seitenbreite")
("paper" "Papier")
("paper type" "Papiertyp")
("papyrus" "Papyrus")
("paragraph" "Absatz")
("paragraph mode" "Absatzformatierung")
("paragraph width" "Absatzbreite")
("pari" "Pari")
("part" "Teil")
("past changes" "frühere Änderungen")
("paste" "einfügen")
("paste from" "einfügen aus")
("paste text" "Text einfügen")
("path" "Weg")
("pdf" "PDF")
("perform operations on cells" "Operationen auf Zellen anwenden")
("perform operations on columns" "Operationen auf Spalten anwenden")
("perform operations on entire table" "Operationen auf der gesamten Tabelle anwenden")
("perform operations on rows" "Operationen auf Reihen anwenden")
("permanent" "permanent")
("person" "Person")
("personal dictionary has been modified" "Ihr persönliches Wörterbuch ist geändert worden")
("phantasy" "Fantasie")
("philosophy" "Philosophie")
("phoenician" "phönizisch")
("phonetic" "phonetisch")
("pink" "rosa")
("plain" "schlicht")
("plain block" "normaler Block")
("plain tabular" "normaler Tabulatormodus")
("planned changes" "Geplante Änderungen")
("plans for the future" "Zukunftspläne")
("please" "bitte")
("please wait" "ein Augenblick bitte")
("plus" "plus")
("polish" "Polnisch")
("porting TeXmacs to other platforms" "TeXmacs auf andere Plattformen portieren")
("portrait" "hochkant")
("portuguese" "portugiesisch")
("position" "Position")
("position float" "bewegliches Objekt positionieren")
("position floating object" "bewegliches Objekt positionieren")
("position the table" "Tabelle positionieren")
("postscript" "Postscript")
("postscript image" "Postscript-Bild")
("pre-alpha release" "Vor-Alpha Version")
("preamble" "Präambel")
("preamble mode" "Präambel-Modus")
("preferences" "Einstellungen")
("presentation" "Darstellung")
("presentation mode" "Präsentationsmodus")
("presentation tag" "Schriftform")
("preview before printing" "Druckvorschau")
("preview command" "Vorschaubefehl")
("preview with ghostview" "Druckvorschau mit Ghostview")
("primary" "erste")
("prime" "Strich")
("print" "drucken")
("print all" "alles drucken")
("print all to file" "alles in Datei drucken")
("print page selection" "Ausgewählte Seiten drucken")
("print page selection to file" "Ausgewählte Seiten in Datei drucken")
("print to postscript file" "drucken in Postscript-Datei")
("printer" "Drucker")
("printer dpi" "Druckerauflösung in Punkten pro Zoll (dpi)")
("printing command" "Druckkommando")
("problem" "Problem")
("professional" "professionell")
("prog" "Prog")
("prog font" "Prog Schriftart")
("prog font family" "Prog Schriftfamilie")
("prog font series" "Prog Schriftserie")
("prog font shape" "Prog Schriftform")
("program" "Programm")
("program mode" "Programmmodus")
("programming" "Programmieren")
("progressive" "fortschrittlich")
("project" "Projekt")
("projects" "Projekte")
("prologue" "Vorwort")
("prompt on scripts" "bei jedem Script nachfragen")
("prompts and default input" "Ausgabe-Kanäle, Eingabe-Aufforderungen und Eingabe-Vorgaben")
("proof" "Beweis")
("proportional" "proportional")
("proportional typewriter" "proportionale Schreibmachinenschrift")
("proposition" "Proposition")
("quasi" "Substitution")
("quasiquote" "Substitution ohne Evaluierung")
("query replace" "ersetzen mit Rückfragen")
("question" "Frage")
("quit" "verlassen")
("quotation" "Zitat")
("quote" "zitieren")
("range" "Bereich")
("really huge" "riesengroß")
("really quit" "wollen Sie wirklich beenden")
("really tiny" "wirklich winzig")
("recent" "rezent")
("red" "rot")
("redo" "wieder")
("redo undone changes" "stornierte Änderungen wiederherstellen")
("reduce bottom margin by" "unteren Randabstand reduzieren um")
("reduce left margin by" "linken Randabstand reduzieren um")
("reduce margins" "Ränder reduzieren")
("reduce right margin by" "rechten Randabstand reduzieren um")
("reduce top margin by" "oberen Randabstand reduzieren um")
("reduction even page margin" "Randreduktion für gerade Seiten")
("reduction odd page margin" "Randreduktion für ungerade Seiten")
("reduction page bottom margin" "Reduktion des unteren Seitenrandes")
("reduction page right margin" "Reduktion des rechten Seitenrandes")
("reduction page top margin" "Reduktion des oberen Seitenrandes")
("reference" "Verweis")
("reference guide" "Referenzhandbuch")
("references" "Verweise")
("regular" "normal")
("release" "Version")
("reload" "wieder laden")
("remark" "Bemerkung")
("remove all output fields" "entferne alle Ausgabe-Felder")
("remove fields" "entferne Felder")
("remove input field" "entferne Eingabe-Feld")
("remove input field above" "entferne Eingabe-Feld oben")
("remove input field below" "entferne Eingabe-Feld unten")
("remove package" "Paket entfernen")
("remove this switch" "entferne diese Ebene")
("renumber this page" "diese Seite nummerieren")
("repeat" "Rekursiv")
("repeat object" "Objekt wiederholen")
("replace" "ersetzen")
("replace by" "ersetzen durch")
("replaced" "ich habe")
("replaced one occurrence" "ich habe ein Vorkommen ersetzt")
("reset" "zurücksetzen")
("resize object" "Objektgröße ändern")
("resized" "gestreckt")
("return" "return")
("revert" "wieder laden")
("revert buffer" "wieder laden")
("right" "rechts")
("right border" "sichtbarer rechter Rand")
("right margin" "rechter Abstand")
("right padding" "Padding rechts")
("right aligned" "rechtsbündig")
("right subscript" "Index rechts unten")
("right superscript" "Index rechts oben")
("right surrounding" "rechtes Umfeld")
("rigid" "fix")
("rigid general case" "fix horiz. .. vor .. nach")
("rigid horizontal" "fix horizontal")
("rigid horizontal space" " fixer horizontaler Abstand")
("rigid space" "fixer Abstand")
("roman" "Roman")
("roman right" "Roman senkrecht")
("romanian" "rumänisch")
("root" "Wurzel")
("rotate backward" "rotiere rückwärts")
("rotate forward" "rotiere vorwärts")
("row" "Zeile")
("row contains glued items" "Zeile enthält verbundene Teile")
("row span" "vertikale Zellanzahl")
("rows" "Reihen")
("rumanian" "rumänisch")
("runic" "runisch")
("running author" "laufender Autor")
("running title" "laufender Titel")
("russian" "russisch")
("russian and Ukrainian users" "russische und ukrainische Benutzer")
("samp" "besonderes Textstück")
("sample" "Beispiel")
("sans serif" "Sans-Serif")
("save" "sichern")
("save TeXmacs file" "TeXmacs Datei sichern")
("save TeXmacs style file" "TeXmacs Stil-Datei sichern")
("save as" "sichern als")
("save as LaTeX" "als LaTeX sichern")
("save as TeX" "als TeX sichern")
("save buffer" "Puffer sichern")
("save buffer as" "Puffer sichern als")
("save file" "Datei sichern")
("save html file" "HTML-Datei sichern")
("save image" "Bild sichern")
("save latex file" "LaTeX-Datei sichern")
("save tex file" "TeX-Datei sichern")
("save this buffer" "Puffer sichern")
("save verbatim file" "Text-Datei sichern")
("saved" "gesichert")
("scheme" "Scheme")
("screen layout" "Layout auf dem Bildschirm")
("screen margins" "Ränder auf dem Bildschirm")
("script" "Index")
("script above" "Index oben")
("script below" "Index unten")
("script script size" "kleiner Index")
("script size" "Index")
("scripts not accepted" "Scripts werden nie akzeptiert")
("search" "suchen")
("searching" "suche")
("secondary" "zweite")
("section" "Abschnitt")
("security" "Sicherheit")
("see" "sehen")
("select a document style" "einen Dokumentenstil auswählen")
("select a foreground color" "eine Vordergrundfarbe auswählen")
("select a language" "eine Sprache auswählen")
("selected region" "ausgewählter Bereich")
("selection" "Auswahl")
("selections" "Auswählen")
("seminar" "Folien")
("sending commands to TeXmacs" "Befehle an TeXmacs senden|")
("separation between lines" "Zeilenabstand")
("separation between paragraphs" "Abstand zwischen Absätzen")
("separator" "Trennzeichen")
("september" "September")
("series" "Stärke")
("series|right" "senkrecht")
("session" "Sitzung")
("session name" "Name der Sitzung")
("session type" "Sitzungstyp")
("sessions" "Sitzungen")
("set" "setze")
("set background color of cell" "Zellenhintergrundfarbe einstellen")
("set cell mode" "Zellenmodus einstellen")
("set extension center" "Referenzzelle festlegen")
("set height" "Höhe einstellen")
("set height of cell" "Zellenhöhe einstellen")
("set margins" "Ränder ändern")
("set n" "n eingeben")
("set paragraph margins" "Absatzränder einstellen")
("set paragraph mode" "Absatzformatierung")
("set printer dpi" "Druckerauflösung festlegen")
("set printing command" "Druckkommando festlegen")
("set span" "n-fache Großzelle")
("set special cell properties" "spezielle Zelleneigenschaften einstellen")
("set special table properties" "spezielle Tabelleneigenschaften einstellen")
("set text width" "Textbreite ändern")
("set width" "Breite einstellen")
("set width of cell" "Zellenbreite einstellen")
("settings" "Einstellungen")
("setup printer" "Drucker einstellen")
("shape" "Form")
("shell" "Shell")
("shift-down" "shift-unten")
("shift-right" "shift-rechts")
("short" "kurz")
("show" "zeigen")
("show header and footer" "Seitenkopf und Seitenfuß zeigen")
("show hidden" "Verborgenes anzeigen")
("show on screen" "auf dem Bildschirm zeigen")
("shrinking factor" "Reduktionsfaktor")
("signature" "Unterschrift")
("size" "Größe")
("size limits" "Größenbegrenzungen")
("size tag" "Schriftgröße")
("slanted" "geneigt")
("sloppy" "nachlässig")
("slovak" "slowakisch")
("slovene" "slowenisch")
("small" "klein")
("small capitals" "Kapitälchen")
("small caps" "Kapitälchen")
("small figure" "kleine Abbildung")
("small skip" "kleiner Abstand")
("small table" "kleiner eigenständiger Tabellenblock")
("solution" "Lösung")
("source" "Quellcode")
("source code" "Quellcode")
("source tags" "Codeformatierung")
("space" "Abstand")
("space between lines" "Zeilenabstand")
("space between paragraphs" "Abstand zwischen Absätzen")
("spaces" "Abstände")
("spacing" "Abstände")
("spanish" "spanisch")
("special" "speziell")
("special cell properties" "spezielle Zelleneigenschaften")
("special table properties" "spezielle Tabelleneigenschaften")
("specific" "spezifisch")
("spell" "Rechtschreibprüfung")
("spell checking complete" "Rechtschreibprüfung beendet")
("spelling error" "Schreibfehler")
("spelling errors have been corrected" "Schreibfehler im Text korrigiert")
("split" "Aufteilung")
("split session" "die Sitzung aufteilen")
("square root" "Quadratwurzel")
("standard TeXmacs styles" "die Standard-TeXmacs-Stile")
("standard environment variables" "vordefinierte Kontext-Variable")
("standard length units" "standard Längeneinheiten")
("start" "Start")
("start a new chapter" "ein neues Kapitel beginnen")
("start a new section" "einen neuen Abschnitt beginnen")
("start an interactive session" "eine interaktive Sitzung beginnen")
("status bar" "Statusbalken")
("stretchable" "dehnbar")
("stretchable horizontal" "horizontal dehnbar")
("stretchable vertical" "vertikal dehnbar")
("stretched" "Gespreizt")
("stroke" "Strich")
("strokes" "Striche")
("strong" "stark")
("structural" "strukturell")
("style" "Stil")
("styles" "Stile")
("stylesheet language" "Konstrukte für Stildefinitionen")
("sub" "Unter-")
("subparagraph" "Unterabsatz")
("subscript" "Index unten")
("subsection" "Unterabschnitt")
("subsub" "Unter-Unter-")
("subsubsection" "Unterunterabschnitt")
("subtable" "Untertabelle")
("subtitle" "Untertitel")
("summary" "Zusammenfassung")
("superpose" "überlagern")
("superposed" "überlagert")
("superscript" "Index oben")
("swedish" "schwedisch")
("switch" "Ebene einfügen")
("switch to first" "zur erste Ebene")
("switch to formula style" "Formelstil benutzen")
("switch to last" "zur letzten Ebene")
("switch to next" "zur nächsten Ebene")
("switch to previous" "zur vorherigen Ebene")
("switching and folding" "zwischen Textebenen schalten")
("symbol" "Symbol")
("system environment variables" "Umgebungsvariablen des Systems")
("tab" "Tab")
("tab-completion" "Eingabe-Ergänzung")
("table" "Tabelle")
("table command" "Tabellenkommando")
("table of contents" "Inhaltsverzeichnis")
("tables" "Tabellen")
("tabular" "tabelliert")
("tabular material" "Tabellen")
("tags" "Schrifteigenschaften")
("teXmacs as an interface" "GNU TeXmacs als Schnittstelle benutzen")
("teXmacs fonts" "TeXmacs Zeichensätze")
("teXmacs notice" "TeXmacs Notiz")
("teXmacs plugins" "TeXmacs und andere Programme (Plugins)")
("teXmacs primitives" "fundamentale TeXmacs-Konstrukte")
("ternary" "dritte")
("test" "test")
("tex" "TeX")
("text" "Text")
("text font" "Text Schriftart")
("text height correction" "Texthöhenkorrektur")
("text width" "Textbreite")
("texts" "Texte")
("th century bc" "te Jahrhundert v.u.Z.")
("th root" "-te Wurzel")
("thai" "thailändish")
("the TeXmacs authors" "die TeXmacs-Autoren")
("the TeXmacs format" "das TeXmacs-Format")
("the application did not send its usual startup banner" "das Programm hat nicht die normale Willkommensbotschaft geschickt")
("the application does not reply" "das Programm antwortet nicht")
("the application is already running" "das Programm läuft schon")
("the boxes produced by the typesetter" "die Boxen, die vom Satzprogramm erzeugt werden")
("the graphical user interface" "die grafische Benutzerschnittstelle")
("the leaves of TeXmacs trees" "die Zweige eines TeXmacs-Baumes")
("the mycas example" "das mycas-Beispiel")
("the primitive TeXmacs constructs" "der grundlegende TeXmacs-Aufbau")
("the standard TeXmacs styles" "die Standardstile von TeXmacs")
("theorem" "Satz")
("there are unsaved documents" "nicht alle Dateien sind gesichert")
("this document has been produced using" "Dieses Dokument wurde erzeugt mit")
("this line" "diese Zeile")
("this page" "diese Seite")
("tilda" "Tilde")
("tilde" "Tilde")
("times" "mal")
("tiny" "winzig")
("title" "Titel")
("to the left" "nach links")
("to the right" "nach rechts")
("today" "heute")
("tools" "Werkzeuge")
("top" "ganz oben")
("top border" "sichtbarer oberer Rand")
("top level" "oberes Niveau")
("top margin" "oberer Abstand")
("top padding" "Padding oben")
("translate" "Übersetzen")
("tree" "Baum")
("tuple" "Tupel")
("turkish" "türkisch")
("tutorial" "Tutorial")
("type" "Typ")
("type a latex command followed by" "LaTeX-Befehl tippen und dann")
("type body" "Körper eingeben")
("type denominator" "Nenner eingeben")
("type numerator" "Zähler eingeben")
("type script" "Index eingeben")
("typesetted boxes" "Typographierte Boxen")
("typewriter" "Schreibmaschine")
("typewriter small caps" "Schreibmachinenschrift mit kleinen Großbuchstaben")
("typing a simple text" "einfachen Text tippen")
("typing simple texts" "Einfache Dokumente verfassen")
("ugaritic" "ugaritisch")
("ukrainian" "ukrainisch")
("underline" "unterstrichen")
("undo" "zurück")
("undo last changes" "letzte Änderungen stornieren")
("unevaluated argument" "nicht evaluiertes Argument")
("unevaluated value" "nicht evaluierter Wert")
("unfold" "verborgenen Text zeigen")
("unquote" "Evaluierung zulassen")
("up" "hoch")
("update" "aktualisieren")
("update from web" "aktualisiere aus dem Internet")
("update image links" "Bildverknüpfungen aktualisieren")
("upper border" "sichtbarer oberer Rand")
("upright" "senkrecht")
("us" "US Stil")
("use TeXmacs" "benutze TeXmacs")
("use a black color" "schwarze Farbe benutzen")
("use a blue color" "blaue Farbe benutzen")
("use a bold font" "benutze einen fetten Zeichensatz")
("use a brown color" "braune Farbe benutzen")
("use a calligraphic font" "eine kalligraphische Schriftart benutzen")
("use a green color" "grüne Farbe benutzen")
("use a grey color" "graue Farbe benutzen")
("use a magenta color" "violette Farbe benutzen")
("use a orange color" "orange Farbe benutzen")
("use a pink color" "rosa Farbe benutzen")
("use a red color" "rote Farbe benutzen")
("use a sans serif font" "Schriftart ohne Serifen benutzen")
("use a typewriter font" "Schreibmachinenschriftart benutzen")
("use a white color" "weiße Farbe benutzen")
("use a yellow color" "gelbe Farbe benutzen")
("use blackboard bold font" "Fette Tafel-Schriftart benutzen")
("use bold font series" "fette Buchstaben benutzen")
("use calligraphic font" "kalligrafische Schriftart benutzen")
("use calligraphical font" "kalligrafische Schriftart nützen")
("use footnote font size" "sehr kleine Buchstaben benutzen")
("use fraktur font" "gotische Schriftart benutzen")
("use huge font size" "riesige Buchstaben benutzen")
("use italic font shape" "kursive Buchstaben benutzen")
("use large font size" "große Buchstaben benutzen")
("use left hand column as border" "linke Spalte als Begrenzung benutzen")
("use medium font series" " Buchstaben mit normaler Dicke benutzen")
("use normal font size" "Buchstaben mit normaler Größe benutzen")
("use package" "Paket benutzen")
("use paragraph width" "Absatzbreite benutzen")
("use really huge font size" "riesengroße Buchstaben benutzen")
("use right font shape" "aufrechte Buchstaben benutzen")
("use right hand column as border" "rechte Spalte als Begrenzung benutzen")
("use roman font family" "romanische Schriftart benutzen")
("use row above as border" "obere Zeile als Begrenzung benutzen")
("use row below as border" "untere Zeile als Begrenzung benutzen")
("use sans serif font family" "Schriftart ohne Serifen benutzen")
("use script font size" "sehr kleine Buchstaben benutzen")
("use slanted font shape" "schräge Buchstaben benutzen")
("use small capitals" "kleine Großbuchstaben benutzen")
("use small font size" "kleine Buchstaben benutzen")
("use small-caps font shape" "kleine Großbuchstaben benutzen")
("use the blackboard bold font" "die Schriftart Blackboard fett benutzen")
("use the fraktur font" "die Fraktur-Schriftart benutzen")
("use tiny font font size" "winzige Buchstaben benutzen")
("use typewriter font family" "Schreibmachinenschriftart benutzen")
("use very large font size" "sehr große Buchstaben benutzen")
("user manual" "Benutzerhandbuch")
("user provided icons" "Anwendersymbole")
("users of Cyrillic languages" "Anmerkungen für russische und ukrainische Anwender")
("value" "Wert")
("variable" "Variable")
("variant" "Variante")
("vector" "Vektor")
("verbatim" "wörtlich")
("verse" "Vers")
("vertical" "vertikal")
("vertical after" "vertikal nach Absatz")
("vertical baseline" "vertikale Basislinie")
("vertical before" "vertikal vor Absatz")
("vertical cell alignment" "vertikale Zellenausrichtung")
("vertical correction of bottom top and the top" "vertikale Korrektur unten und oben")
("vertical correction of the bottom" "vertikale Korrektur unten")
("vertical correction of the top" "vertikale Korrektur oben")
("vertical part" "vertikaler Freiraum")
("vertical position" "vertikale Position")
("vertical space" "vertikaler Abstand")
("vertical space after" "vertikaler Abstand danach")
("vertical space before" "vertikaler Abstand davor")
("vertical table alignment" "vertikale Tabellenausrichtung")
("vertically align cell to the base" "Zelle vertikal an der Basislinie ausrichten")
("vertically center the cell" "Zelle vertikal zentrieren")
("very large" "sehr groß")
("very small" "sehr klein")
("vietnamese" "vietnamesisch")
("view" "Ansicht")
("view and edit document sourcecode" "Dokumente im Quellcode darstellen und editieren")
("visible" "sichtbar")
("warning" "Warnung")
("welcome" "Willkommen")
("welcome to GNU TeXmacs" "Herzlich Willkommen zu GNU TeXmacs")
("what is new" "Was ist neu")
("when finished" "zum Schluss")
("while" "solang")
("white" "weiß")
("wide accent" "breiter Akzent")
("width" "Breite")
("width is exactly the specified width" "Breite ist genau die spezifizierte Breite")
("width is maximum of specified width and box width" "Breite ist das Maximum von spezifizierter Breite und Boxenbreite")
("width is minimum of specified width and box width" "Breite ist das Minimum von spezifizierter Breite und Boxenbreite")
("width magnification" "Breitenvergrößerung")
("window" "Fenster")
("window height" "Fensterhöhe")
("window width" "Fensterbreite")
("windows key" "Windows-Taste")
("with" "mit")
("write a name" "einen Namen schreiben")
("write bold mathematics" "fette Mathematik schreiben")
("write bold text" "fetten Text schreiben")
("write italic text" "kursiven Text schreiben")
("write sample text" "Beispieltext schreiben")
("write strong text" "kräftigen Text schreiben")
("write typewriter text" "Schreibmachinentext schreiben")
("write verbatim text" "wörtlichen Text schreiben")
("writing data converters" "Datenkonverter schreiben")
("writing your own style files" "Ihren ersten eigenen Stil-Definition schreiben")
("written with TeXmacs" "mit TeXmacs verfasst")
("yellow" "gelb")
("yes" "ja")
("you can also obtain" "Sie können")
("your document is back in its original state" "Ihr Dokument ist wieder in seinem Originalzustand")
("your first interface" "Ihre erste Schnittstelle")
("your language" "Ihre Sprache")
