("\"encryption\" features from the preference panel" "fonctions de chiffrement du panneau de préférences")
("(Re)Build autocompletion index" "(Re)Construire l'index d'autocomplétion")
("Bibtex command" "commande Bibtex")
("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("a modifier" "modificateur A")
("a series" "série A")
("a.C.M. computing class" "classification ACM")
("a.M.S. subject class" "classification MSC")
("abbreviated authors" "noms d'auteurs abrégés")
("abbreviation" "abréviation")
("about" "à propos de")
("about menu" "à propos de")
("above" "en haut")
("abbreviated authors" "auteurs abrégés")
("abstract" "résumé")
("accent" "accent")
("accent above" "accent au-dessus")
("accent below" "accent en dessous")
("accept" "accepter")
("accept all scripts" "accepter tous les scripts")
("accept during this pass" "accepter pendant cette passe")
("accept no scripts" "ne jamais accepter de scripts")
("accept script" "accepter le script")
("account" "compte")
("acknowledge" "remercier")
("acknowledgment" "remerciements")
("acknowledgments" "remerciements")
("acronym" "sigle")
("action" "action")
("activate" "activer")
("activate hidden" "activer et cacher")
("activate once" "activer une fois")
("activation" "activation")
("active link types" "types de lien actifs")
("acute" "aigu")
("add" "ajouter")
("add abstract information" "ajouter information de résumé")
("add author information" "ajouter information sur l'auteur")
("add branch after" "ajouter une branche après")
("add branch before" "ajouter une branche avant")
("add other package" "ajouter un autre paquetage")
("add package" "ajouter un paquetage")
("add remote ssh connection" "ajouter une connexion ssh distante")
("add style package" "ajouter un paquetage de style")
("add switch after" "ajouter commutateur après")
("add switch before" "ajouter commutateur avant")
("add title information" "ajouter information de titre")
("add to custom colors" "ajouter aux couleurs personnalisées")
("addition" "addition")
("address" "adresse")
("address block" "bloc d'adresses")
("adjust" "ajuster")
("adjust limits" "ajuster les limites")
("advanced" "avancée")
("advanced font customization" "personnalisation avancée de police")
("advanced layout features" "mise en page avancée")
("affiliation" "affiliation")
("after" "après")
("albanian" "albanais")
("algorithm" "algorithme")
("algorithms" "algorithmes")
("align cell to the bottom" "aligner la cellule en bas")
("align cell to the decimal comma" "aligner sur la virgule décimale")
("align cell to the decimal dot" "aligner sur le point décimal")
("align cell to the left" "aligner la cellule à gauche")
("align cell to the right" "aligner la cellule à droite")
("align cell to the top" "aligner la cellule en haut")
("align table at axis" "aligner sur l'axe")
("align table at base of left column" "aligner tableau à la base de la colonne de gauche")
("align table at base of middle column" "aligner tableau à la base de la colonne du milieu")
("align table at base of origin column" "aligner tableau à la base de la colonne d'origine")
("align table at base of right column" "aligner tableau à la base de la colonne de droite")
("align table at fraction bar height" "aligner tableau à la hauteur des barres des fractions")
("align table at the base of bottom row" "aligner tableau à la base de la ligne du bas")
("align table at the base of middle row" "aligner tableau à la base de la ligne du milieu")
("align table at the base of origin row" "aligner tableau à la base de la ligne d'origine")
("align table at the base of top row" "aligner tableau à la base de la ligne du haut")
("align table at the bottom" "aligner tableau en bas")
("align table at the center" "aligner tableau au centre")
("align table at the horizontal center" "aligner tableau au milieu")
("align table at the left" "aligner tableau à gauche")
("align table at the top" "aligner tableau en haut")
("align table to the right" "aligner tableau à droite")
("align text to the left" "aligner le texte à gauche")
("align text to the right" "aligner le texte à droite")
("aligned" "aligné")
("alignment" "alignement")
("alignment of balloon" "alignement du ballon")
("all" "le tout")
("all cells" "toutes les cellules")
("all data attached to this identity will be lost" "toutes les données associées à cette identité seront perdues")
("all saved passphrases will be lost forever" "toutes les phrases secrètes enregistrées seront perdues à jamais")
("allow" "permettre")
("allow for macro definitions in preamble" "permettre des définitions de macros dans le préambule")
("allow multiple spaces" "autoriser plusieurs espaces")
("allow spurious spaces" "autoriser les espaces superflus")
("allowed extension" "extension permise")
("allowed page height extension" "extension de hauteur de page autorisée")
("allowed page height reduction" "réduction de hauteur de page autorisée")
("allowed positions" "positions autorisées")
("allowed positions of floating object" "positions autorisées de l'objet flottant")
("allowed reduction" "réduction permise")
("alpha release" "version alpha")
("alpha transparency" "transparence alpha")
("also on paper" "drapeaux à l'impression")
("alt key" "touche alt")
("alter" "alterner")
("alternate" "alternatif")
("alternate except here" "alterner sauf ici")
("alternate from here on" "alterner à partir d'ici")
("alternate only here" "alterner seulement ici")
("alternate until here" "alterner jusqu'à ici")
("alternative colors" "couleurs alternatives")
("alternative specification" "spécification alternative")
("always" "toujours")
("american" "américain")
("amplified" "amplifié")
("anchor" "ancre")
("ancient" "ancien")
("and" "et")
("and perform casual settings from the \"Encryption\" tab" "et effectuez des réglages occasionnels à partir de l'onglet chiffrement")
("angle" "angle")
("angular" "angulaire")
("animate" "animer")
("animate folding" "animer pliage")
("animate object" "animer l'objet")
("animate objects" "animer des objets")
("animate unfolding" "animer dépliage")
("animated" "animé")
("animation" "animation")
("animation toolbar" "barre d'outils pour les animations")
("annotate" "annoter")
("annote" "annoter")
("answer" "réponse")
("answer field" "champ de réponse")
("answer to question" "réponse à la question")
("answers" "réponses")
("answers only" "réponses seulement")
("any" "tous")
("appear" "apparaître")
("appendix" "annexe")
("apply" "appliquer")
("apply macro" "appliquer la macro")
("apply macro once" "appliquer la macro une fois")
("approximate" "approximatif")
("april" "avril")
("arab" "arabe")
("arc" "arc")
("arc cosine" "arc cosinus")
("arc sine" "arc sinus")
("arc tangent" "arc tangente")
("arch series" "série arch")
("archaic" "archaïque")
("architecture" "architecture")
("are you sure you want to delete collected public keys" "êtes-vous sûr de vouloir supprimer les clés publiques collectées")
("are you sure you want to delete selected public keys" "êtes-vous sûr de vouloir supprimer les clés publiques sélectionnées")
("are you sure you want to delete selected secret keys" "êtes-vous sûr de vouloir supprimer les clés secrètes sélectionnées")
("are you sure you want to destroy the wallet" "êtes-vous sûr de vouloir détruire le trousseau de clés")
("argument" "argument")
("arithmetic" "arithmétique")
("armenian" "arménien")
("arrow" "flèche")
("arrows" "flèches")
("art Pen" "plume artistique")
("art frame" "cadre artistique")
("article" "article")
("arxiv category" "catégorie ArXiv")
("as on paper" "comme sur le papier")
("as visual grid" "comme grille visuelle")
("aspect" "aspect")
("assign" "changer")
("at fraction bar height" "à la hauteur des barres des fractions")
("at the baseline" "à la ligne de base")
("at the bottom" "en bas")
("at the left" "à gauche")
("at the middle" "au milieu")
("at the right" "à droite")
("at the top" "en haut")
("attach" "attacher")
("attach buffer to which project" "attacher le tampon à un projet")
("attach master" "attacher un document maître")
("attach master file for project" "joindre le fichier maître pour le projet")
("attached" "attaché")
("august" "août")
("author" "auteur")
("authorize" "autoriser")
("auto" "auto")
("auto-save file" "sauvegarde automatique")
("automate" "automatiser")
("automatic" "automatique")
("automatic brackets" "parenthèses automatiques")
("automatic content generation" "génération automatique de contenu")
("automatic correction" "correction automatique")
("automatic program brackets" "parenthèses automatiques (programmes)")
("automatic quotes" "guillemets automatiques")
("automatically close brackets" "fermer automatiquement les parenthèses")
("automatically generated content" "contenu généré automatiquement")
("automatically import bibliographies when opening files" "importer automatiquement des bibliographies lors de l'ouverture de fichiers")
("automatically open this console on errors" "ouvrir automatiquement cette console en cas d'erreur")
("automatically open this console on warnings" "ouvrir automatiquement cette console en cas d'avertissement")
("automatically remember all passphrases in the wallet" "mémoriser automatiquement toutes les phrases secrètes dans le trousseau de clés")
("automatically save" "sauvegarder automatiquement")
("autosave" "sauvegarde automatique")
("avoid spurious spaces" "éviter les espaces superflus")
("axiom" "axiome")
("axioms" "axiomes")
("axis" "axe")
("b series" "série B")
("back" "précédent")
("background" "arrière-plan")
("background color" "couleur de fond")
("background evaluations" "évaluations en arrière-plan")
("background pattern" "motif de fond")
("background picture" "image de fond")
("background picture selector" "sélecteur d'image d'arrière-plan")
("backtrace errors" "pile des erreurs")
("backward replace" "remplacement en arrière")
("backward search" "recherche arrière")
("bad data format" "mauvais format de données")
("balloon" "ballon")
("bar" "barre")
("bard" "bard")
("base" "base")
("base level" "niveau de base")
("baseline" "ligne de base")
("bashkirian" "bashkirien")
("basic" "base")
("basic colors" "couleurs de base")
("basic communication using pipes" "communication de base par tubes")
("basic data types" "types de base")
("basic types" "types de base")
("be useful" "soyez utile")
("beamer" "beamer")
("beamer formats" "formats de vidéoprojecteur")
("beamer theme" "thème de présentation")
("become a TeXmacs developer" "devenez un développeur TeXmacs")
("before" "avant")
("begin" "début")
("below" "en dessous")
("bench" "chronométrer")
("bend bottom" "plier en bas")
("bend corner" "plier le coin")
("bend diagonal" "plier les coins opposés")
("bend in" "plier vers l'avant")
("bend out" "plier vers l'arrière")
("beta release" "version bêta")
("bezier" "bézier")
("bibTeX command" "commande BibTeX")
("bibliography" "bibliographie")
("bibliography file" "fichier de bibliographie")
("bibliography style" "style de bibliographie")
("bidirectional" "bidirectionnel")
("big" "grand")
("big environment box" "grande boîte d'environnement")
("big figure" "grande figure")
("big focus" "grand focus")
("big operator" "grand opérateur")
("big skip" "grand saut")
("big table" "grand tableau")
("binary operation" "opération binaire")
("binary operator" "opérateur binaire")
("binary relation" "relation binaire")
("bitmap resolution (dpi)" "résolution bitmap (points par pouce)")
("black" "noir")
("black floral I" "floral noir I")
("black floral II" "floral noir II")
("blackboard" "tableau noir")
("blackboard bold" "tableau noir gras")
("blackboard embold" "tableau noir gras")
("blackboard math" "tableau noir math")
("blackletter" "lettre noir")
("blank column" "colonne vide")
("blank row" "ligne vide")
("block" "bloc")
("block content" "contenu «bloc»")
("block of code" "bloc de code")
("blue" "bleu")
("bluish" "bleuâtre")
("blur" "flouter")
("blur radius" "rayon de floutage")
("body" "corps")
("body color" "couleur du corps")
("bold" "gras")
("book" "livre")
("booklet" "livret")
("border" "bordure")
("boring-white" "blanc ennuyeux")
("both" "les deux")
("both versions" "les deux versions")
("bothlined" "entre deux lignes")
("bottom" "en bas")
("bottom baseline" "ligne de base en bas")
("bottom border" "bordure du bas")
("bottom cell border" "bordure du bas de la cellule")
("bottom cell padding" "espacement du bas de la cellule")
("bottom center" "en bas au centre")
("bottom left" "en bas à gauche")
("bottom margin" "marge du bas")
("bottom padding" "espacement du bas")
("bottom right" "en bas à droite")
("bottom table border" "bordure du bas du tableau")
("bottom table padding" "espacement du bas du tableau")
("bottom tools" "outils en bas de fenêtre")
("box" "case")
("branch" "branche")
("break" "saut")
("breaking" "sauts")
("breve" "demi-cercle")
("bright" "clair")
("british" "britannique")
("broken citations" "citations cassées")
("broken references" "références cassées")
("broken white" "blanc cassé")
("brown" "brun")
("browse" "naviguer")
("browse back" "naviguer vers le précédent")
("browse forward" "naviguer vers le suivant")
("browse modules documentation" "feuilleter la documentation des modules")
("browse symbols documentation" "feuilleter la documentation des symboles")
("browse web" "naviguer sur le réseau")
("browser" "navigateur")
("buffer" "tampon")
("buffer in this window" "tampon dans cette fenêtre")
("buffer management" "gestion des tampons")
("buffer must be on disk" "le tampon doit être sur le disque")
("buffer must have a name" "le tampon doit avoir un nom")
("build buffer" "construire le tampon")
("build buffer in" "construire le tampon dans")
("build directory" "construire le répertoire")
("build directory in" "reconstruire le répertoire dans")
("build link pages" "construire les pages de liens")
("build-all" "tout construire")
("bulgarian" "bulgare")
("bullet" "puce")
("bullets" "puces")
("bump" "bosse")
("busy" "en cours")
("by" "par")
("by typing" "en tapant")
("bytes free" "octets libres")
("bytes used" "octets utilisés")
("cJK" "cJK")
("cJK spacing" "espacement CJK")
("cSS stylesheet" "feuille de style CSS")
("calculus" "calcul différentiel")
("calligraphic" "calligraphique")
("cancel" "annuler")
("cancelled" "annulé")
("cannot download directory to file" "impossible de télécharger le répertoire dans le fichier")
("cannot rename across different servers" "renommage impossible à travers différents serveurs")
("cannot upload directory to file" "impossible de télécharger le répertoire dans le fichier")
("caps-lock key" "touche majuscules")
("caption" "légende")
("cartesian" "cartésien")
("cartoon" "cartoon")
("carved wood" "bois sculpté")
("case" "choisir")
("case-insensitive search" "recherche insensible à la casse")
("categories" "catégories")
("category" "catégorie")
("cc" "copies à")
("cell" "cellule")
("cell background color" "couleur de la cellule")
("cell border" "bordure de la cellule")
("cell color" "couleur de cellule")
("cell height" "hauteur de la cellule")
("cell operation mode" "mode d'opération sur la cellule")
("cell properties" "propriétés de la cellule")
("cell span" "envergure de cellule")
("cell width" "largeur de la cellule")
("cells" "cellules")
("center" "centre")
("center baseline" "ligne de base du centre")
("center text" "centrer le texte")
("centered" "centré")
("centered block" "bloc centré")
("centered programs" "programmes centrés")
("centered tabular" "tableau centré")
("chalk" "craie")
("change border of cell" "changer la bordure de la cellule")
("change cell operation mode" "changer le mode d'opération")
("change default unit" "changer l'unité par défaut")
("change log" "tous les changements")
("change passphrase" "modifier le mot de passe")
("change permissions" "modifier les autorisations")
("change step-size" "modifier la taille des pas")
("change tags" "modifier les balises")
("change the TeXmacs preferences" "modifier les préférences de TeXmacs")
("change the border of the table" "modifier la bordure du tableau")
("change the style of mathematical formulas" "modifier le style des formules mathématiques")
("change wallet passphrase" "modification du mot de passe du trousseau de clés")
("changes" "changements")
("chapter" "chapitre")
("character compression" "compression de caractères")
("character contraction" "contraction des caractères")
("character count" "nombre de caractères")
("character encoding" "encodage de caractères")
("character expansion" "expansion des caractères")
("check" "tchèche")
("check exported Pdf files for correctness" "vérifier la conformité des fichiers PDF exportés")
("check for automatic updates" "rechercher automatiquement des mises à jour")
("check for updates" "rechercher les mises à jour")
("check text for spelling errors" "vérifier l'orthographe du texte")
("checkable field" "champs vérifiables")
("chinese" "chinois")
("choice" "choix")
("choose background" "choisir le fond")
("choose color" "choisir la couleur")
("cipher algorithm for passphrase encryption" "algorithme de cryptage pour le chiffrement par phrase secrète")
("circle" "cercle")
("citation" "citation")
("cite" "citer")
("cite TeXmacs" "citer TeXmacs")
("cite TeXmacs-related work" "citer des travaux concernant TeXmacs")
("cite related work" "citer des travaux connexes")
("class" "classe")
("classic" "classique")
("classification" "classification")
("clean slate" "feuille vierge")
("clear" "effacer")
("clear all fields" "effacer tous les champs")
("clear local information" "effacer les informations locales")
("clear menu" "effacer le menu")
("clear selection" "effacer la sélection")
("clear undo history" "effacer l'historique des modifications")
("click Ok button twice to discard this warning" "cliquez deux fois sur le bouton OK pour supprimer cet avertissement")
("client" "client")
("clip" "rogner")
("clip object" "rogner l'objet")
("clipboard image format" "format d'image pour presse-papier")
("clipped" "tronqué")
("clipped and magnified" "tronqué et agrandi")
("clipped and resized" "tronqué et redimensionné")
("clone" "cloner")
("clone window" "cloner la fenêtre")
("close" "fermer")
("close TeXmacs" "fermer TeXmacs")
("close animation tool" "fermer l'outil d'animation")
("close buffer" "fermer le tampon")
("close document" "fermer le document")
("close program" "fermer le programme")
("close replace tool" "fermer l'outil de remplacement")
("close search tool" "fermer l'outil de recherche")
("close session" "fermer la session")
("close spell tool" "fermer l'outil de correction d'orthographe")
("close translations to rebuild" "fermer les traductions à reconstruire")
("close window" "fermer la fenêtre")
("closed bezier" "courbe de bézier fermée")
("closed curve" "courbe fermée")
("closed smooth" "courbe lisse fermée")
("closed spline" "spline fermée")
("closing" "fermeture")
("closing style" "style de fermeture")
("cluster by affiliation" "grouper par affiliation")
("code" "code")
("collect garbage" "ramasse-miettes")
("collected keys" "clés collectées")
("color" "couleur")
("color according to nesting level" "couleur selon le niveau d'imbrication")
("color of the axes" "couleur des axes")
("color of the subunits" "couleur des sous-unités")
("color of the units" "couleur des unités")
("colors" "couleurs")
("column" "colonne")
("column contains glued items" "la colonne contient des parties collées")
("column separation" "séparation entre les colonnes")
("column to the left" "colonne vers la gauche")
("column to the right" "colonne vers la droite")
("columns" "colonnes")
("columns separation" "séparation des colonnes")
("command" "commande")
("commit" "enregistrer les modifications")
("commit file" "enregistrer les modifications du fichier")
("common" "commun")
("common formats" "formats courants")
("commutative diagram" "diagramme commutatif")
("compact" "compact")
("compact lists" "listes compactes")
("compactification" "compactification")
("compactify" "compactifier")
("compare" "comparer")
("compare with" "comparer avec")
("compatibility with other formats" "compatibilité avec les autres formats")
("compile article" "compiler un article")
("compile book" "compiler un livre")
("compile buffer" "compiler ce tampon")
("compile project" "compiler le projet courant")
("complete bibliographic reference" "compléter la référence bibliographique")
("completion" "complétion")
("complex" "complexe")
("complex actions" "actions complexes")
("compose" "composer")
("compound" "composé")
("compress" "comprimer")
("compress into toolbar" "compresser dans la barre d'outils")
("compressed" "comprimé")
("conceal" "dissimuler")
("concrete" "concret")
("condensed" "condensé")
("condition" "condition")
("conference" "conférence")
("configuration" "configuration")
("configure look and feel" "configurer l'apparence")
("confirm collected public key deletion" "confirmer la suppression de la clé publique collectée")
("confirm database entry" "confirmer la saisie dans la base de données")
("confirm entry" "confirmer l'entrée")
("confirm public key deletion" "confirmer la suppression de la clé publique")
("confirm secret key deletion" "confirmer la suppression de la clé secrète")
("confirm selected database entries" "confirmer les entrées sélectionnées dans la base de données")
("confirm selected entries" "confirmer les entrées sélectionnées")
("confirm wallet destruction" "confirmer la destruction du trousseau de clés")
("conjecture" "conjecture")
("conjectures" "conjectures")
("connect" "connexion")
("conservative conversion between LaTeX and TeXmacs" "conversion conservatrice entre LaTeX et TeXmacs")
("conservative conversion options" "options de conversion conservatrice")
("consoles" "consoles")
("constants" "constantes")
("constellation" "constellation")
("contact" "contact")
("content" "contenu")
("content tag" "balise de contenu")
("context aids" "aide contextuelle")
("context dependent icons" "icônes dépendantes du contexte")
("contextual hints" "indications contextuelles")
("continuation of" "continuation de")
("continue" "continue")
("continued fraction" "fraction continue")
("contour" "contour")
("contract logarithms" "contracter les logarithmes")
("contribute" "contribuer")
("control flow" "flot de contrôle")
("control the evaluation of expressions" "contrôler l'évaluation des expressions")
("convention" "convention")
("conventions" "conventions")
("convert" "convertir")
("converters" "convertisseurs")
("converters to other data formats" "convertisseurs pour d'autres formats")
("convertible" "convertibles")
("copy" "copier")
("copy new objects to all frames" "copier de nouveaux objets dans tous les cadres")
("copy new objects to previous frames" "copier les nouveaux objets dans les cadres précédents")
("copy new objects to subsequent frames" "copier de nouveaux objets dans les cadres suivants")
("copy text" "copier du texte")
("copy to" "copier vers")
("copy to all frames after" "copie dans tous les cadres après")
("copy to all frames before" "copie dans tous les cadres avant")
("copy to all other frames" "copie dans tous les autres cadres")
("copying" "copie en cours")
("copyright" "copyright")
("cork charset with TeX catcode definition in preamble" "Cork avec définition des catcodes dans le préambule")
("cork with catcodes" "Cork avec catcodes")
("corollaries" "corollaires")
("corollary" "corollaire")
("correct" "corriger")
("correct all" "corriger tout")
("correct formula" "corriger la formule")
("correct manually" "corriger manuellement")
("correct mathematical formulas" "corriger les formules mathématiques")
("correct text" "corriger le texte")
("correction" "correction")
("cosine" "cosinus")
("could not load" "impossible de charger")
("count characters" "compter le nombre de caractères")
("count lines" "compter le nombre de lignes")
("count words" "compter le nombre de mots")
("course" "cours")
("create a new document" "créer un nouveau document")
("create context macro" "créer une macro de contexte")
("create link" "créer un lien")
("create preamble" "créer un préambule")
("create remote account" "créer un compte distant")
("create remote directory" "créer un répertoire distant")
("create remote file" "créer un fichier distant")
("create subprogram" "créer un sous-programme")
("create subsession" "créer une sous-session")
("create table macro" "créer une macro de tableau")
("create web site" "créer un site web")
("created new document" "nouveau document créé")
("creating new account" "création d'un nouveau compte")
("creating technical pictures" "création d'images techniques")
("croatian" "croate")
("crop" "rogner")
("crop marks" "repères de coupe")
("cross" "croix")
("crossed boxes" "cases avec croix")
("crossed circles" "cercles avec croix")
("current graphical mode" "mode graphique actuel")
("current user version" "version utilisateur actuelle")
("current version" "version actuelle")
("cursor" "curseur")
("cursors" "curseurs")
("curve" "courbe")
("curve intersections" "intersections de courbes")
("curve points" "points de la courbe")
("custom colors" "couleurs personnalisées")
("custom tab" "tabulation personnalisée")
("customizations" "personnalisations")
("customize macro" "macro personnalisée")
("customizing TeXmacs" "personnalisation de TeXmacs")
("customizing and extending the user interface" "personnalisation et extension de l'interface utilisateur")
("customizing the TeXmacs styles" "personnaliser les styles de TeXmacs")
("custum tab" "tabulation personnalisée")
("cut" "couper")
("cut text" "couper du texte")
("cut to" "couper vers")
("cyan" "cyan")
("cypriot" "cypriote")
("cyrillic" "cyrillique")
("cyrillic input method" "cyrillique par le clavier")
("cyrillic italic right" "cyrillique italique droit")
("czech" "tchèque")
("dancers" "danseurs")
("danish" "danois")
("dark" "sombre")
("dark grey" "gris foncé")
("dark-vador" "dark vador")
("dash" "tiret")
("dashes" "tirets")
("data" "données")
("data conversion" "conversion de données")
("data format" "format de données")
("database entry" "entrée de base de données")
("database tool" "outil pour les bases de données")
("database toolbar" "barre d'outils pour les bases de données")
("date" "date")
("deactivate" "désactiver")
("deactivate once" "désactiver une fois")
("deactivate table" "désactiver tableau")
("dead" "mort")
("debug" "débogage")
("debugging console" "console de débogage")
("debugging tool" "outil de débogage")
("december" "décembre")
("decimal comma" "virgule décimal")
("decimal dot" "point décimal")
("decomposed" "décomposée")
("decorate atoms" "décorations atomiques")
("decorated" "décorée")
("decorated wood" "bois décoré")
("decorative" "décoratif")
("decrease size" "réduire la taille")
("decrypt" "décrypter")
("decrypted" "déchiffré")
("decryption" "décryptage")
("default" "valeur par défaut")
("default padding" "espacement par défaut")
("default size" "taille par défaut")
("definition" "définition")
("definitions" "définitions")
("degrade" "dégrader")
("degraded" "dégradé")
("delete" "supprimer")
("delete column" "supprimer colonne")
("delete documentation cache" "supprimer le cache de la documentation")
("delete entries" "supprimer les entrées")
("delete link" "supprimer le lien")
("delete row" "supprimer la ligne")
("delete selected entries in wallet" "supprimer les entrées sélectionnées dans le trousseau de clés")
("delete user identity" "supprimer l'identité de l'utilisateur")
("deleted" "supprimé")
("denominator" "dénominateur")
("describe" "décrire")
("describe tag" "décrire la balise")
("description" "description")
("destination" "destination")
("destroy" "détruire")
("detach" "détacher")
("detach master" "détacher le document maître")
("detailed" "détaillé")
("detailed menus" "menus détaillés")
("details in menus" "détails dans les menus")
("determinant" "déterminant")
("determine margins from text width" "déterminer les marges à partir de la largeur du texte")
("devangari" "dévangari")
("developer" "développeur")
("developer tool" "outil de développement")
("developers guide" "guide du développeur")
("device" "appareil")
("diamond" "diamant")
("differentiate" "dériver")
("digital" "numérique")
("dilate" "dilater")
("direction of progression" "sens de progression")
("direction of translation" "sens de la translation")
("directory" "répertoire")
("disable" "désactiver")
("disable coloring on paper" "désactiver la coloration sur le papier")
("disable encryption" "désactiver le cryptage")
("disable first indentation" "désactiver première indentation")
("disable first indentation after" "désactiver première indentation après")
("disable first indentation before" "désactiver première indentation avant")
("disable indentation" "désactiver indentation")
("disable indentation after" "désactiver indentation après")
("disable indentation before" "désactiver indentation avant")
("disable last indentation" "désactiver dernière indentation")
("disable last indentation after" "désactiver dernière indentation après")
("disable last indentation before" "désactiver dernière indentation avant")
("disabled" "désactivé")
("disallow" "interdire")
("disappear" "disparaître")
("disk" "disque")
("display style" "style d'affichage")
("displayed formula" "formule centrée")
("dissociate joined cells" "séparer les cellules jointes")
("distill encapsulated Pdf files" "distiller les fichiers PDF encapsulés")
("distort" "distorsion")
("distorted" "déformé")
("distribute unused space" "distribuer l'espace non utilisé")
("div" "div")
("division" "division")
("do not break up large formulas" "ne pas casser les grandes formules")
("do not remap" "ne pas renvoyer")
("document" "document")
("document colors" "couleurs du document")
("document font selector" "sélection de la police du document")
("document format" "format de document")
("document language" "langue du document")
("document metadata" "métadonnées du document")
("document page format" "format de pages du document")
("document paragraph format" "format de paragraphes du document")
("document source tree preferences" "préférences pour les arbres sources de documents")
("document style" "style de document")
("document styles" "styles de document")
("document updates run" "nombre de tours sur réactualisation")
("documentation" "documentation")
("documents are trees" "les documents sont des arbres")
("documents in separate windows" "documents dans des fenêtres séparées")
("dot" "point")
("dots" "points")
("dotted line" "pointillés")
("double stroke" "lignes doubles")
("double the zoom factor for TeXmacs documents" "doubler le facteur de zoom pour des documents TeXmacs")
("down" "en bas")
("download" "télécharger")
("download file or directory" "télécharger un fichier ou un répertoire")
("downwards" "vers le bas")
("downwards..." "de haut en bas...")
("dpi" "points par pouce")
("dragging" "glisser")
("draw" "dessiner")
("draw graphics" "dessiner des graphiques")
("draw image" "dessiner image")
("draw over" "dessiner sur")
("draw over selection" "dessiner sur sélection")
("draw under" "dessiner en dessous")
("drop" "tombant")
("due to" "due à")
("duplicate" "en double")
("duplicate labels" "étiquettes en double")
("duration" "durée")
("dutch" "néerlandais")
("dynamic" "dynamique")
("dynamic libraries" "librairies dynamiques")
("eRROR" "eRREUR")
("echelon" "échelon")
("edit" "éditer")
("edit animation" "modifier l'animation")
("edit groups of objects" "éditer des groupes d'objets")
("edit macro" "éditer la macro")
("edit macros" "éditer les macros")
("edit object properties" "éditer les propriétés d'un objet")
("edit package" "éditer le package")
("edit preamble" "éditer la préambule")
("edit source" "éditer le code source")
("edit source tree" "éditer l'arbre source")
("edit style" "éditer le style")
("edit translations file" "éditer le fichier de traduction")
("editing tools" "outils d'édition")
("edition" "edition")
("editor" "éditeur")
("editors" "éditeurs")
("education" "éducation")
("effect pen" "stylo pour effets")
("eigenvalues" "valeurs propres")
("eigenvalues and vectors" "valeurs propres et vecteurs")
("eighth" "huitième")
("elevation" "élévation")
("email" "email")
("email address" "adresse email")
("embed all linked images" "incorporer toutes les images liées")
("embed image" "image incorporée")
("embed this image" "incorporer cette image")
("embold" "rendre gras")
("emboss" "bossu")
("emphasize" "mise en relief")
("emphasize text" "mettre en relief du texte")
("empty box" "boîte vide")
("enable" "activer")
("enable first indentation" "activer première indentation")
("enable first indentation after" "activer première indentation après")
("enable first indentation before" "activer première indentation avant")
("enable indentation" "activer indentation")
("enable indentation after" "activer indentation après")
("enable indentation before" "activer indentation avant")
("enable last indentation" "activer dernière indentation")
("enable last indentation after" "activer dernière indentation après")
("enable last indentation before" "activer dernière indentation avant")
("enable page breaking" "activer les sauts de page")
("enabled" "activé")
("encl" "inclus")
("encoding" "encodage")
("encrypt" "chiffrer")
("encrypted" "chiffré")
("encrypted buffer" "tampon chuffré")
("encryption" "chiffrement")
("encryption error" "erreur de chiffrement")
("encryption facilities are not currently available" "le chiffrement n'est pas disponible actuellement")
("encryption facilities have not been enabled for TeXmacs" "le chiffrement n'a pas été activé pour TeXmacs")
("end" "fin")
("enforce brackets to match" "forcer les parenthèses à coincider")
("english" "anglais")
("engrave" "graver")
("enter a title" "entrer un titre")
("enter data" "entrer des données")
("enter graphic mode" "entrer en mode graphique")
("enter graphics" "entrer des graphiques")
("enter graphics mode" "entrer en mode graphique")
("enter new passphrase for encryption" "entrer une nouvelle phrase secrète pour le chiffrement")
("enter passphrase for decryption" "entrer la phrase secrète pour le déchiffrement")
("enter passphrase for identity" "entrer la phrase secrète pour l'identité")
("enter title information" "entrer les informations de titre")
("entire table" "tableau entier")
("entry" "entrée")
("entry type" "type d'entrée")
("entry up to date in database" "entrée à jour dans la base de données")
("enumerate" "énumérer")
("enumerate|Alpha" "Lettres")
("enumerate|Roman" "Romain")
("enumerate|alpha" "lettres")
("enumerate|roman" "romain")
("enunciation" "énoncé")
("env" "environnement")
("environment" "environnement")
("environment variable" "variable d'environnement")
("environments" "environnements")
("epilogue" "épilogue")
("equal" "égal à")
("equation" "équation")
("equations" "équations")
("equivalent for" "équivalent pour")
("erode" "éroder")
("error" "erreur")
("error messages" "messages d'erreur")
("error output" "sortie d'erreur")
("error status report" "rapport du statut d'erreur")
("error: bracket does not match" "erreur : la parenthèse ne correspond pas")
("error: cyclic or missing chunks detected" "erreur : morceaux cycliques ou manquants détectés")
("error: file not found" "erreur: fichier non trouvé")
("error: ghostview does not seem to be installed on your system" "erreur : ghostview ne semble pas être installé sur votre système")
("error: one of the alternatives should be filled out" "erreur : une des alternatives doit être complétée")
("error: only one alternatives should be filled out" "erreur : une seule alternative doit être renseignée")
("error: should fill out name for referencing" "erreur : le nom pour le référencement doit être renseigné")
("error: should fill out required field" "erreur : champ obligatoire à renseigner")
("escape" "échap")
("esperanto" "espéranto")
("etruscan" "étrusque")
("european numbering style" "style de numérotation européen")
("evaluable field" "champ évaluable")
("evaluate" "évaluer")
("evaluate above" "évaluer ci-dessus")
("evaluate all" "évaluer tous")
("evaluate below" "évaluer ci-dessous")
("evaluate fields" "évaluer les champs")
("evaluate fields in order" "évaluer les champs dans l'ordre")
("evaluate scheme expression" "évaluer expression scheme")
("evaluate script" "évaluer le script")
("evaluation" "évaluation")
("evaluation switch" "commutateur d'évaluation")
("evaluation tag" "balise d'évaluation")
("even page" "page paire")
("even page footer" "pied des pages paires")
("even page header" "en-tête des pages paires")
("even page left margin" "marge gauche des pages paires")
("even page margin" "marge des pages paires")
("even page right margin" "marge droite des pages paires")
("even page shift" "décalage des pages paires")
("even page text" "texte des pages paires")
("even pages" "pages paires")
("events" "événements")
("exact" "exact")
("exact horizontal" "horizontal exact")
("exact mode" "mode exact")
("exam" "examen")
("example" "exemple")
("examples" "exemples")
("exclusive" "exclusif")
("exclusive or" "ou exclusif")
("executable" "exécutable")
("execute" "exécuter")
("execute a TeXmacs command" "executer une commande TeXmacs")
("execute system command" "executer une commande système")
("execution of scripts" "exécution de scripts")
("executive" "exécutif")
("exercise" "exercice")
("exercises" "exercices")
("exit graphics" "sortir du graphique")
("exit graphics mode" "quitter le mode graphique")
("exit left" "sortir à gauche")
("exit right" "sortir à droite")
("exit tag on the left" "sortir à gauche de la balise")
("exit tag on the right" "sortir à droite de la balise")
("expand" "développer")
("expand TeXmacs macros with no LaTeX equivalents" "développer les macros TeXmacs sans équivalent LaTeX")
("expand beamer slides" "développer les diapositives beamer")
("expand inclusions" "développer les documents inclus")
("expand logarithms" "développer les logarithmes")
("expand trigonometric functions" "développer les fonctions trigonométriques")
("expand unrecognized macros" "développer les macros non reconnues")
("expand user-defined macros" "développer les macros des utilisateurs")
("expand w.r.t." "développer suivant")
("expanded" "développé")
("experimental" "expérimental")
("experimental features (to be used with care)" "fonctions expérimentales (à utiliser avec précaution)")
("explain" "expliquer")
("explained" "détaillé")
("explanatory item" "élément explicatif")
("explicit keystroke" "frappe de clavier explicite")
("explicit margins" "marges explicites")
("exponential" "exponentielle")
("exponential functions" "fonctions exponentielles")
("export" "exporter")
("export as" "exporter en tant que")
("export bibliographies as links" "exporter les bibliographies comme des liens")
("export bibliography" "exporter la bibliographie")
("export current file" "exporter le fichier courant")
("export entries in buffer" "exporter les entrées dans le tampon")
("export file" "exporter le fichier")
("export formulas as images" "exporter les formules comme des images")
("export mathematical formulas as MathJax" "exporter des formules mathématiques
vers MathJax")
("export mathematical formulas as MathML" "exporter les formules vers du MathML")
("export mathematical formulas as images" "exporter les formules comme des images")
("export selected entries" "exporter les entrées sélectionnées")
("export selection" "exporter la sélection")
("export selection as image" "exporter la sélection comme image")
("export selections as" "exporter les sélections comme")
("export sessions" "exporter les sessions")
("export to remote server" "exporter vers le serveur distant")
("exported bibliographic entries" "entrées bibliographiques exportées")
("exported bibliographic references" "références bibliographiques exportées")
("extend" "étendre")
("extend or normal" "étendu ou normal")
("extend table to full paragraph width" "étendre le tableau à la largeur totale d'un paragraphe")
("extended" "étendu")
("extensible left arrow" "flèche gauche extensible")
("extensible right arrow" "flèche droite extensible")
("extern" "extern")
("extern " "externe")
("external" "externe")
("extra" "extra")
("extra branch" "branche supplémentaire")
("extra interline space" "espace d'interligne supplémentaire")
("extra name" "nom supplémentaire")
("extract" "extraire")
("extract format" "extraire le format")
("extract style file" "extraire le fichier de style")
("extract style package" "extraire le paquetage de style")
("extras" "extra")
("factor" "facteur")
("fade" "fondre")
("fade in" "apparition en fondu")
("fade out" "disparition en fondu")
("family" "famille")
("fast" "rapide")
("fast decrease" "diminuer rapidement")
("fast environments" "environnements rapides")
("fast increase" "augmenter rapidement")
("february" "février")
("field reference" "référence de champ")
("fifth" "cinquième")
("figure" "figure")
("figures" "figures")
("file" "fichier")
("file name" "nom de fichier")
("file not found" "fichier non trouvé")
("file saved" "fichier enregistré")
("files" "fichiers")
("fill color" "couleur de remplissage")
("fill out" "rempli")
("filter" "filtres")
("find file" "trouver le fichier")
("find next match" "chercher l'occurrence suivante")
("find text" "chercher du texte")
("finished collecting symbols documentation" "collecte des symboles de documentation terminée")
("finnish" "finlandais")
("first" "premier")
("first chunk" "premier morceau")
("first contact" "premier contact")
("first difference" "première différence")
("first error" "première erreur")
("first field" "premier champ")
("first indentation" "première indentation")
("first item" "premier élément")
("first occurrence" "première occurrence")
("first page" "première page")
("first similar" "première balise similaire")
("first start" "démarrage")
("fit" "ajuster à la taille")
("fit to height" "ajuster à la hauteur")
("fit to screen" "ajuster à l'écran")
("fit to screen width" "ajuster à la largeur")
("fit to width" "ajuster à la largeur")
("five columns" "cinq colonnes")
("fix broken citations" "corriger les citations cassées")
("fix broken references" "corriger les références cassées")
("fix duplicate labels" "corriger les étiquettes en double")
("fixed" "fixe")
("flag is off" "le drapeau est baissé")
("flag is on" "le drapeau est levé")
("flat" "plat")
("flatten" "aplatir")
("flexibility" "flexibilité")
("flexibility factor for vertical spacing" "facteur de flexibilité pour l'espacement vertical")
("floating algorithm" "algorithme flottant")
("floating figure" "figure flottante")
("floating object" "objet flottant")
("floating phantom" "fantôme flottant")
("floating table" "tableau flottant")
("focus" "focus")
("focus dependent icons" "icônes dépendantes du focus")
("fold" "plier")
("fold all" "plier tous")
("fold all fields" "plier tous les champs")
("fold back" "replier")
("fold input field" "plier champ d'entrée")
("folded" "plié")
("follow external links" "suivre les liens externes")
("follow inverse links" "suivre les liens inverses")
("font" "police")
("font base size" "taille de police de base")
("font customization" "personnalisation de la police")
("font dpi" "points par pouce")
("font effects" "effets de police")
("font family" "famille de police")
("font name" "nom de la police")
("font selector" "sélection de la police")
("font series" "graisse de police")
("font shape" "forme de la police")
("font size" "taille de la police")
("font type" "type de police")
("font variant" "variante de la police")
("fonts" "polices")
("footer" "pied de page")
("footnote" "note en bas de page")
("for" "pour")
("for all" "pour tout")
("for each" "pour chaque")
("force reloading of translations" "rechargement forcé des traductions")
("foreground" "premier-plan")
("foreign" "étranger")
("format" "format")
("formatted and structured output" "sorties formattées et structurées")
("formatted date" "date formatée")
("formatting" "formatage")
("formula" "formule")
("formula style" "style des formules")
("forward" "suivant")
("forward replace" "remplacement en avant")
("forward search" "recherche en avant")
("four columns" "quatre colonnes")
("four dots" "quatre points")
("fourth" "quatrième")
("fraction" "fraction")
("fraktur" "fraktur")
("framed" "encadré")
("framed input fields" "champs de saisie encadrés")
("framed programs" "programmes encadrés")
("framed theorems" "théorèmes encadrés")
("framed title" "titre encadré")
("french" "français")
("frequency" "fréquence")
("from" "de")
("from center" "du centre")
("front matter" "avant-propos")
("full" "complet")
("full author list" "liste complète des auteurs")
("full manuals" "manuels complets")
("full name" "nom complet")
("full screen mode" "mode plein écran")
("function" "fonction")
("functional" "fonctionnel")
("further customization" "personnalisation avancée")
("future changes" "changements à venir")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs n'offre aucune garantie juridique")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs tombe sous la ``GNU general public license''")
("gap" "trou")
("garbage collection" "ramasse-miettes")
("gaussian" "gaussien")
("gaussian blur" "flou gaussien")
("gcd" "pgcd")
("general" "général")
("general architecture of TeXmacs" "architecture générale de TeXmacs")
("general negation" "négation générale")
("general note" "note générale")
("generate GnuPG key" "générer la clé GnuPG")
("generated LaTeX document contains no errors" "le document LaTeX généré ne contient aucune erreur")
("generated field" "champ généré")
("generating font file" "Génération du fichier de police")
("generic" "générique")
("generic input color" "couleur d'entrée générique")
("generic prompt color" "couleur d'invite générique")
("geometry" "géométrie")
("georgian" "géorgien")
("german" "allemand")
("get arity" "obtenir l'arité")
("get label" "obtenir l'étiquette")
("get list with remote versions" "obtenir la liste avec les versions distantes")
("getting started" "commencer")
("global log" "journal global")
("global status" "état global")
("glossary" "glossaire")
("glossary entry" "entrée dans le glossaire")
("glue" "coller")
("glue decorations" "coller décorations")
("glue multiple spaces" "fusionner des espaces multiples")
("glyphs" "glyphes")
("gnaw" "rongés")
("gnawed" "grignoté")
("gnuPG command" "commande gnuPG")
("gnuPG decryption error" "erreur de décryptage gnuPG")
("gnuPG error: buffer encryption failed" "erreur gnuPG : échec du chiffrement de la mémoire tampon")
("gnuPG error: cannot find suitable secret key to decrypt" "erreur gnuPG : impossible de trouver la clé secrète appropriée pour déchiffrer")
("gnuPG requires name and email to have at least 5 characters" "gnuPG requiert que le nom et l'adresse de messagerie aient au moins 5 caractères")
("go" "aller")
("go to anchor" "aller à l'ancre")
("go to anchor or float" "aller à l'ancre ou l'objet flottant")
("go to anchor or footnote" "aller à l'ancre ou à la note en bas de page")
("go to first similar tag" "aller vers la première balise similaire")
("go to float" "aller à l'objet flottant")
("go to footnote" "aller à la note en bas de page")
("go to last similar tag" "aller vers la dernière balise similaire")
("go to next similar tag" "aller vers la balise similaire suivante")
("go to previous similar tag" "aller vers la balise similaire précédente")
("go to section" "aller vers la section")
("gothic" "gothique")
("gradient" "dégradé")
("gradient selector" "sélecteur de dégradé")
("grain" "grain")
("granite" "granit")
("graphical effects" "effets graphiques")
("graphical interface" "interface graphique")
("graphical interface font scale" "échelle de police d'interface graphique")
("graphical overlays" "calques graphiques")
("graphical slides and overlays" "diapositives et calques graphiques")
("graphics" "graphique")
("graphics geometry" "géométrie du graphique")
("graphics grids" "grilles graphiques")
("grave" "grave")
("greater" "supérieur à")
("greater or equal" "supérieur ou égal à")
("greek" "grecque")
("greek letter" "lettre grecque")
("green" "vert")
("grey" "gris")
("greyed" "grisé")
("grid" "grille")
("grid curves" "courbes de la grille")
("grid lines" "lignes de la grille")
("grid points" "points de la grille")
("grid-curve intersections" "intersections courbe-grille")
("group" "groupe")
("group of objects" "groupe d'objets")
("group/ungroup" "grouper/dégrouper")
("group/ungroup objects" "grouper/dégrouper des objets")
("grouped" "groupé")
("guarantee transparent source tracking" "garantir un suivi transparent du texte source")
("h modifier" "modificateur H")
("half wide" "demi-largeur")
("hand drawn" "dessinés à la main")
("handwritten" "manuscrite")
("hang up" "raccrocher")
("hanging theorems" "théorèmes suspendus")
("hangul" "hangul")
("happy typing" "bonne rédaction")
("has been aborted" "a été arrêtée")
("has completed its task" "a effectué sa tâche")
("hat" "circonflexe")
("header" "en-tête")
("header and footer" "en-tête et pied de page")
("header bars" "barres d'en-tête")
("headers" "en-têtes")
("hebrew" "hébreu")
("height" "hauteur")
("height is exactly the specified height" "utiliser la hauteur spécifiée")
("height is maximum of specified height and box height" "utiliser maximum de la hauteur spécifiée et la hauteur de la boîte")
("height is minimum of specified height and box height" "utiliser minimum de la hauteur spécifiée et la hauteur de la boîte")
("height magnification" "agrandissement de la hauteur")
("help" "aide")
("help balloon" "ballon d'aide")
("help me" "aidez-moi")
("help us" "aidez-nous")
("here" "ici")
("hidden" "caché")
("hide TeXmacs" "cacher TeXmacs")
("hide others" "cacher le reste")
("high resolution screen settings" "paramètres d'écran haute résolution")
("high resolution settings" "réglages haute résolution")
("highlight errors" "indiquer les erreurs")
("history" "histoire")
("home" "racine")
("homepage" "page d'acceuil")
("homoglyph substitutions" "substitutions d'homoglyphes")
("horizontal" "horizontal")
("horizontal alignment" "alignement horizontal")
("horizontal cell alignment" "alignement horizontal de la cellule")
("horizontal collapse distance" "distance horizontale pour enfoncement")
("horizontal ink separation" "séparation d'encre horizontale")
("horizontal margins" "marges horizontales")
("horizontal padding" "rembourrage horizontal")
("horizontal part" "partie horizontale")
("horizontal position" "position horizontale")
("horizontal rule" "ligne horizontale")
("horizontal space" "espace horizontal")
("horizontal table alignment" "alignement horizontal du tableau")
("horizontally align cell to the base" "alignement horizontale de la cellule sur la base")
("horizontally center the cell" "centrer la cellule horizontalement")
("how much longer may pages become" "de combien les pages peuvent-elles se rallonger")
("how much shorter may pages become" "de combien les pages peuvent-elles se raccourcir")
("huge" "énorme")
("hungarian" "hongrois")
("hybrid command" "commande hybride")
("hyperbolic functions" "fonctions hyperboliques")
("hyperlink" "hyperlien")
("hyphenate as" "couper comme")
("hyphenation" "césure")
("ice" "glace")
("icelandic" "islandais")
("icon" "icône")
("identifier" "identifiant")
("idle" "inactif")
("if" "si")
("if hyphenated" "en mode césure")
("iff" "ssi")
("ignore" "ignorer")
("image" "image")
("image links" "images liées")
("impact" "impact")
("implementation" "implantation")
("import" "importer")
("import bibliography" "importer la bibliographie")
("import current file" "importer le fichier courant")
("import database entry" "importer l'entrée de base de données")
("import entries in buffer" "importer les entrées dans le tampon")
("import entry" "importer l'entrée")
("import file" "fichier d'importation")
("import font" "importation de police")
("import public keys from buffer" "importer les clés publiques du tampon")
("import selected database entries" "importer les entrées de base de données sélectionnées")
("import selected entries" "importer les entrées sélectionnées")
("import selections as" "importer les sélections comme")
("import sessions" "importer les sessions")
("import sophisticated objects as pictures" "importer des objets complexes sous forme d'images")
("imported bibliographic entries" "importer les entrées bibliographiques")
("improving the current implementation" "amélioration de l'implantation présente")
("in" "dans")
("in popup windows" "dans des nouvelles fenêtres")
("inactive" "inactif")
("inanimated" "inanimé")
("inch" "pouces")
("inches" "pouces")
("include" "inclure")
("include a document" "inclure un document")
("include file" "inclure un fichier")
("inclusion into TeXmacs" "inclusion dans TeXmacs")
("inclusions" "inclusions")
("incomplete entries found to be filled out" "entrées incomplètes à remplir")
("increase size" "augmenter la taille")
("indent" "en retrait")
("indent paragraphs" "indenter les paragraphes")
("indentation" "indentation")
("indentation flag" "marqueur d'indentation")
("index" "index")
("index entry" "entrée dans l'index")
("index level" "niveau d'index")
("indication" "indication")
("inflate" "gonfler")
("informative flags" "drapeaux informatifs")
("initialize" "initialiser")
("initialize wallet" "initialiser le trousseau de clés")
("initials" "initiales")
("ink here" "encrer ici")
("ink in" "apparition en encrant")
("ink out" "disparition en encrant")
("inline" "incorporé")
("inline args" "arguments incorporés")
("inline arguments" "arguments incorporé")
("inline code" "code incorporé")
("inline content" "contenu incorporé")
("inline formula" "formule incorporée")
("inline note" "petite note incorporée")
("inner" "intérieur")
("inner bottom" "intérieur bas")
("inner left" "intérieur gauche")
("inner right" "intérieur droit")
("inner top" "intérieur haut")
("input" "entrée")
("input command" "commande d'entrée")
("input field" "champ de saisie")
("input mode" "mode des entrées")
("input options" "options d'entrée")
("insert" "insérer")
("insert Pr" "insérer Pr")
("insert a TeXmacs symbol" "insérer un symbole TeXmacs")
("insert a big operator" "insérer un grand opérateur")
("insert a binary operation" "insérer une opération binaire")
("insert a binary relation" "insérer une relation binaire")
("insert a blackboard bold character" "insérer un caractère gras de tableau noir")
("insert a bold calligraphic character" "insérer un caractère calligraphique gras")
("insert a bold character" "insérer un caractère gras")
("insert a calligraphic character" "insérer un caractère calligraphique")
("insert a computer program" "insérer un programme d'ordinateur")
("insert a condition" "insérer une condition")
("insert a control flow instruction" "insérer une instruction de flux de contrôle")
("insert a fraction" "insérer une fraction")
("insert a fraktur character" "insérer un caractère gothique")
("insert a gap" "insérer un trou")
("insert a greek character" "insérer un caractère grec")
("insert a large left delimiter" "insérer un grand délimiteur ouvrant")
("insert a large right delimiter" "insérer un grand délimiteur fermant")
("insert a large separator" "insérer un grand séparateur")
("insert a left subscript" "insérer un indice à gauche")
("insert a link" "insérer un lien")
("insert a list" "insérer une liste")
("insert a miscellaneous symbol" "insérer un symbole divers")
("insert a multiple choice" "insérer un choix multiple")
("insert a negation" "insérer une négation")
("insert a new branch" "insère une nouvelle branche")
("insert a new entry" "insérer une nouvelle entrée")
("insert a new item" "insérer un nouvel élément")
("insert a note or a floating object" "insérer une note ou un objet flottant")
("insert a numerical operation" "insérer une opération numérique")
("insert a personal macro" "insérer une macro personnelle")
("insert a picture" "insérer une image")
("insert a prominent piece of text" "insérer du texte en relief")
("insert a question" "insérer une question")
("insert a root" "insérer une racine")
("insert a script" "insérer un script")
("insert a section block" "insérer un bloc de section")
("insert a square root" "insérer une racine carrée")
("insert a table" "insérer un tableau")
("insert a table or a matrix" "insérer un tableau ou une matrice")
("insert a textual operation" "insérer une opération textuelle")
("insert a textual operator" "insérer un opérateur textuel")
("insert a wide symbol above" "insérer un accent large au-dessus")
("insert a wide symbol below" "insérer un accent large en dessous")
("insert above" "insérer vers le haut")
("insert abstract" "insérer le résumé")
("insert an" "insérer un")
("insert an accent" "insérer un accent")
("insert an answer" "insérer une réponse")
("insert an arrow" "insérer une flèche")
("insert an enunciation" "insérer un énoncé")
("insert an environment" "insérer un environnement")
("insert an n" "insérer une racine n")
("insert an operation on tuples" "insérer une opération sur des tuples")
("insert annotation" "insérer une annotation")
("insert appendix" "insérer appendice")
("insert arccos" "insérer arccos")
("insert arcs" "insérer des arcs")
("insert arcsin" "insérer arcsin")
("insert arctan" "insérer arctan")
("insert arg" "insérer arg")
("insert argument" "insérer argument")
("insert argument after" "insérer un argument après")
("insert argument before" "insérer un argument avant")
("insert author" "insérer auteur")
("insert automatically generated content" "insérer du contenu généré automatiquement")
("insert below" "insérer vers le bas")
("insert bibliography" "insérer une bibliographie")
("insert big contour integral" "insérer une grande intégrale de contour")
("insert big coproduct" "insérer un grand coproduit")
("insert big direct sum" "insérer une grande somme directe")
("insert big dotted point" "insérer un grand point dans un cercle")
("insert big integral" "insérer une grande intégrale")
("insert big intersection" "insérer une grande intersection")
("insert big logical and" "insérer un grand et logique")
("insert big logical or" "insérer un grand ou logique")
("insert big product" "insérer un grand produit")
("insert big square union" "insérer une grande réunion angulaire")
("insert big summation" "insérer une grande somme")
("insert big tensor product" "insérer un grand produit tensoriel")
("insert big union" "insérer une grande réunion")
("insert big union sum" "insérer une grande union somme")
("insert big vertical space" "insérer un grand espace vertical")
("insert chapter" "insérer un chapitre")
("insert circles" "insérer des cercles")
("insert closed splines" "insérer des splines fermées")
("insert column" "insérer colonne")
("insert column to the left" "insérer colonne à gauche")
("insert column to the right" "insérer colonne à droite")
("insert copyright and license information" "insérer les informations de copyright et de licence")
("insert cos" "insérer cos")
("insert cosh" "insérer cosh")
("insert cot" "insérer cot")
("insert coth" "insérer coth")
("insert csc" "insérer csc")
("insert deg" "insérer deg")
("insert det" "insérer det")
("insert dim" "insérer dim")
("insert dollar" "insérer dollar")
("insert equation" "insérer équation")
("insert executable markup" "insérer une balise exécutable")
("insert exp" "insérer exp")
("insert explanatory item" "insérer un élément explicatif")
("insert field above" "insérer un champ ci-dessus")
("insert field below" "insérer un champ ci-dessous")
("insert fields" "insérer des champs")
("insert footnote" "insérer une note en bas de page")
("insert formula" "insérer une formule")
("insert gcd" "insérer gcd")
("insert hand drawn curves" "insérer des courbes dessinées à la main")
("insert hom" "insérer hom")
("insert horizontal interword space" "insérer un espace")
("insert image" "insérer une image")
("insert inactive markup" "insérer une balise inactive")
("insert inf" "insérer inf")
("insert input field above" "insérer champ d'entrée au-dessus")
("insert input field below" "insérer champ d'entrée en dessous")
("insert ker" "insérer ker")
("insert large" "insérer un grand")
("insert large delimiters" "insérer des grands délimiteurs")
("insert last name" "insérer le nom de famille")
("insert left" "insérer à gauche")
("insert lg" "insérer lg")
("insert lim" "insérer lim")
("insert liminf" "insérer liminf")
("insert limsup" "insérer limsup")
("insert lines" "insérer des lignes droites")
("insert ln" "insérer ln")
("insert log" "insérer log")
("insert macro" "insérer macro")
("insert mathematics" "insérer des mathématiques")
("insert max" "insérer max")
("insert medium horizontal space" "insérer un espace horizontal moyen")
("insert medium vertical space" "insérer un espace vertical moyen")
("insert min" "insérer min")
("insert missing invisible operators" "insérer les opérateurs invisibles manquants")
("insert more names" "insérer plus de noms")
("insert multiple paragraphs" "insérer plusieurs paragraphes")
("insert negative horizontal space" "insérer un petit espace négatif")
("insert new item or number" "insérer un nouvel élément ou numéro")
("insert new rows or columns" "insérer de nouvelles lignes ou colonnes")
("insert or delete rows or columns" "insérer ou supprimer des lignes ou des colonnes")
("insert overlay after" "insérer un calque après")
("insert overlay before" "insérer un calque avant")
("insert particle" "insérer une particule")
("insert plain text" "insérer du texte brut")
("insert points" "insérer des points")
("insert polygons" "insérer des polygones")
("insert right" "insérer à droite")
("insert row" "insérer une ligne")
("insert row above" "insérer une ligne au-dessus")
("insert row below" "insérer une ligne en dessous")
("insert sec" "insérer sec")
("insert section" "insérer section")
("insert sharp" "insérer dièse")
("insert similar above" "insérer une balise similaire ci-dessus")
("insert similar below" "insérer une balise similaire ci-dessous")
("insert similar block above" "insérer un bloc similaire ci-dessus")
("insert similar block below" "insérer un bloc similaire ci-dessous")
("insert sin" "insérer sin")
("insert sinh" "insérer sinh")
("insert slide after" "insérer une diapositive après")
("insert slide before" "insérer une diapositive avant")
("insert small horizontal space" "insérer un petit espace horizontal")
("insert small vertical space" "insérer un petit espace vertical")
("insert splines" "insérer des splines")
("insert structural markup" "insérer une balise structurelle")
("insert subscript" "insérer un indice")
("insert subsection" "insérer une sous-section")
("insert subsubsection" "insérer une sous-sous-section")
("insert subtable" "insérer un sous-tableau")
("insert sup" "insérer sup")
("insert superscript" "insérer un exposant")
("insert symbol documentation" "insérer la documentation sur le symbole")
("insert tan" "insérer tan")
("insert tanh" "insérer tanh")
("insert template" "insérer un modèle")
("insert text" "insérer du texte")
("insert text field" "insérer un champ de texte")
("insert text field above" "insérer un champ de texte ci-dessus")
("insert text field below" "insérer un champ de texte ci-dessous")
("insert thick horizontal space" "insérer un espace horizontal épais")
("insert title" "insérer un titre")
("insert title after name" "insérer un titre après le nom")
("insert user interface related markup" "insérer une balise associée à l'interface utilisateur")
("insert value" "insérer une valeur")
("inserting control points" "insertion de points de contrôle")
("inside mathematics" "en mode mathématique")
("integer arithmetic" "arithmétique entière")
("integrate" "intégrer")
("interactive command" "commande interactive")
("interactive questions" "questions interactives")
("intercharacter compression" "compression inter-caractères")
("intercharacter stretching" "étirement inter-caractères")
("interfacing" "interfaçage")
("interfacing TeXmacs with other systems" "interfaçage de TeXmacs avec d'autres systèmes")
("interjection" "interjection")
("interline separation" "séparation entre les lignes")
("interline space" "espace d'interligne")
("internationalization" "internationalisation")
("interparagraph space" "espace d'interparagraphe")
("interrupt execution" "interrompre l'exécution")
("interrupted" "interrompu")
("intersperse" "intercaler")
("introduction" "introduction")
("invalid multi-paragraph selection" "sélection multi-paragraphes invalide")
("invalid paste of text into a formula" "collage de texte invalide dans une formule")
("invalid renaming" "renommage invalide")
("invert" "inverser")
("inverted breve" "brève inversée")
("invisible" "invisible")
("invisible citation" "citation invisible")
("invisible ending" "fin invisible")
("invisible newline" "nouvelle ligne invisible")
("invisible opening" "ouverture invisible")
("inwards" "vers l'intérieur")
("irish" "irlandais")
("is running" "est en marche")
("is tuple" "est un tuplet")
("ispell does not respond" "ispell ne répond pas")
("ispell is already busy" "ispell a déjà été lancé")
("italian" "italien")
("italic" "italique")
("italic right" "italique droit")
("itemize" "liste")
("january" "janvier")
("japanese" "japonais")
("join selected cells" "unir les cellules sélectionnées")
("journal" "journal")
("july" "juillet")
("jump in" "retrait après coupures")
("june" "juin")
("junior" "junior")
("justified" "justifié")
("justify" "justifier")
("justify text" "justifier le texte")
("keep evaluated expressions" "garder les expressions évaluées")
("keep local" "garder en local")
("keep remote" "garder à distance")
("keep track of source code" "garder trace du code source")
("keep unfolded" "garder déplié")
("key" "touche")
("key manager" "gestionnaire de clés")
("keyboard" "clavier")
("keyboard configuration" "configuration du clavier")
("keyboard equivalent" "raccourci clavier")
("keyboard modifiers" "modificateurs de clavier")
("keyboard shortcut" "raccourci clavier")
("keymaps" "claviers")
("keys" "clés")
("keyword" "mot-clef")
("keywords" "mots-clefs")
("kill" "tuer")
("known bugs" "bogues connus")
("korean" "coréen")
("laTeX errors" "erreurs LaTeX")
("label" "étiquette")
("landscape" "paysage")
("language" "langue")
("laptop presentations" "présentations")
("large" "grand")
("large brackets" "grandes parenthèses")
("large cells" "grandes cellules")
("large closing bracket" "grande parenthèse fermante")
("large delimiter" "grand délimiteur")
("large displayed" "affichage en largeur")
("large displayed fraction" "grande fraction")
("large opening bracket" "grande parenthèse ouvrante")
("large separator" "grand séparateur")
("large tables" "grandes tables")
("last" "dernier")
("last check" "dernier contrôle")
("last difference" "dernière différence")
("last error" "dernière erreur")
("last field" "dernier champ")
("last indentation" "dernière indentation")
("last name" "nom de famille")
("last occurrence" "dernière occurrence")
("last page" "dernière page")
("last similar" "dernière balise similaire")
("latex command" "commande latex")
("latin" "latin")
("layout" "mise en page")
("lcm" "ppcm")
("left" "à gauche")
("left aligned" "aligné à gauche")
("left arrow" "flèche vers la gauche")
("left axis" "axe gauche")
("left baseline" "ligne de base gauche")
("left border" "limite gauche")
("left bottom" "en bas à gauche")
("left cell border" "bordure gauche de la cellule")
("left cell padding" "espacement à gauche des cellules")
("left center" "centre gauche")
("left click: add point; Right click: undo" "clic gauche : ajouter un point ;
clic droit : annuler")
("left click: finish; Right click: undo" "clic gauche : terminer ; clic droit : annuler")
("left click: new object" "clic gauche : nouvel objet")
("left click: operate" "clic gauche : appliquer")
("left down" "en bas à gauche")
("left margin" "marge à gauche")
("left on even pages" "à gauche sur les pages paires")
("left padding" "espacement à gauche")
("left prime" "prime à gauche")
("left slanted" "italique vers la gauche")
("left subscript" "indice à gauche")
("left superscript" "exposant à gauche")
("left surrounding" "entourage à gauche")
("left table border" "bordure gauche du tableau")
("left table padding" "espacement à gauche du tableau")
("left top" "en haut à gauche")
("left up" "en haut à gauche")
("left-right arrow" "flèche gauche-droite")
("leftwards" "vers la gauche")
("leftwards..." "de droite à gauche...")
("legal" "légal")
("lemma" "lemme")
("lemmas" "lemmes")
("length" "longueur")
("less" "inférieur à")
("less or equal" "inférieur ou égal à")
("let the environment float" "laisser l'environnement flotter")
("letter" "lettre")
("license" "licence")
("light" "léger")
("light grey" "gris clair")
("limit" "limite")
("limitations" "limitations")
("limits" "limites")
("line" "droite")
("line arrows" "flèches de ligne")
("line break" "saut de ligne")
("line breaking" "coupure de lignes")
("line count" "nombre de lignes")
("line dashes" "traits de ligne")
("line portion" "portion de ligne")
("line stretch" "étirabilité des lignes")
("line style" "style de trait")
("line width" "largeur de trait")
("line wrapping" "passage à la ligne automatique")
("line wrapping inside cell" "retour à la ligne dans la cellule")
("linear 2D" "linéaire 2D")
("linear algebra" "algèbre linéaire")
("lines around" "entre deux lignes")
("link" "lien")
("link all embedded images" "lier toutes les images incorporées")
("link image" "lier image")
("link image and copies as" "lier image et copies comme")
("link image as" "lier image comme")
("link mode" "mode de liens")
("link to URL" "lien vers URL")
("linking tool" "outil de liens")
("lissajous" "lissajous")
("list" "liste")
("list all commands" "lister toutes les commandes")
("list of figures" "liste de figures")
("list of tables" "liste de tableaux")
("live" "live")
("live input-output" "entrées-sorties en direct")
("load" "charger")
("load LaTeX file" "charger un fichier LaTeX")
("load TeX file" "charger un fichier TeX")
("load TeXmacs file" "charger un fichier TeXmacs")
("load TeXmacs style file" "charger un fichier de style TeXmacs")
("load a file" "charger un fichier")
("load buffer" "charger un tampon")
("load file" "charger un fichier")
("load help file" "charger le fichier d'aide")
("load html file" "charger un fichier html")
("load image" "charger une image")
("load in new window" "charger dans une nouvelle fenêtre")
("load latex file" "charger un fichier latex")
("load more recent autosave file" "charger le fichier plus récent de sauvegarde automatique")
("load remote file" "charger un fichier distant")
("load tex file" "charger un fichier tex")
("load verbatim file" "charger un fichier verbatim")
("loaded" "chargé")
("loading" "chargement")
("local entries" "entrées locales")
("loci" "loci")
("locus" "locus")
("locus color" "couleur de liens non visités")
("locus rendering" "rendu de locus")
("logarithm" "logarithme")
("logarithmic" "logarithmique")
("logarithmic base" "base logarithmique")
("logarithms" "logarithmes")
("logging in" "se connecter")
("logical and" "et logique")
("logical implication" "implication logique")
("logical not" "négation logique")
("logical or" "ou logique")
("login" "login")
("logout" "déconnexion")
("long" "long")
("long macro" "macro longue")
("long text" "texte long")
("look and feel" "aspect de l'interface")
("look for more fonts" "rechercher de nouvelles polices")
("look up" "rechercher")
("loops" "boucles")
("lower border" "limite en bas")
("m modifier" "modificateur M")
("macro" "macro")
("macro argument" "argument de macro")
("macro definition" "définition de macro")
("macro editor" "éditeur de macro")
("macro name" "nom de la macro")
("macros" "macros")
("macros editor" "éditeur de macros")
("magenta" "mauve")
("magic" "magique")
("magnification" "agrandissement")
("magnified" "agrandi")
("magnify horizontally" "agrandir horizontalement")
("magnify vertically" "agrandir verticalement")
("main" "principal")
("main document font" "police principale du document")
("main document style" "style de document principal")
("main icon bar" "barre d'icônes principale")
("main presentation style" "style principal de présentation")
("major changes" "changements majeurs")
("make a letter environment" "créer un environnement de lettre")
("make a multi-slide presentation" "faire une présentation sur plusieurs diapositives")
("make a page insertion" "créer une insertion de page")
("make a subscript" "insérer un indice")
("make a superscript" "insérer un exposant")
("make acute" "insérer un accent aigu")
("make bar" "créer une barre")
("make block wide" "créer un bloc large")
("make check" "insérer un tchèche")
("make float wide" "créer un objet flottant large")
("make floating" "faire flotter")
("make footnote wide" "créer une note de bas de page large")
("make fraction" "insérer une fraction")
("make grave" "insérer un accent grave")
("make hat" "insérer un accent circonflexe")
("make label" "insérer une étiquette")
("make link" "insérer un lien")
("make negation" "insérer une négation")
("make non floating" "empêcher l'objet de flotter")
("make opaque" "rendre opaque")
("make page reference" "créer une référence de page")
("make reference" "insérer une référence")
("make slides" "créer des diapositives")
("make square root" "insérer une racine carrée")
("make tilde" "insérer un tilde")
("make title" "construire le titre")
("make transparent" "rendre transparent")
("make vector" "insérer un vecteur")
("make wide" "créer un objet large")
("making donations" "effectuer des dons")
("manila paper" "papier de Manille")
("manila-paper" "papier de Manille")
("manual" "manuel")
("manual correction" "correction manuelle")
("manual path" "chemin manuel")
("map arguments" "envoyer arguments")
("map to" "envoyer vers")
("march" "mars")
("marginal note" "note marginale")
("margins" "marges")
("margins as on paper" "marges comme sur le papier")
("margins from width" "marges en fonction de la largeur")
("margins on paper" "marges sur le papier")
("margins on screen" "marges sur l'écran")
("marked" "marqué")
("marker" "marqueur")
("master" "maître")
("master file" "fichier maître")
("master's thesis" "mémoire de master")
("material" "matériaux")
("math" "maths")
("math Extra" "extras mathématiques")
("math Letters" "lettres mathématiques")
("math Symbols" "symboles mathématiques")
("math font" "police mathématique")
("math font family" "famille de police mathématique")
("math font series" "graisse de police mathématique")
("math font shape" "forme de police mathématique")
("mathematical" "mathématique")
("mathematical and customized input" "entrées mathématiques et personnalisées")
("mathematical font" "police mathématique")
("mathematical formulas" "formules mathématiques")
("mathematical input" "entrées sous forme mathématique")
("mathematical output" "sorties sous forme mathématique")
("mathematical typesetting" "mise en page mathématique")
("mathematics" "mathématiques")
("matrices" "matrices")
("matrix" "matrice")
("matrix factorization" "factorisation matricielle")
("maximal" "maximal")
("maximal cell height" "hauteur maximale de la cellule")
("maximal cell width" "largeur maximale de la cellule")
("maximal clustering" "groupage maximal")
("maximal number of columns" "nombre minimal de colonnes")
("maximal number of rows" "nombre maximal de lignes")
("maximal table height" "hauteur maximale du tableau")
("maximal table width" "largeur maximale du tableau")
("maximum" "maximum")
("maximum mode" "mode maximum")
("may" "mai")
("meander" "méandres")
("medieval" "médiéval")
("medium" "moyen")
("medium skip" "saut moyen")
("meminfo" "info mémoire")
("memory" "mémoire")
("memory usage" "utilisation de la mémoire")
("menu" "menu")
("merge" "fusion")
("merge lines into paragraphs unless separated by blank lines" "fusionner des lignes non vides contiguës en paragraphes")
("messages" "messages")
("messy" "embrouillé")
("meta data" "métadonnées")
("meta key" "touche meta")
("metadata" "métadonnées")
("metafont and available type 1" "metafont et type 1 disponible")
("metafont bitmaps only" "metafont bitmaps seulement")
("metal" "métal")
("middle" "au milieu")
("middle baseline" "ligne de base du milieu")
("minimal" "minimal")
("minimal cell height" "hauteur minimale de la cellule")
("minimal cell width" "largeur minimale de la cellule")
("minimal line separation" "séparation minimale de ligne")
("minimal number of columns" "nombre minimal de colonnes")
("minimal number of rows" "nombre minimal de lignes")
("minimal table height" "hauteur minimale du tableau")
("minimal table width" "largeur minimale du tableau")
("minimum" "minimum")
("minimum mode" "mode minimum")
("minus" "moins")
("mirror" "miroir")
("miscellaneous" "divers")
("miscellaneous features" "fonctionnalités diverses")
("miscellanous" "divers")
("mixed" "mixte")
("mod" "mod")
("mode" "mode")
("mode dependent icons" "icônes dépendantes du mode")
("modifier" "modificateur")
("modify bibliography" "modifier la bibliographie")
("modify cell alignment" "modifier alignement de la cellule")
("modify cell border" "modifier la bordure de la cellule")
("modify cell padding" "modifier l'espacement autour de la cellule")
("modify cell size" "modifier la taille de la cellule")
("modify remote live document" "modifier le document live distant")
("modify table border" "bordure du tableau")
("modify table padding" "espacement autour du tableau")
("module" "module")
("module browser" "explorateur de module")
("mongolian" "mongol")
("monospaced" "mono-espacé")
("month" "mois")
("more information about GNU TeXmacs can be found in the Help" "pour plus de renseignements sur GNU TeXmacs, veuillez consulter le menu Aide")
("more information about GNU TeXmacs can be found in the Help->About menu" "plus d'informations sur GNU TeXmacs peuvent être trouvées dans le menu Aide -> À propos")
("more information about GNU TeXmacs can be found in the help" "vous trouverez plus d'informations sur GNU TeXmacs dans l'aide")
("mosaic" "mosaïque")
("motion" "mouvement")
("motion blur" "flou de mouvement")
("mouse over balloon" "souris sur ballon")
("mouse over object" "souris au-dessus de l'objet")
("move" "aller")
("move down" "descendre")
("move object" "déplacer objet")
("move objects" "déplacer des objets")
("move over object on which to operate" "se mettre au-dessus de l'objet sur lequel opérer")
("move to the right when finished" "aller à droite pour terminer")
("move up" "monter")
("move::difference" "aller vers")
("move::similar" "naviguer")
("multiline" "multi-lignes")
("multiline input" "entrées multi-lignes")
("multiple choice" "choix multiple")
("multiple documents share window" "fenêtre de partage de documents multiples")
("multiple root" "racine multiple")
("multiplication" "multiplication")
("mutator tags" "balises mutantes")
("my bibliographic database" "ma base de données bibliographiques")
("my documents" "mes documents")
("n-th" "n-ième")
("n-th root" "racine n-ième")
("name" "nom")
("name of bibliography" "nom de la bibliographie")
("name of glossary" "nom du glossaire")
("name of index" "nom de l'index")
("name of list of figures" "nom de la liste des figures")
("name of list of tables" "nom de la liste des tableaux")
("name of table of contents" "nom de la table des matières")
("named" "nommé")
("navigation options" "options de navigation")
("negation" "négation")
("never" "jamais")
("new" "nouveau")
("new account" "nouveau compte")
("new bibliography dialogue" "nouveau dialogue de bibliographie")
("new buffer" "nouveau tampon")
("new column" "nouvelle colonne")
("new context macro" "nouvelle macro de contexte")
("new document" "nouveau document")
("new double page" "nouvelle page double")
("new double page before" "nouvelle page double avant")
("new entry" "nouvelle entrée")
("new identity" "nouvelle identité")
("new item" "nouvel élément")
("new line" "nouvelle ligne")
("new locus" "nouveau locus")
("new macro" "nouvelle macro")
("new number" "nouveau nombre")
("new page" "nouvelle page")
("new page before" "nouvelle page avant")
("new paragraph" "nouveau paragraphe")
("new passphrase" "nouvelle phrase de passe")
("new remote directory" "nouveau répertoire distant")
("new remote file" "nouveau fichier distant")
("new roman" "new roman")
("new row" "nouvelle ligne")
("new style fonts" "nouveau style de polices")
("new style page breaking" "nouveau style de sauts de page")
("new table" "nouveau tableau")
("new table macro" "nouvelle macro de tableau")
("new version" "nouvelle version")
("new window" "nouvelle fenêtre")
("newer version" "version plus récente")
("next" "suivant")
("next chunk" "morceau suivant")
("next difference" "différence suivante")
("next error" "erreur suivante")
("next field" "champ suivant")
("next line" "ligne suivante")
("next match" "suivant")
("next occurrence" "prochaine occurrence")
("next screen" "écran suivant")
("next similar" "balise similaire suivante")
("nickname" "surnom")
("no" "non")
("no animation" "pas d'animation")
("no changes need to be saved" "il n'y a pas de changements à sauvegarder")
("no clustering" "pas de regroupement")
("no completions" "pas de complétions")
("no dictionary for" "pas de dictionnaire pour")
("no errors have been corrected" "aucune erreur n'a été corrigée")
("no first indentation" "pas de première indentation")
("no grid" "pas de grille")
("no indentation" "pas d'indentation")
("no line break" "pas de saut de ligne")
("no matches found" "aucune occurrence trouvée")
("no matches found for" "pas d'occurrences pour")
("no more matches for" "tout a déjà été défait")
("no more redo information available" "tout a déjà été refait")
("no more undo information available" "les renseignements pour défaire ont été épuisés")
("no multiple spaces" "pas d'espaces multiples")
("no name" "sans nom")
("no new public key in document" "pas de nouvelle clé publique dans le document")
("no page break" "pas de saut de page")
("no page break after" "pas de saut de page après")
("no page break before" "pas de saut de page avant")
("no page numbers" "pas de numéros de page")
("no parent" "pas de parent")
("no selection" "pas de sélection")
("no spelling errors" "pas de fautes d'orthographe")
("no spelling errors found in text" "le texte ne contient pas de fautes d'orthographe")
("no spurious spaces" "pas d'espaces superflus")
("no style" "sans style")
("none" "néant")
("normal" "normal(e)")
("normal loci" "loci normaux")
("normal size" "taille normale")
("norwegian" "norvégien")
("not" "non")
("not allowed to remove home directory" "pas autorisé à supprimer le répertoire de base")
("not connected to server" "non connecté au serveur")
("not equal" "différent de")
("not found" "non trouvé")
("not yet implemented" "pas encore implémenté")
("notation" "notation")
("notations" "notations")
("note" "note")
("notebook" "cahier")
("notes" "notes")
("november" "novembre")
("number" "nombre")
("number equation" "numéroter l'équation")
("number of columns" "nombre de colonnes")
("number of polar steps" "nombre de pas angulaires")
("number of subunit steps" "nombre de pas pour les sous-unités")
("numbered" "numéroté")
("numbered equation" "équation numérotée")
("numbered equations" "équations numérotées")
("numbering" "numérotation")
("numerator" "numérateur")
("numeric" "numérique")
("numeric analysis" "analyse numérique")
("numeric comma table" "tableau à virgules décimales")
("numeric dot table" "tableau à points décimaux")
("numeric spreadsheet" "tableur numérique")
("objectives" "objectifs")
("oblique" "obliques")
("occurrences" "occurrences")
("october" "octobre")
("odd page" "page impaire")
("odd page footer" "pied de page des pages impaires")
("odd page header" "en-tête des pages impaires")
("odd page left margin" "marge gauche des pages impaires")
("odd page margin" "marge des pages impaires")
("odd page right margin" "marge droite des pages impaires")
("odd page shift" "décalage pour les pages impaires")
("odd page text" "texte pour les pages impaires")
("odd pages" "pages impaires")
("of" "de")
("of fingerprint" "d'empreinte digitale")
("off" "désactiver")
("ok" "ok")
("old english" "vieil anglais")
("old slavonic" "vieux slave")
("old style" "ancien style")
("old version" "ancienne version")
("older version" "version plus ancienne")
("on" "activer")
("on cells" "par cellules")
("on columns" "par colonnes")
("on entire table" "par tableau entier")
("on rows" "par lignes")
("on the footer" "sur la barre d'état")
("on your system and set it up from the \"Security\" tab" "sur votre système et configurez-le à partir de l'onglet «Sécurité»")
("once" "une fois")
("one column" "une colonne")
("one error has been corrected" "une erreur a été corrigée")
("one lower case letter, one non alpha-numeric symbol" "une lettre minuscule, un symbole non alpha-numérique")
("one numeric character, one upper case letter" "un caractère numérique, une lettre majuscule")
("one spelling error has been corrected" "une faute d'orthographe a été corrigée")
("online documentation" "documentation en ligne")
("online help" "aide en ligne")
("only convert changes when re-importing" "convertir uniquement les modifications lors de la réimportation")
("only convert changes with respect to imported version" "Convertir uniquement les modifications par rapport à la version importée")
("only convert changes with respect to tracked version" "convertir uniquement les modifications par rapport à la version suivie")
("only implemented for complete subtrees" "implémenté uniquement pour les sous-arbres complets")
("only inline tags" "balises incorporées seulement")
("only keep folded" "garder seulement les objets pliés")
("only keep unfolded" "garder seulement les objets dépliés")
("only show paragraphs with hits" "Afficher uniquement les paragraphes avec des occurrences")
("only show semantic focus" "seulement montrer le focus sémantique")
("opacity" "opacité")
("open" "ouvrir")
("open a new buffer" "ouvrir un nouveau tampon")
("open bibliography" "ouvrir la bibliographie")
("open identities" "ouvrir les identités")
("open in new window" "ouvrir dans une nouvelle fenêtre")
("open key manager" "ouvrir le gestionnaire de clés")
("open licence agreement" "ouvrir le contrat de licence")
("open mailbox" "ouvrir la boîte aux lettres")
("open module browser" "ouvrir l'explorateur de modules")
("open new window" "ouvrir une nouvelle fenêtre")
("open on errors" "ouvrir en cas d'erreur")
("open on warnings" "ouvrir en cas d'avertissement")
("open symbol browser" "ouvrir l'explotateur de symboles")
("open tool in separate window" "ouvrir l'outil dans une fenêtre séparée")
("opening" "ouverture")
("operation mode" "mode d'opération")
("operation on named selection" "opération sur une sélection nommée")
("operation on primary selection" "opération sur la sélection primaire")
("operation on secondary selection" "opération sur la sélection secondaire")
("operation on ternary selection" "opération sur la sélection ternaire")
("optical" "optique")
("option" "option")
("options" "options")
("or" "ou")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ou donnez le chemin complet à la commande «gpg» ou «gpg2»")
("orange" "orange")
("order" "ordre")
("ordinary symbol" "symbole ordinaire")
("orientation" "orientation")
("origin" "origine")
("original welcome message" "message de bienvenue originel")
("ornamented" "orné")
("other" "autre")
("other login" "autre login")
("other package" "autre paquetage")
("other pages" "autres pages")
("other projects" "autres projets")
("other style" "autre style")
("outer" "extérieur")
("outer bottom" "extérieur bas")
("outer left" "extérieur gauche")
("outer right" "extérieur droit")
("outer top" "extérieur haut")
("outline" "contours")
("outlined" "contours")
("outlined emboss" "contours bossu")
("outlined engrave" "contours gravé")
("outlined roman" "contours romain")
("output" "sortie")
("output options" "options de sortie")
("outwards" "vers l'extérieur")
("oval" "ovale")
("oval blur" "flou ovale")
("over" "sur")
("overbrace" "accolade au-dessus")
("overlap" "chevauchement")
("overlay" "calque")
("overlay mode" "mode calques")
("overlays" "calques")
("overline" "surligner")
("overlined" "surligné")
("overview of the scheme extension language" "aperçu du langage d'extension scheme")
("owner" "propriétaire")
("padded" "entre espaces verticales")
("padding" "espacement")
("padding above" "rembourrage au dessus")
("padding below" "rembourrage ci-dessous")
("page" "page")
("page background" "fond de page")
("page bottom margin" "marge de page en bas")
("page break" "saut de page")
("page break after" "saut de page après")
("page break before" "saut de page avant")
("page breaking algorithm" "algorithme de coupure de page")
("page format" "format de page")
("page height" "hauteur de page")
("page insertion" "insertion de page")
("page layout" "mise en page")
("page number" "numéro de la page")
("page number rendering" "rendu du numéro de page")
("page number text" "texte pour les numéros de page")
("page numbering" "numérotation des pages")
("page reference" "référence de page")
("page rendering" "rendu de page")
("page right margin" "marge droite de la page")
("page setup" "paramètres d'impression")
("page top margin" "marge de page en haut")
("page type" "type de page")
("page width" "largeur de page")
("pagedown" "page suivante")
("pages" "pages")
("pageup" "page précédente")
("pale-blue" "bleu pâle")
("palette" "palette")
("panorama" "panorama")
("paper" "papier")
("paper size" "taille de papier")
("paper type" "type de papier")
("papyrus" "papyrus")
("paragraph" "paragraphe")
("paragraph format" "format de paragraphe")
("paragraph mode" "type de paragraphe")
("paragraph width" "largeur du paragraphe")
("paragraph::section" "paragraphe")
("paragraphs" "paragraphes")
("parametric curve" "courbe paramétrée")
("parametric surface" "surface paramétrée")
("parchment" "parchemin")
("parenthesis" "parenthèse")
("parenthesized" "parenthésé")
("parser" "parseur")
("part" "partie")
("particle" "particule")
("passphrase decryption" "déchiffrement par phrase secrète")
("passphrase encryption" "chiffrement par phrase secrète")
("passphrase wallet facilities are not currently available" "les fonctionnalités du trousseau de clés ne sont pas disponibles actuellement")
("passphrases are expected to have at least: 8 characters" "les phrases de passe doivent comporter au moins 8 caractères")
("passphrases mismatch" "incompatibilité des phrases secrètes")
("password" "mot de passe")
("past changes" "changements effectués")
("paste" "coller")
("paste from" "coller de")
("paste text" "coller du texte")
("pastel" "pastel")
("path" "chemin")
("pattern" "motif")
("pattern selector" "sélecteur de motifs")
("pause" "pause")
("pdf version number" "numéro de version Pdf")
("pen" "stylo")
("pen angle" "angle du trait")
("pen height" "hauteur du trait")
("pen width" "épaisseur du trait")
("perform operations on cells" "opérer cellule par cellule")
("perform operations on columns" "opérer sur des colonnes")
("perform operations on entire table" "opérer sur le tableau entier")
("perform operations on rows" "opérer sur des lignes")
("permanent" "permanent")
("permanent footer" "pied de page permanent")
("permanent header" "en-tête permanent")
("permanently add to dictionary" "ajouter définitivement au dictionnaire")
("permanently insert into dictionary" "rajouter de façon permanente au dictionnaire")
("permissions" "autorisations")
("person" "personne")
("personal dictionary has been modified" "votre dictionnaire personnel a été modifié")
("phantasy" "fantaisie")
("phantom" "fantômes")
("phantoms" "fantômes")
("phd thesis" "thèse de doctorat")
("philosophy" "philosophie")
("phoenician" "phénicien")
("phonetic" "phonétique")
("physics and astronomy class" "classification PACS")
("picture" "image")
("pine" "pin")
("pink" "rose")
("plain" "ordinaire")
("plain block" "bloc standard")
("plain boxes" "cases remplies")
("plain circles" "cercles remplis")
("plain tabular" "tableau standard")
("planned changes" "changements prévus")
("plans for the future" "projets pour l'avenir")
("play" "jouer")
("play all animations" "jouer toutes les animations")
("play animation" "jouer l'animation")
("please" "de grâce")
("please install GnuPG software from https://www.gnupg.org" "installez le logiciel GnuPG à partir de https://www.gnupg.org")
("please wait" "patientez un instant s.v.p.")
("plot" "graphique")
("plots editor" "éditeur de tracés")
("plug-ins" "greffons")
("plugin" "greffon")
("plugins" "greffons")
("plural" "pluriel")
("plus" "plus")
("point" "point")
("point border" "bordure de points")
("point size" "taille en points")
("point style" "style de points")
("polar" "polaire")
("polish" "polonais")
("polygon" "polygone")
("polynomial arithmetic" "arithmétique polynomiale")
("pop server settings" "paramètres du serveur pop")
("porting TeXmacs to other platforms" "porter TeXmacs vers d'autres plate-formes")
("portion" "portion")
("portrait" "portrait")
("portuguese" "portugais")
("position" "position")
("position float" "positionner flottant")
("position floating object" "positionner l'objet flottant")
("position of marginal note" "position de la note en marge")
("position the table" "positionner le tableau")
("poster" "affiche")
("poster formats" "formats de posters")
("poster theme" "thème du poster")
("postfix" "postfix")
("postscript" "postscript")
("postscript image" "image postscript")
("pre-alpha release" "version pré-alpha")
("preamble" "préambule")
("preamble mode" "mode préambule")
("preferences" "préférences")
("preferences for editing mathematical formulas" "préférences pour l'édition de formules mathématiques")
("preferences for tag" "préférences pour la balise")
("prefix" "préfix")
("prefix by section number" "préfixe par numéro de section")
("presentation" "présentation")
("presentation mode" "mode présentation")
("presentation tag" "balise de présentation")
("presentation tool" "outil de présentation")
("preserve" "conserver")
("preserve tags" "préserver les balises")
("preserving syntactic correctness while editing mathematical formulas" "Préservation de l'exactitude syntaxique lors de l'édition de formules mathématiques")
("pretty" "joli")
("pretty scheme tree output" "jolie sortie d'arbre de schéma")
("pretty tree output" "jolie sortie pour des arbres")
("preview" "aperçu")
("preview before printing" "aperçu avant l'impression")
("preview command" "commande de prévisualisation")
("preview with ghostview" "prévisualiser avec ghostview")
("previous" "précédent")
("previous difference" "différence précédente")
("previous error" "erreur précédente")
("previous field" "champ précédent")
("previous match" "précédent")
("previous occurrence" "occurrence précédente")
("previous screen" "écran précédent")
("previous similar" "balise similaire précédente")
("primary" "primaire")
("prime" "prime")
("primitive or macro" "primitive ou macro")
("print" "imprimer")
("print all" "imprimer tout")
("print all to file" "imprimer tout vers un fichier")
("print buffer" "imprimer le document")
("print buffer to file" "imprimer le document vers un fichier")
("print document" "document imprimé")
("print page selection" "imprimer une sélection de pages")
("print page selection to file" "imprimer une sélection de pages vers un fichier")
("print to file" "imprimer vers un fichier")
("print to postscript file" "imprimer vers fichier postscript")
("printer" "imprimante")
("printer dpi" "résolution de l'imprimante en points par pouce")
("printer setup" "configuration de l'imprimante")
("printing command" "commande d'impression")
("problem" "problème")
("problems" "problèmes")
("proceed" "continuer")
("produce Pdf using native export filter" "produire un fichier Pdf en utilisant un filtre d'exportation natif")
("produce Postscript using native export filter" "produire du Postscript à l'aide du filtre d'exportation natif")
("professional" "professionnel")
("prog" "prog")
("prog font" "police pour programmer")
("prog font family" "famille de police de programmation")
("prog font series" "graisse de police de programmation")
("prog font shape" "forme de police de programmation")
("program" "programme")
("program bracket matching" "correspondance entre parenthèses (programmes)")
("program bracket selections" "sélections de parenthèses (programmes)")
("program commands" "commandes de programme")
("program font" "police de programmation")
("program interface for buffer management" "interface pour gérer les tampons")
("program mode" "mode programmation")
("programming" "programmation")
("programming routines for editing documents" "routines de programmation pour l'édition de documents")
("progressive" "progressif")
("project" "projet")
("projector" "projecteur")
("projects" "projets")
("prologue" "prologue")
("prominent" "mise en valeur")
("prompt on scripts" "demander l'acceptation de chaque script")
("prompts and default input" "prompts et entrées par défaut")
("proof" "démonstration")
("proofs" "démonstrations")
("properties" "propriétés")
("proportional" "proportionnel")
("proportional typewriter" "machine à écrire proportionnelle")
("property" "propriété")
("proposition" "proposition")
("propositions" "propositions")
("provoke C++ error" "provoquer une erreur C++")
("provoke menu error" "provoquer une erreur de menu")
("provoke scheme error" "provoquer une erreur Scheme")
("pseudo code" "pseudo-code")
("public key encryption" "chiffrement à clé publique")
("public keys" "clés publiques")
("pulse" "pulsation")
("qt GUI only, sorry. Use \"Export selection\"" "pour interface qt seulement, désolé. Utiliser «Exporter la sélection»")
("qt-widgets" "widgets Qt")
("quadratic forms" "formes quadratiques")
("quantifier" "quantificateur")
("quasi" "quasi")
("query replace" "remplacement contrôlé")
("question" "question")
("questions" "questions")
("questions only" "questions seulement")
("questions with answers" "questions et réponses")
("quick evaluation of formulas" "évaluation rapide des formules")
("quit" "quitter")
("quit TeXmacs" "quitter TeXmacs")
("quotation" "citation")
("quote" "citer")
("radius" "rayon")
("radius x" "rayon x")
("radius y" "rayon y")
("range" "partie")
("rank" "rang")
("raw" "brut")
("read" "lecture")
("real" "réel")
("really close it" "vraiment fermer")
("really delete user identity" "efface vraiment l'identité de l'utilisateur")
("really huge" "vraiment énorme")
("really quit" "voulez-vous vraiment quitter")
("really tiny" "vraiment minuscule")
("rebuild translations file" "reconstruire le fichier de traduction")
("recent" "récent")
("recent documents" "documents récents")
("recipients" "destinataires")
("recognize" "reconnaître")
("recolor" "recolorer")
("recover autosave file" "recupérer fichier de sauvegarde automatique")
("rectangle" "rectangle")
("rectangular" "rectangulaire")
("red" "rouge")
("reddish" "rougeâtre")
("redo" "répéter")
("redo undone changes" "refaire des changements annulés")
("reduce" "réduire")
("reduce bottom margin by" "réduire marge en bas de")
("reduce by" "réduire de")
("reduce left margin by" "réduire marge à gauche de")
("reduce margins" "réduire les marges")
("reduce right margin by" "réduire marge à droite de")
("reduce top margin by" "réduire marge en haut de")
("reduce trigonometric functions" "réduire les fonctions trigonométriques")
("reduced margins" "marges réduites")
("reduction bottom margin" "réduction marge en bas")
("reduction even page margin" "réduction marge de page impaire")
("reduction odd page margin" "réduction marge de page paire")
("reduction page bottom margin" "réduction de la marge de page en bas")
("reduction page right margin" "réduction de la marge de page à droite")
("reduction page top margin" "réduction de la marge de page en haut")
("reduction right margin" "réduction marge à droite")
("reduction top margin" "réduction marge en haut")
("reference" "référence")
("reference guide" "guide de référence")
("reference guide for the TeXmacs primitives" "guide de référence pour les primitives TeXmacs")
("reference guide for the standard TeXmacs styles" "guide de référence pour les styles standards de TeXmacs")
("reference to note" "référence vers une note")
("references" "références")
("regenerate" "régénérer")
("register" "enrégistrer")
("register file" "enrégistrer le fichier")
("regular" "normal")
("relate" "en relation")
("relation" "relation")
("release" "version")
("release left button: finish editing" "relâcher le bouton gauche : terminer l'édition")
("reload" "recharger")
("remark" "remarque")
("remarks" "remarques")
("remote" "distant")
("remote connections" "connexions à distance")
("remote control" "commande à distance")
("remote controllers with keyboard simulation" "télécommandes avec simulation
du clavier")
("remote directory" "répertoire distant")
("remote login" "connexion à distance")
("remote plug-ins" "plug-ins distants")
("remote servers" "serveurs distants")
("remote tool" "outil de connections distantes")
("remove" "enlever")
("remove all output fields" "enlever tous les champs de sortie")
("remove animation" "supprimer l'animation")
("remove argument after" "supprimer l'argument après")
("remove argument before" "supprimer l'argument avant")
("remove banner" "enlever la bannière")
("remove database entry" "supprimer une entrée de base de données")
("remove downwards" "supprimer vers le bas")
("remove entries" "supprimer des entrées")
("remove entry" "supprimer l'entrée")
("remove field above" "supprimer le champ ci-dessus")
("remove field below" "supprimer le champ ci-dessous")
("remove fields" "enlever des champs")
("remove folded" "enlever l'objet plié")
("remove from previous frames" "supprimer des cadres précédents")
("remove from subsequent frames" "enlever des cadres suivants")
("remove input field" "enlever champ d'entrée")
("remove input field above" "enlever champ d'entrée au-dessus")
("remove last field" "supprimer le dernier champ")
("remove leftwards" "supprimer vers la gauche")
("remove link" "supprimer le lien")
("remove next field" "supprimer le champ suivant")
("remove number" "enlever le numéro")
("remove overlay after" "supprimer le calque après")
("remove overlay before" "supprimer le calque avant")
("remove package" "supprimer paquetage")
("remove previous field" "supprimer le champ précédent")
("remove remote ssh connection" "supprimer la connexion ssh distante")
("remove rightwards" "supprimer vers la droite")
("remove selected database entries" "supprimer les entrées de base de données sélectionnées")
("remove selected entries" "supprimer les entrées sélectionnées")
("remove slide after" "supprimer la diapositive après")
("remove slide before" "supprimer la diapositive avant")
("remove superfluous invisible operators" "supprimer les opérateurs invisibles superflus")
("remove tag" "supprimer la balise")
("remove this branch" "supprimer cette branche")
("remove this frame" "supprimer ce cadre")
("remove this switch" "enlever ce commutateur")
("remove unfolded" "supprimer l'objet déplié")
("remove upwards" "supprimer vers le haut")
("removed entries from database" "entrées supprimées de la base de données")
("removed entry from database" "entrée supprimée de la base de données")
("rename" "renommer")
("rename section" "renommer la section")
("rendering" "rendu")
("rendering options for tag" "options de rendu pour la balise")
("renumber this page" "renuméroter cette page")
("repeat" "répéter")
("repeat object" "répéter objet")
("replace" "remplacer")
("replace TeXmacs styles with no LaTeX equivalents" "remplacer les styles TeXmacs sans équivalent LaTeX")
("replace all further occurrences" "remplacer toutes les occurrences ultérieures")
("replace by" "remplacer par")
("replace one occurrence" "remplacer une occurrence")
("replace toolbar" "barre d'outils pour des remplacements")
("replace unrecognized styles" "remplacer des styles non reconnus")
("replaced" "j'ai remplacé")
("replaced one occurrence" "j'ai remplacé une occurrence")
("research papers" "articles de recherche")
("reset" "remettre")
("reset error counters" "réinitialiser les compteurs d'erreur")
("resize" "redimensionner")
("resize object" "redimensionner objet")
("resize objects" "redimensionner des objets")
("resized" "redimensionné")
("restart TeXmacs in order to let changes take effect" "redémarrer TeXmacs pour que les modifications prennent effet")
("restart in order to let the new look and feel take effect" "redémarrer afin de laisser la nouvelle apparence prendre effet")
("retain" "retenir")
("retime" "transformer le temps")
("retina settings" "paramètres d'écran rétina")
("retrieve email" "récupérer le courrier électronique")
("retrieve remote live document" "récupérer un document actif à distance")
("retrieved contents" "contenus récupérés")
("retro" "rétro")
("return" "entrée")
("reverse" "inverser")
("reverse ordering" "ordre inverse")
("revert" "recharger")
("revert buffer" "actualiser tampon")
("rewriting" "réécriture")
("ridged paper" "papier plissé")
("ridged-paper" "papier plissé")
("right" "à droite")
("right aligned" "aligné à droite")
("right arrow" "flèche vers la droite")
("right baseline" "ligne de base droite")
("right border" "limite droite")
("right cell border" "bordure droite de la cellule")
("right cell padding" "espacement à droite des cellules")
("right down" "en bas à droite")
("right margin" "marge à droite")
("right on even pages" "à droite sur les pages paires")
("right padding" "espacement à droite")
("right page margin" "marge de page à droite")
("right subscript" "indice à droite")
("right superscript" "exposant à droite")
("right surrounding" "entourage à droite")
("right table border" "bordure droite du tableau")
("right table padding" "espacement à gauche du tableau")
("right up" "en haut à droite")
("rightwards" "vers la droite")
("rightwards..." "de gauche à droite...")
("rigid" "fixe")
("rigid box" "boîte fixe")
("rigid horizontal" "horizontal fixe")
("rigid space" "espace fixe")
("ring binder notebook style" "style cahier à reliure à anneaux")
("roman" "romain")
("romanian" "roumain")
("root" "racine")
("rotate" "tourner")
("rotate backward" "tourner en arrière")
("rotate forward" "tourner en avant")
("rotate objects" "faire pivoter des objets")
("rough" "brut")
("rough paper" "papier rugueux")
("rough-paper" "papier rugueux")
("round" "rond")
("round overbrace" "parenthèse au-dessus")
("round underbrace" "parenthèse en dessous")
("rounded" "arrondis")
("row" "ligne")
("row above" "ligne au-dessus")
("row below" "ligne en dessous")
("row contains glued items" "la ligne contient des parties collées")
("rows" "lignes")
("run" "exécuter")
("run current file" "exécuter le fichier actuel")
("runic" "runes")
("running author" "auteur courant")
("running title" "titre courant")
("russian" "russe")
("russian and Ukrainian users" "utilisateurs Russes et Ukrainiens")
("same names" "mêmes noms")
("same screen margins as on paper" "mêmes marges sur l'écran et sur le papier")
("sample" "échantillon")
("sample text" "échantillon de texte")
("sans serif" "sans sérifs")
("save" "sauvegarder")
("save TeXmacs file" "sauvegarder fichier TeXmacs")
("save TeXmacs style file" "sauvegarder fichier de style TeXmacs")
("save all embedded images" "enregistrer toutes les images incorporées")
("save as" "sauvegarder sous")
("save as LaTeX" "sauvegarder comme LaTeX")
("save as TeX" "sauvegarder comme TeX")
("save auxiliary data" "sauvegarder les données auxiliaires")
("save buffer" "sauvegarder tampon")
("save buffer as" "sauvegarder tampon sous")
("save entries" "sauvegarder les entrées")
("save entry" "sauvegarder l'entrée")
("save file" "sauvegarder fichier")
("save html file" "sauvegarder fichier html")
("save image" "sauvegarder image")
("save image as" "sauvegarder l'image sous")
("save latex file" "sauvegarder fichier latex")
("save position" "retenir la position")
("save remote file" "sauvegarder le fichier distant")
("save tex file" "sauvegarder fichier tex")
("save this buffer" "sauvegarder ce tampon")
("save verbatim file" "sauvegarder fichier verbatim")
("saved" "sauvegardé")
("saved modifications in database" "modifications sauvegardées dans la base de données")
("scale of the graphical user interface" "échelle de l'interface utilisateur")
("scale graphical interface" "échelle de l'interface utilisateur")
("scheme command" "commande scheme")
("scheme developers guide" "guide pour développeurs en Scheme")
("scheme extensions" "extensions scheme")
("scheme interface for the graphical mode" "interface Scheme pour le mode graphique")
("screen" "écran")
("screen layout" "apparence sur l'écran")
("screen margins" "marges sur l'écran")
("screen rendering" "rendu sur écran")
("screens" "écrans")
("screenshot" "capture d'écran")
("script" "indice")
("script above" "indice en haut")
("script below" "indice en bas")
("script script size" "taille d'indices d'indices")
("script size" "taille d'indices")
("scripting language" "langage de scripts")
("scripts" "scripts")
("scripts not accepted" "les scripts ne sont jamais acceptés")
("search" "chercher")
("search and replace" "chercher et remplacer")
("search in database" "recherche dans la base de données")
("search results for" "resultats de la recherche pour")
("search toolbar" "barre d'outils pour des recherches")
("search words in my documents" "chercher des mots dans mes documents")
("search words in the documentation" "chercher des mots dans la documentation")
("search words in the source code" "chercher des mots dans le code source")
("searching" "cherche")
("second" "seconde")
("secondary" "secondaire")
("secret keys" "clés secrètes")
("section" "section")
("sections" "sections")
("security" "sécurité")
("see" "voir")
("see documentation" "voir documentation")
("select GnuPG recipients" "certains destinataires GnuPG")
("select a document style" "sélectionner un style de document")
("select a foreground color" "sélectionner une couleur")
("select a language" "sélectionner une langue")
("select background picture" "sélectionner l'image de fond")
("select color" "sélectionner la couleur")
("select document style" "sélectionner le style du document")
("select pen" "sélectionner un stylo")
("select the action to be undertaken for each conflict" "sélectionner l'action à entreprendre pour chaque conflit")
("select view mode" "mode de visualisation")
("selected region" "région sélectionnée")
("selection" "sélection")
("selections" "sélections")
("semantic correctness" "correction sémantique")
("semantic editing" "édition sémantique")
("semantic selections" "sélections sémantiques")
("semantics" "sémantique")
("seminar" "séminaire")
("sending commands to TeXmacs" "envoi de commandes à TeXmacs")
("senior" "senior")
("separation between lines" "espacement entre les lignes")
("separation between paragraphs" "espacement entre les paragraphes")
("separator" "séparateur")
("september" "septembre")
("serb" "serbe")
("series" "graisse")
("series|right" "droit")
("serif" "sérif")
("server" "serveur")
("server licence agreement" "contrat de licence de serveur")
("session" "session")
("session commands" "commandes de session")
("session name" "nom de la session")
("session type" "type de la session")
("sessions" "sessions")
("set" "mettre")
("set background color of cell" "changer la couleur de la cellule")
("set cell mode" "mode d'opération sur les cellules")
("set default" "changer la valeur par défaut")
("set difference" "différence ensembliste")
("set extension center" "centre d'extension")
("set height" "changer hauteur")
("set height of cell" "changer la hauteur de la cellule")
("set intersection" "intersection ensembliste")
("set margins" "changer indentations")
("set n" "entrer n")
("set number of columns" "changer le nombre de colonnes")
("set number of rows" "changer le nombre de lignes")
("set or get environment variables" "changer ou obtenir des variables d'environnement")
("set paragraph margins" "changer les marges du paragraphe")
("set paragraph mode" "changer le mode d'alignement du paragraphe")
("set printer dpi" "spécifier résolution de l'imprimante")
("set printing command" "commande pour imprimer")
("set properties" "changer les propriétés")
("set span" "changer portée")
("set special cell properties" "changer propriétés spéciales de la cellule")
("set special table properties" "changer propriétés spéciales du tableau")
("set text width" "changer largeur du texte")
("set union" "union ensembliste")
("set user information" "changer les informations utilisateur")
("set width" "changer largeur")
("set width of cell" "changer la largeur de la cellule")
("settings" "réglage")
("setup printer" "configurer imprimante")
("seventh" "septième")
("several equations" "plusieurs équations")
("shadow" "ombre")
("shadowed" "ombre")
("shadowed raise" "élever avec ombre")
("shape" "forme")
("sharpness" "netteté")
("shift" "décaler")
("shift-down" "shift-bas")
("shift-right" "shift-droite")
("shift::keyboard" "maj")
("short" "court")
("shortcut" "raccourci")
("show" "afficher")
("show all" "tout afficher")
("show all parts" "montrer toutes les parties")
("show current focus" "montrer le focus actuel")
("show full context" "montrer le contexte complet")
("show grid" "montrer la grille")
("show header and footer" "afficher en-tête et pied de page")
("show hidden" "montrer partie cachée")
("show key presses" "montrer les frappes sur le clavier")
("show main document" "afficher le document principal")
("show memory usage" "afficher l'utilisation de la mémoire")
("show on screen" "montrer sur l'écran")
("show one part" "montrer une partie")
("show panorama" "mode panorama")
("show preamble" "afficher le préambule")
("show several parts" "montrer plusieurs parties")
("show subunits" "montrer les sous-unités")
("show table cells" "montrer les cellules de tableau")
("show timings" "afficher les durées d'exécution")
("shrinking factor" "facteur de réduction")
("side tools" "outils latéraux")
("signature" "signature")
("simple" "simple")
("simple form" "formulaire simple")
("simple widget" "widget simple")
("simplification" "simplification")
("simplified evaluation of formulas" "évaluation simplifiée de formules")
("simplified menus" "menus simplifiés")
("simplify" "simplifier")
("sine" "sinus")
("sine and cosine" "sinus et cosinus")
("sixth" "sixième")
("size" "taille")
("size limits" "limitations de taille")
("size tag" "balise de taille")
("skew" "tordre")
("skin" "peau")
("skip all" "sauter tout")
("slant" "pente")
("slanted" "oblique")
("slashed fraction" "fraction barrée")
("slide" "diapositive")
("slides" "diapositives")
("sloppy" "relâché")
("slovak" "slovaque")
("slovene" "slovène")
("slow" "lent")
("slow decrease" "diminuer lentement")
("slow increase" "augmenter lentement")
("small" "petit")
("small Capitals" "petites majuscules")
("small capitals" "petites majuscules")
("small caps" "petites majuscules")
("small environment box" "petite boîte d'environnement")
("small figure" "petite figure")
("small focus" "petit focus")
("small inline" "petit et incorporé")
("small inline fraction" "petite fraction incorporée")
("small skip" "petit saut")
("small table" "petit tableau")
("smash" "écraser")
("smooth" "lisse")
("smooth end" "fin lisse")
("smooth extremities" "extrémités lisses")
("smooth start" "début lisse")
("snap" "accrocher")
("snap distance" "distance d'accrochage")
("snap to curves" "s'accrocher aux courbes")
("snap to grid" "s'accrocher à la grille")
("snap to grid curve" "s'accrocher aux courbes de la grille")
("snap to intersections of curves" "s'accrocher aux intersections de courbes")
("snap to pages" "accrocher aux pages")
("snap to text borders" "s'accrocher aux bordures du texte")
("snap to text corners" "s'accrocher aux coins du texte")
("solution" "solution")
("solution to exercise" "solution de l'exercice")
("solution to problem" "solution au problème")
("solutions" "solutions")
("solve" "résoudre")
("solve in" "résoudre en")
("solving equations" "résolution d'équations")
("sound" "son")
("sound..." "son...")
("source" "source")
("source code" "code source")
("source directory" "répertoire source")
("source macros tool" "outil pour les macros des sources")
("source tags" "balises du code source")
("south" "sud")
("south east" "sud est")
("space" "espace")
("space bar in math mode" "barre d'espace en mode math")
("space bar in text mode" "barre d'espace en mode texte")
("space between lines" "espace d'interligne")
("space between paragraphs" "espace d'interparagraphe")
("space stretchability" "étirabilité de l'espace")
("spacing" "espacement")
("span" "portée")
("span over all columns" "étendre sur toutes les colonnes")
("spanish" "espagnol")
("special" "spécial")
("special cell properties" "propriétés spéciales de la cellule")
("special cell properties and actions" "propriétés et actions spéciales des cellules")
("special functions" "fonctions spéciales")
("special properties" "propriétés spéciales")
("special table properties" "propriétés spéciales du tableau")
("specific" "spécifique")
("specific baseline" "ligne de base spécifique")
("specified" "spécifié")
("specify color alternation" "spécifier l'alternance des couleurs")
("specify how to traverse the manual" "spécifier comment parcourir le manuel")
("specify semantics of a symbol or formula" "spécifier la sémantique d'un symbole ou d'une formule")
("specify the size of the table" "spécifier la taille du tableau")
("specify user identity" "spécifier l'identité de l'utilisateur")
("spell" "orthographe")
("spell check" "correction d'orthographe")
("spell checking complete" "vérification orthographique terminée")
("spelling error" "faute d'orthographe")
("spelling errors have been corrected" "les fautes d'orthographe ont été corrigées")
("spline" "spline")
("split" "division")
("split program" "couper le programme")
("split session" "diviser la session")
("square" "carré")
("square overbrace" "crochet au-dessus")
("square root" "racine carrée")
("square underbrace" "crochet en dessous")
("stack" "pile")
("standard" "standard")
("standard Output" "sortie standard")
("standard TeXmacs styles" "styles TeXmacs standards")
("standard environment variables" "variables d'environnement standards")
("standard formats" "formats standards")
("standard fraction" "fraction standard")
("star" "étoile")
("start" "début")
("start a new chapter" "commencer un nouveau chapitre")
("start a new section" "commencer une nouvelle section")
("start an interactive session" "commencer une session interactive")
("start remote session" "démarrer la session à distance")
("start server" "démarrer le serveur")
("statement" "déclaration")
("statistics" "statistiques")
("status" "statut")
("status bar" "barre d'état")
("stop server" "arrêter le serveur")
("storage" "stockage")
("store tracking information in LaTeX files" "stocker les informations de suivi dans les fichiers LaTeX")
("strength" "force")
("stretch" "étirer")
("stretch factor" "facteur d'étirement")
("stretchable" "étirable")
("stretchable horizontal" "horizontal étirable")
("stretchable vertical" "vertical étirable")
("stretched" "étiré")
("strict Ascii" "Ascii strict")
("strike through" "barrer")
("string" "chaîne")
("stroke" "tiret")
("strokes" "tirets")
("strong" "important")
("structural" "structurel")
("structured insert above" "insertion structurée vers le haut")
("structured insert at the left" "insertion structurée vers la gauche")
("structured insert at the right" "insertion structurée vers la droite")
("structured insert below" "insertion structurée vers le bas")
("structured remove downwards" "suppression structurée vers le bas")
("structured remove leftwards" "suppression structurée vers la gauche")
("structured remove rightwards" "suppression structurée vers la droite")
("structured remove upwards" "suppression structurée vers le haut")
("structured variant" "variante structurée")
("style" "style")
("style options" "options de style")
("style parameters" "paramètres de style")
("styles" "styles")
("stylesheet language" "langage des feuilles de style")
("sub" "sous")
("subject" "sujet")
("submenu" "sous-menu")
("subparagraph" "sous-paragraphe")
("subparagraphs" "sous-paragraphes")
("subscript" "indice")
("subscript below" "indice en dessous")
("subsection" "sous-section")
("subsections" "sous-sections")
("subsub" "sous-sous")
("subsubmenu" "sous-menu")
("subsubsection" "sous-sous-section")
("subsubsections" "sous-sous-sections")
("subsubsubmenu" "sous-sous-menu")
("subsubsubsubmenu" "sous-sous-sous-menu")
("subtable" "sous-tableau")
("subtitle" "sous-titre")
("subtraction" "soustraction")
("summarized" "résumé")
("summary" "résumé")
("summary of the principal TeXmacs tags" "les principaux marqueurs de contenu")
("superpose" "superposer")
("superposed" "superposé")
("superscript" "exposant")
("superscript above" "exposant au-dessus")
("supported plug-ins" "greffons pris en charge")
("surface" "surface")
("surveys" "survols")
("swedish" "suédois")
("swiss" "suisse")
("switch" "commutateur")
("switch to buffer" "passer au tampon")
("switch to first" "passer au premier")
("switch to formula style" "basculer vers le style de formules")
("switch to last" "passer au dernier")
("switch to next" "passer au suivant")
("switch to previous" "passer au précédant")
("switching and folding" "commuter et plier")
("symbol" "symbole")
("symbol browser" "navigateur de symboles")
("symbol properties not found" "propriétés du symbole introuvables")
("symbols" "symboles")
("synchronization status" "état de synchronisation")
("synchronize" "synchroniser")
("synchronize bibliographic references" "synchroniser les références bibliographiques")
("synchronize file or directory" "synchroniser un fichier ou un répertoire")
("synchronize with remote server" "synchroniser avec le serveur distant")
("synopsis" "synopsis")
("system command" "commande système")
("system environment variables" "variables d'environnement système")
("tab-completion" "tab-complétion")
("tabbed" "tabulé")
("table" "tableau")
("table breaking" "coupure de tables")
("table command" "commande de tableau")
("table height" "hauteur du tableau")
("table of contents" "table des matières")
("table properties" "propriétés du tableau")
("table width" "largeur du tableau")
("tables" "tableaux")
("tabular" "tabuler")
("tabular material" "tableaux")
("tag" "balise")
("tags with special rendering" "balises avec rendu spécial")
("taiwanese" "taiwanais")
("tangent" "tangente")
("target" "cible")
("teXmacs DTD" "DTD teXmacs")
("teXmacs as an interface" "teXmacs en tant qu'interface")
("teXmacs buffer expected" "tampon TeXmacs attendu")
("teXmacs buffer on disk expected" "tampon TeXmacs sur disque attendu")
("teXmacs database preferences" "préférences de base de données teXmacs")
("teXmacs extensions to scheme and utilities" "extensions de TeXmacs pour Scheme et outils")
("teXmacs fonts" "les polices TeXmacs")
("teXmacs macro" "macro TeXmacs")
("teXmacs manual" "manuel de TeXmacs")
("teXmacs manuel" "manuel TeXmacs")
("teXmacs notice" "avis sur TeXmacs")
("teXmacs package" "paquetage TeXmacs")
("teXmacs plugins" "greffons TeXmacs")
("teXmacs primitives" "primitives de TeXmacs")
("teXmacs style" "style TeXmacs")
("teXmacs style files" "fichiers de style TeXmacs")
("teXmacs website" "site web de TeXmacs")
("teXmacs-related work" "des travaux concernant TeXmacs")
("technical report" "rapport technique")
("ternary" "tertiaire")
("test" "test")
("test routine" "routine de test")
("testing tree-view" "tester vue arborescente")
("tex" "tex")
("text" "texte")
("text borders" "bordures de texte")
("text box style" "style de boîte de texte")
("text corners" "coins de texte")
("text font" "police en mode texte")
("text for note" "texte pour la note")
("text height correction" "correction de la hauteur du texte")
("text padding" "espacement autour du texte")
("text width" "largeur du texte")
("texts" "textes")
("textual" "textuel")
("textual operator" "opérateur textuel")
("textual spreadsheet" "tableur textuel")
("textual table" "tableau textuel")
("th century bc" "ième siècle avant J.C.")
("th root" "ième racine")
("thai" "thaï")
("the TeXmacs authors" "les auteurs de TeXmacs")
("the TeXmacs format" "le format TeXmacs")
("the TeXmacs plug-in system" "le système des greffons de TeXmacs")
("the application did not send its usual startup banner" "l'application n'a pas envoyé son message habituel de lancement")
("the application does not reply" "l'application ne répond pas")
("the application is already running" "l'application tourne déjà")
("the boxes produced by the typesetter" "les boîtes produites par le metteur en page")
("the buffer has not been saved" "le tampon n'a pas été enregistré")
("the document has not been saved" "ce document n'a pas été sauvegardé")
("the graphical user interface" "interface graphique d'utilisateur")
("the leaves of TeXmacs trees" "les feuilles des arbres TeXmacs")
("the mycas example" "l'exemple 'mycas'")
("the primitive TeXmacs constructs" "constructeurs TeXmacs primitifs")
("the standard TeXmacs styles" "les styles TeXmacs standards")
("the texmacs plugin system" "le système des greffons de TeXmacs")
("theme" "thème")
("theme parameters" "paramètres de thème")
("theorem" "théorème")
("theorems" "théorèmes")
("there are unsaved documents" "tous les fichiers n'ont pas été sauvegardés")
("there are unsaved files" "il y a des fichiers non enregistrés")
("these collected public keys will be definitely lost" "ces clés publiques collectées seront définitivement perdues")
("these public keys will be definitely lost" "ces clés publiques seront définitivement perdues")
("these secret keys will be definitely lost" "ces clés secrètes seront définitivement perdues")
("thicken" "épaissir")
("thickness" "épaisseur")
("thin" "mince")
("third" "troisième")
("this" "ceci")
("this article has been written using" "cet article a été rédigé avec")
("this buffer has not been saved" "ce tampon n'a pas été enregistré")
("this column" "cette colonne")
("this document has been produced using" "ce document a été conçu avec")
("this document has been written using" "ce document a été rédigé avec")
("this document has not been saved" "ce document n'a pas été sauvegardé")
("this line" "cette ligne")
("this page" "cette page")
("this page footer" "au bas de cette page")
("this page header" "en-tête de cette page")
("this page number" "le numéro de cette page")
("this row" "cette ligne")
("this style specifies page margins in the TeX way" "ce style spécifie les marges de la page à la manière de TeX")
("three columns" "trois colonnes")
("three dots" "trois points")
("three times" "trois fois")
("threshold" "seuil")
("through popup windows" "dans des fenêtres popup")
("through the menus" "via les menus")
("thumbnails" "onglets d'images")
("tilda" "tilde")
("tilde" "tilde")
("time evolution" "évolution du temps")
("times" "fois")
("timings" "durées d'exécution")
("tiny" "minuscule")
("title" "titre")
("title presentation options" "options de présentation du titre")
("title style" "style de titre")
("title suffix" "suffixe de titre")
("titled block" "bloc avec titre")
("to the left" "vers la gauche")
("to the right" "vers la droite")
("today" "aujourd'hui")
("toggle cell wrapping mode" "passage automatique à la ligne")
("toggle here" "basculer ici")
("toggle name" "basculer le nom")
("toggle numbering" "basculer la numérotation")
("toggle off" "désactiver")
("toggle on" "activer")
("toggle specification" "basculer la spécification")
("toggle titled" "basculer le titre")
("tolerant" "tolérant")
("tools" "outils")
("top" "en haut")
("top baseline" "ligne de base en haut")
("top border" "bordure en haut")
("top cell border" "bordure en haut de la cellule")
("top cell padding" "espacement en haut de la cellule")
("top level" "niveau supérieur")
("top margin" "marge en haut")
("top padding" "espacement en haut")
("top table border" "bordure en haut du tableau")
("top table padding" "espacement en haut du tableau")
("topless title" "titre jusqu'en haut")
("transfer" "transférer")
("transform" "transformations")
("transform cell into subtable" "transformer une cellule en sous-table")
("transformations" "transformations")
("translate" "traduire")
("translate::language" "traduire")
("translations" "traductions")
("translations loaded" "traductions chargées")
("transpose" "transposer")
("traversal" "traversée")
("traverse" "traverser")
("tree" "arbre")
("triangle" "triangle")
("triangular list items" "éléments de liste triangulaires")
("triangularize" "trianguler")
("trigonometric" "trigonométrique")
("trigonometric functions" "fonctions trigonométriques")
("trigonometry" "trigonométrie")
("try to import formulas using LaTeX annotations" "essayez d'importer des formules à l'aide d'annotations LaTeX")
("tuple" "tuplet")
("turkish" "turque")
("turn off" "éteindre")
("turn on" "allumer")
("turn on wallet" "activer le trousseau de clés")
("tutorial" "tutoriel")
("tutorials" "tutoriels")
("twice" "deux fois")
("two columns" "deux colonnes")
("two dots" "deux points")
("type" "type")
("type 1 only" "type 1 seulement")
("type 1 with metafont fallback" "type")
("type a LaTeX command followed by" "tapez une commande LaTeX suivie de")
("type a latex command followed by" "tapez une commande latex, puis")
("type a latex command followed by return" "taper une commande latex suivie d'entrée")
("type body" "entrer corps")
("type denominator" "entrer dénominateur")
("type numerator" "entrer numérateur")
("type script" "entrer indice")
("typesetted boxes" "boîtes typographiées")
("typewriter" "machine à écrire")
("typewriter small caps" "petites majuscules machine à écrire")
("typing a simple text" "saisie d'un texte simple")
("typing simple texts" "saisie de textes simples")
("uTF-8 with inputenc LaTeX package" "uTF-8 avec package LaTeX inputenc")
("ugaritic" "ougaritique")
("ukrainian" "ukrainien")
("ultra compact" "ultra compact")
("unchanged" "inchangé")
("underbrace" "accolade en dessous")
("underline" "souligner")
("underlined" "souligné")
("undo" "annuler")
("undo last changes" "annuler les derniers changements")
("unevaluated argument" "argument non évalué")
("unevaluated value" "valeur non évaluée")
("unextended" "non étendue")
("unfold" "déplier")
("unfold all" "déplier tout")
("unfold all fields" "déplier tous les champs")
("unfolded" "déplié")
("ungroup" "dissocier")
("unit" "unité")
("unit length" "unité de longueur")
("unknown secret key fingerprint" "empreinte de clé secrète inconnue")
("unpublished" "non publié")
("unregistered file" "fichier non enregistré")
("unroll" "déroulé")
("unsecure script refused" "script non sécurisé refusé")
("unsupported link mode" "mode de lien non pris en charge")
("until" "jusqu'à")
("untitled block" "bloc sans titre")
("up" "en haut")
("up to date" "à jour")
("update" "actualiser")
("update buffer" "tampon de mise à jour")
("update from web" "réactualiser à partir du réseau")
("update image links" "mise à jour des images liées")
("update remote ssh connection" "mettre à jour la connexion ssh distante")
("update this buffer" "réactualiser le document")
("update web site" "mise à jour du site web")
("upgrade" "mise à jour")
("upight" "droit")
("upload" "téléverser")
("upload file or directory" "télécharger un fichier ou un répertoire")
("upper border" "limite en haut")
("upright" "droit")
("upwards" "vers le haut")
("upwards..." "de bas en haut...")
("url" "url")
("use CSS for more advanced formatting" "utiliser CSS pour améliorer la mise en page")
("use Inkscape for conversion from SVG" "utiliser Inkscape pour la conversion de SVG")
("use MathML" "utiliser MathML")
("use TeXmacs" "utilisez TeXmacs")
("use a black color" "utiliser une couleur noire")
("use a blue color" "utiliser une couleur bleue")
("use a bold font" "utiliser une police grasse")
("use a brown color" "utiliser une couleur brune")
("use a calligraphic font" "utiliser une police calligraphique")
("use a green color" "utiliser une couleur verte")
("use a grey color" "utiliser une couleur grise")
("use a magenta color" "utiliser une couleur mauve")
("use a orange color" "utiliser une couleur orange")
("use a pink color" "utiliser une couleur rose")
("use a red color" "utiliser une couleur rouge")
("use a sans serif font" "utiliser une police sans sérifs")
("use a typewriter font" "utiliser une police de machine à écrire")
("use a white color" "utiliser une couleur blanche")
("use a yellow color" "utiliser une couleur jaune")
("use as master" "utiliser comme document maître")
("use blackboard bold font" "utiliser la police pour tableau noir")
("use bold font series" "utiliser une police grasse")
("use calligraphic font" "utiliser la police calligraphique")
("use calligraphical font" "utiliser une police calligraphique")
("use catcode definitions in preamble" "utiliser des catcodes dans la préambule")
("use custom note symbol" "symbole de note personnalisé")
("use extensible brackets" "parenthèses extensibles")
("use footnote font size" "utiliser une très petite police")
("use fraktur font" "utiliser la police Gothique")
("use high resolution fonts" "utiliser des polices haute résolution")
("use high resolution icons" "utiliser des icônes haute résolution")
("use huge font size" "utiliser une police énorme")
("use italic font shape" "utiliser une police italique")
("use large font size" "utiliser une grande police")
("use left hand column as border" "utiliser colonne à gauche comme bordure")
("use line wrapping for lines which are longer than 80 characters" "utiliser un retour à la ligne pour les lignes de plus de 80 caractères")
("use margin kerning (protrusion)" "utiliser le crénage des marges")
("use medium font series" "utiliser une police d'épaisseur normale")
("use normal font size" "utiliser une police de taille normale")
("use package" "utiliser paquetage")
("use paragraph width" "utiliser largeur du paragraphe")
("use print dialogue" "utiliser un dialogue d'impression")
("use protrusion" "utiliser le crénage des marges")
("use really huge font size" "utiliser une police vraiment énorme")
("use relative path" "utiliser un chemin relatif")
("use retina fonts" "utiliser des polices rétina")
("use retina icons" "utiliser des icônes rétina")
("use right font shape" "utiliser une police droite")
("use right hand column as border" "utiliser colonne à droite comme bordure")
("use roman font family" "utiliser la police romain")
("use row above as border" "utiliser ligne en haut comme bordure")
("use row below as border" "utiliser ligne en bas comme bordure")
("use sans serif font family" "utiliser la police sans sérifs")
("use script font size" "utiliser une très petite police")
("use slanted font shape" "utiliser une police oblique")
("use small capitals" "utiliser des petites majuscules")
("use small font size" "utiliser une petite police")
("use small-caps font shape" "utiliser une police de petites majuscules")
("use the blackboard bold font" "utiliser la police de tableau noir gras")
("use the fraktur font" "utiliser la police fraktur")
("use tiny font font size" "utiliser une police minuscule")
("use typewriter font family" "utiliser la police machine à écrire")
("use unified toolbars" "utiliser des barres d'outils unifiées")
("use very large font size" "utiliser une très grande police")
("user interface" "interface utilisateur")
("user interface language" "langue de l'interface utilisateur")
("user interface theme" "thème de l'interface utilisateur")
("user manual" "manuel d'utilisation")
("user preferences" "préférences de l'utilisateur")
("user provided icons" "icônes définies par l'utilisateur")
("users of Cyrillic languages" "utilisateurs de langues cyrilliques")
("users of oriental languages" "utilisateurs de langues orientales")
("utf-8 with inputenc" "utf-8 avec inputenc")
("utf-8 with inputenc LaTeX package" "Utf-8 avec le paquet LaTeX inputenc")
("utilities" "utilitaires")
("value" "valeur")
("vanish" "disparaître")
("variable" "variable")
("variant" "variante")
("vector" "vecteur")
("verbatim" "verbatim")
("verbose" "verbeux")
("verse" "vers")
("version" "version")
("versioning tool" "outil de gestion des versions")
("vertical" "vertical")
("vertical after" "vertical après")
("vertical alignment" "alignement vertical")
("vertical before" "vertical avant")
("vertical cell alignment" "alignement vertical de la cellule")
("vertical margins" "marges verticales")
("vertical padding" "rembourrage vertical")
("vertical part" "partie verticale")
("vertical position" "position verticale")
("vertical space" "espace vertical")
("vertical space after" "espace vertical après")
("vertical space before" "espace vertical avant")
("vertical space stretchability" "extensibilité de l'espace vertical")
("vertical table alignment" "alignmement vertical du tableau")
("vertically align cell to the base" "alignement verticale de la cellule à la base")
("vertically center the cell" "centrer la cellule verticalement")
("very large" "très grand")
("very small" "très petit")
("vietnamese" "vietnamien")
("view" "vue")
("visible" "visible")
("visible except here" "visible sauf ici")
("visible from here on" "visible à partir d'ici")
("visible only here" "visible seulement ici")
("visible until here" "visible jusqu'à ici")
("visited color" "couleurs de liens visités")
("visited loci" "loci visités")
("volume" "volume")
("w.r.t." "suivant")
("wallet" "trousseau de clés")
("warning" "avertissement")
("warnings" "avertissements")
("wave" "onde")
("wave length x" "longueur d'onde x")
("wave length y" "longueur d'onde y")
("web" "toile")
("weight" "graisse")
("welcome" "bienvenue")
("welcome to GNU TeXmacs" "bienvenue à GNU TeXmacs")
("what is new" "nouveautés")
("when finished" "pour terminer")
("when line wrapping" "si passage à la ligne automatique")
("when wrapping" "lors des passages à la ligne")
("while" "tant que")
("white" "blanc")
("whitespace" "espace")
("wide" "large")
("wide accent" "accent large")
("wide bar" "barre large")
("wide block" "Bloc en largeur")
("wide colored" "large colorié")
("wide float" "objet flottant large")
("wide footnote" "note en bas de page large")
("wide note" "note sur toute la largeur")
("wide tabular" "Tableau en largeur")
("widescreen" "écran large")
("width" "largeur")
("width is exactly the specified width" "utiliser la largeur spécifiée")
("width is maximum of specified width and box width" "utiliser maximum de la largeur spécifiée et la largeur de la boîte")
("width is minimum of specified width and box width" "utiliser minimum de la largeur spécifiée et la largeur de la boîte")
("width magnification" "agrandissement de la largeur")
("window" "fenêtre")
("windows" "fenêtres")
("window height" "hauteur de fenêtre")
("window width" "largeur de fenêtre")
("windows key" "touche windows")
("with" "avec")
("with newer version" "avec la nouvelle version")
("with older version" "avec l'ancienne version")
("wood" "bois")
("word count" "nombre de mots")
("wrap lines" "couper les lignes")
("write" "écriture")
("write a macro" "écrire un macro")
("write a name" "écrire un nom")
("write bold mathematics" "écrire des mathématiques en gras")
("write bold text" "écrire en gras")
("write italic text" "écrire en italique")
("write sample text" "écrire du texte illustratif")
("write strong text" "écrire du texte important")
("write typewriter text" "écrire du texte de machine à écrire")
("write verbatim text" "écrire en verbatim")
("writing TeXmacs bibliography styles" "créer des styles de bibliographie TeXmacs")
("writing data converters" "écrire des convertisseurs de données")
("writing documentation" "pour écrire de la documentation")
("writing your own style files" "écrire vos propres feuilles de style")
("written with TeXmacs" "conçu avec TeXmacs")
("wrong empty passphrase" "phrase de passe vide incorrecte")
("wrong passphrase" "mot de passe incorrect")
("year" "année")
("year, Name" "année, Nom")
("yellow" "jaune")
("yes" "oui")
("you are attempting to open an encrypted file while" "vous essayez d'ouvrir un fichier crypté en")
("you can also obtain" "vous pouvez également obtenir")
("you might consider enabling the experimental" "vous pourriez envisager d'activer l'expérimental")
("you must add a bibliography file" "vous devez ajouter un fichier de bibliographie")
("you should also make sure that GnuPG is installed" "vous devez également vous assurer que GnuPG est installé")
("your document is back in its original state" "votre document est revenu dans son état original")
("your first interface" "votre première interface")
("your language" "votre langue")
("your personal dictionary has been modified" "votre dictionnaire personnel a été modifié")
("zebra" "zèbre")
("zigzag" "zigzag")
("zoom" "zoomer")
("zoom factor" "facteur de zoom")
("zoom in" "agrandir")
("zoom out" "réduire")
("zoom/unzoom objects" "agrandir/réduire des objets")
