("\"encryption\" features from the preference panel" "Verschlüsselungsfunktion im Einstellungsfeld")
("(Re)Build autocompletion index" "Autovervollständigungsindex (neu) erstellen")
("a series" "eine Reihe")
("a.C.M. computing class" "a.C.M. Computerklasse")
("a.M.S. subject class" "a.M.S. Fachklasse")
("abbreviated authors" "abgekürzte Autoren")
("abreviated authors" "abgekürzte Autoren")
("accent above" "Akzent oben")
("accent below" "Akzent unten")
("accept during this pass" "Akzeptiere während dieses Passes")
("acknowledgments" "Danksagungen")
("activate hidden" "versteckt aktivieren")
("active link types" "aktive Verbindungstypen")
("add" "hinzufügen")
("add abstract information" "abstrakte Informationen hinzufügen")
("add author information" "Autoreninformationen hinzufügen")
("add branch after" "Zweig hinzufügen nach")
("add branch before" "Zweig vorher hinzufügen")
("add other package" "Anderes Paket hinzufügen")
("add style package" "Style-Paket hinzufügen")
("add title information" "Titelinformationen hinzufügen")
("addition" "Ergänzung")
("adjust" "anpassen")
("adjust limits" "Grenzen anpassen")
("advanced font customization" "Erweiterte Schriftanpassung")
("affiliation" "Zugehörigkeit")
("albanian" "albanisch")
("align cell to the decimal comma" "Zelle an Komma ausrichten")
("align cell to the decimal dot" "Zelle am Dezimalpunkt ausrichten")
("align table at axis" "Tisch an Achse ausrichten")
("alignment of balloon" "Ausrichtung des Ballons")
("all cells" "alle Zellen")
("all data attached to this identity will be lost" "Alle an diese Identität angehängten Daten gehen verloren")
("all saved passphrases will be lost forever" "Alle gespeicherten Passwörter gehen für immer verloren")
("allow for macro definitions in preamble" "Makrodefinitionen in der Präambel zulassen")
("allowed page height extension" "erlaubte Seitenhöhenerweiterung")
("allowed page height reduction" "erlaubte Reduzierung der Seitenhöhe")
("allowed positions" "erlaubte Positionen")
("allowed positions of floating object" "erlaubte Positionen von schwimmenden Objekten")
("alpha transparency" "Alpha-Transparenz")
("also on paper" "auch auf Papier")
("alter" "alter")
("alternate" "alternate")
("alternate except here" "Alternative außer hier")
("alternate from here on" "ab hier abwechseln")
("alternate only here" "nur hier abwechseln")
("alternate until here" "bis hier abwechseln")
("alternative specification" "alternative Spezifikation")
("always" "immer")
("amplified" "verstärkt")
("and perform casual settings from the \"Encryption\" tab" "und nehmen Sie gelegentliche Einstellungen auf der Registerkarte \"Verschlüsselung\" vor.")
("animate" "animieren")
("animate folding" "animiertes Falten")
("animate unfolding" "Animation entfaltet sich")
("animated" "animiert")
("animation" "Animation")
("animation toolbar" "Animationssymbolleiste")
("annotate" "annotieren")
("answer field" "Antwortfeld")
("answer to question" "Antwort auf Frage")
("answers only" "nur Antworten")
("any" "any")
("appear" "erscheinen")
("apply macro" "Makro anwenden")
("apply macro once" "Makro einmal anwenden")
("approximate" "ungefähr")
("arc" "Bogen")
("arc cosine" "Arcuscosinus")
("arc sine" "Arcussinus")
("arc tangent" "Arcustangens")
("arch series" "Bogenserie")
("are you sure you want to delete collected public keys" "Sind Sie sicher, dass Sie gesammelte öffentliche Schlüssel löschen möchten?")
("are you sure you want to delete selected public keys" "Möchten Sie die ausgewählten öffentlichen Schlüssel wirklich löschen?")
("are you sure you want to delete selected secret keys" "Möchten Sie die ausgewählten geheimen Schlüssel wirklich löschen?")
("are you sure you want to destroy the wallet" "Bist du sicher, dass du die Brieftasche zerstören willst?")
("art frame" "Kunstrahmen")
("arxiv category" "arxiv category")
("as visual grid" "als visuelles Gitter")
("aspect" "Aspekt")
("attach master" "Meister anhängen")
("auto" "auto")
("auto-save file" "Datei automatisch speichern")
("automatic brackets" "automatische Klammern")
("automatic content generation" "Automatische Inhaltserstellung")
("automatic program brackets" "automatische Programmklammern")
("automatically import bibliographies when opening files" "Bibliografien beim Öffnen von Dateien automatisch importieren")
("automatically remember all passphrases in the wallet" "Alle Passphrasen in der Brieftasche automatisch merken")
("automatically save" "automatisch speichern")
("axis" "Achse")
("b series" "b series")
("back" "zurück")
("backtrace errors" "Rückverfolgungsfehler")
("base" "base")
("beamer" "Beamer")
("beamer formats" "Beamerformate")
("beamer theme" "Beamer-Thema")
("bench" "Bank")
("bend bottom" "Biegung unten")
("bend corner" "Kurve")
("bend diagonal" "Biegediagonale")
("bend in" "einbiegen")
("bend out" "ausbiegen")
("bezier" "bezier")
("bibTeX command" "bibTeX-Befehl")
("bidirectional" "bidirektional")
("big environment box" "große Umgebungsbox")
("big focus" "großer Fokus")
("binary operator" "binärer Operator")
("bitmap resolution (dpi)" "Bitmap-Auflösung (dpi)")
("black floral I" "black floral I")
("black floral II" "black floral II")
("blackboard embold" "Tafel einbetten")
("blank column" "leere Spalte")
("blank row" "leere Zeile")
("block" "Block")
("block content" "Blockinhalt")
("block of code" "Codeblock")
("blur" "Unschärfe")
("both versions" "beide Versionen")
("bottom baseline" "Grundlinie")
("bottom cell border" "unterer Zellenrand")
("bottom cell padding" "untere Zellauffüllung")
("bottom table border" "unterer Tabellenrand")
("bottom table padding" "untere Tischpolsterung")
("bottom tools" "Unterwerkzeuge")
("box" "box")
("broken white" "gebrochenes Weiß")
("browse back" "zurückblättern")
("browse forward" "Vorwärts blättern")
("browse modules documentation" "Durchsuchen der Moduldokumentation")
("buffer management" "Pufferverwaltung")
("buffer must be on disk" "Puffer muss sich auf der Festplatte befinden")
("buffer must have a name" "Puffer muss einen Namen haben")
("build buffer" "Build Buffer")
("build buffer in" "Puffer einbauen")
("build directory" "Build-Verzeichnis")
("build directory in" "build directory in")
("build link pages" "Link-Seiten erstellen")
("build-all" "Alles zusammenbauen")
("bulgarian" "bulgarisch")
("bump" "Unebenheit")
("busy" "beschäftigt")
("cJK" "cJK")
("cJK spacing" "cJK-Abstand")
("calculus" "calculus")
("cancelled" "annulliert")
("cannot download directory to file" "Verzeichnis kann nicht in Datei heruntergeladen werden")
("cannot rename across different servers" "kann nicht zwischen verschiedenen Servern umbenennen")
("cannot upload directory to file" "Verzeichnis kann nicht in Datei hochgeladen werden")
("caps-lock key" "Feststelltaste")
("cartesian" "kartesisch")
("carved wood" "Holz geschnitzt")
("case-insensitive search" "Suche ohne Berücksichtigung der Groß- / Kleinschreibung")
("categories" "Kategorien")
("category" "Kategorie")
("cell properties" "Zelleigenschaften")
("change default unit" "Standardeinheit ändern")
("change passphrase" "Passwort ändern")
("change step-size" "Schrittweite ändern")
("change tags" "Tags ändern")
("change the TeXmacs preferences" "Ändern der TeXmacs-Einstellungen")
("change the border of the table" "ändere den Rand der Tabelle")
("change the style of mathematical formulas" "Ändern Sie den Stil der mathematischen Formeln")
("character contraction" "Zeichenkontraktion")
("character encoding" "Zeichenkodierung")
("character expansion" "Zeichenerweiterung")
("check for updates" "Nach Updates suchen")
("checkable field" "überprüfbares Feld")
("cipher algorithm for passphrase encryption" "Verschlüsselungsalgorithmus für die Passwortverschlüsselung")
("circle" "Kreis")
("classification" "Klassifizierung")
("clean slate" "sauberer Schiefer")
("clear all fields" "Alle Felder löschen")
("clear local information" "Lokale Informationen löschen")
("clear menu" "Menü löschen")
("clear undo history" "Verlauf löschen")
("click Ok button twice to discard this warning" "Klicken Sie zweimal auf OK, um diese Warnung zu verwerfen")
("clip" "Clip")
("clipboard image format" "Zwischenablage-Bildformat")
("close animation tool" "Animationstool schließen")
("close document" "Dokument schließen")
("close program" "Programm schließen")
("close replace tool" "Ersatzwerkzeug schließen")
("close search tool" "Suchfunktion schließen")
("close spell tool" "Rechtschreibprüfung schließen")
("close translations to rebuild" "close translations to rebuild")
("closed bezier" "geschlossener Bezier")
("closed curve" "geschlossene Kurve")
("closed smooth" "glatt geschlossen")
("closed spline" "geschlossener Spline")
("cluster by affiliation" "Cluster durch Zugehörigkeit")
("collect garbage" "Müll sammeln")
("collected keys" "Gesammelte Schlüssel")
("color of the axes" "Farbe der Achsen")
("color of the subunits" "Farbe der Untereinheiten")
("color of the units" "Farbe der Einheiten")
("colors" "Farben")
("column to the left" "Spalte links")
("column to the right" "Spalte rechts")
("column separation" "Säulentrennung")
("commit file" "Commit-Datei")
("common" "common")
("common formats" "gängige Formate")
("commutative diagram" "kommutatives Diagramm")
("compactify" "verdichten")
("complete bibliographic reference" "vollständiger Literaturhinweis")
("complex actions" "komplexe Handlungen")
("compose" "verfassen")
("compress" "komprimieren")
("compress into toolbar" "In Symbolleiste komprimieren")
("compressed" "komprimiert")
("conceal" "verbergen")
("configure look and feel" "Erscheinungsbild konfigurieren")
("confirm database entry" "Datenbankeintrag bestätigen")
("confirm entry" "Eingabe bestätigen")
("confirm selected database entries" "Ausgewählte Datenbankeinträge bestätigen")
("confirm selected entries" "Ausgewählte Einträge bestätigen")
("conservative conversion options" "konservative Konvertierungsoptionen")
("consoles" "Konsolen")
("constellation" "Sternbild")
("contact" "Kontakt")
("context aids" "Kontexthilfen")
("contextual hints" "Kontextbezogene Hinweise")
("continue" "Weiter")
("continued fraction" "fortgesetzte Fraktion")
("contour" "Kontur")
("contract logarithms" "Vertragslogarithmen")
("contribute" "beitragen")
("control the evaluation of expressions" "Kontrolle der Auswertung von Ausdrücken")
("convert" "konvertieren")
("convertible" "Cabrio")
("copyright" "Urheberrecht")
("cork charset with TeX catcode definition in preamble" "Korkzeichensatz mit TeX-Catcode-Definition in der Präambel")
("correct" "richtig")
("correct all" "alles korrigieren")
("correct formula" "richtige Formel")
("correct manually" "manuell korrigieren")
("correct mathematical formulas" "richtige mathematische Formeln")
("correction" "Korrektur")
("cosine" "Cosinus")
("count characters" "Zeichen zählen")
("count lines" "Zeilen zählen")
("count words" "Wörter zählen")
("create a new document" "Neues Dokument erstellen")
("create link" "Verknüpfung erstellen")
("create preamble" "Präambel erstellen")
("create remote directory" "Remote-Verzeichnis erstellen")
("create remote file" "entfernte Datei erstellen")
("create subprogram" "Unterprogramm erstellen")
("create subsession" "Subsession erstellen")
("create table macro" "Tabellenmakro erstellen")
("create web site" "Website erstellen")
("creating new account" "Neues Konto erstellen")
("creating technical pictures" "Technische Bilder erstellen")
("crop" "Zuschneiden")
("crop marks" "Schnittmarken")
("cross" "Kreuz")
("crossed boxes" "gekreuzte Kästchen")
("crossed circles" "gekreuzte Kreise")
("current user version" "aktuelle Benutzerversion")
("current version" "aktuelle Version")
("cursor" "Cursor")
("curve" "Kurve")
("curve intersections" "Kurvenschnitte")
("curve points" "Kurvenpunkte")
("customizations" "Anpassungen")
("customizing and extending the user interface" "Anpassen und Erweitern der Benutzeroberfläche")
("dark grey" "dunkelgrau")
("data" "Daten")
("database entry" "Datenbankeintrag")
("database tool" "Datenbanktool")
("database toolbar" "Datenbank-Symbolleiste")
("deactivate once" "einmal deaktivieren")
("dead" "dead")
("debug" "Debug")
("debugging console" "Debugging-Konsole")
("debugging tool" "Debugging-Tool")
("decomposed" "zerlegt")
("decorated" "dekoriert")
("decorated wood" "dekoriertes Holz")
("decrease size" "Größe verringern")
("decrypt" "entschlüsseln")
("default size" "Standardgröße")
("degrade" "degradieren")
("degraded" "degradiert")
("delete documentation cache" "Dokumentations-Cache löschen")
("delete entries" "Einträge löschen")
("delete link" "Link löschen")
("deleted" "gelöscht")
("describe" "beschreiben")
("describe tag" "Tag beschreiben")
("destroy" "zerstören")
("detach master" "Meister trennen")
("detailed menus" "detaillierte Menüs")
("details in menus" "Details in Menüs")
("determine margins from text width" "Ränder aus Textbreite ermitteln")
("developer" "Entwickler")
("developer tool" "Entwicklertool")
("device" "Gerät")
("diamond" "Diamant")
("differentiate" "differenzieren")
("dilate" "dilate")
("direction of progression" "Fortschrittsrichtung")
("direction of translation" "Übersetzungsrichtung")
("disable coloring on paper" "Papierfarbe deaktivieren")
("disable encryption" "Verschlüsselung deaktivieren")
("disappear" "verschwinden")
("disk" "Scheibe")
("displayed formula" "angezeigte Formel")
("dissociate joined cells" "getrennte verbundene Zellen")
("distort" "verzerren")
("distorted" "verzerrt")
("division" "Division")
("document font selector" "Dokumentschriftartenauswahl")
("document language" "Dokumentsprache")
("document page format" "Dokumentseitenformat")
("document paragraph format" "Dokument-Absatzformat")
("document updates run" "Dokumentaktualisierungen werden ausgeführt")
("download" "Download")
("downwards" "abwärts")
("dragging" "Ziehen")
("draw image" "Bild zeichnen")
("draw over" "Unentschieden vorbei")
("draw over selection" "Auswahl aufheben")
("drop" "drop")
("due to" "wegen")
("dynamic" "dynamisch")
("eRROR" "eRROR")
("edit animation" "Animation bearbeiten")
("edit groups of objects" "Gruppen von Objekten bearbeiten")
("edit macro" "Makro bearbeiten")
("edit macros" "Makros bearbeiten")
("edit preamble" "Präambel bearbeiten")
("edit source" "Quelle bearbeiten")
("edit style" "Stil bearbeiten")
("edit translations file" "Übersetzungsdatei bearbeiten")
("education" "Bildung")
("effect pen" "Effektstift")
("eigenvalues" "Eigenwerte")
("eighth" "Achtel")
("embold" "embold")
("emboss" "Relief")
("enable page breaking" "Seitenumbruch aktivieren")
("encoding" "Kodierung")
("encrypt" "verschlüsseln")
("encryption" "Verschlüsselung")
("encryption facilities are not currently available" "Verschlüsselungsfunktionen sind derzeit nicht verfügbar")
("encryption facilities have not been enabled for TeXmacs" "Verschlüsselungsfunktionen wurden für TeXmacs nicht aktiviert")
("enforce brackets to match" "Klammern für Übereinstimmung erzwingen")
("engrave" "gravieren")
("enter data" "Daten eingeben")
("enter graphics" "Grafiken eingeben")
("enter graphics mode" "Grafikmodus aktivieren")
("enter new passphrase for encryption" "Neue Passphrase für die Verschlüsselung eingeben")
("enter passphrase for decryption" "Passwort zur Entschlüsselung eingeben")
("enter passphrase for identity" "Passwort für Identität eingeben")
("enter title information" "Titelinformationen eingeben")
("entry up to date in database" "Eintrag in Datenbank aktuell")
("enunciation" "Verkündigung")
("env" "env")
("environment variable" "Umgebungsvariable")
("environments" "Umgebungen")
("erode" "erodieren")
("error messages" "Fehlermeldungen")
("error output" "Fehlerausgabe")
("error status report" "Fehlerstatusbericht")
("error: bracket does not match" "Fehler: Klammer stimmt nicht überein")
("error: cyclic or missing chunks detected" "Fehler: zyklische oder fehlende Chunks erkannt")
("error: file not found" "Fehler: Datei nicht gefunden")
("error: ghostview does not seem to be installed on your system" "Fehler: ghostview scheint nicht auf Ihrem System installiert zu sein")
("error: one of the alternatives should be filled out" "Fehler: Eine der Alternativen sollte ausgefüllt werden")
("error: only one alternatives should be filled out" "Fehler: Es sollte nur eine Alternative ausgefüllt werden")
("error: should fill out name for referencing" "Fehler: Name für Referenzierung ausfüllen")
("error: should fill out required field" "Fehler: Pflichtfeld ausfüllen")
("esperanto" "Esperanto")
("evaluable field" "auswertbares Feld")
("evaluate above" "oben bewerten")
("evaluate all" "bewerte alle")
("evaluate below" "weiter unten auswerten")
("evaluate fields" "Felder auswerten")
("evaluate fields in order" "Felder nacheinander auswerten")
("evaluate script" "Skript auswerten")
("evaluation switch" "Auswerteschalter")
("evaluation tag" "Bewertungstag")
("even page" "gerade Seite")
("even page left margin" "gerader linker Seitenrand")
("even page shift" "gerade Seitenverschiebung")
("even pages" "gerade Seiten")
("events" "Ereignisse")
("exact" "genau")
("execution of scripts" "Ausführung von Skripten")
("exit graphics" "Grafik beenden")
("exit graphics mode" "Grafikmodus beenden")
("exit left" "Ausfahrt links")
("exit right" "Ausfahrt rechts")
("exit tag on the left" "Ausfahrt Tag auf der linken Seite")
("exit tag on the right" "Ausgangsmarke rechts")
("expand TeXmacs macros with no LaTeX equivalents" "TeXmacs-Makros ohne LaTeX-Entsprechungen erweitern")
("expand beamer slides" "Beamerfolien erweitern")
("expand inclusions" "Einschlüsse erweitern")
("expand logarithms" "Logarithmen erweitern")
("expand trigonometric functions" "trigonometrische Funktionen erweitern")
("expand unrecognized macros" "Nicht erkannte Makros erweitern")
("expand user-defined macros" "Benutzerdefinierte Makros erweitern")
("expanded" "erweitert")
("experimental features (to be used with care)" "Versuchsmerkmale (mit Vorsicht zu verwenden)")
("explain" "erklären")
("explanatory item" "erläuternder Punkt")
("explicit keystroke" "expliziter Tastenanschlag")
("explicit margins" "explizite Ränder")
("exponential" "exponentiell")
("export bibliography" "Exportbibliographie")
("export entries in buffer" "Einträge in Puffer exportieren")
("export file" "Exportdatei")
("export formulas as images" "Formeln als Bilder exportieren")
("export mathematical formulas as MathML" "mathematische Formeln als MathML exportieren")
("export mathematical formulas as images" "mathematische Formeln als Bilder exportieren")
("export selected entries" "ausgewählte Einträge exportieren")
("export selection" "Auswahl exportieren")
("export selection as image" "Auswahl als Bild exportieren")
("export selections as" "Auswahl exportieren als")
("export sessions" "Exportsitzungen")
("exported bibliographic entries" "exportierte bibliografische Einträge")
("exported bibliographic references" "exportierte bibliografische Referenzen")
("extend" "verlängern")
("extended" "erweitert")
("extensible left arrow" "ausziehbarer linker Pfeil")
("extensible right arrow" "ausziehbarer Pfeil nach rechts")
("extern" "extern")
("external" "extern")
("extra branch" "zusätzlicher Zweig")
("extra interline space" "zusätzlicher Zeilenabstand")
("extra name" "zusätzlicher Name")
("extract" "Extrakt")
("extract style file" "Stildatei extrahieren")
("extract style package" "Style-Paket extrahieren")
("factor" "Faktor")
("fade" "verblassen")
("fade in" "Einblenden")
("fade out" "Ausblenden")
("fast" "schnell")
("fast decrease" "schnelle Abnahme")
("fast environments" "schnelle Umgebungen")
("fast increase" "schneller Anstieg")
("field reference" "Feldreferenz")
("fifth" "5th")
("file saved" "Datei gespeichert")
("fill color" "Füllfarbe")
("fill out" "Ausfüllen")
("filter" "Filter")
("find file" "Datei finden")
("finished collecting symbols documentation" "Sammelsymboldokumentation beendet")
("first" "first")
("first chunk" "first chunk")
("first difference" "erster Unterschied")
("first error" "erster Fehler")
("first field" "erstes Feld")
("first occurrence" "erstes Vorkommen")
("first similar" "erste ähnliche")
("fit to screen" "An Bildschirm anpassen")
("fit to screen width" "An Bildschirmbreite anpassen")
("five columns" "fünf Spalten")
("fixed" "fest")
("flag is off" "Flagge ist aus")
("flag is on" "Flagge ist an")
("flatten" "Abflachen")
("floating algorithm" "Gleitender Algorithmus")
("floating phantom" "schwebendes Phantom")
("focus" "Fokus")
("focus dependent icons" "fokusabhängige Symbole")
("fold all" "Alle falten")
("fold all fields" "Alle Felder zusammenfalten")
("fold back" "zurückfalten")
("follow external links" "Externen Links folgen")
("follow inverse links" "Inverse Links folgen")
("font effects" "Schriftarteneffekte")
("font selector" "Schriftartenauswahl")
("force reloading of translations" "Neuladen von Übersetzungen erzwingen")
("forward" "vorwärts")
("four columns" "vier Spalten")
("four dots" "vier Punkte")
("fourth" "vierte")
("fraktur" "fraktur")
("framed" "gerahmt")
("from" "von")
("from center" "von der Mitte")
("front matter" "vordere Angelegenheit")
("full" "voll")
("full author list" "vollständige Autorenliste")
("functional" "funktional")
("gap" "Lücke")
("garbage collection" "Müllabfuhr")
("gaussian" "Gauß")
("gcd" "gcd")
("general" "general")
("generated LaTeX document contains no errors" "generiertes LaTeX-Dokument enthält keine Fehler")
("generated field" "generiertes Feld")
("geometry" "Geometrie")
("get arity" "Arität bekommen")
("get label" "get label")
("get list with remote versions" "Liste mit entfernten Versionen abrufen")
("glyphs" "Glyphen")
("gnaw" "nagen")
("gnawed" "genagt")
("gnuPG command" "gnuPG-Befehl")
("gnuPG error: buffer encryption failed" "gnuPG-Fehler: Pufferverschlüsselung fehlgeschlagen")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG-Fehler: Es kann kein passender geheimer Schlüssel zum Entschlüsseln gefunden werden")
("gnuPG requires name and email to have at least 5 characters" "gnuPG erfordert Namen und E-Mail-Adresse mit mindestens 5 Zeichen")
("go to anchor" "vor Anker gehen")
("go to anchor or float" "vor Anker gehen oder schwimmen")
("go to anchor or footnote" "Gehe zu Anker oder Fußnote")
("go to first similar tag" "Gehe zum ersten ähnlichen Tag")
("go to float" "zum Schwimmen gehen")
("go to footnote" "zur Fußnote")
("go to last similar tag" "Zum letzten ähnlichen Tag wechseln")
("go to next similar tag" "Zum nächsten ähnlichen Tag wechseln")
("go to previous similar tag" "Zum vorherigen ähnlichen Tag wechseln")
("go to section" "gehe zu Abschnitt")
("grain" "Getreide")
("granite" "Granit")
("graphical effects" "Grafische Effekte")
("graphical interface font scale" "Schriftskala für grafische Benutzeroberfläche")
("graphics" "Grafiken")
("graphics geometry" "Grafikgeometrie")
("graphics grids" "Grafikraster")
("greyed" "grau")
("grid" "Raster")
("grid curves" "Gitterkurven")
("grid points" "Gitterpunkte")
("grid-curve intersections" "Gitterkurvenschnittpunkte")
("group of objects" "Gruppe von Objekten")
("group/ungroup" "Gruppe / Gruppe aufheben")
("grouped" "gruppiert")
("guarantee transparent source tracking" "Transparente Quellenverfolgung garantieren")
("half wide" "halb breit")
("hand drawn" "handgezeichnet")
("headers" "Überschriften")
("history" "Geschichte")
("homepage" "homepage")
("homoglyph substitutions" "Homoglyphen-Substitutionen")
("horizontal alignment" "horizontale Ausrichtung")
("horizontal collapse distance" "horizontaler Kollapsabstand")
("horizontal margins" "horizontale Ränder")
("hybrid command" "Hybridbefehl")
("hyphenate as" "Bindestrich als")
("icon" "icon")
("if hyphenated" "falls getrennt")
("ignore" "ignorieren")
("impact" "Auswirkungen")
("import bibliography" "Bibliographie importieren")
("import database entry" "Datenbankeintrag importieren")
("import entries in buffer" "Einträge in Puffer importieren")
("import entry" "Importeintrag")
("import file" "Importdatei")
("import selected database entries" "Ausgewählte Datenbankeinträge importieren")
("import selected entries" "ausgewählte Einträge importieren")
("import selections as" "Auswahl importieren als")
("import sessions" "Importsitzungen")
("import sophisticated objects as pictures" "Anspruchsvolle Objekte als Bilder importieren")
("imported bibliographic entries" "importierte bibliografische Einträge")
("in popup windows" "in Popup-Fenstern")
("inanimated" "unbelebt")
("inch" "inch")
("incomplete entries found to be filled out" "Unvollständige Einträge müssen ausgefüllt werden")
("increase size" "Größe erhöhen")
("indent paragraphs" "Absätze einrücken")
("indentation" "Einrückung")
("indication" "Angabe")
("initialize" "initialisieren")
("ink here" "Tinte hier")
("ink in" "Tinte ein")
("ink out" "Tinte heraus")
("inline" "Inline")
("inline code" "Inline-Code")
("inline content" "Inline-Inhalt")
("inline formula" "Inline-Formel")
("inner bottom" "Innenboden")
("inner left" "innen links")
("inner right" "innen rechts")
("inner top" "Innendecke")
("input command" "Eingabebefehl")
("input field" "Eingabefeld")
("input options" "Eingabeoptionen")
("insert Pr" "Einfügung Pr")
("insert a computer program" "Ein Computerprogramm einfügen")
("insert a condition" "Bedingung einfügen")
("insert a control flow instruction" "Steuerflussanweisung einfügen")
("insert a gap" "Lücke einfügen")
("insert a list" "Liste einfügen")
("insert a multiple choice" "Multiple Choice einfügen")
("insert a negation" "Negation einfügen")
("insert a new entry" "Neuen Eintrag einfügen")
("insert a note or a floating object" "Eine Notiz oder ein schwebendes Objekt einfügen")
("insert a numerical operation" "Numerische Operation einfügen")
("insert a prominent piece of text" "Einfügen eines markanten Textes")
("insert a question" "Frage einfügen")
("insert a root" "Wurzel einfügen")
("insert a script" "Ein Skript einfügen")
("insert a section block" "Einfügen eines Abschnittsblocks")
("insert a textual operation" "Einfügen einer Textoperation")
("insert a textual operator" "Textoperator einfügen")
("insert a wide symbol above" "Ein breites Symbol oben einfügen")
("insert a wide symbol below" "Ein breites Symbol unten einfügen")
("insert above" "oben einfügen")
("insert abstract" "Zusammenfassung einfügen")
("insert an answer" "Antwort einfügen")
("insert an enunciation" "eine Ankündigung einfügen")
("insert an operation on tuples" "Operation für Tupel einfügen")
("insert annotation" "Anmerkung einfügen")
("insert below" "unten einfügen")
("insert copyright and license information" "Copyright- und Lizenzinformationen einfügen")
("insert explanatory item" "erläuternden Punkt einfügen")
("insert field above" "Feld oben einfügen")
("insert field below" "Feld darunter einfügen")
("insert large delimiters" "Große Trennzeichen einfügen")
("insert last name" "Nachname einfügen")
("insert left" "links einfügen")
("insert macro" "Makro einfügen")
("insert missing invisible operators" "fehlende unsichtbare Operatoren einfügen")
("insert more names" "Weitere Namen einfügen")
("insert particle" "Partikel einfügen")
("insert plain text" "Nur Text einfügen")
("insert right" "rechts einfügen")
("insert similar above" "Ähnliches wie oben einfügen")
("insert similar below" "Ähnliches unten einfügen")
("insert similar block above" "ähnlichen Block oben einfügen")
("insert similar block below" "ähnlichen Block unten einfügen")
("insert subtable" "Untertabelle einfügen")
("insert symbol documentation" "Symboldokumentation einfügen")
("insert template" "Vorlage einfügen")
("insert text field above" "Textfeld oben einfügen")
("insert text field below" "Textfeld darunter einfügen")
("insert title after name" "Titel nach Name einfügen")
("insert user interface related markup" "benutzeroberflächenbezogenes Markup einfügen")
("insert value" "Wert einfügen")
("inserting control points" "Einfügen von Kontrollpunkten")
("integrate" "integrieren")
("interactive command" "Interaktiver Befehl")
("interactive questions" "interaktive Fragen")
("intercharacter compression" "Intercharacter Compression")
("intercharacter stretching" "Intercharacter Stretching")
("interrupted" "unterbrochen")
("invalid multi-paragraph selection" "Ungültige Auswahl mehrerer Absätze")
("invalid renaming" "Ungültige Umbenennung")
("invert" "invert")
("inverted breve" "inverted breve")
("invisible ending" "unsichtbares Ende")
("invisible newline" "unsichtbare Newline")
("invisible opening" "unsichtbare Öffnung")
("join selected cells" "Ausgewählte Zellen verbinden")
("jump in" "Einspringen")
("junior" "junior")
("keep evaluated expressions" "Bewertete Ausdrücke beibehalten")
("keep local" "lokal halten")
("keep remote" "fern halten")
("keep track of source code" "Verfolgen Sie den Quellcode")
("keep unfolded" "entfaltet halten")
("keyboard configuration" "Tastaturkonfiguration")
("laptop presentations" "Laptop-Präsentationen")
("large cells" "große Zellen")
("large displayed" "groß angezeigt")
("large displayed fraction" "großer angezeigter Bruch")
("large tables" "große Tische")
("last" "last")
("last difference" "letzter Unterschied")
("last error" "letzter Fehler")
("last field" "letztes Feld")
("last name" "Nachname")
("last occurrence" "letztes Vorkommen")
("last similar" "last similar")
("lcm" "lcm")
("left arrow" "linker Pfeil")
("left axis" "linke Achse")
("left baseline" "linke Grundlinie")
("left bottom" "links unten")
("left cell border" "linke Zellgrenze")
("left cell padding" "linke Zellauffüllung")
("left center" "linke Mitte")
("left click: add point; Right click: undo" "Linksklick: Punkt hinzufügen; Rechtsklick: Rückgängig")
("left click: finish; Right click: undo" "Linksklick: Beenden; Rechtsklick: Rückgängig")
("left click: new object" "linker Mausklick: neues Objekt")
("left click: operate" "Linksklick: Bedienen")
("left down" "links unten")
("left on even pages" "Links auf geraden Seiten")
("left table border" "linker Tabellenrand")
("left table padding" "Tischpolster links")
("left top" "links oben")
("left up" "links oben")
("left-right arrow" "Links-Rechts-Pfeil")
("leftwards" "nach links")
("let the environment float" "lass die Umwelt schweben")
("light grey" "hellgrau")
("line breaking" "Zeilenumbruch")
("line wrapping" "Zeilenumbruch")
("linear 2D" "lineares 2D")
("linear algebra" "lineare Algebra")
("lines around" "Zeilen um")
("link image and copies as" "Link-Bild und Kopien als")
("link image as" "Link-Bild als")
("link mode" "Verbindungsmodus")
("link to URL" "Link zu URL")
("linking tool" "Verbindungswerkzeug")
("live" "live")
("live input-output" "Live Input-Output")
("load help file" "Hilfedatei laden")
("load remote file" "Remote-Datei laden")
("loading" "loading")
("local entries" "lokale Einträge")
("loci" "loci")
("locus" "Ort")
("locus rendering" "Ortswiedergabe")
("logarithm" "Logarithmus")
("logarithmic" "logarithmisch")
("logarithmic base" "logarithmische Basis")
("logarithms" "Logarithmen")
("logging in" "Anmelden")
("logical and" "logisch und")
("logical implication" "logische Implikation")
("logical not" "logisch nicht")
("logical or" "logisch oder")
("login" "login")
("logout" "Abmelden")
("long macro" "langes Makro")
("long text" "Langtext")
("look for more fonts" "Weitere Schriftarten suchen")
("loops" "Schleifen")
("macro argument" "Makroargument")
("macro definition" "Makrodefinition")
("macro name" "Makroname")
("macros" "Makros")
("magnify horizontally" "horizontal vergrößern")
("magnify vertically" "Vertikal vergrößern")
("main presentation style" "Hauptpräsentationsstil")
("make a letter environment" "Umgebung für Briefe erstellen")
("make a multi-slide presentation" "Präsentieren Sie mehrere Folien")
("make floating" "schweben lassen")
("make link" "Verknüpfung herstellen")
("make non floating" "Nicht schwebend machen")
("manila paper" "Manila-Papier")
("map arguments" "Kartenargumente")
("marginal note" "Randnotiz")
("margins from width" "Ränder von der Breite")
("margins on paper" "Ränder auf Papier")
("margins on screen" "Ränder auf dem Bildschirm")
("marked" "markiert")
("material" "Material")
("mathematical font" "mathematische Schrift")
("mathematical output" "mathematische Ausgabe")
("matrices" "Matrizen")
("maximal cell height" "maximale Zellenhöhe")
("maximal clustering" "maximale Clusterbildung")
("maximal table height" "maximale Tischhöhe")
("maximal table width" "maximale Tischbreite")
("maximum" "Maximum")
("meander" "Mäander")
("memory" "Speicher")
("memory usage" "Speichernutzung")
("menu" "Menü")
("merge lines into paragraphs unless separated by blank lines" "Zeilen in Absätze zusammenführen, sofern nicht durch Leerzeilen getrennt")
("messages" "Nachrichten")
("meta data" "Metadaten")
("metadata" "Metadaten")
("metal" "Metall")
("middle baseline" "mittlere Grundlinie")
("minimal cell height" "minimale Zellenhöhe")
("minimal cell width" "minimale Zellenbreite")
("minimal line separation" "minimaler Zeilenabstand")
("minimal table height" "minimale Tischhöhe")
("minimal table width" "minimale Tischbreite")
("minimum" "Minimum")
("mirror" "Spiegel")
("miscellanous" "Sonstiges")
("mode dependent icons" "modusabhängige Symbole")
("modify remote live document" "Remote-Live-Dokument ändern")
("module" "Modul")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help->About menu" "Weitere Informationen zu GNU TeXmacs finden Sie im Menü Hilfe-> Info")
("more information about GNU TeXmacs can be found in the help" "Weitere Informationen zu GNU TeXmacs finden Sie in der Hilfe")
("motion" "Bewegung")
("mouse over object" "Maus über Objekt")
("move" "bewegen")
("move objects" "Objekte verschieben")
("move over object on which to operate" "Objekt, an dem gearbeitet werden soll, überfahren")
("multiline" "mehrzeilig")
("multiple choice" "Multiple Choice")
("multiple root" "Mehrfachwurzel")
("multiplication" "Multiplikation")
("my documents" "meine Dokumente")
("navigation options" "Navigationsoptionen")
("never" "nie")
("new account" "neuer Account")
("new bibliography dialogue" "Neuer Literaturdialog")
("new document" "neues Dokument")
("new entry" "neuer Eintrag")
("new identity" "neue Identität")
("new locus" "new locus")
("new macro" "neues Makro")
("new passphrase" "neue Passphrase")
("new remote directory" "neues Remote-Verzeichnis")
("new remote file" "neue Remote-Datei")
("new style fonts" "Schriften im neuen Stil")
("new style page breaking" "Neuer Seitenumbruch")
("new version" "neue Version")
("new window" "neues Fenster")
("newer version" "neuere Version")
("next" "next")
("next chunk" "next chunk")
("next difference" "nächster Unterschied")
("next error" "nächster Fehler")
("next field" "nächstes Feld")
("next occurrence" "nächstes Vorkommen")
("next screen" "nächster Bildschirm")
("next similar" "next similar")
("no clustering" "kein Clustering")
("no completions" "keine Vervollständigungen")
("no errors have been corrected" "Es wurden keine Fehler korrigiert")
("no grid" "kein Gitter")
("no matches found for" "Es wurden keine Übereinstimmungen gefunden")
("no new public key in document" "Kein neuer öffentlicher Schlüssel im Dokument")
("no page break" "kein Seitenumbruch")
("no page numbers" "keine Seitenzahlen")
("no parent" "kein Elternteil")
("no selection" "keine Auswahl")
("no spelling errors" "Keine Rechtschreibfehler")
("normal loci" "normale Loci")
("norwegian" "norwegisch")
("not allowed to remove home directory" "Heimatverzeichnis darf nicht entfernt werden")
("not connected to server" "nicht mit dem Server verbunden")
("not yet implemented" "noch nicht implementiert")
("notebook" "Notebook")
("number equation" "Zahlengleichung")
("number of polar steps" "Anzahl der Polschritte")
("number of subunit steps" "Anzahl der Untereinheitsschritte")
("numbering" "Nummerierung")
("numeric spreadsheet" "numerische Tabelle")
("odd page" "ungerade Seite")
("odd page left margin" "ungerade Seite, linker Rand")
("odd page right margin" "ungerader rechter Seitenrand")
("odd page shift" "ungerade Seitenverschiebung")
("odd pages" "ungerade Seiten")
("of fingerprint" "von Fingerabdruck")
("old version" "alte Version")
("older version" "ältere Version")
("on the footer" "in der Fußzeile")
("on your system and set it up from the \"Security\" tab" "auf Ihrem System und richten Sie es auf der Registerkarte \"Sicherheit\" ein.")
("one column" "eine Spalte")
("one error has been corrected" "Ein Fehler wurde behoben")
("one lower case letter, one non alpha-numeric symbol" "ein Kleinbuchstabe, ein nicht alphanumerisches Symbol")
("one numeric character, one upper case letter" "ein numerisches Zeichen, ein Großbuchstabe")
("only convert changes when re-importing" "Änderungen nur beim erneuten Import konvertieren")
("only convert changes with respect to imported version" "Änderungen nur in Bezug auf die importierte Version konvertieren")
("only convert changes with respect to tracked version" "Änderungen nur in Bezug auf die verfolgte Version konvertieren")
("only implemented for complete subtrees" "nur für vollständige Teilbäume implementiert")
("only keep folded" "nur gefaltet halten")
("only keep unfolded" "nur ungefaltet aufbewahren")
("only show semantic focus" "nur semantischen Fokus anzeigen")
("opacity" "Deckkraft")
("open bibliography" "Bibliographie öffnen")
("open identities" "offene Identitäten")
("open in new window" "In neuem Fenster öffnen")
("open key manager" "Open Key Manager")
("open licence agreement" "offene Lizenzvereinbarung")
("open mailbox" "Mailbox öffnen")
("open module browser" "Modul-Browser öffnen")
("open symbol browser" "Symbolbrowser öffnen")
("open tool in separate window" "Werkzeug in separatem Fenster öffnen")
("operation mode" "Betriebsmodus")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "oder geben Sie den vollständigen Pfad zum \"gpg\"- oder \"gpg2\"-Befehl an")
("order" "Bestellung")
("ordinary symbol" "gewöhnliches Symbol")
("ornamented" "verziert")
("other login" "other login")
("other package" "anderes Paket")
("outer bottom" "äußerer Boden")
("outer left" "links außen")
("outer right" "rechts außen")
("outer top" "äußere Oberseite")
("outline" "outline")
("outlined" "umrissen")
("outlined emboss" "skizzierte Prägung")
("outlined engrave" "umrissen gravieren")
("output options" "Ausgabeoptionen")
("oval" "oval")
("overbrace" "overbrace")
("overlap" "Überlappung")
("overlay" "Overlay")
("overlays" "Overlays")
("overlined" "überstrichen")
("overview of the scheme extension language" "Übersicht über die Schemaerweiterungssprache")
("padded" "gepolstert")
("page background" "Seitenhintergrund")
("page break after" "Seitenumbruch danach")
("page breaking algorithm" "Seitenumbruchalgorithmus")
("page number" "Seitenzahl")
("page number rendering" "Seitenzahlwiedergabe")
("page rendering" "Seitendarstellung")
("palette" "Palette")
("panorama" "Panorama")
("paragraphs" "Absätze")
("parametric curve" "parametrische Kurve")
("parametric surface" "parametrische Oberfläche")
("parenthesis" "Klammer")
("parenthesized" "in Klammern")
("particle" "Partikel")
("passphrase encryption" "Passwortverschlüsselung")
("passphrase wallet facilities are not currently available" "Passphrase Wallet-Funktionen sind derzeit nicht verfügbar")
("passphrases are expected to have at least: 8 characters" "Passphrasen müssen mindestens 8 Zeichen enthalten")
("passphrases mismatch" "Passphrasen stimmen nicht überein")
("pastel" "Pastell")
("pattern" "Muster")
("pause" "Pause")
("pen width" "Stiftbreite")
("permanent footer" "permanente Fußzeile")
("permanent header" "permanenter Header")
("permanently add to dictionary" "dauerhaft zum Wörterbuch hinzufügen")
("permanently insert into dictionary" "dauerhaft in Wörterbuch einfügen")
("permissions" "Berechtigungen")
("phantom" "Phantom")
("phantoms" "Phantome")
("physics and astronomy class" "Physik- und Astronomieklasse")
("picture" "Bild")
("pine" "Kiefer")
("plain" "plain")
("plain boxes" "einfache Kästen")
("plain circles" "einfache Kreise")
("play" "spielen")
("play animation" "Animation abspielen")
("please install GnuPG software from https://www.gnupg.org" "Bitte installieren Sie die GnuPG-Software von https://www.gnupg.org")
("plot" "Handlung")
("plug-ins" "Plug-Ins")
("plugin" "Plugin")
("plugins" "Plugins")
("plural" "plural")
("point" "point")
("polar" "polar")
("polygon" "Polygon")
("pop server settings" "Popserver-Einstellungen")
("position of marginal note" "Position der Randnotiz")
("poster formats" "Posterformate")
("poster theme" "Posterthema")
("postfix" "postfix")
("preferences for editing mathematical formulas" "Einstellungen zum Bearbeiten von mathematischen Formeln")
("preferences for tag" "Einstellungen für Tag")
("prefix" "Präfix")
("presentation tool" "Präsentationstool")
("preserve" "bewahren")
("preserve tags" "Tags beibehalten")
("pretty tree output" "Pretty Tree Output")
("preview" "Vorschau")
("previous" "vorherige")
("previous difference" "vorherige Differenz")
("previous error" "vorheriger Fehler")
("previous field" "vorheriges Feld")
("previous occurrence" "vorheriges Vorkommen")
("previous screen" "vorheriger Bildschirm")
("previous similar" "vorherige ähnliche")
("primitive or macro" "primitiv oder Makro")
("print buffer" "Druckpuffer")
("print buffer to file" "Druckpuffer in Datei")
("print to file" "In Datei drucken")
("printer setup" "Druckereinrichtung")
("program bracket matching" "Programmklammer passend")
("program bracket selections" "Programmklammerauswahl")
("program commands" "Programmbefehle")
("program font" "Programmschrift")
("program interface for buffer management" "Programmschnittstelle zur Pufferverwaltung")
("programming routines for editing documents" "Programmierroutinen zum Bearbeiten von Dokumenten")
("prominent" "prominent")
("provoke C++ error" "C ++ - Fehler provozieren")
("provoke menu error" "Menüfehler provozieren")
("provoke scheme error" "Schemafehler provozieren")
("pseudo code" "Pseudocode")
("public key encryption" "Verschlüsselung mit öffentlichem Schlüssel")
("public keys" "öffentliche Schlüssel")
("pulse" "Puls")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUI only, sorry. Benutze \"Auswahl exportieren \"")
("qt-widgets" "qt-widgets")
("quantifier" "Quantifizierer")
("questions only" "nur Fragen")
("questions with answers" "Fragen mit Antworten")
("quick evaluation of formulas" "schnelle Auswertung von Formeln")
("rank" "Rang")
("raw" "roh")
("really close it" "Schließe es wirklich")
("really delete user identity" "Benutzeridentität wirklich löschen")
("rebuild translations file" "Übersetzungsdatei neu erstellen")
("recent documents" "Aktuelle Dokumente")
("recipients" "Empfänger")
("recognize" "erkennen")
("recover autosave file" "Automatisch gespeicherte Datei wiederherstellen")
("rectangular" "rechteckig")
("reduce" "reduzieren")
("reduce trigonometric functions" "Trigonometrische Funktionen reduzieren")
("reduced margins" "reduzierte Ränder")
("reference guide for the TeXmacs primitives" "Referenzhandbuch für die TeXmacs-Grundelemente")
("reference guide for the standard TeXmacs styles" "Referenzhandbuch für die Standard-TeXmacs-Stile")
("regenerate" "regenerieren")
("register file" "Registerdatei")
("relate" "beziehen")
("relation" "Relation")
("release left button: finish editing" "Linke Maustaste loslassen: Bearbeitung beenden")
("remote" "remote")
("remote connections" "Remoteverbindungen")
("remote control" "Fernbedienung")
("remote controllers with keyboard simulation" "Fernbedienungen mit Tastatursimulation")
("remote directory" "Remote-Verzeichnis")
("remote servers" "Remote-Server")
("remote tool" "Remote-Tool")
("remove" "entfernen")
("remove banner" "Banner entfernen")
("remove database entry" "Datenbankeintrag entfernen")
("remove downwards" "nach unten entfernen")
("remove entries" "Einträge entfernen")
("remove entry" "Eintrag entfernen")
("remove field above" "Feld oben entfernen")
("remove field below" "Feld darunter entfernen")
("remove folded" "gefaltet entfernen")
("remove last field" "letztes Feld entfernen")
("remove leftwards" "nach links entfernen")
("remove link" "Verknüpfung entfernen")
("remove next field" "nächstes Feld entfernen")
("remove number" "Nummer entfernen")
("remove previous field" "vorheriges Feld entfernen")
("remove rightwards" "nach rechts entfernen")
("remove selected database entries" "Ausgewählte Datenbankeinträge entfernen")
("remove selected entries" "Ausgewählte Einträge entfernen")
("remove superfluous invisible operators" "überflüssige unsichtbare Operatoren entfernen")
("remove tag" "Tag entfernen")
("remove this branch" "Diesen Zweig entfernen")
("remove unfolded" "entfaltet entfernen")
("remove upwards" "nach oben entfernen")
("removed entries from database" "Einträge aus der Datenbank entfernt")
("removed entry from database" "Eintrag aus Datenbank entfernt")
("rename" "umbenennen")
("rename section" "Abschnitt umbenennen")
("replace TeXmacs styles with no LaTeX equivalents" "TeXmacs-Stile durch keine LaTeX-Entsprechungen ersetzen")
("replace all further occurrences" "Alle weiteren Vorkommen ersetzen")
("replace one occurrence" "Ein Vorkommen ersetzen")
("replace toolbar" "Symbolleiste ersetzen")
("replace unrecognized styles" "Nicht erkannte Stile ersetzen")
("reset error counters" "Fehlerzähler zurücksetzen")
("resize" "Größe ändern")
("resize objects" "Objekte in der Größe ändern")
("restart TeXmacs in order to let changes take effect" "Starten Sie TeXmacs neu, damit die Änderungen wirksam werden")
("restart in order to let the new look and feel take effect" "Neustart, damit das neue Erscheinungsbild wirksam wird")
("retain" "behalten")
("retime" "Retime")
("retina settings" "Retina-Einstellungen")
("retrieve email" "E-Mail abrufen")
("retrieve remote live document" "Remote-Live-Dokument abrufen")
("retrieved contents" "Abgerufener Inhalt")
("reverse" "rückwärts")
("reverse ordering" "umgekehrte Reihenfolge")
("ridged paper" "geriffeltes Papier")
("right arrow" "Rechtspfeil")
("right baseline" "rechte Grundlinie")
("right cell border" "rechter Zellenrand")
("right cell padding" "Auffüllen der rechten Zelle")
("right down" "rechts unten")
("right on even pages" "direkt auf geraden Seiten")
("right table border" "rechter Tabellenrand")
("right table padding" "rechte Tischpolsterung")
("right up" "rechts oben")
("rightwards" "nach rechts")
("rigid box" "starre Box")
("rotate" "drehen")
("rotate objects" "Objekte drehen")
("rough" "grob")
("rough paper" "raues Papier")
("round" "rund")
("round overbrace" "runde Klammer")
("round underbrace" "runde Unterbrust")
("row above" "Zeile oben")
("row below" "Zeile darunter")
("run" "run")
("run current file" "Aktuelle Datei ausführen")
("same names" "gleiche Namen")
("same screen margins as on paper" "gleiche Bildschirmränder wie auf Papier")
("sample text" "Beispieltext")
("save auxiliary data" "Hilfsdaten speichern")
("save entries" "Einträge speichern")
("save entry" "Eintrag speichern")
("save image as" "Bild speichern unter")
("save position" "Position speichern")
("save remote file" "Remote-Datei speichern")
("saved modifications in database" "gespeicherte Änderungen in der Datenbank")
("scheme command" "Schemabefehl")
("scheme developers guide" "Schema-Entwicklerhandbuch")
("scheme extensions" "Schemaerweiterungen")
("scheme interface for the graphical mode" "Schema-Oberfläche für den Grafikmodus")
("screen" "Bildschirm")
("screen rendering" "Bildschirmwiedergabe")
("screens" "Bildschirme")
("screenshot" "Screenshot")
("scripting language" "Skriptsprache")
("scripts" "Skripte")
("search and replace" "Suchen und Ersetzen")
("search results for" "Suchresultate für")
("search toolbar" "Suchsymbolleiste")
("search words in my documents" "Suchbegriffe in meinen Dokumenten")
("search words in the documentation" "Suchbegriffe in der Dokumentation")
("search words in the source code" "Suchbegriffe im Quellcode")
("second" "Sekunde")
("secret keys" "geheime Schlüssel")
("sections" "Abschnitte")
("see documentation" "siehe Dokumentation")
("select pen" "Stift auswählen")
("select the action to be undertaken for each conflict" "Wählen Sie die für jeden Konflikt auszuführende Aktion aus")
("select view mode" "Anzeigemodus auswählen")
("semantic correctness" "semantische Korrektheit")
("semantic editing" "semantische Bearbeitung")
("semantic selections" "semantische Selektionen")
("semantics" "Semantik")
("senior" "Senior")
("serb" "serb")
("serif" "Serife")
("server" "Server")
("session commands" "Sitzungsbefehle")
("set default" "Standard festlegen")
("set difference" "Differenz einstellen")
("set intersection" "Schnittmenge setzen")
("set number of columns" "Spaltenanzahl festlegen")
("set number of rows" "Zeilenanzahl festlegen")
("set or get environment variables" "Umgebungsvariablen setzen oder holen")
("set properties" "Eigenschaften festlegen")
("set union" "Vereinigung setzen")
("set user information" "Benutzerinformationen festlegen")
("seventh" "siebte")
("several equations" "mehrere Gleichungen")
("shadow" "Schatten")
("shadowed" "beschattet")
("shadowed raise" "Schattenerhöhung")
("shift" "Verschiebung")
("show all parts" "Alle Teile anzeigen")
("show current focus" "Aktuellen Fokus anzeigen")
("show full context" "vollständigen Kontext anzeigen")
("show key presses" "Tastendruck anzeigen")
("show main document" "Hauptdokument anzeigen")
("show memory usage" "Speicherverbrauch anzeigen")
("show one part" "zeige einen Teil")
("show panorama" "Panorama anzeigen")
("show preamble" "Präambel anzeigen")
("show several parts" "mehrere Teile zeigen")
("show subunits" "zeige Untereinheiten")
("show table cells" "Tabellenzellen anzeigen")
("show timings" "Timings anzeigen")
("side tools" "Nebenwerkzeuge")
("simple" "einfach")
("simplification" "Vereinfachung")
("simplified evaluation of formulas" "Vereinfachte Auswertung von Formeln")
("simplified menus" "vereinfachte Menüs")
("simplify" "vereinfachen")
("sine" "Sinus")
("sixth" "sixth")
("skew" "Versatz")
("skip all" "Alles überspringen")
("slant" "Schräge")
("slashed fraction" "Schrägstrich")
("slides" "Folien")
("slow" "langsam")
("slow decrease" "langsame Abnahme")
("slow increase" "langsamer Anstieg")
("small environment box" "kleine Umweltbox")
("small focus" "kleiner Fokus")
("small inline" "small inline")
("small inline fraction" "kleiner Inline-Anteil")
("smash" "Smash")
("smooth" "glatt")
("smooth end" "glattes Ende")
("smooth extremities" "glatte Extremitäten")
("smooth start" "reibungsloser Start")
("snap" "Einrasten")
("snap distance" "Einrastabstand")
("snap to curves" "An Kurven ausrichten")
("snap to grid" "Am Raster ausrichten")
("snap to grid curve" "An Gitterkurve ausrichten")
("snap to intersections of curves" "An Schnittpunkten von Kurven ausrichten")
("snap to text borders" "An Texträndern ausrichten")
("snap to text corners" "An Textecken ausrichten")
("solution to exercise" "Übungslösung")
("solution to problem" "Lösung des Problems")
("solutions" "Lösungen")
("sound" "Ton")
("source macros tool" "Quellmakrotool")
("south" "Süd")
("south east" "Südosten")
("space bar in math mode" "Leertaste im Mathematikmodus")
("space bar in text mode" "Leertaste im Textmodus")
("space stretchability" "Raumdehnbarkeit")
("span" "span")
("span over all columns" "Spanne über alle Spalten")
("special functions" "Sonderfunktionen")
("special properties" "besondere eigenschaften")
("specific baseline" "spezifische Grundlinie")
("specify color alternation" "Farbwechsel festlegen")
("specify how to traverse the manual" "Geben Sie an, wie das Handbuch durchsucht werden soll")
("specify semantics of a symbol or formula" "Semantik eines Symbols oder einer Formel angeben")
("specify the size of the table" "Größe der Tabelle angeben")
("spell check" "Rechtschreibprüfung")
("spline" "Spline")
("split program" "Split-Programm")
("square" "Quadrat")
("square overbrace" "quadratische Klammer")
("square underbrace" "quadratische Unterbrust")
("stack" "Stapel")
("standard" "Standard")
("standard Output" "Standardausgabe")
("standard formats" "Standardformate")
("standard fraction" "Standardfraktion")
("star" "Stern")
("start server" "Server starten")
("statement" "Aussage")
("statistics" "Statistiken")
("status" "Status")
("stop server" "Server stoppen")
("storage" "Speicher")
("store tracking information in LaTeX files" "Verfolgungsinformationen in LaTeX-Dateien speichern")
("stretch" "Strecke")
("stretch factor" "Dehnungsfaktor")
("strict Ascii" "strict Ascii")
("strike through" "Durchgestrichen")
("structured insert above" "Strukturiertes Insert oben")
("structured insert at the left" "Strukturierte Einfügung links")
("structured insert at the right" "strukturierte Einfügung rechts")
("structured insert below" "strukturierte Einfügung unten")
("structured remove downwards" "strukturiert nach unten entfernen")
("structured remove leftwards" "strukturiert nach links entfernen")
("structured remove rightwards" "strukturiert nach rechts entfernen")
("structured remove upwards" "strukturiert nach oben entfernen")
("structured variant" "strukturierte Variante")
("style options" "Stiloptionen")
("style parameters" "Stilparameter")
("subject" "Betreff")
("submenu" "Untermenü")
("subscript below" "tiefgestellt unten")
("subsubmenu" "Untermenü")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtraction" "Subtraktion")
("summarized" "zusammengefasst")
("summary of the principal TeXmacs tags" "Zusammenfassung der wichtigsten TeXmacs-Tags")
("superscript above" "hochgestellt oben")
("supported plug-ins" "Unterstützte Plugins")
("surface" "Oberfläche")
("inflate" "Dünung")
("swiss" "swiss")
("switch to buffer" "Umschalten auf Puffer")
("symbol properties not found" "Symboleigenschaften nicht gefunden")
("symbols" "Symbole")
("synchronize" "synchronisieren")
("synchronize bibliographic references" "Literaturhinweise synchronisieren")
("synchronize with remote server" "Mit Remote-Server synchronisieren")
("synopsis" "Zusammenfassung")
("system command" "Systembefehl")
("tabbed" "tabbed")
("table breaking" "Tischbrechen")
("table height" "Tischhöhe")
("table properties" "Tabelleneigenschaften")
("table width" "Tischbreite")
("tags with special rendering" "Tags mit speziellem Rendering")
("tangent" "Tangente")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacs-Puffer erwartet")
("teXmacs buffer on disk expected" "teXmacs-Puffer auf der Festplatte erwartet")
("teXmacs extensions to scheme and utilities" "teXmacs-Erweiterungen für Schema und Dienstprogramme")
("teXmacs macro" "teXmacs-Makro")
("teXmacs package" "teXmacs-Paket")
("teXmacs style" "teXmacs style")
("teXmacs style files" "teXmacs style files")
("test routine" "Testroutine")
("testing tree-view" "Baumansicht testen")
("text borders" "Textrahmen")
("text box style" "Textfeldstil")
("text corners" "Textecken")
("textual" "Text")
("textual operator" "Textoperator")
("textual spreadsheet" "Textkalkulation")
("the TeXmacs plug-in system" "das TeXmacs-Plug-in-System")
("the document has not been saved" "Das Dokument wurde nicht gespeichert")
("theme parameters" "Themenparameter")
("these collected public keys will be definitely lost" "Diese gesammelten öffentlichen Schlüssel gehen definitiv verloren")
("these public keys will be definitely lost" "Diese öffentlichen Schlüssel gehen definitiv verloren")
("these secret keys will be definitely lost" "Diese geheimen Schlüssel gehen definitiv verloren")
("thicken" "verdicken")
("third" "dritte")
("this" "this")
("this column" "diese Spalte")
("this document has not been saved" "Dieses Dokument wurde nicht gespeichert")
("this page footer" "dieser Seitenfuß")
("this page header" "dieser Seitenkopf")
("this page number" "diese Seitennummer")
("this row" "diese Reihe")
("this style specifies page margins in the TeX way" "Dieser Stil legt Seitenränder in der Art von TeX fest")
("three columns" "drei Spalten")
("three dots" "drei Punkte")
("through popup windows" "durch Popup-Fenster")
("through the menus" "durch die Menüs")
("thumbnails" "Miniaturansichten")
("time evolution" "Zeitentwicklung")
("timings" "Timings")
("title presentation options" "Titelpräsentationsoptionen")
("title style" "Titelstil")
("title suffix" "Titelsuffix")
("titled block" "Titelblock")
("toggle cell wrapping mode" "Zellenumbruchmodus umschalten")
("toggle here" "hier umschalten")
("toggle off" "ausschalten")
("toggle on" "umschalten")
("tolerant" "tolerant")
("top baseline" "oberste Grundlinie")
("top cell border" "oberster Zellenrand")
("top cell padding" "Polsterung der oberen Zellen")
("top table border" "oberster Tabellenrand")
("top table padding" "oberste Tischpolsterung")
("transform" "transform")
("transform cell into subtable" "Zelle in Untertabelle umwandeln")
("translations" "Übersetzungen")
("translations loaded" "Übersetzungen geladen")
("transpose" "transponieren")
("traversal" "Traversal")
("traverse" "Traverse")
("triangle" "Dreieck")
("triangularize" "triangularisieren")
("trigonometric" "trigonometrisch")
("trigonometry" "Trigonometrie")
("turn off" "ausschalten")
("turn on" "Einschalten")
("two columns" "zwei Spalten")
("two dots" "zwei Punkte")
("type a latex command followed by return" "Geben Sie einen Latex-Befehl gefolgt von der Rückgabe ein")
("underbrace" "Underbrace")
("underlined" "unterstrichen")
("unfold all" "Alles entfalten")
("unfold all fields" "Alle Felder aufklappen")
("unit" "Einheit")
("unit length" "Einheitslänge")
("unknown secret key fingerprint" "Fingerabdruck des unbekannten geheimen Schlüssels")
("unregistered file" "nicht registrierte Datei")
("unroll" "Abrollen")
("unsecure script refused" "unsicheres Skript abgelehnt")
("unsupported link mode" "Nicht unterstützter Verbindungsmodus")
("until" "bis")
("untitled block" "Block ohne Titel")
("up to date" "aktuell")
("update buffer" "Aktualisierungspuffer")
("update this buffer" "Diesen Puffer aktualisieren")
("update web site" "Website aktualisieren")
("upight" "upight")
("upload" "Upload")
("upwards" "aufwärts")
("use CSS for more advanced formatting" "CSS für erweiterte Formatierung verwenden")
("use MathML" "verwende MathML")
("use as master" "Verwendung als Master")
("use extensible brackets" "Ausziehbare Klammern verwenden")
("use line wrapping for lines which are longer than 80 characters" "Zeilenumbruch für Zeilen verwenden, die länger als 80 Zeichen sind")
("use margin kerning (protrusion)" "Randkerning (Vorsprung) verwenden")
("use protrusion" "Vorsprung verwenden")
("use relative path" "Relativen Pfad verwenden")
("user interface" "Benutzeroberfläche")
("user interface language" "Sprache der Benutzeroberfläche")
("user preferences" "Benutzerpräferenzen")
("users of oriental languages" "Nutzer orientalischer Sprachen")
("utf-8 with inputenc LaTeX package" "utf-8 mit LaTeX-Eingabepaket")
("utilities" "Dienstprogramme")
("vanish" "verschwinden")
("verbose" "verbose")
("version" "Version")
("versioning tool" "Versionierungstool")
("vertical alignment" "vertikale Ausrichtung")
("vertical margins" "vertikale Ränder")
("vertical space stretchability" "vertikale Raumstreckbarkeit")
("visible except here" "nur hier sichtbar")
("visible from here on" "ab hier sichtbar")
("visible only here" "nur hier sichtbar")
("visible until here" "bis hierher sichtbar")
("visited loci" "besuchte Orte")
("wallet" "Brieftasche")
("wave" "Welle")
("web" "web")
("weight" "Gewicht")
("when line wrapping" "beim Zeilenumbruch")
("whitespace" "Leerzeichen")
("wide" "breit")
("wide bar" "breite Stange")
("wide block" "breiter Block")
("wide colored" "breit gefärbt")
("wide float" "Wide Float")
("wide footnote" "breite Fußnote")
("wide tabular" "wide tabular")
("widescreen" "Breitbild")
("wrap lines" "Zeilenumbruch")
("write a macro" "Makro schreiben")
("writing TeXmacs bibliography styles" "Schreiben von TeXmacs-Bibliographiestilen")
("writing documentation" "Dokumentation schreiben")
("wrong empty passphrase" "falsche leere Passphrase")
("wrong passphrase" "falsche Passphrase")
("year" "Jahr")
("you are attempting to open an encrypted file while" "Sie versuchen, eine verschlüsselte Datei zu öffnen, während")
("you might consider enabling the experimental" "Sie könnten erwägen, das Experiment zu aktivieren")
("you must add a bibliography file" "Sie müssen eine Bibliografie-Datei hinzufügen")
("you should also make sure that GnuPG is installed" "Sie sollten auch sicherstellen, dass GnuPG installiert ist")
("your personal dictionary has been modified" "Ihr persönliches Wörterbuch wurde geändert")
("zoom" "Zoom")
("zoom in" "Vergrößern")
("zoom out" "Verkleinern")
