("A modifier" "A-vaihtonäppäin")
("GNU" "GNU")
("H modifier" "H-vaihtonäppäin")
("LaTeX" "LaTeX")
("M modifier" "M-vaihtonäppäin")
("TeX" "TeX")
("abbreviation" "lyhenne")
("about" "tietoja")
("about menu" "tietoja-menu")
("above" "yläpuolelle")
("abstract" "tiivistelmä")
("accent" "aksentti")
("accept" "hyväksy")
("accept all scripts" "hyväksy kaikki skriptit")
("accept no scripts" "älä hyväksy skriptejä")
("accept script" "hyväksy skripti")
("acknowledgment" "kiitokset")
("acronym" "akronyymi")
("action" "toiminto")
("activate" "aktivoi")
("acute" "acute")
("add switch after" "lisää valitsin jälkeen")
("add switch before" "lisää valitsin ennen")
("address" "osoite")
("address block" "osoitelohko")
("advanced" "edistynyt")
("advanced layout features" "edistyneet asetteluominaisuudet")
("after" "jälkeen")
("algorithm" "algoritmi")
("align cell to the bottom" "tasaa solu alareunaan")
("align cell to the left" "tasaa solu vasemmalle")
("align cell to the right" "tasaa solu oikealle")
("align cell to the top" "tasaa solu yläreunaan")
("align table at base of left column" "tasaa taulukko vasemman sarakkeen alareunaan")
("align table at base of middle column" "tasaa taulukko keskimmäisen sarakkeen alareunaan")
("align table at base of origin column" "tasaa taulukko sarakkeen alareunaan")
("align table at base of right column" "tasaa taulukko oikeanpuoleisen sarakkeen alareunaan")
("align table at fraction bar height" "tasaa taulukko murtolukuviivan korkeudelle")
("align table at the base of bottom row" "tasaa taulukko alimmaisen rivin alareunaan")
("align table at the base of middle row" "tasaa taulukko keskimmäisen rivin alareunaan")
("align table at the base of origin row" "tasaa taulukko rivin alareunaan")
("align table at the base of top row" "tasaa taulukko ylimmäisen rivin alareunaan")
("align table at the bottom" "tasaa taulukko alareunaan")
("align table at the center" "tasaa taulukko keskelle")
("align table at the horizontal center" "tasaa taulukko keskelle horisontaalisesti")
("align table at the left" "tasaa taulukko vasemmalle")
("align table at the top" "tasaa taulukko yläreunaan")
("align table to the right" "tasaa taulukko oikealle")
("align text to the left" "tasaa teksti vasemmalle")
("align text to the right" "tasaa teksti oikealle")
("alignment" "tasaus")
("all" "kaikki")
("allow" "salli")
("allowed extension" "sallittu laajennus")
("allowed reduction" "sallittu reduktio")
("alpha release" "alfa-versio")
("alt key" "alt-näppäin")
("and" "ja")
("appendix" "liite")
("apply" "sovella")
("april" "huhtikuu")
("arab" "arabi")
("archaic" "arkaainen")
("architecture" "arkkitehtuuri")
("argument" "argumentti")
("arithmetic" "aritmetiikka")
("armenian" "armenia")
("arrow" "nuoli")
("arrows" "nuolin")
("article" "artikkeli")
("as on paper" "kuin paperilla")
("assign" "assign")
("at fraction bar height" "murtolukuviivan korkeudelle")
("at the baseline" "perusviivalle")
("at the bottom" "alareunaan")
("at the left" "vasemmalle")
("at the middle" "keskelle")
("at the right" "oikealle")
("at the top" "yläreunaan")
("attach" "liitä")
("attach buffer to which project" "mihin projektiin puskuri liitetään")
("august" "elokuu")
("author" "tekijä")
("authorize" "salli")
("automatic" "automaattinen")
("automatically generated content" "automaattisesti generoitu teksti")
("axiom" "aksiooma")
("background" "tausta")
("background color" "taustaväri")
("backward replace" "korvaa taaksepäin")
("backward search" "etsi taaksepäin")
("bad data format" "väärä dataformaatti")
("bar" "viiva")
("bard" "bardi")
("base level" "perustaso")
("bashkirian" "bashkirian")
("basic" "perus")
("basic data types" "perusdatatyypit")
("basic types" "perustyypit")
("be useful" "olla hyödyllinen")
("become a TeXmacs developer" "ala TeXmacsin kehittäjäksi")
("before" "ennen")
("begin" "aloita")
("below" "alapuolelle")
("beta release" "beta-versio")
("bibliography" "kirjallisuutta")
("bibliography file" "kirjallisuusviitetiedosto")
("bibliography style" "kirjallisusviitteiden tyylitiedosto")
("big" "suuri")
("big figure" "suuri kuva")
("big operator" "suuri operaattori")
("big skip" "suuri väli")
("big table" "suuri taulukko")
("binary operation" "kaksipaikkainen operaattori")
("binary relation" "kaksipaikkainen relaatio")
("black" "musta")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard matematiikka")
("blackletter" "blackletter")
("blue" "sininen")
("body" "runko")
("bold" "lihavoitu")
("book" "kirja")
("border" "reunus")
("both" "molemmat")
("bottom" "pohja")
("bottom border" "alareuna")
("bottom margin" "alareunus")
("bottom padding" "alatäyttö")
("branch" "haaraudu")
("break" "rivin- tai sivunvaihto")
("breaking" "sivunvaihto")
("breve" "kaari")
("british" "britti")
("brown" "ruskea")
("browse" "selaa")
("browse web" "selaa www:tä")
("browser" "selain")
("buffer" "puskuri")
("bullet" "luettelomerkki")
("bullets" "palloin")
("by" " ")
("by typing" "kirjoittamalla")
("bytes free" "tavua vapaana")
("bytes used" "tavua käytetty")
("calligraphic" "kalligrafinen")
("cancel" "peruuta")
("caps-lock key" "caps-lock-näppäin")
("case" "case")
("cc" "cc")
("cell" "solu")
("cell background color" "solun taustaväri")
("cell border" "solun reuna")
("cell height" "solun korkeus")
("cell operation mode" "komennot vaikuttavat")
("cell width" "solun leveys")
("center" "keskitä")
("center text" "keskitä teksti")
("centered" "keskitetty")
("centered block" "keskitetty lohko")
("centered tabular" "keskitetty taulukoitu")
("change border of cell" "vaihda solun reunusta")
("change cell operation mode" "vaihda solun toimintatilaa")
("change log" "muutosloki")
("changes" "muutokset")
("chapter" "luku")
("check" "väkänen")
("check text for spelling errors" "tarkasta tekstin oikeinkirjoitus")
("chinese" "kiina")
("choice" "valinta")
("citation" "viite")
("cite" "viittaa")
("class" "luokka")
("clear" "tyhjennä")
("clear selection" "tyhjennä valinta")
("clipped" "leikattu")
("clipped and magnified" "leikattu ja suurennettu")
("clipped and resized" "leikattu ja pienennetty tai suurennettu")
("clone" "kloonaa")
("clone window" "kloonaa ikkuna")
("close" "sulje")
("close TeXmacs" "sulje TeXmacs")
("close buffer" "sulje puskuri")
("close session" "sulje istunto")
("close window" "sulje ikkuna")
("closing" "lopetus")
("code" "koodi")
("color" "väri")
("column" "sarake")
("column contains glued items" "sarakkeessa on liimattuja osia")
("compatibility with other formats" "yhteensopivuus muiden formaattien kanssa")
("compile article" "käännä artikkeli")
("compile book" "käännä kirja")
("compile buffer" "käännä puskuri")
("compile project" "käännä projekti")
("complex" "kompleksinen merkintä")
("concrete" "concrete")
("condensed" "tiivistetty")
("condition" "ehto")
("configuration" "asetukset")
("content tag" "sisältötagi")
("context dependent icons" "kontekstista riippuvat ikonit")
("continuation of" "jatke")
("convention" "tapa")
("converters to other data formats" "muuntaminen toiseen tiedostomuotoon")
("copy" "kopioi")
("copy text" "kopioi teksti")
("copy to" "kopioi")
("copying" "kopiointi")
("corollary" "korollaari")
("correct text" "korjaa teksti")
("cursors" "kursorit")
("custom tab" "kustomoitu tabulaattori")
("customizing TeXmacs" "TeXmacsin säätäminen")
("customizing the TeXmacs styles" "TeXmacsin tyylien säätäminen")
("custum tab" "virhe!")
("cut" "leikkaa")
("cut text" "leikkaa tekstiä")
("cut to" "leikkaa")
("cypriot" "kypros")
("cyrillic" "kyrillinen")
("cyrillic input method" "kyrillisen tekstin syöttötapa")
("cyrillic italic right" "kyrillinen kursiivi oikealle")
("czech" "tsekki")
("dancers" "tanssijat")
("dash" "viiva")
("dashes" "viivoin")
("data conversion" "datan muuttaminen")
("data format" "dataformaatti")
("date" "päivämäärä")
("deactivate" "deaktivoi")
("deactivate table" "deaktivoi taulukko")
("december" "joulukuu")
("decorate atoms" "decorate atoms")
("default" "oletus")
("default padding" "oletustäyttö")
("definition" "määritelmä")
("delete" "poista")
("delete column" "poista sarake")
("delete row" "poista rivi")
("denominator" "nimittäjä")
("description" "kuvaile")
("destination" "määränpää")
("detach" "irrota")
("determinant" "determinantti")
("devangari" "devangari")
("developers guide" "kehittäjän opas")
("directory" "hakemisto")
("disable first indentation" "ota ensimmäinen sisennys pois käytöstä")
("disable first indentation after" "poista ensimmäinen sisennys jälkeen")
("disable first indentation before" "poista ensimmäinen sisennys ennen")
("disable indentation" "poista sisennys")
("disable indentation after" "poista sisennys jälkeen")
("disable indentation before" "poista sisennys ennen")
("disallow" "älä salli")
("distribute unused space" "jaa käyttämätön tila")
("div" "div")
("document" "asiakirja")
("document format" "tallennusmuoto")
("document style" "asiakirjan tyyli")
("document styles" "asiakirjatyylit")
("documentation" "dokumentaatio")
("documents are trees" "asiakirjat ovat puita")
("dot" "piste")
("dots" "pisteet")
("double stroke" "ajatusviiva")
("down" "alas")
("dpi" "dpi")
("duplicate" "toistettu")
("dutch" "hollanti")
("dynamic libraries" "dynaamiset kirjastot")
("edit" "muokkaa")
("editing tools" "editointityökalut")
("email" "email")
("emphasize" "korosta")
("emphasize text" "korosta tekstiä")
("empty box" "tyhjä laatikko")
("enable first indentation" "ota käyttöön ensimmäinen sisennys")
("enable first indentation after" "ota käyttöön ensimmäinen sisennys jälkeen")
("enable first indentation before" "ota käyttöön ensimmäinen sisennys ennen")
("enable indentation" "ota sisennys käyttöön")
("enable indentation after" "ota sisennys käyttöön jälkeen")
("enable indentation before" "ota sisennys käyttöön ennen")
("encl" "encl")
("end" "loppu")
("english" "englanti")
("enter a title" "syötä otsikko")
("enumerate" "numeroi")
("enumerate|Alpha" "numeroi|Aakkosin")
("enumerate|Roman" "numeroi|Roomalaisin numeroin")
("enumerate|alpha" "numeroi|aakkosin")
("enumerate|roman" "numeroi|roomalaisin numeroin")
("env" "env")
("environment" "ympäristö")
("epilogue" "epilogi")
("equal" "yhtäkuin")
("equation" "yhtälö")
("equations" "yhtälöryhmä")
("equivalent for" "ekvivalentti")
("error" "virhe")
("etruscan" "etruski")
("evaluate" "evaluoi")
("evaluate scheme expression" "evaluoi scheme-lauseke")
("even page footer" "parillisen sivun alatunniste")
("even page header" "parillisen sivun ylätunniste")
("even page margin" "parillisen sivun marginaali")
("even page text" "parillisen sivun teksti")
("exact horizontal" "eksakti vaakasuora")
("exact mode" "eksakti tila")
("exam" "koe")
("example" "esimerkki")
("exclusive" "poissulkeva")
("exclusive or" "poissulkeva tai")
("executable" "suoritettava")
("execute" "suorita")
("execute a TeXmacs command" "suorita TeXmacs-komento")
("execute system command" "suorita systeemikomento")
("executive" "executive")
("exercise" "harjoitus")
("expand" "laajenna")
("explained" "selitetty")
("export" "tallenna muodossa")
("export as" "talleta muodossa")
("extend or normal" "laajennettu tai normaali")
("extern " "ulkoinen")
("extra" "ylimääräinen")
("extract format" "talleta formaatti")
("family" "perhe")
("february" "helmikuu")
("figure" "kuva")
("file" "tiedosto")
("file name" "tiedostonimi")
("file not found" "tiedostoa ei löytynyt")
("find next match" "etsi seuraava")
("find text" "etsi tekstistä")
("first contact" "ensimmäinen kontakti")
("first indentation" "ensimmäinen sisennys")
("first item" "ensimmäinen kohta")
("first page" "ensimmäinen sivu")
("first start" "ensimmäinen alku")
("flat" "lattana")
("flexibility" "joustavuus")
("flexibility factor for vertical spacing" "pystysuoran välistyksen joustavuuskerroin")
("floating figure" "vapaasti asettuva kuva")
("floating object" "vapaasti asettuva objekti")
("floating table" "vapaasti asettuva taulukko")
("fold" "taite")
("folded" "taitettu")
("font" "kirjasintyyppi")
("font base size" "kirjasintyypin peruskoko")
("font dpi" "kirjasintyypin dpi")
("font family" "kirjasintyyppiperhe")
("font name" "kirjasintyypin nimi")
("font series" "kirjasintyypin sarja")
("font shape" "kirjasintyypin muoto")
("font size" "kirjasintyypin koko")
("font variant" "kirjasintyypin muunnelma")
("fonts" "kirjasintyypit")
("footer" "alatunniste")
("footnote" "alaviite")
("for" "sillä")
("foreground" "edusta")
("foreign" "muut kielet")
("format" "muotoilu")
("formatted date" "muotoiltu päivämäärä")
("formula" "kaava")
("formula style" "kaavan tyyli")
("forward replace" "korvaa eteenpäin")
("forward search" "etsi eteenpäin")
("fraction" "murtoluku")
("french" "ranska")
("full manuals" "kokonaiset manuaalit")
("function" "funktio")
("further customization" "lisää kustomointeja")
("future changes" "tulevia muutoksia")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs ei sisällä minkäänlaista takuuta")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs on lisensoitu GNU:n yleisellä lisenssillä")
("general architecture of TeXmacs" "TeXmacsin yleinen arkkitehtuuri")
("general negation" "yleinen negaatio")
("generating font file" "generoin kirjasintiedostoja")
("generic" "yleinen")
("georgian" "georgia")
("german" "saksa")
("getting started" "aloittaminen")
("glossary" "sanasto")
("glossary entry" "sanastomerkintä")
("glue" "liima")
("glue decorations" "lisää koristeet")
("go" "siirry")
("gothic" "gothic")
("graphical interface" "graafinen käyttöliittymä")
("grave" "grave")
("greater" "suurempi")
("greater or equal" "suurempi tai yhtäsuuri")
("greek" "kreikka")
("greek letter" "kreikkalainen kirjain")
("green" "vihreä")
("grey" "harmaa")
("group" "ryhmä")
("happy typing" "kirjoita hyvin")
("has been aborted" "on keskeytetty")
("has completed its task" "on suorittanut tehtävänsä")
("hat" "hattu")
("header" "ylätunniste")
("header and footer" "ylä- ja alatunniste")
("hebrew" "heprea")
("height" "korkeus")
("height is exactly the specified height" "korkeus on täsmälleen sama kuin on määritelty")
("height is maximum of specified height and box height" "korkeus on määritelmästä ja laatikon korkeudesta suurempi")
("height is minimum of specified height and box height" "korkeus on määritelmästä ja laatikon korkeudesta pienempi")
("height magnification" "korkeuden suurennos")
("help" "ohje")
("help me" "auta minua")
("help us" "auttaminen")
("here" "tässä")
("home" "kotihakemisto")
("horizontal" "vaakasuora")
("horizontal cell alignment" "vaakasuora solun tasaus")
("horizontal ink separation" "vaakasuora musteväli")
("horizontal part" "vaakasuora osa")
("horizontal position" "vaakasuora paikka")
("horizontal space" "vaakasuora väli")
("horizontal table alignment" "taulukon tasaus vaakasuoraan")
("horizontally align cell to the base" "tasaa solu alareunaan vaakasuoraan")
("horizontally center the cell" "keskitä solu vaakasuorassa suunnassa")
("how much longer may pages become" "kuinka paljon pidemmiksi sivut voivat tulla")
("how much shorter may pages become" "kuinka paljon lyhyemmiksi sivut voivat tulla")
("huge" "valtava")
("hungarian" "unkari")
("hyperlink" "hyperlinkki")
("hyphenation" "tavutus")
("icelandic" "islanti")
("if" "if")
("image" "kuva")
("image links" "kuvalinkit")
("implementation" "toteutus")
("import" "tuo muodossa")
("improving the current implementation" "tämänhetkisen toteutuksen parantaminen")
("inactive" "epäaktiivinen")
("include" "sisällytä")
("include a document" "sisällytä asiakirja")
("include file" "sisällytä tiedosto")
("inclusion into TeXmacs" "TeXmacsiin sisällyttäminen")
("inclusions" "sisällytetyt")
("indent" "sisennä")
("indentation flag" "sisennysasetus")
("index" "hakemisto")
("index entry" "hakemistomerkintä")
("index level" "hakemistotaso")
("insert" "lisää")
("insert Pr" "lisää Pr")
("insert a TeXmacs symbol" "lisää TeXmacs-symboli")
("insert a big operator" "lisää suuri operaattori")
("insert a binary operation" "lisää kaksipaikkainen operaattori")
("insert a binary relation" "lisää kaksipaikkainen relaatio")
("insert a blackboard bold character" "lisää blackboard bold kirjain")
("insert a bold calligraphic character" "lisää lihavoitu kalligrafinen kirjain")
("insert a bold character" "lisää lihavoitu kirjain")
("insert a calligraphic character" "lisää kalligrafinen kirjain")
("insert a fraction" "lisää murtoluku")
("insert a fraktur character" "lisää fraktuurakirjain")
("insert a greek character" "lisää kreikkalainen kirjain")
("insert a large left delimiter" "lisää suuri vasemmanpuoleinen sulku")
("insert a large right delimiter" "lisää suuri oikeanpuoleinen sulku")
("insert a large separator" "lisää suuri erotin")
("insert a left subscript" "lisää vasen alaindeksi")
("insert a link" "lisää linkki")
("insert a miscellaneous symbol" "lisää muu merkki")
("insert a new branch" "lisää uusi haara")
("insert a new item" "lisää uusi tietue")
("insert a picture" "sisällytä kuva")
("insert a square root" "lisää neliöjuuri")
("insert a table" "lisää taulukko")
("insert a table or a matrix" "lisää taulukko tai matriisi")
("insert an" "lisää")
("insert an accent" "lisää aksentti")
("insert an arrow" "lisää nuoli")
("insert an environment" "lisää ympäristö")
("insert an n" "lisää n")
("insert appendix" "lisää liite")
("insert arccos" "lisää arcuskosini")
("insert arcsin" "lisää arcussini")
("insert arctan" "lisää arcustangentti")
("insert arg" "lisää argumentti")
("insert argument" "lisää argumentti")
("insert automatically generated content" "lisää automaattisesti luotua tekstiä")
("insert big contour integral" "lisää suuri reitti-integraali")
("insert big coproduct" "lisää suuri tulo")
("insert big direct sum" "lisää suuri suora summa")
("insert big dotted point" "lisää suuri pilkutettu piste")
("insert big integral" "lisää suuri integraali")
("insert big intersection" "lisää suuri leikkaus")
("insert big logical and" "lisää suuri looginen ja")
("insert big logical or" "lisää suuri looginen tai")
("insert big product" "lisää suuri tulo")
("insert big square union" "lisää suuri kulmikas unioni")
("insert big summation" "lisää suuri summa")
("insert big tensor product" "lisää suuri tensoritulo")
("insert big union" "lisää suuri yhdiste")
("insert big union sum" "lisää suuri yhdistesumma")
("insert big vertical space" "lisää suuri pystysuora väli")
("insert chapter" "lisää luku")
("insert column" "lisää sarake")
("insert column to the left" "lisää sarake vasemmalle")
("insert column to the right" "lisää sarake oikealle")
("insert cos" "lisää kosini")
("insert cosh" "lisää hyperbolinen kosini")
("insert cot" "lisää kotangentti")
("insert coth" "lisää hyperbolinen kotangentti")
("insert csc" "lisää kosekantti")
("insert deg" "lisää aste")
("insert det" "lisää det")
("insert dim" "lisää dim")
("insert dollar" "lisää dollari")
("insert equation" "lisää yhtälö")
("insert executable markup" "lisää suoritettava merkkaus")
("insert exp" "lisää exp")
("insert footnote" "lisää alaviite")
("insert formula" "lisää kaava")
("insert gcd" "lisää gcd")
("insert hom" "lisää hom")
("insert horizontal interword space" "lisää vaakasuora sanaväli")
("insert image" "lisää kuva")
("insert inactive markup" "lisää vuorovaikutteinen merkkaus")
("insert inf" "lisää inf")
("insert ker" "lisää ker")
("insert lg" "lisää lg")
("insert lim" "lisää lim")
("insert liminf" "lisää liminf")
("insert limsup" "lisää limsup")
("insert ln" "lisää ln")
("insert log" "lisää log")
("insert mathematics" "lisää matematiikkaa")
("insert max" "lisää max")
("insert medium horizontal space" "lisää keskisuuri vaakasuora väli")
("insert medium vertical space" "lisää keskisuuri pystysuora väli")
("insert min" "lisää min")
("insert negative horizontal space" "lisää negatiivinen vaakasuora väli")
("insert new item or number" "lisää uusi kohta tai numero")
("insert new rows or columns" "lisää uusia rivejä tai sarakkeita")
("insert or delete rows or columns" "lisää tai poista rivejä tai sarakkeita")
("insert row" "lisää rivi")
("insert row above" "lisää rivi yläpuolelle")
("insert row below" "lisää rivi alapuolelle")
("insert sec" "lisää sekantti")
("insert section" "lisää osio")
("insert sharp" "lisää korotus")
("insert sin" "lisää sini")
("insert sinh" "lisää hyperbolinen sini")
("insert small horizontal space" "lisää pieni vaakasuora väli")
("insert small vertical space" "lisää pieni pystysuora väli")
("insert structural markup" "lisää rakenteista merkkausta")
("insert subsection" "lisää alaosio")
("insert subsubsection" "lisää ala-alaosio")
("insert sup" "lisää sup")
("insert tan" "lisää tangentti")
("insert tanh" "lisää hyperbolinen tangentti")
("insert thick horizontal space" "lisää leveä vaakasuora väli")
("interfacing" "liittäminen")
("interfacing TeXmacs with other systems" "TeXmacsin liittäminen muihin järjestelmiin")
("interjection" "lisäys")
("interline separation" "rivien erotus")
("interline space" "rivien väli")
("internationalization" "kääntäminen")
("interparagraph space" "kappaleiden väli")
("interrupt execution" "keskeytä suoritus")
("introduction" "johdanto")
("invisible" "näkymätön")
("invisible citation" "näkymätön viittaus")
("irish" "irlanti")
("is running" "on suorituksessa")
("is tuple" "on tuple")
("ispell does not respond" "ispell ei vastaa")
("ispell is already busy" "ispell on jo käytössä")
("italian" "italia")
("italic" "kursiivi")
("italic right" "kursiivi oikealle")
("itemize" "luetteloi")
("january" "tammikuu")
("japanese" "japani")
("july" "heinäkuu")
("june" "kesäkuu")
("justified" "tasattu")
("justify text" "tasaa teksti")
("key" "näppäin")
("keyboard" "näppäimistö")
("keyboard equivalent" "vastine näppäimistöllä")
("keyboard modifiers" "näppäinmuuntimet")
("keyboard shortcut" "näppäimistölyhenne")
("keymaps" "näppäinkartat")
("keyword" "avainsana")
("keywords" "avainsanat")
("kill" "tapa")
("known bugs" "tunnetut bugit")
("label" "nimilappu")
("landscape" "vaakasuora")
("language" "kieli")
("large" "suuri")
("large closing bracket" "suuri oikea sulku")
("large delimiter" "suuri välike")
("large opening bracket" "suuri vasen sulku")
("large separator" "suuri erotin")
("last page" "viimeinen sivu")
("latex command" "latex-komento")
("latin" "latin")
("layout" "asettelu")
("left" "vasen")
("left border" "vasen reuna")
("left margin" "vasen marginaali")
("left padding" "vasen täyttö")
("left prime" "vasemmanpuoleinen yläpilkku")
("left aligned" "vasen reuna epätasainen")
("left slanted" "vasemmalle kalteva")
("left subscript" "vasemmanpuoleinen yläindeksi")
("left superscript" "vasemmanpuoleinen alaindeksi")
("left surrounding" "vasen ympäröivä")
("legal" "legal")
("lemma" "lemma")
("length" "pituus")
("less" "pienempi")
("less or equal" "pienempi tai yhtäsuuri")
("letter" "kirje")
("license" "lisenssi")
("light" "kevyt")
("limitations" "rajoitukset")
("limits" "rajat")
("line" "rivi")
("line break" "rivinvaihto")
("line stretch" "rivin venytys")
("link" "linkki")
("link image" "lisää linkki kuvaan")
("list" "lista")
("list of figures" "kuvat")
("list of tables" "taulukot")
("load" "avaa")
("load LaTeX file" "avaa LaTeX-tiedosto")
("load TeX file" "avaa TeX-tiedosto")
("load TeXmacs file" "avaa TeXmacs-tiedosto")
("load TeXmacs style file" "avaa TeXmacsin tyylitiedosto")
("load a file" "avaa tiedosto")
("load buffer" "avaa puskuri")
("load file" "avaa tiedosto")
("load html file" "avaa html-tiedosto")
("load image" "avaa kuva")
("load in new window" "avaa uuteen ikkunaan")
("load latex file" "avaa LaTeX-tiedosto")
("load more recent autosave file" "avaa uudempi automaattisesti talletettu tiedosto")
("load tex file" "avaa TeX-tiedosto")
("load verbatim file" "syötä tiedosto muotoilemattomana")
("loaded" "ladattu")
("long" "pitkä")
("look and feel" "ulkonäkö")
("look up" "look up")
("lower border" "alempi reuna")
("macro" "makro")
("magenta" "magenta")
("magic" "maaginen")
("magnification" "suurennus")
("magnified" "suurennettu")
("main" "pääasiallinen")
("main icon bar" "pääikonipalkki")
("major changes" "suuret muutokset")
("make a page insertion" "lisää sivu")
("make a subscript" "lisää alaindeksi")
("make a superscript" "lisää yläindeksi")
("make acute" "tee karetti")
("make bar" "tee viiva")
("make check" "tarkista")
("make fraction" "tee murtoluku")
("make grave" "tee vakava")
("make hat" "tee hattu")
("make label" "tee nimilappu")
("make negation" "tee negaatio")
("make page reference" "tee sivuviite")
("make reference" "tee viite")
("make square root" "tee neliöjuuri")
("make tilde" "tee tilde")
("make title" "tee otsikko")
("make vector" "tee vektori")
("making donations" "lahjoittaminen")
("manual" "manuaali")
("map to" "kuvaa")
("march" "maaliskuu")
("margins" "marginaalit")
("margins as on paper" "marginaalit kuten paperilla")
("master" "isäntätiedosto")
("master file" "isäntätiedosto")
("math" "matematiikka")
("math font" "matematiikkakirjasin")
("math font family" "matematiikkakirjasinperhe")
("math font series" "matematiikkakirjasinsarja")
("math font shape" "matematiikkakirjasinmuoto")
("mathematical" "matemaattinen")
("mathematical formulas" "matemaattiset kaavat")
("mathematical typesetting" "matematiikan ladonta")
("mathematics" "matematiikka")
("matrix" "matriisi")
("maximal number of columns" "sarakkeiden maksimimäärä")
("maximal number of rows" "rivien maksimimäärä")
("maximum mode" "maksimitila")
("may" "voi")
("medium" "keskisuuri")
("medium skip" "keskisuuri väli")
("meminfo" "meminfo")
("merge" "yhdistä")
("messy" "messy")
("meta key" "meta-näppäin")
("middle" "keskimmäinen")
("minimal number of columns" "sarakkeiden minimimäärä")
("minimal number of rows" "rivien minimimäärä")
("minimum mode" "miminitila")
("minus" "miinus")
("miscellaneous" "muu merkki")
("mod" "mod")
("mode" "tila")
("modifier" "muunnin")
("modify cell alignment" "muuta solun tasausta")
("modify cell border" "muuta solun reunusta")
("modify cell padding" "muuta solun täyttöä")
("modify cell size" "muuta solun kokoa")
("modify table border" "muuta taulukon reunusta")
("modify table padding" "muuta taulukon täyttöä")
("mongolian" "mongolia")
("more information about GNU TeXmacs can be found in the help" "lisää tietoa GNU TeXmacsista löydät ohjeista")
("mosaic" "mosaiikki")
("move down" "siirry alas")
("move object" "siirrä objektia")
("move to the right when finished" "siirry oikealle kun olet valmis")
("move up" "siirry ylös")
("n-th" "n:s")
("n-th root" "n:s juuri")
("name" "nimi")
("negation" "negaatio")
("new" "uusi")
("new buffer" "uusi puskuri")
("new column" "uusi sarake")
("new item" "uusi kohta")
("new line" "uusi rivi")
("new number" "uusi numero")
("new page" "uusi sivu")
("new page before" "uusi sivu ennen")
("new paragraph" "uusi kappale")
("new roman" "new roman")
("new row" "uusi rivi")
("new table" "uusi taulukko")
("next line" "seuraava rivi")
("no changes need to be saved" "ei tallennettavia muutoksia")
("no dictionary for" "ei sanastoa")
("no first indentation" "ei ensimmäistä sisennystä")
("no indentation" "ei sisennystä")
("no line break" "ei rivinvaihtoa")
("no matches found" "ei tuloksia")
("no more matches for" "ei enää tuloksia sanalle")
("no more redo information available" "ei lisää palautettavaa")
("no more undo information available" "ei enää peruutettavaa")
("no name" "ei nimeä")
("no page break after" "ei sivunvaihtoa jälkeen")
("no page break before" "ei sivunvaihtoa ennen")
("no spelling errors found in text" "kirjoitusvirheitä ei löytynyt")
("no style" "ei tyyliä")
("none" "ei mitään")
("normal" "normaali")
("not" "ei")
("not equal" "erisuuri")
("not found" "ei löytynyt")
("notation" "notaatio")
("note" "huomioitavaa")
("november" "marraskuu")
("number" "numero")
("number of columns" "sarakkeiden lukumäärä")
("numbered equation" "numeroitu yhtälö")
("numbered equations" "numeroidut yhtälöt")
("numerator" "osoittaja")
("numeric" "numeerinen")
("objectives" "tavoitteet")
("occurrences" "tapaukset")
("october" "lokakuu")
("odd page footer" "parittoman sivun alatunniste")
("odd page header" "parittoman sivun ylätunniste")
("odd page margin" "parittoman sivun marginaali")
("odd page text" "parittoman sivun teksti")
("off" "pois")
("ok" "ok")
("old english" "vanha englanti")
("old slavonic" "vanha slavonia")
("old style" "vanha tyyli")
("on" "päällä")
("on cells" "soluissa")
("on columns" "sarakkeissa")
("on entire table" "koko taulukossa")
("on rows" "riveissä")
("one spelling error has been corrected" "yksi kirjoitusvirhe korjattu")
("online documentation" "dokumentaatio")
("online help" "ohje")
("open" "avaa")
("open a new buffer" "avaa uusi puskuri")
("open new window" "avaa uusi ikkuna")
("opening" "aloitus")
("operation on named selection" "operaatio nimettyyn valintaan")
("operation on primary selection" "operaatio ensimmäiseen valintaan")
("operation on secondary selection" "operaatio toiseen valintaan")
("operation on ternary selection" "operaatio kolmanteen valintaan")
("optical" "optinen")
("option" "asetus")
("options" "asetukset")
("or" "tai")
("orange" "oranssi")
("orientation" "suunta")
("origin" "origo")
("original welcome message" "alkuperäinen tervetuloviesti")
("other" "muu")
("other pages" "muut sivut")
("other projects" "muut projektit")
("other style" "muu tyyli")
("outlined roman" "ääriviivallinen roman")
("over" "jakolasku")
("padding" "täyttö")
("page" "sivu")
("page bottom margin" "sivun alamarginaali")
("page break" "sivunvaihto")
("page break before" "sivunvaihto ennen")
("page height" "sivun korkeus")
("page insertion" "sivun lisääminen")
("page layout" "sivun asettelu")
("page reference" "sivuviite")
("page right margin" "sivun oikea marginaali")
("page top margin" "sivun ylämarginaali")
("page type" "sivun tyyppi")
("page width" "sivun leveys")
("paper" "paperi")
("paper type" "paperityyppi")
("papyrus" "papyrus")
("paragraph" "kappale")
("paragraph mode" "kappeletila")
("paragraph width" "kappeleen leveys")
("part" "osa")
("past changes" "tehdyt muutokset")
("paste" "liitä")
("paste from" "liitä")
("paste text" "liitä tekstiä")
("path" "polku")
("perform operations on cells" "operoi yhteen soluun")
("perform operations on columns" "operoi sarakkeeseen")
("perform operations on entire table" "operoi koko taulukkoon")
("perform operations on rows" "operoi riviin")
("permanent" "pysyvä")
("person" "henkilö")
("personal dictionary has been modified" "henkilökohtaista hakemistoa on muutettu")
("phantasy" "phantasy")
("philosophy" "filosofia")
("phoenician" "foinikia")
("phonetic" "foneettinen")
("pink" "vaaleanpunainen")
("plain block" "tavallinen lohko")
("plain tabular" "tavallinen taulukoitu")
("planned changes" "suunnitellut muutokset")
("plans for the future" "tulevaisuudensuunnitelmat")
("please" "ole hyvä")
("please wait" "odota")
("plus" "plus")
("polish" "puola")
("porting TeXmacs to other platforms" "TeXmacsin siirtäminen muille laitealustoille")
("portrait" "pystysuora")
("portuguese" "portugali")
("position" "sijainti")
("position float" "sijoita kelluva")
("position floating object" "sijoita kelluva objekti")
("position the table" "sijoita taulukko")
("postscript" "postscript")
("postscript image" "postscript-kuva")
("pre-alpha release" "esialfa-julkaisu")
("preamble" "koodi")
("preamble mode" "kooditila")
("preferences" "asetukset")
("presentation mode" "esitystila")
("preview before printing" "esikatsele ennen tulostamista")
("preview with ghostview" "esikatselu ghostview'llä")
("primary" "ensimmäinen")
("prime" "pilkku")
("print" "tulosta")
("print all" "tulosta kaikki")
("print all to file" "tulosta kaikki tiedostoon")
("print page selection" "tulosta valitut sivut")
("print page selection to file" "tulosta valitut sivut tiedostoon")
("print to postscript file" "tulosta postscript-tiedostoon")
("printer" "tulostin")
("printer dpi" "tulostimen dpi")
("printing command" "tulostuskomento")
("problem" "tehtävä")
("professional" "ammattimainen")
("prog" "prog")
("prog font" "prog-kirjasin")
("prog font family" "prog-kirjasinperhe")
("prog font series" "prog-kirjasinsarja")
("prog font shape" "prog-kirjasinmuoto")
("program" "ohjelma")
("program mode" "ohjelmatila")
("programming" "ohjelmointi")
("progressive" "kehittyvä")
("project" "projekti")
("projects" "projektit")
("prologue" "prologi")
("prompt on scripts" "kysy skripteistä")
("proof" "todistus")
("proportional" "tasavälinen")
("proportional typewriter" "tasavälinen kirjoituskone")
("proposition" "propositio")
("query replace" "etsi ja korvaa")
("quit" "lopeta")
("quotation" "lainaus (quotation)")
("quote" "lainaus (quote)")
("range" "alue")
("really huge" "todella valtava")
("really quit" "lopetetaanko")
("red" "punainen")
("redo" "palauta")
("redo undone changes" "palauta peruutetut muutokset")
("reduce bottom margin by" "pienennä alamarginaalia")
("reduce left margin by" "pienennä vasenta marginaalia")
("reduce margins" "pienennä marginaaleja")
("reduce right margin by" "pienennä oikeaa marginaalia")
("reduce top margin by" "pienennä ylämarginaalia")
("reduction even page margin" "parillisen sivun marginaalin pienentäminen")
("reduction odd page margin" "parittoman sivun marginaalin pienentäminen")
("reduction page bottom margin" "sivun alamarginaalin pienentäminen")
("reduction page right margin" "sivun oikean marginaalin pienentäminen")
("reduction page top margin" "sivun ylämarginaalin pienentäminen")
("reference" "viite")
("references" "viittaukset")
("regular" "tavallinen")
("release" "julkaisu")
("reload" "lataa uudelleen")
("remark" "huomautus")
("remove this switch" "poista tämä valitsin")
("repeat object" "toista objekti")
("replace" "korvaa")
("replace by" "merkkijonolla")
("replaced" "korvattu")
("replaced one occurrence" "korvattiin yksi tapaus")
("reset" "nollaa")
("resize object" "muuta objektin kokoa")
("resized" "koko muutettu")
("return" "return")
("revert" "palauta")
("revert buffer" "palauta puskuri")
("right" "oikea")
("right border" "oikea reuna")
("right margin" "oikea marginaali")
("right padding" "oikea täyttö")
("right aligned" "oikea reuna epätasainen")
("right subscript" "oikea alaindeksi")
("right superscript" "oikea yläindeksi")
("right surrounding" "oikea ympäristö")
("rigid" "jäykkä")
("rigid horizontal" "jäykkä vaakasuora")
("rigid space" "jäykkä välilyönti")
("romanian" "romania")
("root" "juuri")
("rotate backward" "kierrä takaperin")
("rotate forward" "kierrä eteenpäin")
("row" "rivi")
("row contains glued items" "rivi sisältää liimattuja osia")
("runic" "riimukirjoitus")
("running author" "juokseva tekijä")
("running title" "juokseva otsikko")
("russian" "venäjä")
("russian and Ukrainian users" "venäläiset ja Ukrainalaiset käyttäjät")
("sample" "malli")
("sans serif" "sans serif")
("save" "talleta")
("save TeXmacs file" "talleta TeXmacs-tiedosto")
("save TeXmacs style file" "talleta TeXmacsin tyylitiedosto")
("save as" "talleta nimellä")
("save as LaTeX" "talleta LaTeX-muodossa")
("save as TeX" "talleta TeX-muodossa")
("save buffer" "talleta puskuri")
("save buffer as" "talleta puskuri nimellä")
("save file" "talleta tiedosto")
("save html file" "talleta html-tiedosto")
("save image" "talleta kuva")
("save latex file" "talleta LaTeX-tiedosto")
("save tex file" "talleta TeX-tiedosto")
("save this buffer" "talleta puskuri")
("save verbatim file" "talleta muotoilematon tiedosto")
("saved" "tallennettu")
("screen layout" "näyttö ruudulla")
("screen margins" "marginaalit ruudulla")
("script" "skripti")
("script above" "skripti yläpuolella")
("script below" "skripti alapuolella")
("script script size" "skripti skriptin koko")
("script size" "skriptin koko")
("scripts not accepted" "skriptejä ei hyväksytä")
("search" "etsi")
("searching" "etsitään")
("secondary" "toinen")
("section" "osio")
("security" "turvallisuus")
("see" "katso")
("select a document style" "valitse asiakirjan tyyli")
("select a foreground color" "valitse edustaväri")
("select a language" "valitse kieli")
("selected region" "valittu alue")
("selection" "valinta")
("selections" "valinnat")
("seminar" "seminaari")
("separation between lines" "rivien väli")
("separation between paragraphs" "kappaleiden väli")
("separator" "erotin")
("september" "syyskuu")
("series" "sarja")
("series|right" "sarja|oikea")
("session" "istunto")
("session name" "istunnon nimi")
("session type" "istunnon tyyppi")
("sessions" "istunnot")
("set" "aseta")
("set background color of cell" "aseta solun taustaväri")
("set cell mode" "aseta solun tila")
("set extension center" "aseta jatkeen keskus")
("set height" "aseta korkeus")
("set height of cell" "aseta solun korkeus")
("set margins" "aseta marginaalit")
("set n" "aseta n")
("set paragraph margins" "aseta kappaleen marginaalit")
("set paragraph mode" "aseta kappaletila")
("set printer dpi" "aseta tulostimen dpi")
("set printing command" "aseta tulostuskomento")
("set span" "aseta span")
("set special cell properties" "aseta solun erikoisominaisuudet")
("set special table properties" "aseta taulukon erikoisominaisuudet")
("set text width" "aseta tekstin leveys")
("set width" "aseta leveys")
("set width of cell" "aseta solun leveys")
("settings" "asetukset")
("setup printer" "asenna tulostin")
("shape" "muoto")
("shift-down" "vaihto-alas")
("shift-right" "oikea vaihto")
("show" "näytä")
("show header and footer" "näytä ylä- ja alatunniste")
("show on screen" "näytä ruudulla")
("shrinking factor" "pienennystekijä")
("signature" "allekirjoitus")
("size" "koko")
("size limits" "kokorajat")
("slanted" "kalteva")
("sloppy" "epämääräinen")
("small" "pieni")
("small caps" "kapiteeli")
("small figure" "pieni kuva")
("small skip" "pieni väli")
("small table" "pieni taulukko")
("source code" "lähdekoodi")
("space" "väli")
("space between lines" "riviväli")
("space between paragraphs" "kappaleväli")
("spacing" "välistys")
("spanish" "espanja")
("special" "erikois")
("special cell properties" "solun erikoisominaisuudet")
("special table properties" "taulukon erikoisominaisuudet")
("specific" "koodi")
("spell" "oikolue")
("spell checking complete" "oikeinkirjoituksen tarkistus valmis")
("spelling error" "oikeinkirjoitusvirhe")
("spelling errors have been corrected" "oikeinkirjoitusvirheet on korjattu")
("split" "jaa")
("square root" "neliöjuuri")
("start" "aloita")
("start a new chapter" "aloita uusi luku")
("start a new section" "aloita uusi osio")
("start an interactive session" "aloita vuorovaikutteinen istunto")
("status bar" "tilarivi")
("stretchable" "venytettävä")
("stretchable horizontal" "vaakasuoraan venytettävä")
("stretchable vertical" "pystysuoraan venytettävä")
("stroke" "viiva")
("strokes" "viivat")
("strong" "vahva")
("structural" "rakenteellinen")
("style" "tyyli")
("styles" "tyylit")
("sub" "alamerkintä")
("subparagraph" "alikappale")
("subscript" "alaindeksi")
("subsection" "alaosio")
("subsub" "ala-alamerkintä")
("subsubsection" "ala-alaosio")
("summary" "yhteenveto")
("superpose" "aseta päällekäin")
("superposed" "päällekäin asetettu")
("superscript" "yläindeksi")
("swedish" "ruotsi")
("switch" "valitsin")
("switch to first" "vaihda ensimmäiseen")
("switch to formula style" "vaihda kaavatyyliin")
("switch to last" "vaihda viimeiseen")
("switch to next" "vaihda seuraavaan")
("switch to previous" "vaihda edelliseen")
("switching and folding" "vaihtaminen ja taittaminen")
("symbol" "symboli")
("system environment variables" "järjestelmän ympäristömuuttujat")
("tab" "tabulaattori")
("table" "taulukko")
("table command" "taulukkokomento")
("table of contents" "sisältö")
("tables" "taulukot")
("tabular" "taulukoitu")
("tabular material" "taulukoitu aineisto")
("teXmacs as an interface" "teXmacs käyttöliittymänä")
("teXmacs fonts" "teXmacsin kirjasimet")
("teXmacs notice" "teXmacs-huomautus")
("ternary" "kolmas")
("test" "testi")
("tex" "tex")
("text" "teksti")
("text font" "tekstikirjasin")
("text height correction" "tekstin korkeuden korjaaminen")
("text width" "tekstin leveys")
("texts" "tekstit")
("th century bc" ":llä vuosisadalla eaa")
("th root" ":s juuri")
("thai" "thai")
("the TeXmacs authors" "TeXmacsin tekijät")
("the application did not send its usual startup banner" "sovellus ei lähettänyt tavanomaista alkuikkunaa")
("the application does not reply" "sovellus ei vastaa")
("the application is already running" "sovellus on jo käynnissä")
("the boxes produced by the typesetter" "latojan tuottamat laatikot")
("the graphical user interface" "graafinen käyttöliittymä")
("the leaves of TeXmacs trees" "TeXmacs-puun lehdet")
("the mycas example" "mycas-esimerkki")
("the primitive TeXmacs constructs" "TeXmacsin alkeiskonstruktiot")
("the standard TeXmacs styles" "TeXmacsin standardityylit")
("theorem" "lause")
("there are unsaved documents" "kaikkia tiedostoja ei ole talletettu")
("this document has been produced using" "tämä asiakirja on tehty käyttäen")
("this line" "tämä rivi")
("this page" "tämä sivu")
("tilda" "tilda")
("tilde" "tilde")
("times" "kertaa")
("tiny" "todella pieni")
("title" "otsikko")
("to the left" "vasemmalle")
("to the right" "oikealle")
("today" "tänään")
("tools" "työkalut")
("top" "ylä")
("top border" "yläreuna")
("top level" "ylätaso")
("top margin" "ylämarginaali")
("top padding" "yläreunan täyttö")
("translate" "käännä")
("tree" "puu")
("tuple" "tuple")
("turkish" "turkki")
("tutorial" "johdatus")
("type" "tyyppi")
("type a latex command followed by" "kirjoita LaTeX-komento jota seuraa")
("type body" "kirjoita runko")
("type denominator" "kirjoita nimittäjä")
("type numerator" "kirjoita osoittaja")
("type script" "kirjoita skripti")
("typesetted boxes" "ladotut laatikot")
("typewriter" "kirjoituskone")
("typewriter small caps" "kirjoituskonekapiteeli")
("typing a simple text" "yksinkertaisen tekstin kirjoittaminen")
("typing simple texts" "yksinkertaisten tekstien kirjoittaminen")
("ugaritic" "ugaritic")
("ukrainian" "ukraina")
("undo" "peruuta")
("undo last changes" "peruuta viimeiset muutokset")
("up" "ylös")
("update" "päivitä")
("update from web" "päivitä verkosta")
("update image links" "päivitä kuvalinkit")
("upper border" "yläreunus")
("use TeXmacs" "käytä TeXmacsia")
("use a black color" "käytä mustaa väriä")
("use a blue color" "käytä sinistä väriä")
("use a bold font" "käytä lihvoitua kirjasinta")
("use a brown color" "käytä ruskeaa väriä")
("use a calligraphic font" "käytä kalligrafista kirjasinta")
("use a green color" "käytä vihreää väriä")
("use a grey color" "käytä harmaata väriä")
("use a magenta color" "käytä magentaa väriä")
("use a orange color" "käytä oranssia väriä")
("use a pink color" "käytä vaaleanpunaista väriä")
("use a red color" "käytä punaista väriä")
("use a sans serif font" "käytä sans-serif-kirjasinta")
("use a typewriter font" "käytä kirjoituskonekirjasinta")
("use a white color" "käytä valkoista väriä")
("use a yellow color" "käytä keltaista väriä")
("use blackboard bold font" "käytä blackboard bold kirjasinta")
("use bold font series" "käytä lihavoitua kirjasinsarjaa")
("use calligraphical font" "käytä kalligrafista kirjasinta")
("use footnote font size" "käytä kirjasinkokoa footnote")
("use fraktur font" "käytä fraktuura-kirjasinta")
("use huge font size" "käytä kirjasinkokoa huge")
("use italic font shape" "käytä kursiivikirjasinta")
("use large font size" "käytä kirjasinkokoa large")
("use left hand column as border" "käytä vasemmanpuoleisinta saraketta reunuksena")
("use medium font series" "käytä medium kirjasinsarjaa")
("use normal font size" "käytä kirjasinkokoa normal")
("use package" "käytä pakettia")
("use paragraph width" "käytä kappaleenleveyttä")
("use really huge font size" "käytä kirjasinkokoa really huge")
("use right font shape" "käytä oikeaa kirjasinkokoa")
("use right hand column as border" "käytä oikeanpuoleista saraketta reunuksena")
("use roman font family" "käytä kirjasinperhettä roman")
("use row above as border" "käytä yläpuolista riviä reunuksena")
("use row below as border" "käytä alapuolista riviä reunuksena")
("use sans serif font family" "käytä sans-serif kirjasinperhettä")
("use script font size" "käytä kirjasinkokoa script")
("use slanted font shape" "käytä kirjasinmuotoa slanted")
("use small capitals" "käytä kapiteelia")
("use small font size" "käytä kirjasinkokoa small")
("use small-caps font shape" "käytä kapiteeli-kirjasinmuotoa")
("use the blackboard bold font" "käytä blackboard bold-kirjasinta")
("use the fraktur font" "käytä fraktuura-kirjasinta")
("use tiny font font size" "käytä kirjasinkokoa tiny")
("use typewriter font family" "käytä kirjoituskonekirjasinperhettä")
("use very large font size" "käytä kirjasinkokoa very large")
("user manual" "käyttäjän opas")
("user provided icons" "käyttäjän asentamat ikonit")
("value" "value")
("variable" "muuttuja")
("variant" "variantti")
("vector" "vektori")
("verbatim" "muotoilematon")
("verse" "säe")
("vertical" "pystysuora")
("vertical after" "pystysuora jälkeen")
("vertical before" "pystysuora ennen")
("vertical cell alignment" "pystysuora solun tasaus")
("vertical part" "pystysuora osa")
("vertical position" "pystysuora sijainti")
("vertical space" "pystysuora väli")
("vertical table alignment" "pystysuora taulukon tasaus")
("vertically align cell to the base" "tasaa solu vaakasuoraan alareunaan")
("vertically center the cell" "keskitä solu pystysuoraan")
("very large" "erittäin suuri")
("very small" "erittäin pieni")
("vietnamese" "vietnam")
("view" "näytä")
("visible" "näkyvä")
("warning" "varoitus")
("welcome" "tervetuloa")
("welcome to GNU TeXmacs" "tervetuloa GNU TeXmacsiin")
("what is new" "mitä uutta")
("when finished" "kun valmis")
("while" "while")
("white" "valkoinen")
("wide accent" "leveä aksentti")
("width" "leveys")
("width is exactly the specified width" "leveys on täsmälleen se mikä on määritelty")
("width is maximum of specified width and box width" "leveys on suurempi määritellystä ja laatikon leveydestä")
("width is minimum of specified width and box width" "leveys on pienempi määritellystä ja laatikon leveydestä")
("width magnification" "leveyden suurennos")
("window" "ikkuna")
("window height" "ikkunan korkeus")
("window width" "ikkunan leveys")
("windows key" "windows-näppäin")
("with" "with")
("write a name" "kirjoita nimi")
("write bold mathematics" "kirjoita lihavoitua matematiikkaa")
("write bold text" "kirjoita lihavoitua tekstiä")
("write italic text" "kirjoita kursivoitua tekstiä")
("write sample text" "kirjoita malliteksti")
("write strong text" "kirjoita vahvaa tekstiä")
("write typewriter text" "kirjoita kirjoituskonetekstiä")
("write verbatim text" "kirjoita muotoilematonta tekstiä")
("writing data converters" "datamuuntimien tekeminen")
("writing your own style files" "omien tyylitiedostojen kirjoittaminen")
("yellow" "keltainen")
("you can also obtain" "voit myös hankkia")
("your document is back in its original state" "asiakirja on palautettu alkuperäiseen tilaan")
("your first interface" "ensimmäinen liittymäsi")
